(FAMILY STIXMathCalligraphy)
(CODINGSCHEME STIXMATHCAL)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   )
(LIGTABLE
   (LABEL O 101) (comment uniE22D)
   (KRN O 177 R 0.216) (comment uni2040)
   (STOP)
   (LABEL O 102) (comment uniE22E)
   (KRN O 177 R 0.15) (comment uni2040)
   (STOP)
   (LABEL O 103) (comment uniE22F)
   (KRN O 177 R 0.1285) (comment uni2040)
   (STOP)
   (LABEL O 104) (comment uniE230)
   (KRN O 177 R 0.0995) (comment uni2040)
   (STOP)
   (LABEL O 105) (comment uniE231)
   (KRN O 177 R 0.124) (comment uni2040)
   (STOP)
   (LABEL O 106) (comment uniE232)
   (KRN O 177 R 0.0325) (comment uni2040)
   (STOP)
   (LABEL O 107) (comment uniE233)
   (KRN O 177 R 0.162) (comment uni2040)
   (STOP)
   (LABEL O 110) (comment uniE234)
   (KRN O 177 R 0.064) (comment uni2040)
   (STOP)
   (LABEL O 111) (comment uniE235)
   (KRN O 177 R 0.093) (comment uni2040)
   (STOP)
   (LABEL O 112) (comment uniE236)
   (KRN O 177 R 0.197) (comment uni2040)
   (STOP)
   (LABEL O 113) (comment uniE237)
   (KRN O 177 R 0.0955) (comment uni2040)
   (STOP)
   (LABEL O 114) (comment uniE238)
   (KRN O 177 R 0.1295) (comment uni2040)
   (STOP)
   (LABEL O 115) (comment uniE239)
   (KRN O 177 R 0.13) (comment uni2040)
   (STOP)
   (LABEL O 116) (comment uniE23A)
   (KRN O 177 R 0.0815) (comment uni2040)
   (STOP)
   (LABEL O 117) (comment uniE23B)
   (KRN O 177 R 0.0975) (comment uni2040)
   (STOP)
   (LABEL O 120) (comment uniE23C)
   (KRN O 177 R 0.014) (comment uni2040)
   (STOP)
   (LABEL O 121) (comment uniE23D)
   (KRN O 177 R 0.084) (comment uni2040)
   (STOP)
   (LABEL O 122) (comment uniE23E)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 123) (comment uniE23F)
   (KRN O 177 R 0.119) (comment uni2040)
   (STOP)
   (LABEL O 124) (comment uniE240)
   (KRN O 177 R 0.0085) (comment uni2040)
   (STOP)
   (LABEL O 125) (comment uniE241)
   (KRN O 177 R 0.0385) (comment uni2040)
   (STOP)
   (LABEL O 126) (comment uniE242)
   (KRN O 177 R 0.0705) (comment uni2040)
   (STOP)
   (LABEL O 127) (comment uniE243)
   (KRN O 177 R 0.0525) (comment uni2040)
   (STOP)
   (LABEL O 130) (comment uniE244)
   (KRN O 177 R 0.118) (comment uni2040)
   (STOP)
   (LABEL O 131) (comment uniE245)
   (KRN O 177 R 0.091) (comment uni2040)
   (STOP)
   (LABEL O 132) (comment uniE246)
   (KRN O 177 R 0.12) (comment uni2040)
   (STOP)
   (LABEL O 172) (comment u1D718)
   (KRN O 177 R -0.0155) (comment uni2040)
   (STOP)
   )
(CHARACTER O 0 (comment uni222B.sm)
   (CHARWD R 0.496)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   (CHARIC R 0.156)
   )
(CHARACTER O 1 (comment uni222C.sm)
   (CHARWD R 0.726)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   (CHARIC R 0.156)
   )
(CHARACTER O 2 (comment uni222D.sm)
   (CHARWD R 0.956)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   (CHARIC R 0.156)
   )
(CHARACTER O 3 (comment uni222E.sm)
   (CHARWD R 0.56)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 4 (comment uni222F.sm)
   (CHARWD R 0.79)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 5 (comment uni2230.sm)
   (CHARWD R 1.02)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 6 (comment uni2231.sm)
   (CHARWD R 0.56)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 7 (comment uni2232.sm)
   (CHARWD R 0.56)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 10 (comment uni2233.sm)
   (CHARWD R 0.56)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 11 (comment uni2A0B.sm)
   (CHARWD R 0.593)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 12 (comment uni2A0C.sm)
   (CHARWD R 1.152)
   (CHARHT R 0.695)
   (CHARDP R 0.189)
   (CHARIC R 0.19)
   )
(CHARACTER O 13 (comment uni2A0D.sm)
   (CHARWD R 0.512)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   (CHARIC R 0.14)
   )
(CHARACTER O 14 (comment uni2A0E.sm)
   (CHARWD R 0.512)
   (CHARHT R 0.693)
   (CHARDP R 0.19)
   (CHARIC R 0.14)
   )
(CHARACTER O 15 (comment uni2A0F.sm)
   (CHARWD R 0.56)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 16 (comment uni2A10.sm)
   (CHARWD R 0.496)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   (CHARIC R 0.156)
   )
(CHARACTER O 17 (comment uni2A11.sm)
   (CHARWD R 0.56)
   (CHARHT R 0.695)
   (CHARDP R 0.189)
   )
(CHARACTER O 20 (comment uni2A12.sm)
   (CHARWD R 0.513)
   (CHARHT R 0.694)
   (CHARDP R 0.191)
   (CHARIC R 0.139)
   )
(CHARACTER O 21 (comment uni2A13.sm)
   (CHARWD R 0.512)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   (CHARIC R 0.14)
   )
(CHARACTER O 22 (comment uni2A14.sm)
   (CHARWD R 0.635)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 23 (comment uni2A15.sm)
   (CHARWD R 0.512)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   (CHARIC R 0.14)
   )
(CHARACTER O 24 (comment uni2A16.sm)
   (CHARWD R 0.512)
   (CHARHT R 0.695)
   (CHARDP R 0.189)
   (CHARIC R 0.14)
   )
(CHARACTER O 25 (comment uni2A17.sm)
   (CHARWD R 0.613)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 26 (comment uni2A18.sm)
   (CHARWD R 0.512)
   (CHARHT R 0.695)
   (CHARDP R 0.189)
   (CHARIC R 0.14)
   )
(CHARACTER O 27 (comment uni2A19.sm)
   (CHARWD R 0.512)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   (CHARIC R 0.139)
   )
(CHARACTER O 30 (comment uni2A1A.sm)
   (CHARWD R 0.512)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   (CHARIC R 0.139)
   )
(CHARACTER O 31 (comment uni2A1B.sm)
   (CHARWD R 0.462)
   (CHARHT R 0.784)
   (CHARDP R 0.19)
   (CHARIC R 0.19)
   )
(CHARACTER O 32 (comment uni2A1C.sm)
   (CHARWD R 0.496)
   (CHARHT R 0.694)
   (CHARDP R 0.284)
   (CHARIC R 0.156)
   )
(CHARACTER O 33 (comment uni222B.upsm)
   (CHARWD R 0.357)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   (CHARIC R 0.118)
   )
(CHARACTER O 34 (comment uni222C.upsm)
   (CHARWD R 0.587)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   (CHARIC R 0.118)
   )
(CHARACTER O 35 (comment uni222D.upsm)
   (CHARWD R 0.817)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   (CHARIC R 0.118)
   )
(CHARACTER O 36 (comment uni222E.upsm)
   (CHARWD R 0.452)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 37 (comment uni222F.upsm)
   (CHARWD R 0.682)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 40 (comment uni2230.upsm)
   (CHARWD R 0.909)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 41 (comment uni2231.upsm)
   (CHARWD R 0.48)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 42 (comment uni2232.upsm)
   (CHARWD R 0.48)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 43 (comment uni2233.upsm)
   (CHARWD R 0.48)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 44 (comment uni2A0B.upsm)
   (CHARWD R 0.556)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 45 (comment uni2A0C.upsm)
   (CHARWD R 1.044)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   (CHARIC R 0.137)
   )
(CHARACTER O 46 (comment uni2A0D.upsm)
   (CHARWD R 0.42)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 47 (comment uni2A0E.upsm)
   (CHARWD R 0.42)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 50 (comment uni2A0F.upsm)
   (CHARWD R 0.52)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 51 (comment uni2A10.upsm)
   (CHARWD R 0.324)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   (CHARIC R 0.156)
   )
(CHARACTER O 52 (comment uni2A11.upsm)
   (CHARWD R 0.48)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 53 (comment uni2A12.upsm)
   (CHARWD R 0.45)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 54 (comment uni2A13.upsm)
   (CHARWD R 0.45)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 55 (comment uni2A14.upsm)
   (CHARWD R 0.55)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 56 (comment uni2A15.upsm)
   (CHARWD R 0.45)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 57 (comment uni2A16.upsm)
   (CHARWD R 0.45)
   (CHARHT R 0.694)
   (CHARDP R 0.191)
   )
(CHARACTER O 60 (comment uni2A17.upsm)
   (CHARWD R 0.611)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 61 (comment uni2A18.upsm)
   (CHARWD R 0.45)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 62 (comment uni2A19.upsm)
   (CHARWD R 0.45)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 63 (comment uni2A1A.upsm)
   (CHARWD R 0.45)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 64 (comment uni2A1B.upsm)
   (CHARWD R 0.379)
   (CHARHT R 0.784)
   (CHARDP R 0.189)
   (CHARIC R 0.137)
   )
(CHARACTER O 65 (comment uni2A1C.upsm)
   (CHARWD R 0.357)
   (CHARHT R 0.69)
   (CHARDP R 0.283)
   (CHARIC R 0.143)
   )
(CHARACTER O 72 (comment uni24C7)
   (CHARWD R 0.684)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 73 (comment uni24C8)
   (CHARWD R 0.684)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 74 (comment uni27CD)
   (CHARWD R 0.838)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 75 (comment uni27CB)
   (CHARWD R 0.838)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 76 (comment eth)
   (CHARWD R 0.5)
   (CHARHT R 0.686)
   (CHARDP R 0.01)
   )
(CHARACTER O 77 (comment uni2322.var)
   (CHARWD R 0.685)
   (CHARHT R 0.386)
   )
(CHARACTER O 100 (comment uni2323.var)
   (CHARWD R 0.685)
   (CHARHT R 0.386)
   )
(CHARACTER O 101 (comment uniE22D)
   (CHARWD R 0.852)
   (CHARHT R 0.677)
   (CHARDP R 0.045)
   )
(CHARACTER O 102 (comment uniE22E)
   (CHARWD R 0.724)
   (CHARHT R 0.67)
   (CHARDP R 0.003)
   )
(CHARACTER O 103 (comment uniE22F)
   (CHARWD R 0.569)
   (CHARHT R 0.671)
   (CHARDP R 0.011)
   (CHARIC R 0.062)
   )
(CHARACTER O 104 (comment uniE230)
   (CHARWD R 0.801)
   (CHARHT R 0.662)
   )
(CHARACTER O 105 (comment uniE231)
   (CHARWD R 0.553)
   (CHARHT R 0.67)
   (CHARDP R 0.004)
   (CHARIC R 0.091)
   )
(CHARACTER O 106 (comment uniE232)
   (CHARWD R 0.652)
   (CHARHT R 0.662)
   (CHARIC R 0.103)
   )
(CHARACTER O 107 (comment uniE233)
   (CHARWD R 0.58)
   (CHARHT R 0.671)
   (CHARDP R 0.131)
   )
(CHARACTER O 110 (comment uniE234)
   (CHARWD R 0.831)
   (CHARHT R 0.664)
   (CHARDP R 0.021)
   (CHARIC R 0.059)
   )
(CHARACTER O 111 (comment uniE235)
   (CHARWD R 0.575)
   (CHARHT R 0.662)
   (CHARIC R 0.061)
   )
(CHARACTER O 112 (comment uniE236)
   (CHARWD R 0.632)
   (CHARHT R 0.662)
   (CHARDP R 0.12)
   (CHARIC R 0.198)
   )
(CHARACTER O 113 (comment uniE237)
   (CHARWD R 0.809)
   (CHARHT R 0.67)
   (CHARDP R 0.013)
   )
(CHARACTER O 114 (comment uniE238)
   (CHARWD R 0.693)
   (CHARHT R 0.67)
   (CHARDP R 0.007)
   )
(CHARACTER O 115 (comment uniE239)
   (CHARWD R 1.166)
   (CHARHT R 0.671)
   (CHARDP R 0.045)
   )
(CHARACTER O 116 (comment uniE23A)
   (CHARWD R 0.957)
   (CHARHT R 0.795)
   (CHARDP R 0.037)
   (CHARIC R 0.152)
   )
(CHARACTER O 117 (comment uniE23B)
   (CHARWD R 0.737)
   (CHARHT R 0.669)
   (CHARDP R 0.01)
   )
(CHARACTER O 120 (comment uniE23C)
   (CHARWD R 0.667)
   (CHARHT R 0.662)
   (CHARIC R 0.087)
   )
(CHARACTER O 121 (comment uniE23D)
   (CHARWD R 0.744)
   (CHARHT R 0.671)
   (CHARDP R 0.131)
   )
(CHARACTER O 122 (comment uniE23E)
   (CHARWD R 0.854)
   (CHARHT R 0.662)
   (CHARDP R 0.003)
   )
(CHARACTER O 123 (comment uniE23F)
   (CHARWD R 0.634)
   (CHARHT R 0.671)
   (CHARIC R 0.082)
   )
(CHARACTER O 124 (comment uniE240)
   (CHARWD R 0.509)
   (CHARHT R 0.721)
   (CHARIC R 0.266)
   )
(CHARACTER O 125 (comment uniE241)
   (CHARWD R 0.817)
   (CHARHT R 0.672)
   (CHARDP R 0.013)
   (CHARIC R 0.178)
   )
(CHARACTER O 126 (comment uniE242)
   (CHARWD R 0.638)
   (CHARHT R 0.677)
   (CHARDP R 0.033)
   (CHARIC R 0.087)
   )
(CHARACTER O 127 (comment uniE243)
   (CHARWD R 0.956)
   (CHARHT R 0.685)
   (CHARDP R 0.032)
   (CHARIC R 0.087)
   )
(CHARACTER O 130 (comment uniE244)
   (CHARWD R 0.692)
   (CHARHT R 0.672)
   (CHARDP R 0.013)
   (CHARIC R 0.092)
   )
(CHARACTER O 131 (comment uniE245)
   (CHARWD R 0.719)
   (CHARHT R 0.675)
   (CHARDP R 0.131)
   (CHARIC R 0.089)
   )
(CHARACTER O 132 (comment uniE246)
   (CHARWD R 0.752)
   (CHARHT R 0.664)
   (CHARDP R 0.094)
   )
(CHARACTER O 133 (comment uni2269.var)
   (CHARWD R 0.685)
   (CHARHT R 0.718)
   (CHARDP R 0.275)
   )
(CHARACTER O 134 (comment uni2268.var)
   (CHARWD R 0.685)
   (CHARHT R 0.718)
   (CHARDP R 0.275)
   )
(CHARACTER O 135 (comment uni2224.var)
   (CHARWD R 0.404)
   (CHARHT R 0.451)
   (CHARDP R 0.019)
   )
(CHARACTER O 136 (comment uni2226.var)
   (CHARWD R 0.609)
   (CHARHT R 0.451)
   (CHARDP R 0.019)
   )
(CHARACTER O 137 (comment uni2223.var)
   (CHARWD R 0.266)
   (CHARHT R 0.451)
   (CHARDP R 0.019)
   )
(CHARACTER O 140 (comment uni2225.var)
   (CHARWD R 0.446)
   (CHARHT R 0.451)
   (CHARDP R 0.011)
   )
(CHARACTER O 141 (comment uni228A.var)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.229)
   )
(CHARACTER O 142 (comment uni228B.var)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.229)
   )
(CHARACTER O 143 (comment uni2ACB.var)
   (CHARWD R 0.685)
   (CHARHT R 0.718)
   (CHARDP R 0.321)
   )
(CHARACTER O 144 (comment uni2ACC.var)
   (CHARWD R 0.685)
   (CHARHT R 0.718)
   (CHARDP R 0.321)
   )
(CHARACTER O 145 (comment uni2263)
   (CHARWD R 0.685)
   (CHARHT R 0.544)
   (CHARDP R 0.038)
   )
(CHARACTER O 146 (comment uni2264)
   (CHARWD R 0.685)
   (CHARHT R 0.609)
   (CHARDP R 0.103)
   )
(CHARACTER O 147 (comment uni2265)
   (CHARWD R 0.685)
   (CHARHT R 0.609)
   (CHARDP R 0.103)
   )
(CHARACTER O 150 (comment uni2266)
   (CHARWD R 0.685)
   (CHARHT R 0.718)
   (CHARDP R 0.211)
   )
(CHARACTER O 151 (comment uni2267)
   (CHARWD R 0.685)
   (CHARHT R 0.718)
   (CHARDP R 0.211)
   )
(CHARACTER O 172 (comment u1D718)
   (CHARWD R 0.561)
   (CHARHT R 0.441)
   (CHARDP R 0.013)
   (CHARIC R 0.07)
   )
(CHARACTER O 173 (comment uni03DD.ital)
   (CHARWD R 0.487)
   (CHARHT R 0.433)
   (CHARDP R 0.19)
   )
(CHARACTER O 174 (comment uni03F6.ital)
   (CHARWD R 0.444)
   (CHARHT R 0.441)
   (CHARDP R 0.011)
   )
(CHARACTER O 175 (comment yen)
   (CHARWD R 0.5)
   (CHARHT R 0.662)
   )
(CHARACTER O 176 (comment uni221D.var)
   (CHARWD R 0.685)
   (CHARHT R 0.428)
   )
(CHARACTER O 177 (comment uni2040)
   (CHARWD R 0.798)
   (CHARHT R 0.709)
   )
(CHARACTER O 200 (comment uni224F)
   (CHARWD R 0.685)
   (CHARHT R 0.471)
   )
(CHARACTER O 201 (comment uni2250)
   (CHARWD R 0.685)
   (CHARHT R 0.611)
   )
(CHARACTER O 202 (comment uni2251)
   (CHARWD R 0.685)
   (CHARHT R 0.611)
   (CHARDP R 0.106)
   )
(CHARACTER O 203 (comment uni2252)
   (CHARWD R 0.685)
   (CHARHT R 0.611)
   (CHARDP R 0.105)
   )
(CHARACTER O 204 (comment uni2253)
   (CHARWD R 0.685)
   (CHARHT R 0.611)
   (CHARDP R 0.106)
   )
(CHARACTER O 205 (comment uni2254)
   (CHARWD R 0.824)
   (CHARHT R 0.417)
   )
(CHARACTER O 206 (comment uni2255)
   (CHARWD R 0.824)
   (CHARHT R 0.417)
   )
(CHARACTER O 207 (comment uni2256)
   (CHARWD R 0.685)
   (CHARHT R 0.416)
   )
(CHARACTER O 210 (comment uni2257)
   (CHARWD R 0.685)
   (CHARHT R 0.752)
   )
(CHARACTER O 211 (comment uni2258)
   (CHARWD R 0.685)
   (CHARHT R 0.729)
   )
(CHARACTER O 212 (comment uni2259)
   (CHARWD R 0.685)
   (CHARHT R 0.853)
   )
(CHARACTER O 213 (comment uni225A)
   (CHARWD R 0.685)
   (CHARHT R 0.853)
   )
(CHARACTER O 214 (comment uni225B)
   (CHARWD R 0.685)
   (CHARHT R 0.756)
   )
(CHARACTER O 215 (comment uni225C)
   (CHARWD R 0.685)
   (CHARHT R 0.853)
   )
(CHARACTER O 216 (comment uni225D)
   (CHARWD R 0.685)
   (CHARHT R 0.823)
   )
(CHARACTER O 217 (comment uni225E)
   (CHARWD R 0.685)
   (CHARHT R 0.703)
   )
(CHARACTER O 220 (comment uni225F)
   (CHARWD R 0.685)
   (CHARHT R 0.863)
   )
(CHARACTER O 221 (comment uni2260)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 222 (comment uni2261)
   (CHARWD R 0.685)
   (CHARHT R 0.478)
   )
(CHARACTER O 223 (comment uni2262)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 224 (comment uni222B)
   (CHARWD R 0.459)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.28)
   (NEXTLARGER O 312)
   )
(CHARACTER O 225 (comment uni222C)
   (CHARWD R 0.701)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.28)
   (NEXTLARGER O 313)
   )
(CHARACTER O 226 (comment uni222D)
   (CHARWD R 0.943)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.28)
   (NEXTLARGER O 314)
   )
(CHARACTER O 227 (comment uni222E)
   (CHARWD R 0.499)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 315)
   )
(CHARACTER O 230 (comment uni222F)
   (CHARWD R 0.741)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 316)
   )
(CHARACTER O 231 (comment uni2230)
   (CHARWD R 0.982)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 317)
   )
(CHARACTER O 232 (comment uni2231)
   (CHARWD R 0.499)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 320)
   )
(CHARACTER O 233 (comment uni2232)
   (CHARWD R 0.499)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 321)
   )
(CHARACTER O 234 (comment uni2233)
   (CHARWD R 0.499)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 322)
   )
(CHARACTER O 235 (comment uni2A0B)
   (CHARWD R 0.69)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.18)
   (NEXTLARGER O 323)
   )
(CHARACTER O 236 (comment uni2A0C)
   (CHARWD R 1.184)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.28)
   (NEXTLARGER O 324)
   )
(CHARACTER O 237 (comment uni2A0D)
   (CHARWD R 0.499)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 325)
   )
(CHARACTER O 240 (comment uni2A0E)
   (CHARWD R 0.499)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 326)
   )
(CHARACTER O 241 (comment uni2A0F)
   (CHARWD R 0.499)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 327)
   )
(CHARACTER O 242 (comment uni2A10)
   (CHARWD R 0.499)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 330)
   )
(CHARACTER O 243 (comment uni2A11)
   (CHARWD R 0.499)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 331)
   )
(CHARACTER O 244 (comment uni2A12)
   (CHARWD R 0.519)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.22)
   (NEXTLARGER O 332)
   )
(CHARACTER O 245 (comment uni2A13)
   (CHARWD R 0.499)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 333)
   )
(CHARACTER O 246 (comment uni2A14)
   (CHARWD R 0.628)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.16)
   (NEXTLARGER O 334)
   )
(CHARACTER O 247 (comment uni2A15)
   (CHARWD R 0.499)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.24)
   (NEXTLARGER O 335)
   )
(CHARACTER O 250 (comment uni2A16)
   (CHARWD R 0.529)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.21)
   (NEXTLARGER O 336)
   )
(CHARACTER O 251 (comment uni2A17)
   (CHARWD R 0.738)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.18)
   (NEXTLARGER O 337)
   )
(CHARACTER O 252 (comment uni2A18)
   (CHARWD R 0.539)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.2)
   (NEXTLARGER O 340)
   )
(CHARACTER O 253 (comment uni2A19)
   (CHARWD R 0.559)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.18)
   (NEXTLARGER O 341)
   )
(CHARACTER O 254 (comment uni2A1A)
   (CHARWD R 0.559)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.18)
   (NEXTLARGER O 342)
   )
(CHARACTER O 255 (comment uni2A1B)
   (CHARWD R 0.459)
   (CHARHT R 0.947)
   (CHARDP R 0.32)
   (CHARIC R 0.28)
   (NEXTLARGER O 343)
   )
(CHARACTER O 256 (comment uni2A1C)
   (CHARWD R 0.559)
   (CHARHT R 0.824)
   (CHARDP R 0.443)
   (CHARIC R 0.18)
   (NEXTLARGER O 344)
   )
(CHARACTER O 257 (comment uni222B.up)
   (CHARWD R 0.366)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.142)
   (NEXTLARGER O 345)
   )
(CHARACTER O 260 (comment uni222C.up)
   (CHARWD R 0.596)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.142)
   (NEXTLARGER O 346)
   )
(CHARACTER O 261 (comment uni222D.up)
   (CHARWD R 0.826)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.142)
   (NEXTLARGER O 347)
   )
(CHARACTER O 262 (comment uni222E.up)
   (CHARWD R 0.397)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.189)
   (NEXTLARGER O 350)
   )
(CHARACTER O 263 (comment uni222F.up)
   (CHARWD R 0.548)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.189)
   (NEXTLARGER O 351)
   )
(CHARACTER O 264 (comment uni2230.up)
   (CHARWD R 0.876)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.196)
   (NEXTLARGER O 352)
   )
(CHARACTER O 265 (comment uni2231.up)
   (CHARWD R 0.478)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.169)
   (NEXTLARGER O 353)
   )
(CHARACTER O 266 (comment uni2232.up)
   (CHARWD R 0.441)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.189)
   (NEXTLARGER O 354)
   )
(CHARACTER O 267 (comment uni2233.up)
   (CHARWD R 0.475)
   (CHARHT R 0.824)
   (CHARDP R 0.32)
   (CHARIC R 0.189)
   (NEXTLARGER O 355)
   )
(CHARACTER O 270 (comment uni2A0B.up)
   (CHARWD R 0.706)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.142)
   (NEXTLARGER O 356)
   )
(CHARACTER O 271 (comment uni2A0C.up)
   (CHARWD R 1.093)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.142)
   (NEXTLARGER O 357)
   )
(CHARACTER O 272 (comment uni2A0D.up)
   (CHARWD R 0.467)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.142)
   (NEXTLARGER O 360)
   )
(CHARACTER O 273 (comment uni2A0E.up)
   (CHARWD R 0.467)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.142)
   (NEXTLARGER O 361)
   )
(CHARACTER O 274 (comment uni2A0F.up)
   (CHARWD R 0.529)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.142)
   (NEXTLARGER O 362)
   )
(CHARACTER O 275 (comment uni2A10.up)
   (CHARWD R 0.346)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.189)
   (NEXTLARGER O 363)
   )
(CHARACTER O 276 (comment uni2A11.up)
   (CHARWD R 0.478)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.169)
   (NEXTLARGER O 364)
   )
(CHARACTER O 277 (comment uni2A12.up)
   (CHARWD R 0.365)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.169)
   (NEXTLARGER O 365)
   )
(CHARACTER O 300 (comment uni2A13.up)
   (CHARWD R 0.384)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.169)
   (NEXTLARGER O 366)
   )
(CHARACTER O 301 (comment uni2A14.up)
   (CHARWD R 0.509)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.169)
   (NEXTLARGER O 367)
   )
(CHARACTER O 302 (comment uni2A15.up)
   (CHARWD R 0.533)
   (CHARHT R 0.756)
   (CHARDP R 0.218)
   (CHARIC R 0.142)
   (NEXTLARGER O 370)
   )
(CHARACTER O 303 (comment uni2A16.up)
   (CHARWD R 0.412)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.169)
   (NEXTLARGER O 371)
   )
(CHARACTER O 304 (comment uni2A17.up)
   (CHARWD R 0.771)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.16)
   (NEXTLARGER O 372)
   )
(CHARACTER O 305 (comment uni2A18.up)
   (CHARWD R 0.455)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.16)
   (NEXTLARGER O 373)
   )
(CHARACTER O 306 (comment uni2A19.up)
   (CHARWD R 0.504)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.165)
   (NEXTLARGER O 374)
   )
(CHARACTER O 307 (comment uni2A1A.up)
   (CHARWD R 0.504)
   (CHARHT R 0.812)
   (CHARDP R 0.332)
   (CHARIC R 0.165)
   (NEXTLARGER O 375)
   )
(CHARACTER O 310 (comment uni2A1B.up)
   (CHARWD R 0.453)
   (CHARHT R 0.935)
   (CHARDP R 0.332)
   (CHARIC R 0.142)
   (NEXTLARGER O 376)
   )
(CHARACTER O 311 (comment uni2A1C.up)
   (CHARWD R 0.509)
   (CHARHT R 0.812)
   (CHARDP R 0.455)
   (CHARIC R 0.05)
   (NEXTLARGER O 377)
   )
(CHARACTER O 312 (comment uni222B.dsp)
   (CHARWD R 0.585)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.55)
   )
(CHARACTER O 313 (comment uni222C.dsp)
   (CHARWD R 0.895)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.55)
   )
(CHARACTER O 314 (comment uni222D.dsp)
   (CHARWD R 1.205)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.55)
   )
(CHARACTER O 315 (comment uni222E.dsp)
   (CHARWD R 0.635)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 316 (comment uni222F.dsp)
   (CHARWD R 0.945)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 317 (comment uni2230.dsp)
   (CHARWD R 1.255)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 320 (comment uni2231.dsp)
   (CHARWD R 0.635)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 321 (comment uni2232.dsp)
   (CHARWD R 0.635)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 322 (comment uni2233.dsp)
   (CHARWD R 0.635)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 323 (comment uni2A0B.dsp)
   (CHARWD R 0.914)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.221)
   )
(CHARACTER O 324 (comment uni2A0C.dsp)
   (CHARWD R 1.515)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.55)
   )
(CHARACTER O 325 (comment uni2A0D.dsp)
   (CHARWD R 0.635)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 326 (comment uni2A0E.dsp)
   (CHARWD R 0.635)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 327 (comment uni2A0F.dsp)
   (CHARWD R 0.635)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 330 (comment uni2A10.dsp)
   (CHARWD R 0.635)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 331 (comment uni2A11.dsp)
   (CHARWD R 0.635)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 332 (comment uni2A12.dsp)
   (CHARWD R 0.735)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.4)
   )
(CHARACTER O 333 (comment uni2A13.dsp)
   (CHARWD R 0.635)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 334 (comment uni2A14.dsp)
   (CHARWD R 0.844)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.31)
   )
(CHARACTER O 335 (comment uni2A15.dsp)
   (CHARWD R 0.635)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 336 (comment uni2A16.dsp)
   (CHARWD R 0.735)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.4)
   )
(CHARACTER O 337 (comment uni2A17.dsp)
   (CHARWD R 0.819)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.32)
   )
(CHARACTER O 340 (comment uni2A18.dsp)
   (CHARWD R 0.635)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 341 (comment uni2A19.dsp)
   (CHARWD R 0.735)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.4)
   )
(CHARACTER O 342 (comment uni2A1A.dsp)
   (CHARWD R 0.735)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.4)
   )
(CHARACTER O 343 (comment uni2A1B.dsp)
   (CHARWD R 0.636)
   (CHARHT R 2.157)
   (CHARDP R 0.269)
   (CHARIC R 0.5)
   )
(CHARACTER O 344 (comment uni2A1C.dsp)
   (CHARWD R 0.895)
   (CHARHT R 2)
   (CHARDP R 0.426)
   (CHARIC R 0.24)
   )
(CHARACTER O 345 (comment uni222B.updsp)
   (CHARWD R 0.467)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.145)
   )
(CHARACTER O 346 (comment uni222C.updsp)
   (CHARWD R 0.787)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.145)
   )
(CHARACTER O 347 (comment uni222D.updsp)
   (CHARWD R 1.107)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.145)
   )
(CHARACTER O 350 (comment uni222E.updsp)
   (CHARWD R 0.616)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.169)
   )
(CHARACTER O 351 (comment uni222F.updsp)
   (CHARWD R 0.849)
   (CHARHT R 2)
   (CHARDP R 0.269)
   )
(CHARACTER O 352 (comment uni2230.updsp)
   (CHARWD R 1.161)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.111)
   )
(CHARACTER O 353 (comment uni2231.updsp)
   (CHARWD R 0.608)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.228)
   )
(CHARACTER O 354 (comment uni2232.updsp)
   (CHARWD R 0.616)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.23)
   )
(CHARACTER O 355 (comment uni2233.updsp)
   (CHARWD R 0.605)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.28)
   )
(CHARACTER O 356 (comment uni2A0B.updsp)
   (CHARWD R 0.914)
   (CHARHT R 2)
   (CHARDP R 0.269)
   )
(CHARACTER O 357 (comment uni2A0C.updsp)
   (CHARWD R 1.397)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.145)
   )
(CHARACTER O 360 (comment uni2A0D.updsp)
   (CHARWD R 0.609)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.138)
   )
(CHARACTER O 361 (comment uni2A0E.updsp)
   (CHARWD R 0.609)
   (CHARHT R 1.999)
   (CHARDP R 0.27)
   (CHARIC R 0.138)
   )
(CHARACTER O 362 (comment uni2A0F.updsp)
   (CHARWD R 0.658)
   (CHARHT R 1.999)
   (CHARDP R 0.27)
   (CHARIC R 0.176)
   )
(CHARACTER O 363 (comment uni2A10.updsp)
   (CHARWD R 0.629)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.106)
   )
(CHARACTER O 364 (comment uni2A11.updsp)
   (CHARWD R 0.608)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.228)
   )
(CHARACTER O 365 (comment uni2A12.updsp)
   (CHARWD R 0.568)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.129)
   )
(CHARACTER O 366 (comment uni2A13.updsp)
   (CHARWD R 0.53)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.169)
   )
(CHARACTER O 367 (comment uni2A14.updsp)
   (CHARWD R 0.695)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.181)
   )
(CHARACTER O 370 (comment uni2A15.updsp)
   (CHARWD R 0.615)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.169)
   )
(CHARACTER O 371 (comment uni2A16.updsp)
   (CHARWD R 0.653)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.129)
   )
(CHARACTER O 372 (comment uni2A17.updsp)
   (CHARWD R 0.945)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.194)
   )
(CHARACTER O 373 (comment uni2A18.updsp)
   (CHARWD R 0.597)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.111)
   )
(CHARACTER O 374 (comment uni2A19.updsp)
   (CHARWD R 0.735)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.166)
   )
(CHARACTER O 375 (comment uni2A1A.updsp)
   (CHARWD R 0.735)
   (CHARHT R 2)
   (CHARDP R 0.269)
   (CHARIC R 0.166)
   )
(CHARACTER O 376 (comment uni2A1B.updsp)
   (CHARWD R 0.701)
   (CHARHT R 2.157)
   (CHARDP R 0.269)
   (CHARIC R 0.14)
   )
(CHARACTER O 377 (comment uni2A1C.updsp)
   (CHARWD R 0.799)
   (CHARHT R 2)
   (CHARDP R 0.426)
   )
