(FAMILY ts1-stixgral-italic)
(CODINGSCHEME STIXTS1)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 16)
(FONTDIMEN
   (SLANT R 0.292989)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 428)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   )
(CHARACTER O 0 (comment grave)
   (CHARWD R 333)
   (CHARHT R 664)
   )
(CHARACTER O 1 (comment acute)
   (CHARWD R 333)
   (CHARHT R 664)
   (CHARIC R 70)
   )
(CHARACTER O 2 (comment circumflex)
   (CHARWD R 333)
   (CHARHT R 661)
   (CHARIC R 52)
   )
(CHARACTER O 3 (comment tilde)
   (CHARWD R 333)
   (CHARHT R 624)
   (CHARIC R 94)
   )
(CHARACTER O 4 (comment dieresis)
   (CHARWD R 333)
   (CHARHT R 606)
   (CHARIC R 72)
   )
(CHARACTER O 5 (comment hungarumlaut)
   (CHARWD R 333)
   (CHARHT R 664)
   (CHARIC R 153)
   )
(CHARACTER O 6 (comment ring)
   (CHARWD R 333)
   (CHARHT R 707)
   (CHARIC R 22)
   )
(CHARACTER O 7 (comment caron)
   (CHARWD R 333)
   (CHARHT R 661)
   (CHARIC R 93)
   )
(CHARACTER O 10 (comment breve)
   (CHARWD R 333)
   (CHARHT R 650)
   (CHARIC R 85)
   )
(CHARACTER O 11 (comment macron)
   (CHARWD R 333)
   (CHARHT R 583)
   (CHARIC R 78)
   )
(CHARACTER O 12 (comment dotaccent)
   (CHARWD R 333)
   (CHARHT R 606)
   )
(CHARACTER O 13 (comment cedilla)
   (CHARWD R 333)
   (CHARDP R 217)
   )
(CHARACTER O 14 (comment ogonek)
   (CHARWD R 333)
   (CHARHT R 40)
   (CHARDP R 169)
   )
(CHARACTER O 15 (comment quotesinglbase)
   (CHARWD R 333)
   (CHARHT R 101)
   (CHARDP R 129)
   )
(CHARACTER O 22 (comment quotedblbase)
   (CHARWD R 556)
   (CHARHT R 101)
   (CHARDP R 129)
   )
(CHARACTER O 44 (comment dollar)
   (CHARWD R 500)
   (CHARHT R 731)
   (CHARDP R 89)
   )
(CHARACTER O 47 (comment quotesingle)
   (CHARWD R 214)
   (CHARHT R 666)
   (CHARIC R 27)
   )
(CHARACTER O 54 (comment comma)
   (CHARWD R 250)
   (CHARHT R 101)
   (CHARDP R 129)
   )
(CHARACTER O 56 (comment period)
   (CHARWD R 250)
   (CHARHT R 100)
   (CHARDP R 11)
   )
(CHARACTER O 57 (comment fraction)
   (CHARWD R 167)
   (CHARHT R 676)
   (CHARDP R 10)
   (CHARIC R 170)
   )
(CHARACTER O 60 (comment zero.oldstyle)
   (CHARWD R 570)
   (CHARHT R 460)
   (CHARDP R 11)
   )
(CHARACTER O 61 (comment one.oldstyle)
   (CHARWD R 570)
   (CHARHT R 460)
   )
(CHARACTER O 62 (comment two.oldstyle)
   (CHARWD R 570)
   (CHARHT R 460)
   )
(CHARACTER O 63 (comment three.oldstyle)
   (CHARWD R 570)
   (CHARHT R 461)
   (CHARDP R 217)
   )
(CHARACTER O 64 (comment four.oldstyle)
   (CHARWD R 570)
   (CHARHT R 450)
   (CHARDP R 217)
   )
(CHARACTER O 65 (comment five.oldstyle)
   (CHARWD R 570)
   (CHARHT R 450)
   (CHARDP R 218)
   )
(CHARACTER O 66 (comment six.oldstyle)
   (CHARWD R 570)
   (CHARHT R 668)
   (CHARDP R 10)
   )
(CHARACTER O 67 (comment seven.oldstyle)
   (CHARWD R 570)
   (CHARHT R 450)
   (CHARDP R 217)
   )
(CHARACTER O 70 (comment eight.oldstyle)
   (CHARWD R 570)
   (CHARHT R 668)
   (CHARDP R 10)
   )
(CHARACTER O 71 (comment nine.oldstyle)
   (CHARWD R 570)
   (CHARHT R 460)
   (CHARDP R 217)
   )
(CHARACTER O 75 (comment minus)
   (CHARWD R 675)
   (CHARHT R 286)
   )
(CHARACTER O 140 (comment grave)
   (CHARWD R 333)
   (CHARHT R 664)
   )
(CHARACTER O 200 (comment breve)
   (CHARWD R 333)
   (CHARHT R 650)
   (CHARIC R 85)
   )
(CHARACTER O 201 (comment caron)
   (CHARWD R 333)
   (CHARHT R 661)
   (CHARIC R 93)
   )
(CHARACTER O 202 (comment hungarumlaut)
   (CHARWD R 333)
   (CHARHT R 664)
   (CHARIC R 153)
   )
(CHARACTER O 204 (comment dagger)
   (CHARWD R 500)
   (CHARHT R 666)
   (CHARDP R 159)
   )
(CHARACTER O 205 (comment daggerdbl)
   (CHARWD R 500)
   (CHARHT R 666)
   (CHARDP R 143)
   )
(CHARACTER O 207 (comment perthousand)
   (CHARWD R 1117)
   (CHARHT R 706)
   (CHARDP R 19)
   )
(CHARACTER O 210 (comment bullet)
   (CHARWD R 523)
   (CHARHT R 444)
   )
(CHARACTER O 212 (comment dollar)
   (CHARWD R 500)
   (CHARHT R 731)
   (CHARDP R 89)
   )
(CHARACTER O 213 (comment cent)
   (CHARWD R 500)
   (CHARHT R 560)
   (CHARDP R 143)
   )
(CHARACTER O 214 (comment florin)
   (CHARWD R 472)
   (CHARHT R 706)
   (CHARDP R 159)
   (CHARIC R 22)
   )
(CHARACTER O 222 (comment uni20A4)
   (CHARWD R 500)
   (CHARHT R 670)
   (CHARDP R 8)
   (CHARIC R 17)
   )
(CHARACTER O 227 (comment trademark)
   (CHARWD R 980)
   (CHARHT R 653)
   )
(CHARACTER O 230 (comment uni2031)
   (CHARWD R 1479)
   (CHARHT R 706)
   (CHARDP R 19)
   )
(CHARACTER O 233 (comment uni2116)
   (CHARWD R 1046)
   (CHARHT R 668)
   (CHARDP R 15)
   )
(CHARACTER O 242 (comment cent)
   (CHARWD R 500)
   (CHARHT R 560)
   (CHARDP R 143)
   )
(CHARACTER O 243 (comment sterling)
   (CHARWD R 500)
   (CHARHT R 670)
   (CHARDP R 8)
   (CHARIC R 17)
   )
(CHARACTER O 244 (comment currency)
   (CHARWD R 500)
   (CHARHT R 534)
   (CHARDP R 10)
   (CHARIC R 22)
   )
(CHARACTER O 245 (comment yen)
   (CHARWD R 500)
   (CHARHT R 653)
   (CHARIC R 105)
   )
(CHARACTER O 246 (comment brokenbar)
   (CHARWD R 275)
   (CHARHT R 666)
   (CHARDP R 18)
   )
(CHARACTER O 247 (comment section)
   (CHARWD R 500)
   (CHARHT R 666)
   (CHARDP R 162)
   )
(CHARACTER O 250 (comment dieresis)
   (CHARWD R 333)
   (CHARHT R 606)
   (CHARIC R 72)
   )
(CHARACTER O 251 (comment copyright)
   (CHARWD R 760)
   (CHARHT R 666)
   (CHARDP R 18)
   )
(CHARACTER O 252 (comment ordfeminine)
   (CHARWD R 276)
   (CHARHT R 676)
   (CHARIC R 76)
   )
(CHARACTER O 254 (comment logicalnot)
   (CHARWD R 675)
   (CHARHT R 386)
   )
(CHARACTER O 255 (comment uni24C5)
   (CHARWD R 684)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER O 256 (comment registered)
   (CHARWD R 760)
   (CHARHT R 666)
   (CHARDP R 18)
   )
(CHARACTER O 257 (comment macron)
   (CHARWD R 333)
   (CHARHT R 583)
   (CHARIC R 78)
   )
(CHARACTER O 260 (comment degree)
   (CHARWD R 400)
   (CHARHT R 676)
   )
(CHARACTER O 261 (comment plusminus)
   (CHARWD R 675)
   (CHARHT R 568)
   )
(CHARACTER O 262 (comment twosuperior)
   (CHARWD R 300)
   (CHARHT R 676)
   (CHARIC R 24)
   )
(CHARACTER O 263 (comment threesuperior)
   (CHARWD R 300)
   (CHARHT R 676)
   (CHARIC R 39)
   )
(CHARACTER O 264 (comment acute)
   (CHARWD R 333)
   (CHARHT R 664)
   (CHARIC R 70)
   )
(CHARACTER O 265 (comment mu)
   (CHARWD R 500)
   (CHARHT R 428)
   (CHARDP R 209)
   )
(CHARACTER O 266 (comment paragraph)
   (CHARWD R 559)
   (CHARHT R 653)
   (CHARDP R 123)
   (CHARIC R 62)
   )
(CHARACTER O 267 (comment periodcentered)
   (CHARWD R 250)
   (CHARHT R 310)
   )
(CHARACTER O 271 (comment onesuperior)
   (CHARWD R 300)
   (CHARHT R 676)
   )
(CHARACTER O 272 (comment ordmasculine)
   (CHARWD R 310)
   (CHARHT R 676)
   (CHARIC R 52)
   )
(CHARACTER O 274 (comment onequarter)
   (CHARWD R 750)
   (CHARHT R 676)
   (CHARDP R 10)
   )
(CHARACTER O 275 (comment onehalf)
   (CHARWD R 750)
   (CHARHT R 676)
   (CHARDP R 10)
   )
(CHARACTER O 276 (comment threequarters)
   (CHARWD R 750)
   (CHARHT R 676)
   (CHARDP R 10)
   )
(CHARACTER O 277 (comment uni20AC)
   (CHARWD R 500)
   (CHARHT R 664)
   (CHARDP R 12)
   (CHARIC R 38)
   )
(CHARACTER O 326 (comment multiply)
   (CHARWD R 675)
   (CHARHT R 497)
   )
(CHARACTER O 366 (comment divide)
   (CHARWD R 675)
   (CHARHT R 517)
   (CHARDP R 11)
   )
