(FAMILY STIXMathBlackboard)
(CODINGSCHEME STIXMATHBBIT-BOLD)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   )
(LIGTABLE
   (LABEL O 101) (comment uniE200)
   (KRN O 177 R 0.1005) (comment uni2040)
   (STOP)
   (LABEL O 102) (comment uniE201)
   (KRN O 177 R 0.1315) (comment uni2040)
   (STOP)
   (LABEL O 103) (comment uni2102.bi)
   (KRN O 177 R 0.1015) (comment uni2040)
   (STOP)
   (LABEL O 104) (comment uni2145)
   (KRN O 177 R 0.076) (comment uni2040)
   (STOP)
   (LABEL O 105) (comment uniE203)
   (KRN O 177 R 0.116) (comment uni2040)
   (STOP)
   (LABEL O 106) (comment uniE204)
   (KRN O 177 R 0.116) (comment uni2040)
   (STOP)
   (LABEL O 107) (comment uniE205)
   (KRN O 177 R 0.142) (comment uni2040)
   (STOP)
   (LABEL O 110) (comment uni210D.bi)
   (KRN O 177 R 0.0755) (comment uni2040)
   (STOP)
   (LABEL O 111) (comment uniE206)
   (KRN O 177 R 0.118) (comment uni2040)
   (STOP)
   (LABEL O 112) (comment uniE207)
   (KRN O 177 R 0.1165) (comment uni2040)
   (STOP)
   (LABEL O 113) (comment uniE208)
   (KRN O 177 R 0.139) (comment uni2040)
   (STOP)
   (LABEL O 114) (comment uniE209)
   (KRN O 177 R 0.1165) (comment uni2040)
   (STOP)
   (LABEL O 115) (comment uniE20A)
   (KRN O 177 R 0.12) (comment uni2040)
   (STOP)
   (LABEL O 116) (comment uni2115.bi)
   (KRN O 177 R 0.083) (comment uni2040)
   (STOP)
   (LABEL O 117) (comment uniE20B)
   (KRN O 177 R 0.1395) (comment uni2040)
   (STOP)
   (LABEL O 120) (comment uni2119.bi)
   (KRN O 177 R 0.074) (comment uni2040)
   (STOP)
   (LABEL O 121) (comment uni211A.bi)
   (KRN O 177 R 0.081) (comment uni2040)
   (STOP)
   (LABEL O 122) (comment uni211D.bi)
   (KRN O 177 R 0.0945) (comment uni2040)
   (STOP)
   (LABEL O 123) (comment uniE20C)
   (KRN O 177 R 0.122) (comment uni2040)
   (STOP)
   (LABEL O 124) (comment uniE20D)
   (KRN O 177 R -0.005) (comment uni2040)
   (STOP)
   (LABEL O 125) (comment uniE20E)
   (KRN O 177 R 0.125) (comment uni2040)
   (STOP)
   (LABEL O 126) (comment uniE20F)
   (KRN O 177 R 0.034) (comment uni2040)
   (STOP)
   (LABEL O 127) (comment uniE210)
   (KRN O 177 R 0.08) (comment uni2040)
   (STOP)
   (LABEL O 130) (comment uniE211)
   (KRN O 177 R 0.1105) (comment uni2040)
   (STOP)
   (LABEL O 131) (comment uniE212)
   (KRN O 177 R 0.0305) (comment uni2040)
   (STOP)
   (LABEL O 132) (comment uni2124.bi)
   (KRN O 177 R 0.113) (comment uni2040)
   (STOP)
   (LABEL O 141) (comment uniE213)
   (KRN O 177 R 0.1) (comment uni2040)
   (STOP)
   (LABEL O 142) (comment uniE214)
   (KRN O 177 R 0.0955) (comment uni2040)
   (STOP)
   (LABEL O 143) (comment uniE215)
   (KRN O 177 R 0.1095) (comment uni2040)
   (STOP)
   (LABEL O 144) (comment uni2146)
   (KRN O 177 R 0.0805) (comment uni2040)
   (STOP)
   (LABEL O 145) (comment uni2147)
   (KRN O 177 R 0.0745) (comment uni2040)
   (STOP)
   (LABEL O 146) (comment uniE218)
   (KRN O 177 R 0.0995) (comment uni2040)
   (STOP)
   (LABEL O 147) (comment uniE219)
   (KRN O 177 R 0.102) (comment uni2040)
   (STOP)
   (LABEL O 150) (comment uniE21A)
   (KRN O 177 R 0.0945) (comment uni2040)
   (STOP)
   (LABEL O 151) (comment uni2148)
   (KRN O 177 R 0.0565) (comment uni2040)
   (STOP)
   (LABEL O 152) (comment uni2149)
   (KRN O 177 R 0.0625) (comment uni2040)
   (STOP)
   (LABEL O 153) (comment uniE21D)
   (KRN O 177 R 0.1045) (comment uni2040)
   (STOP)
   (LABEL O 154) (comment uniE21E)
   (KRN O 177 R 0.094) (comment uni2040)
   (STOP)
   (LABEL O 155) (comment uniE21F)
   (KRN O 177 R 0.095) (comment uni2040)
   (STOP)
   (LABEL O 156) (comment uniE220)
   (KRN O 177 R 0.0945) (comment uni2040)
   (STOP)
   (LABEL O 157) (comment uniE221)
   (KRN O 177 R 0.061) (comment uni2040)
   (STOP)
   (LABEL O 160) (comment uniE222)
   (KRN O 177 R 0.084) (comment uni2040)
   (STOP)
   (LABEL O 161) (comment uniE223)
   (KRN O 177 R 0.106) (comment uni2040)
   (STOP)
   (LABEL O 162) (comment uniE224)
   (KRN O 177 R 0.0935) (comment uni2040)
   (STOP)
   (LABEL O 163) (comment uniE225)
   (KRN O 177 R 0.1095) (comment uni2040)
   (STOP)
   (LABEL O 164) (comment uniE226)
   (KRN O 177 R 0.0885) (comment uni2040)
   (STOP)
   (LABEL O 165) (comment uniE227)
   (KRN O 177 R 0.1055) (comment uni2040)
   (STOP)
   (LABEL O 166) (comment uniE228)
   (KRN O 177 R 0.0295) (comment uni2040)
   (STOP)
   (LABEL O 167) (comment uniE229)
   (KRN O 177 R 0.042) (comment uni2040)
   (STOP)
   (LABEL O 170) (comment uniE22A)
   (KRN O 177 R 0.039) (comment uni2040)
   (STOP)
   (LABEL O 171) (comment uniE22B)
   (KRN O 177 R 0.073) (comment uni2040)
   (STOP)
   (LABEL O 172) (comment uniE22C)
   (KRN O 177 R 0.1045) (comment uni2040)
   (STOP)
   (LABEL O 173) (comment uni2148.dtls)
   (KRN O 177 R 0.0165) (comment uni2040)
   (STOP)
   (LABEL O 174) (comment uni2149.dtls)
   (KRN O 177 R 0.0375) (comment uni2040)
   (STOP)
   )
(CHARACTER O 0 (comment uniE004)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 1 (comment uniE005)
   (CHARWD R 0.926)
   (CHARHT R 0.53)
   )
(CHARACTER O 2 (comment uniE00E)
   (CHARWD R 0.75)
   (CHARHT R 0.819)
   (CHARDP R 0.339)
   )
(CHARACTER O 3 (comment uniE00F)
   (CHARWD R 0.75)
   (CHARHT R 0.742)
   (CHARDP R 0.235)
   )
(CHARACTER O 4 (comment uniE010)
   (CHARWD R 0.75)
   (CHARHT R 0.742)
   (CHARDP R 0.235)
   )
(CHARACTER O 5 (comment uniE011)
   (CHARWD R 0.75)
   (CHARHT R 0.819)
   (CHARDP R 0.339)
   )
(CHARACTER O 6 (comment uniE016)
   (CHARWD R 0.685)
   (CHARHT R 0.818)
   (CHARDP R 0.311)
   )
(CHARACTER O 7 (comment uniE018)
   (CHARWD R 0.685)
   (CHARHT R 0.818)
   (CHARDP R 0.311)
   )
(CHARACTER O 10 (comment uniE01E)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.11)
   )
(CHARACTER O 11 (comment uniE023)
   (CHARWD R 0.75)
   (CHARHT R 0.742)
   (CHARDP R 0.235)
   )
(CHARACTER O 12 (comment uniE025)
   (CHARWD R 0.75)
   (CHARHT R 0.852)
   (CHARDP R 0.345)
   )
(CHARACTER O 13 (comment uniE028)
   (CHARWD R 1)
   (CHARHT R 0.672)
   (CHARDP R 0.166)
   )
(CHARACTER O 14 (comment uniE029)
   (CHARWD R 1)
   (CHARHT R 0.672)
   (CHARDP R 0.166)
   )
(CHARACTER O 15 (comment uniE02A)
   (CHARWD R 1.24)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 16 (comment uniE02B)
   (CHARWD R 1.24)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 17 (comment uniE035)
   (CHARWD R 0.486)
   (CHARHT R 0.602)
   (CHARDP R 0.098)
   )
(CHARACTER O 20 (comment uniE03A)
   (CHARWD R 0.471)
   (CHARHT R 0.811)
   (CHARDP R 0.156)
   )
(CHARACTER O 21 (comment uniE03B)
   (CHARWD R 0.685)
   (CHARHT R 0.736)
   (CHARDP R 0.156)
   )
(CHARACTER O 22 (comment uniE03C)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 23 (comment uniE03D)
   (CHARWD R 0.486)
   (CHARHT R 0.602)
   (CHARDP R 0.098)
   )
(CHARACTER O 24 (comment uniE045)
   (CHARWD R 0.685)
   (CHARHT R 0.818)
   (CHARDP R 0.311)
   )
(CHARACTER O 25 (comment uniE046)
   (CHARWD R 0.685)
   (CHARHT R 0.818)
   (CHARDP R 0.311)
   )
(CHARACTER O 26 (comment uniE04B)
   (CHARWD R 0.685)
   (CHARHT R 0.745)
   (CHARDP R 0.242)
   )
(CHARACTER O 27 (comment uniE04C)
   (CHARWD R 0.685)
   (CHARHT R 0.845)
   (CHARDP R 0.341)
   )
(CHARACTER O 30 (comment uniE04E)
   (CHARWD R 0.685)
   (CHARHT R 0.845)
   (CHARDP R 0.341)
   )
(CHARACTER O 31 (comment uniE04F)
   (CHARWD R 0.685)
   (CHARHT R 0.745)
   (CHARDP R 0.242)
   )
(CHARACTER O 32 (comment uniE050)
   (CHARWD R 0.75)
   (CHARHT R 0.672)
   (CHARDP R 0.166)
   )
(CHARACTER O 33 (comment uniE051)
   (CHARWD R 0.75)
   (CHARHT R 0.672)
   (CHARDP R 0.166)
   )
(CHARACTER O 34 (comment uniE052)
   (CHARWD R 0.75)
   (CHARHT R 0.574)
   (CHARDP R 0.069)
   )
(CHARACTER O 35 (comment uniE059)
   (CHARWD R 0.685)
   (CHARHT R 0.73)
   (CHARDP R 0.224)
   )
(CHARACTER O 36 (comment uniE05A)
   (CHARWD R 0.685)
   (CHARHT R 0.73)
   (CHARDP R 0.224)
   )
(CHARACTER O 37 (comment uniE05B)
   (CHARWD R 0.75)
   (CHARHT R 0.574)
   )
(CHARACTER O 40 (comment uniE05C)
   (CHARWD R 0.75)
   (CHARHT R 0.553)
   (CHARDP R 0.031)
   )
(CHARACTER O 41 (comment uniE06D)
   (CHARWD R 0.75)
   (CHARHT R 0.835)
   (CHARDP R 0.113)
   )
(CHARACTER O 42 (comment uniE06E)
   (CHARWD R 0.75)
   (CHARHT R 0.835)
   (CHARDP R 0.113)
   )
(CHARACTER O 43 (comment uniE075)
   (CHARWD R 0.685)
   (CHARHT R 0.626)
   (CHARDP R 0.119)
   )
(CHARACTER O 44 (comment uniE07C)
   (CHARWD R 0.685)
   (CHARHT R 0.758)
   (CHARDP R 0.252)
   )
(CHARACTER O 45 (comment uniE082)
   (CHARWD R 0.75)
   (CHARHT R 0.742)
   (CHARDP R 0.235)
   )
(CHARACTER O 46 (comment uniE083)
   (CHARWD R 0.75)
   (CHARHT R 0.742)
   (CHARDP R 0.234)
   )
(CHARACTER O 47 (comment uniE086)
   (CHARWD R 0.685)
   (CHARHT R 0.818)
   (CHARDP R 0.311)
   )
(CHARACTER O 50 (comment uniE087)
   (CHARWD R 0.685)
   (CHARHT R 0.818)
   (CHARDP R 0.311)
   )
(CHARACTER O 51 (comment uniE094)
   (CHARWD R 0.685)
   (CHARHT R 0.719)
   (CHARDP R 0.24)
   )
(CHARACTER O 52 (comment uniE095)
   (CHARWD R 0.685)
   (CHARHT R 0.719)
   (CHARDP R 0.24)
   )
(CHARACTER O 53 (comment uniE098)
   (CHARWD R 0.685)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 54 (comment uniE14C)
   (CHARWD R 0.857)
   (CHARHT R 0.66)
   (CHARDP R 0.158)
   )
(CHARACTER O 55 (comment uniE14D)
   (CHARWD R 0.857)
   (CHARHT R 0.66)
   (CHARDP R 0.158)
   )
(CHARACTER O 56 (comment uniE14E)
   (CHARWD R 0.685)
   (CHARHT R 0.661)
   (CHARDP R 0.157)
   )
(CHARACTER O 57 (comment uniE14F)
   (CHARWD R 0.685)
   (CHARHT R 0.661)
   (CHARDP R 0.157)
   )
(CHARACTER O 60 (comment u1D7D8)
   (CHARWD R 0.54)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 61 (comment u1D7D9)
   (CHARWD R 0.54)
   (CHARHT R 0.693)
   )
(CHARACTER O 62 (comment u1D7DA)
   (CHARWD R 0.547)
   (CHARHT R 0.676)
   )
(CHARACTER O 63 (comment u1D7DB)
   (CHARWD R 0.54)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 64 (comment u1D7DC)
   (CHARWD R 0.54)
   (CHARHT R 0.676)
   )
(CHARACTER O 65 (comment u1D7DD)
   (CHARWD R 0.54)
   (CHARHT R 0.662)
   (CHARDP R 0.014)
   )
(CHARACTER O 66 (comment u1D7DE)
   (CHARWD R 0.54)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 67 (comment u1D7DF)
   (CHARWD R 0.54)
   (CHARHT R 0.662)
   )
(CHARACTER O 70 (comment u1D7E0)
   (CHARWD R 0.54)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 71 (comment u1D7E1)
   (CHARWD R 0.54)
   (CHARHT R 0.676)
   (CHARDP R 0.012)
   )
(CHARACTER O 101 (comment uniE200)
   (CHARWD R 0.733)
   (CHARHT R 0.669)
   )
(CHARACTER O 102 (comment uniE201)
   (CHARWD R 0.729)
   (CHARHT R 0.669)
   )
(CHARACTER O 103 (comment uni2102.bi)
   (CHARWD R 0.713)
   (CHARHT R 0.685)
   (CHARDP R 0.014)
   )
(CHARACTER O 104 (comment uni2145)
   (CHARWD R 0.748)
   (CHARHT R 0.669)
   (CHARIC R 0.02)
   )
(CHARACTER O 105 (comment uniE203)
   (CHARWD R 0.68)
   (CHARHT R 0.669)
   (CHARIC R 0.068)
   )
(CHARACTER O 106 (comment uniE204)
   (CHARWD R 0.474)
   (CHARHT R 0.669)
   (CHARIC R 0.274)
   )
(CHARACTER O 107 (comment uniE205)
   (CHARWD R 0.718)
   (CHARHT R 0.685)
   (CHARDP R 0.014)
   )
(CHARACTER O 110 (comment uni210D.bi)
   (CHARWD R 0.773)
   (CHARHT R 0.669)
   (CHARIC R 0.08)
   )
(CHARACTER O 111 (comment uniE206)
   (CHARWD R 0.382)
   (CHARHT R 0.669)
   (CHARIC R 0.074)
   )
(CHARACTER O 112 (comment uniE207)
   (CHARWD R 0.603)
   (CHARHT R 0.669)
   (CHARDP R 0.014)
   (CHARIC R 0.086)
   )
(CHARACTER O 113 (comment uniE208)
   (CHARWD R 0.766)
   (CHARHT R 0.669)
   )
(CHARACTER O 114 (comment uniE209)
   (CHARWD R 0.613)
   (CHARHT R 0.669)
   )
(CHARACTER O 115 (comment uniE20A)
   (CHARWD R 0.912)
   (CHARHT R 0.669)
   (CHARIC R 0.076)
   )
(CHARACTER O 116 (comment uni2115.bi)
   (CHARWD R 0.76)
   (CHARHT R 0.669)
   (CHARIC R 0.068)
   )
(CHARACTER O 117 (comment uniE20B)
   (CHARWD R 0.749)
   (CHARHT R 0.685)
   (CHARDP R 0.014)
   )
(CHARACTER O 120 (comment uni2119.bi)
   (CHARWD R 0.497)
   (CHARHT R 0.669)
   (CHARIC R 0.263)
   )
(CHARACTER O 121 (comment uni211A.bi)
   (CHARWD R 0.754)
   (CHARHT R 0.685)
   (CHARDP R 0.074)
   )
(CHARACTER O 122 (comment uni211D.bi)
   (CHARWD R 0.727)
   (CHARHT R 0.669)
   )
(CHARACTER O 123 (comment uniE20C)
   (CHARWD R 0.686)
   (CHARHT R 0.685)
   (CHARDP R 0.014)
   (CHARIC R 0.07)
   )
(CHARACTER O 124 (comment uniE20D)
   (CHARWD R 0.445)
   (CHARHT R 0.669)
   (CHARIC R 0.253)
   )
(CHARACTER O 125 (comment uniE20E)
   (CHARWD R 0.709)
   (CHARHT R 0.669)
   (CHARDP R 0.014)
   (CHARIC R 0.091)
   )
(CHARACTER O 126 (comment uniE20F)
   (CHARWD R 0.504)
   (CHARHT R 0.669)
   (CHARIC R 0.246)
   )
(CHARACTER O 127 (comment uniE210)
   (CHARWD R 0.891)
   (CHARHT R 0.669)
   (CHARIC R 0.145)
   )
(CHARACTER O 130 (comment uniE211)
   (CHARWD R 0.759)
   (CHARHT R 0.669)
   (CHARIC R 0.118)
   )
(CHARACTER O 131 (comment uniE212)
   (CHARWD R 0.462)
   (CHARHT R 0.669)
   (CHARIC R 0.297)
   )
(CHARACTER O 132 (comment uni2124.bi)
   (CHARWD R 0.807)
   (CHARHT R 0.669)
   (CHARIC R 0.075)
   )
(CHARACTER O 141 (comment uniE213)
   (CHARWD R 0.634)
   (CHARHT R 0.462)
   (CHARDP R 0.013)
   )
(CHARACTER O 142 (comment uniE214)
   (CHARWD R 0.661)
   (CHARHT R 0.699)
   (CHARDP R 0.013)
   )
(CHARACTER O 143 (comment uniE215)
   (CHARWD R 0.571)
   (CHARHT R 0.462)
   (CHARDP R 0.013)
   )
(CHARACTER O 144 (comment uni2146)
   (CHARWD R 0.633)
   (CHARHT R 0.699)
   (CHARDP R 0.013)
   (CHARIC R 0.08)
   )
(CHARACTER O 145 (comment uni2147)
   (CHARWD R 0.575)
   (CHARHT R 0.462)
   (CHARDP R 0.013)
   )
(CHARACTER O 146 (comment uniE218)
   (CHARWD R 0.438)
   (CHARHT R 0.699)
   (CHARIC R 0.225)
   )
(CHARACTER O 147 (comment uniE219)
   (CHARWD R 0.666)
   (CHARHT R 0.462)
   (CHARDP R 0.205)
   )
(CHARACTER O 150 (comment uniE21A)
   (CHARWD R 0.661)
   (CHARHT R 0.699)
   )
(CHARACTER O 151 (comment uni2148)
   (CHARWD R 0.379)
   (CHARHT R 0.669)
   (CHARIC R 0.08)
   )
(CHARACTER O 152 (comment uni2149)
   (CHARWD R 0.421)
   (CHARHT R 0.669)
   (CHARDP R 0.205)
   (CHARIC R 0.08)
   )
(CHARACTER O 153 (comment uniE21D)
   (CHARWD R 0.641)
   (CHARHT R 0.699)
   )
(CHARACTER O 154 (comment uniE21E)
   (CHARWD R 0.372)
   (CHARHT R 0.699)
   (CHARIC R 0.086)
   )
(CHARACTER O 155 (comment uniE21F)
   (CHARWD R 0.942)
   (CHARHT R 0.462)
   )
(CHARACTER O 156 (comment uniE220)
   (CHARWD R 0.661)
   (CHARHT R 0.462)
   )
(CHARACTER O 157 (comment uniE221)
   (CHARWD R 0.586)
   (CHARHT R 0.462)
   (CHARDP R 0.013)
   )
(CHARACTER O 160 (comment uniE222)
   (CHARWD R 0.68)
   (CHARHT R 0.462)
   (CHARDP R 0.205)
   )
(CHARACTER O 161 (comment uniE223)
   (CHARWD R 0.662)
   (CHARHT R 0.462)
   (CHARDP R 0.205)
   )
(CHARACTER O 162 (comment uniE224)
   (CHARWD R 0.403)
   (CHARHT R 0.462)
   (CHARIC R 0.18)
   )
(CHARACTER O 163 (comment uniE225)
   (CHARWD R 0.533)
   (CHARHT R 0.462)
   (CHARDP R 0.013)
   )
(CHARACTER O 164 (comment uniE226)
   (CHARWD R 0.403)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   (CHARIC R 0.064)
   )
(CHARACTER O 165 (comment uniE227)
   (CHARWD R 0.661)
   (CHARHT R 0.449)
   (CHARDP R 0.013)
   )
(CHARACTER O 166 (comment uniE228)
   (CHARWD R 0.477)
   (CHARHT R 0.449)
   (CHARIC R 0.102)
   )
(CHARACTER O 167 (comment uniE229)
   (CHARWD R 0.733)
   (CHARHT R 0.449)
   (CHARIC R 0.075)
   )
(CHARACTER O 170 (comment uniE22A)
   (CHARWD R 0.562)
   (CHARHT R 0.449)
   (CHARIC R 0.072)
   )
(CHARACTER O 171 (comment uniE22B)
   (CHARWD R 0.584)
   (CHARHT R 0.449)
   (CHARDP R 0.205)
   (CHARIC R 0.104)
   )
(CHARACTER O 172 (comment uniE22C)
   (CHARWD R 0.619)
   (CHARHT R 0.449)
   )
(CHARACTER O 173 (comment uni2148.dtls)
   (CHARWD R 0.379)
   (CHARHT R 0.449)
   (CHARIC R 0.08)
   )
(CHARACTER O 174 (comment uni2149.dtls)
   (CHARWD R 0.421)
   (CHARHT R 0.449)
   (CHARDP R 0.205)
   (CHARIC R 0.08)
   )
(CHARACTER O 175 (comment sterling)
   (CHARWD R 0.5)
   (CHARHT R 0.683)
   (CHARDP R 0.012)
   )
(CHARACTER O 177 (comment uni2040)
   (CHARWD R 0.798)
   (CHARHT R 0.7)
   )
(CHARACTER O 200 (comment uni0300)
   (CHARWD R 0.238)
   (CHARHT R 0.7)
   )
(CHARACTER O 201 (comment uni0301)
   (CHARWD R 0.238)
   (CHARHT R 0.7)
   )
(CHARACTER O 202 (comment uni0302)
   (CHARWD R 0.337)
   (CHARHT R 0.7)
   )
(CHARACTER O 203 (comment uni0303)
   (CHARWD R 0.365)
   (CHARHT R 0.7)
   )
(CHARACTER O 204 (comment uni0304)
   (CHARWD R 0.33)
   (CHARHT R 0.6)
   )
(CHARACTER O 205 (comment uni0306)
   (CHARWD R 0.303)
   (CHARHT R 0.7)
   )
(CHARACTER O 206 (comment uni0307)
   (CHARWD R 0.129)
   (CHARHT R 0.7)
   )
(CHARACTER O 207 (comment uni0308)
   (CHARWD R 0.339)
   (CHARHT R 0.7)
   )
(CHARACTER O 210 (comment uni0309)
   (CHARWD R 0.205)
   (CHARHT R 0.8)
   )
(CHARACTER O 211 (comment uni030A)
   (CHARWD R 0.213)
   (CHARHT R 0.8)
   )
(CHARACTER O 212 (comment uni030C)
   (CHARWD R 0.337)
   (CHARHT R 0.7)
   )
(CHARACTER O 213 (comment uni0310)
   (CHARWD R 0.303)
   (CHARHT R 0.8)
   )
(CHARACTER O 214 (comment uni0312)
   (CHARWD R 0.184)
   (CHARHT R 0.9)
   )
(CHARACTER O 215 (comment uni0315)
   (CHARWD R 0.184)
   (CHARHT R 0.9)
   )
(CHARACTER O 216 (comment uni031A)
   (CHARWD R 0.317)
   (CHARHT R 0.8)
   )
(CHARACTER O 217 (comment uni20D0)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 220 (comment uni20D1)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 221 (comment uni20D6)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 222 (comment uni20D7)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 223 (comment uni20DB)
   (CHARWD R 0.549)
   (CHARHT R 0.7)
   )
(CHARACTER O 224 (comment uni20DC)
   (CHARWD R 0.759)
   (CHARHT R 0.7)
   )
(CHARACTER O 225 (comment uni20E1)
   (CHARWD R 0.594)
   (CHARHT R 0.8)
   )
(CHARACTER O 226 (comment uni20E7)
   (CHARWD R 0.843)
   (CHARHT R 0.8)
   (CHARDP R 0.2)
   )
(CHARACTER O 227 (comment uni20E9)
   (CHARWD R 0.564)
   (CHARHT R 0.7)
   )
(CHARACTER O 230 (comment uni20F0)
   (CHARWD R 0.27)
   (CHARHT R 0.8)
   )
(CHARACTER O 231 (comment uni2ACB)
   (CHARWD R 0.685)
   (CHARHT R 0.717)
   (CHARDP R 0.319)
   )
(CHARACTER O 232 (comment uni2ACC)
   (CHARWD R 0.685)
   (CHARHT R 0.717)
   (CHARDP R 0.319)
   )
(CHARACTER O 233 (comment uni2ACD)
   (CHARWD R 1.352)
   (CHARHT R 0.558)
   (CHARDP R 0.053)
   )
(CHARACTER O 234 (comment uni2ACE)
   (CHARWD R 1.352)
   (CHARHT R 0.558)
   (CHARDP R 0.053)
   )
(CHARACTER O 235 (comment uni2ACF)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 236 (comment uni2AD0)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 237 (comment uni2AD1)
   (CHARWD R 0.685)
   (CHARHT R 0.609)
   (CHARDP R 0.103)
   )
(CHARACTER O 240 (comment uni2AD2)
   (CHARWD R 0.685)
   (CHARHT R 0.609)
   (CHARDP R 0.103)
   )
(CHARACTER O 241 (comment uni2AD3)
   (CHARWD R 0.685)
   (CHARHT R 0.715)
   (CHARDP R 0.209)
   )
(CHARACTER O 242 (comment uni2AD4)
   (CHARWD R 0.685)
   (CHARHT R 0.715)
   (CHARDP R 0.209)
   )
(CHARACTER O 243 (comment uni2AD5)
   (CHARWD R 0.685)
   (CHARHT R 0.715)
   (CHARDP R 0.209)
   )
(CHARACTER O 244 (comment uni2AD6)
   (CHARWD R 0.685)
   (CHARHT R 0.715)
   (CHARDP R 0.209)
   )
(CHARACTER O 245 (comment uni2AD7)
   (CHARWD R 1.25)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 246 (comment uni2AD8)
   (CHARWD R 1.25)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 247 (comment uni2AD9)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 250 (comment uni2ADA)
   (CHARWD R 0.62)
   (CHARHT R 0.697)
   (CHARDP R 0.128)
   )
(CHARACTER O 251 (comment uni2ADB)
   (CHARWD R 0.62)
   (CHARHT R 0.695)
   (CHARDP R 0.097)
   )
(CHARACTER O 252 (comment uni2ADC)
   (CHARWD R 0.62)
   (CHARHT R 0.557)
   (CHARDP R 0.01)
   )
(CHARACTER O 253 (comment uni2ADD)
   (CHARWD R 0.62)
   (CHARHT R 0.557)
   (CHARDP R 0.01)
   )
(CHARACTER O 254 (comment uni2ADE)
   (CHARWD R 0.497)
   (CHARHT R 0.662)
   )
(CHARACTER O 255 (comment uni2ADF)
   (CHARWD R 0.685)
   (CHARHT R 0.371)
   )
(CHARACTER O 256 (comment uni2AE0)
   (CHARWD R 0.685)
   (CHARHT R 0.371)
   )
(CHARACTER O 257 (comment uni2AE1)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   )
(CHARACTER O 260 (comment uni2AE2)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   )
(CHARACTER O 261 (comment uni2AE3)
   (CHARWD R 0.86)
   (CHARHT R 0.662)
   )
(CHARACTER O 262 (comment uni2AE4)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   )
(CHARACTER O 263 (comment uni2AE5)
   (CHARWD R 0.86)
   (CHARHT R 0.662)
   )
(CHARACTER O 264 (comment uni2AE6)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   )
(CHARACTER O 265 (comment uni2AE7)
   (CHARWD R 0.685)
   (CHARHT R 0.571)
   )
(CHARACTER O 266 (comment uni2AE8)
   (CHARWD R 0.685)
   (CHARHT R 0.571)
   )
(CHARACTER O 267 (comment uni2AE9)
   (CHARWD R 0.685)
   (CHARHT R 0.691)
   (CHARDP R 0.185)
   )
(CHARACTER O 270 (comment uni2AEA)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   )
(CHARACTER O 271 (comment uni2AEB)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   )
(CHARACTER O 272 (comment uni2AEC)
   (CHARWD R 0.6)
   (CHARHT R 0.489)
   )
(CHARACTER O 273 (comment uni2AED)
   (CHARWD R 0.6)
   (CHARHT R 0.489)
   )
(CHARACTER O 274 (comment uni2AEE)
   (CHARWD R 0.404)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 275 (comment uni2AEF)
   (CHARWD R 0.502)
   (CHARHT R 0.66)
   (CHARDP R 0.154)
   )
(CHARACTER O 276 (comment uni2AF0)
   (CHARWD R 0.502)
   (CHARHT R 0.66)
   (CHARDP R 0.154)
   )
(CHARACTER O 277 (comment uni2AF1)
   (CHARWD R 0.502)
   (CHARHT R 0.693)
   (CHARDP R 0.187)
   )
(CHARACTER O 300 (comment uni2AF2)
   (CHARWD R 0.523)
   (CHARHT R 0.695)
   (CHARDP R 0.189)
   )
(CHARACTER O 301 (comment uni2AF3)
   (CHARWD R 0.685)
   (CHARHT R 0.695)
   (CHARDP R 0.189)
   )
(CHARACTER O 302 (comment uni2AF4)
   (CHARWD R 0.685)
   (CHARHT R 0.695)
   (CHARDP R 0.189)
   )
(CHARACTER O 303 (comment uni2AF5)
   (CHARWD R 0.685)
   (CHARHT R 0.695)
   (CHARDP R 0.189)
   )
(CHARACTER O 304 (comment uni2AF6)
   (CHARWD R 0.685)
   (CHARHT R 0.608)
   (CHARDP R 0.102)
   )
(CHARACTER O 305 (comment uni2AF7)
   (CHARWD R 1.17)
   (CHARHT R 0.661)
   (CHARDP R 0.155)
   )
(CHARACTER O 306 (comment uni2AF8)
   (CHARWD R 1.17)
   (CHARHT R 0.661)
   (CHARDP R 0.155)
   )
(CHARACTER O 307 (comment uni2AF9)
   (CHARWD R 0.685)
   (CHARHT R 0.726)
   (CHARDP R 0.22)
   )
(CHARACTER O 310 (comment uni2AFA)
   (CHARWD R 0.685)
   (CHARHT R 0.726)
   (CHARDP R 0.22)
   )
(CHARACTER O 311 (comment uni2AFB)
   (CHARWD R 0.894)
   (CHARHT R 0.71)
   (CHARDP R 0.222)
   )
(CHARACTER O 312 (comment uni2AFC)
   (CHARWD R 0.654)
   (CHARHT R 0.763)
   (CHARDP R 0.259)
   )
(CHARACTER O 313 (comment uni2AFD)
   (CHARWD R 0.709)
   (CHARHT R 0.71)
   (CHARDP R 0.222)
   )
(CHARACTER O 314 (comment uni2AFE)
   (CHARWD R 0.41)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 315 (comment uni2B12)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 316 (comment uni2B13)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 317 (comment uni2B14)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 320 (comment uni2B15)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 321 (comment uni2B16)
   (CHARWD R 1.064)
   (CHARHT R 0.744)
   (CHARDP R 0.242)
   )
(CHARACTER O 322 (comment uni2B17)
   (CHARWD R 1.064)
   (CHARHT R 0.744)
   (CHARDP R 0.242)
   )
(CHARACTER O 323 (comment uni2B18)
   (CHARWD R 1.064)
   (CHARHT R 0.744)
   (CHARDP R 0.242)
   )
(CHARACTER O 324 (comment uni2B19)
   (CHARWD R 1.064)
   (CHARHT R 0.744)
   (CHARDP R 0.242)
   )
(CHARACTER O 325 (comment uni2B1A)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 326 (comment uni2B1B)
   (CHARWD R 1.04)
   (CHARHT R 0.78)
   (CHARDP R 0.18)
   )
(CHARACTER O 327 (comment uni2B1C)
   (CHARWD R 1.04)
   (CHARHT R 0.78)
   (CHARDP R 0.18)
   )
(CHARACTER O 330 (comment uni2B1D)
   (CHARWD R 0.24)
   (CHARHT R 0.332)
   )
(CHARACTER O 331 (comment uni2B1E)
   (CHARWD R 0.24)
   (CHARHT R 0.332)
   )
(CHARACTER O 332 (comment uni2B1F)
   (CHARWD R 0.91)
   (CHARHT R 0.69)
   (CHARDP R 0.105)
   )
(CHARACTER O 333 (comment uni2B20)
   (CHARWD R 0.91)
   (CHARHT R 0.69)
   (CHARDP R 0.105)
   )
(CHARACTER O 334 (comment uni2B21)
   (CHARWD R 0.91)
   (CHARHT R 0.68)
   (CHARDP R 0.178)
   )
(CHARACTER O 335 (comment uni2B22)
   (CHARWD R 0.91)
   (CHARHT R 0.68)
   (CHARDP R 0.178)
   )
(CHARACTER O 336 (comment uni2B23)
   (CHARWD R 0.926)
   (CHARHT R 0.633)
   (CHARDP R 0.127)
   )
(CHARACTER O 337 (comment uni2B24)
   (CHARWD R 1.207)
   (CHARHT R 0.785)
   (CHARDP R 0.282)
   )
(CHARACTER O 340 (comment uni2B25)
   (CHARWD R 0.779)
   (CHARHT R 0.581)
   (CHARDP R 0.096)
   )
(CHARACTER O 341 (comment uni2B26)
   (CHARWD R 0.779)
   (CHARHT R 0.581)
   (CHARDP R 0.096)
   )
(CHARACTER O 342 (comment uni2B27)
   (CHARWD R 0.544)
   (CHARHT R 0.609)
   (CHARDP R 0.105)
   )
(CHARACTER O 343 (comment uni2B28)
   (CHARWD R 0.544)
   (CHARHT R 0.609)
   (CHARDP R 0.105)
   )
(CHARACTER O 344 (comment uni2B29)
   (CHARWD R 0.523)
   (CHARHT R 0.488)
   )
(CHARACTER O 345 (comment uni2B2A)
   (CHARWD R 0.357)
   (CHARHT R 0.488)
   )
(CHARACTER O 346 (comment uni2B2B)
   (CHARWD R 0.357)
   (CHARHT R 0.488)
   )
(CHARACTER O 347 (comment uni2B2C)
   (CHARWD R 0.842)
   (CHARHT R 0.5)
   )
(CHARACTER O 350 (comment uni2B2D)
   (CHARWD R 0.842)
   (CHARHT R 0.5)
   )
(CHARACTER O 351 (comment uni2B2E)
   (CHARWD R 0.596)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 352 (comment uni2B2F)
   (CHARWD R 0.596)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 353 (comment uni2B50)
   (CHARWD R 0.794)
   (CHARHT R 0.619)
   (CHARDP R 0.03)
   )
(CHARACTER O 354 (comment uni2B51)
   (CHARWD R 0.794)
   (CHARHT R 0.619)
   (CHARDP R 0.03)
   )
(CHARACTER O 355 (comment uni2B52)
   (CHARWD R 0.7)
   (CHARHT R 0.597)
   (CHARDP R 0.013)
   )
(CHARACTER O 356 (comment uni2B53)
   (CHARWD R 0.865)
   (CHARHT R 0.712)
   (CHARDP R 0.126)
   )
(CHARACTER O 357 (comment uni2B54)
   (CHARWD R 0.865)
   (CHARHT R 0.712)
   (CHARDP R 0.127)
   )
(CHARACTER O 360 (comment uni3012)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   )
(CHARACTER O 361 (comment uni3030)
   (CHARWD R 1.412)
   (CHARHT R 0.417)
   )
(CHARACTER O 362 (comment uni23B6)
   (CHARWD R 0.926)
   (CHARHT R 0.495)
   )
(CHARACTER O 363 (comment uni23E0)
   (CHARWD R 1)
   (CHARHT R 0.1)
   (CHARDP R 0.114)
   )
(CHARACTER O 364 (comment uni23E1)
   (CHARWD R 1)
   (CHARHT R 0.778)
   )
(CHARACTER O 365 (comment uni2609)
   (CHARWD R 0.762)
   (CHARHT R 0.583)
   (CHARDP R 0.079)
   )
(CHARACTER O 366 (comment uni2621)
   (CHARWD R 0.619)
   (CHARHT R 0.63)
   (CHARDP R 0.035)
   )
(CHARACTER O 367 (comment uni263B)
   (CHARWD R 1.15)
   (CHARHT R 0.728)
   (CHARDP R 0.082)
   )
(CHARACTER O 370 (comment uni263C)
   (CHARWD R 0.837)
   (CHARHT R 0.623)
   (CHARDP R 0.122)
   )
(CHARACTER O 371 (comment uni263D)
   (CHARWD R 0.641)
   (CHARHT R 0.728)
   (CHARDP R 0.082)
   )
(CHARACTER O 372 (comment uni263E)
   (CHARWD R 0.641)
   (CHARHT R 0.728)
   (CHARDP R 0.082)
   )
(CHARACTER O 373 (comment uni2640)
   (CHARWD R 0.603)
   (CHARHT R 0.638)
   (CHARDP R 0.135)
   )
(CHARACTER O 374 (comment uni2642)
   (CHARWD R 0.66)
   (CHARHT R 0.634)
   (CHARDP R 0.131)
   )
(CHARACTER O 375 (comment uni2664)
   (CHARWD R 0.685)
   (CHARHT R 0.609)
   (CHARDP R 0.099)
   )
(CHARACTER O 376 (comment uni2665)
   (CHARWD R 0.685)
   (CHARHT R 0.603)
   (CHARDP R 0.105)
   )
(CHARACTER O 377 (comment uni2666)
   (CHARWD R 0.685)
   (CHARHT R 0.609)
   (CHARDP R 0.105)
   )
