(FAMILY STIXMathBlackboard)
(CODINGSCHEME STIXMATHBB)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   )
(LIGTABLE
   (LABEL O 173) (comment u1D55A.dtls)
   (KRN O 177 R -0.036) (comment uni2040)
   (STOP)
   (LABEL O 174) (comment u1D55B.dtls)
   (KRN O 177 R -0.0035) (comment uni2040)
   (STOP)
   )
(CHARACTER O 0 (comment uni213E)
   (CHARWD R 0.497)
   (CHARHT R 0.676)
   (CHARIC R 0.13)
   )
(CHARACTER O 5 (comment uni213F)
   (CHARWD R 0.768)
   (CHARHT R 0.676)
   )
(CHARACTER O 15 (comment uni213D)
   (CHARWD R 0.646)
   (CHARHT R 0.486)
   (CHARDP R 0.203)
   )
(CHARACTER O 31 (comment uni213C)
   (CHARWD R 0.804)
   (CHARHT R 0.461)
   (CHARDP R 0.011)
   )
(CHARACTER O 46 (comment uni2AB2)
   (CHARWD R 0.685)
   (CHARHT R 0.628)
   (CHARDP R 0.216)
   )
(CHARACTER O 47 (comment uni2AB3)
   (CHARWD R 0.685)
   (CHARHT R 0.717)
   (CHARDP R 0.211)
   )
(CHARACTER O 50 (comment uni2AB4)
   (CHARWD R 0.685)
   (CHARHT R 0.717)
   (CHARDP R 0.211)
   )
(CHARACTER O 51 (comment uni2AB5)
   (CHARWD R 0.685)
   (CHARHT R 0.747)
   (CHARDP R 0.26)
   )
(CHARACTER O 52 (comment uni2AB6)
   (CHARWD R 0.685)
   (CHARHT R 0.747)
   (CHARDP R 0.26)
   )
(CHARACTER O 53 (comment uni2AB7)
   (CHARWD R 0.685)
   (CHARHT R 0.747)
   (CHARDP R 0.275)
   )
(CHARACTER O 54 (comment uni2AB8)
   (CHARWD R 0.685)
   (CHARHT R 0.747)
   (CHARDP R 0.275)
   )
(CHARACTER O 55 (comment uni2AB9)
   (CHARWD R 0.685)
   (CHARHT R 0.747)
   (CHARDP R 0.309)
   )
(CHARACTER O 56 (comment uni2ABA)
   (CHARWD R 0.685)
   (CHARHT R 0.747)
   (CHARDP R 0.309)
   )
(CHARACTER O 57 (comment uni2ABB)
   (CHARWD R 0.933)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 60 (comment u1D7D8)
   (CHARWD R 0.54)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 61 (comment u1D7D9)
   (CHARWD R 0.54)
   (CHARHT R 0.693)
   )
(CHARACTER O 62 (comment u1D7DA)
   (CHARWD R 0.547)
   (CHARHT R 0.676)
   )
(CHARACTER O 63 (comment u1D7DB)
   (CHARWD R 0.54)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 64 (comment u1D7DC)
   (CHARWD R 0.54)
   (CHARHT R 0.676)
   )
(CHARACTER O 65 (comment u1D7DD)
   (CHARWD R 0.54)
   (CHARHT R 0.662)
   (CHARDP R 0.014)
   )
(CHARACTER O 66 (comment u1D7DE)
   (CHARWD R 0.54)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 67 (comment u1D7DF)
   (CHARWD R 0.54)
   (CHARHT R 0.662)
   )
(CHARACTER O 70 (comment u1D7E0)
   (CHARWD R 0.54)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 71 (comment u1D7E1)
   (CHARWD R 0.54)
   (CHARHT R 0.676)
   (CHARDP R 0.012)
   )
(CHARACTER O 72 (comment uni2ABC)
   (CHARWD R 0.933)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 73 (comment uni2ABD)
   (CHARWD R 0.75)
   (CHARHT R 0.547)
   (CHARDP R 0.013)
   )
(CHARACTER O 74 (comment uni2ABE)
   (CHARWD R 0.75)
   (CHARHT R 0.547)
   (CHARDP R 0.013)
   )
(CHARACTER O 75 (comment uni2ABF)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.103)
   )
(CHARACTER O 76 (comment uni2AC0)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.103)
   )
(CHARACTER O 77 (comment uni2AC1)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.103)
   )
(CHARACTER O 100 (comment uni2AC2)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.103)
   )
(CHARACTER O 101 (comment u1D538)
   (CHARWD R 0.787)
   (CHARHT R 0.676)
   )
(CHARACTER O 102 (comment u1D539)
   (CHARWD R 0.729)
   (CHARHT R 0.676)
   )
(CHARACTER O 103 (comment uni2102)
   (CHARWD R 0.727)
   (CHARHT R 0.691)
   (CHARDP R 0.019)
   )
(CHARACTER O 104 (comment u1D53B)
   (CHARWD R 0.748)
   (CHARHT R 0.676)
   )
(CHARACTER O 105 (comment u1D53C)
   (CHARWD R 0.65)
   (CHARHT R 0.676)
   )
(CHARACTER O 106 (comment u1D53D)
   (CHARWD R 0.474)
   (CHARHT R 0.676)
   (CHARIC R 0.14)
   )
(CHARACTER O 107 (comment u1D53E)
   (CHARWD R 0.751)
   (CHARHT R 0.691)
   (CHARDP R 0.019)
   )
(CHARACTER O 110 (comment uni210D)
   (CHARWD R 0.768)
   (CHARHT R 0.676)
   )
(CHARACTER O 111 (comment u1D540)
   (CHARWD R 0.38)
   (CHARHT R 0.676)
   )
(CHARACTER O 112 (comment u1D541)
   (CHARWD R 0.618)
   (CHARHT R 0.676)
   (CHARDP R 0.019)
   )
(CHARACTER O 113 (comment u1D542)
   (CHARWD R 0.792)
   (CHARHT R 0.676)
   )
(CHARACTER O 114 (comment u1D543)
   (CHARWD R 0.662)
   (CHARHT R 0.676)
   )
(CHARACTER O 115 (comment u1D544)
   (CHARWD R 0.914)
   (CHARHT R 0.676)
   )
(CHARACTER O 116 (comment uni2115)
   (CHARWD R 0.738)
   (CHARHT R 0.676)
   )
(CHARACTER O 117 (comment u1D546)
   (CHARWD R 0.787)
   (CHARHT R 0.691)
   (CHARDP R 0.019)
   )
(CHARACTER O 120 (comment uni2119)
   (CHARWD R 0.7)
   (CHARHT R 0.676)
   )
(CHARACTER O 121 (comment uni211A)
   (CHARWD R 0.797)
   (CHARHT R 0.691)
   (CHARDP R 0.064)
   )
(CHARACTER O 122 (comment uni211D)
   (CHARWD R 0.783)
   (CHARHT R 0.676)
   )
(CHARACTER O 123 (comment u1D54A)
   (CHARWD R 0.702)
   (CHARHT R 0.692)
   (CHARDP R 0.019)
   )
(CHARACTER O 124 (comment u1D54B)
   (CHARWD R 0.556)
   (CHARHT R 0.676)
   (CHARIC R 0.14)
   )
(CHARACTER O 125 (comment u1D54C)
   (CHARWD R 0.738)
   (CHARHT R 0.676)
   (CHARDP R 0.019)
   )
(CHARACTER O 126 (comment u1D54D)
   (CHARWD R 0.627)
   (CHARHT R 0.676)
   (CHARIC R 0.13)
   )
(CHARACTER O 127 (comment u1D54E)
   (CHARWD R 0.996)
   (CHARHT R 0.676)
   (CHARIC R 0.06)
   )
(CHARACTER O 130 (comment u1D54F)
   (CHARWD R 0.794)
   (CHARHT R 0.676)
   )
(CHARACTER O 131 (comment u1D550)
   (CHARWD R 0.652)
   (CHARHT R 0.676)
   (CHARIC R 0.15)
   )
(CHARACTER O 132 (comment uni2124)
   (CHARWD R 0.777)
   (CHARHT R 0.691)
   )
(CHARACTER O 133 (comment uni2AC3)
   (CHARWD R 0.685)
   (CHARHT R 0.709)
   (CHARDP R 0.103)
   )
(CHARACTER O 134 (comment uni2AC4)
   (CHARWD R 0.685)
   (CHARHT R 0.709)
   (CHARDP R 0.103)
   )
(CHARACTER O 135 (comment uni2AC5)
   (CHARWD R 0.75)
   (CHARHT R 0.73)
   (CHARDP R 0.222)
   )
(CHARACTER O 136 (comment uni2AC6)
   (CHARWD R 0.75)
   (CHARHT R 0.73)
   (CHARDP R 0.222)
   )
(CHARACTER O 137 (comment uni2AC7)
   (CHARWD R 0.685)
   (CHARHT R 0.665)
   (CHARDP R 0.164)
   )
(CHARACTER O 140 (comment uni2AC8)
   (CHARWD R 0.685)
   (CHARHT R 0.665)
   (CHARDP R 0.164)
   )
(CHARACTER O 141 (comment u1D552)
   (CHARWD R 0.623)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 142 (comment u1D553)
   (CHARWD R 0.643)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 143 (comment u1D554)
   (CHARWD R 0.574)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 144 (comment u1D555)
   (CHARWD R 0.643)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 145 (comment u1D556)
   (CHARWD R 0.573)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 146 (comment u1D557)
   (CHARWD R 0.474)
   (CHARHT R 0.676)
   (CHARIC R 0.105)
   )
(CHARACTER O 147 (comment u1D558)
   (CHARWD R 0.643)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 150 (comment u1D559)
   (CHARWD R 0.624)
   (CHARHT R 0.676)
   )
(CHARACTER O 151 (comment u1D55A)
   (CHARWD R 0.33)
   (CHARHT R 0.691)
   )
(CHARACTER O 152 (comment u1D55B)
   (CHARWD R 0.371)
   (CHARHT R 0.691)
   (CHARDP R 0.205)
   )
(CHARACTER O 153 (comment u1D55C)
   (CHARWD R 0.646)
   (CHARHT R 0.676)
   )
(CHARACTER O 154 (comment u1D55D)
   (CHARWD R 0.325)
   (CHARHT R 0.676)
   )
(CHARACTER O 155 (comment u1D55E)
   (CHARWD R 0.908)
   (CHARHT R 0.473)
   )
(CHARACTER O 156 (comment u1D55F)
   (CHARWD R 0.624)
   (CHARHT R 0.473)
   )
(CHARACTER O 157 (comment u1D560)
   (CHARWD R 0.598)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 160 (comment u1D561)
   (CHARWD R 0.643)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 161 (comment u1D562)
   (CHARWD R 0.643)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 162 (comment u1D563)
   (CHARWD R 0.339)
   (CHARHT R 0.473)
   (CHARIC R 0.145)
   )
(CHARACTER O 163 (comment u1D564)
   (CHARWD R 0.549)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 164 (comment u1D565)
   (CHARWD R 0.446)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 165 (comment u1D566)
   (CHARWD R 0.619)
   (CHARHT R 0.461)
   (CHARDP R 0.016)
   )
(CHARACTER O 166 (comment u1D567)
   (CHARWD R 0.494)
   (CHARHT R 0.461)
   (CHARIC R 0.07)
   )
(CHARACTER O 167 (comment u1D568)
   (CHARWD R 0.786)
   (CHARHT R 0.461)
   (CHARIC R 0.06)
   )
(CHARACTER O 170 (comment u1D569)
   (CHARWD R 0.66)
   (CHARHT R 0.461)
   )
(CHARACTER O 171 (comment u1D56A)
   (CHARWD R 0.471)
   (CHARHT R 0.461)
   (CHARDP R 0.205)
   (CHARIC R 0.08)
   )
(CHARACTER O 172 (comment u1D56B)
   (CHARWD R 0.513)
   (CHARHT R 0.461)
   )
(CHARACTER O 173 (comment u1D55A.dtls)
   (CHARWD R 0.33)
   (CHARHT R 0.461)
   )
(CHARACTER O 174 (comment u1D55B.dtls)
   (CHARWD R 0.371)
   (CHARHT R 0.461)
   (CHARDP R 0.205)
   )
(CHARACTER O 175 (comment uni2AC9)
   (CHARWD R 0.685)
   (CHARHT R 0.746)
   (CHARDP R 0.274)
   )
(CHARACTER O 176 (comment uni2ACA)
   (CHARWD R 0.685)
   (CHARHT R 0.746)
   (CHARDP R 0.274)
   )
(CHARACTER O 177 (comment uni2040)
   (CHARWD R 0.798)
   (CHARHT R 0.7)
   )
(CHARACTER O 200 (comment uni0300)
   (CHARWD R 0.238)
   (CHARHT R 0.7)
   )
(CHARACTER O 201 (comment uni0301)
   (CHARWD R 0.238)
   (CHARHT R 0.7)
   )
(CHARACTER O 202 (comment uni0302)
   (CHARWD R 0.337)
   (CHARHT R 0.7)
   )
(CHARACTER O 203 (comment uni0303)
   (CHARWD R 0.365)
   (CHARHT R 0.7)
   )
(CHARACTER O 204 (comment uni0304)
   (CHARWD R 0.33)
   (CHARHT R 0.6)
   )
(CHARACTER O 205 (comment uni0306)
   (CHARWD R 0.303)
   (CHARHT R 0.7)
   )
(CHARACTER O 206 (comment uni0307)
   (CHARWD R 0.129)
   (CHARHT R 0.7)
   )
(CHARACTER O 207 (comment uni0308)
   (CHARWD R 0.339)
   (CHARHT R 0.7)
   )
(CHARACTER O 210 (comment uni0309)
   (CHARWD R 0.205)
   (CHARHT R 0.8)
   )
(CHARACTER O 211 (comment uni030A)
   (CHARWD R 0.213)
   (CHARHT R 0.8)
   )
(CHARACTER O 212 (comment uni030C)
   (CHARWD R 0.337)
   (CHARHT R 0.7)
   )
(CHARACTER O 213 (comment uni0310)
   (CHARWD R 0.303)
   (CHARHT R 0.8)
   )
(CHARACTER O 214 (comment uni0312)
   (CHARWD R 0.184)
   (CHARHT R 0.9)
   )
(CHARACTER O 215 (comment uni0315)
   (CHARWD R 0.184)
   (CHARHT R 0.9)
   )
(CHARACTER O 216 (comment uni031A)
   (CHARWD R 0.317)
   (CHARHT R 0.8)
   )
(CHARACTER O 217 (comment uni20D0)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 220 (comment uni20D1)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 221 (comment uni20D6)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 222 (comment uni20D7)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 223 (comment uni20DB)
   (CHARWD R 0.549)
   (CHARHT R 0.7)
   )
(CHARACTER O 224 (comment uni20DC)
   (CHARWD R 0.759)
   (CHARHT R 0.7)
   )
(CHARACTER O 225 (comment uni20E1)
   (CHARWD R 0.594)
   (CHARHT R 0.8)
   )
(CHARACTER O 226 (comment uni20E7)
   (CHARWD R 0.843)
   (CHARHT R 0.8)
   (CHARDP R 0.2)
   )
(CHARACTER O 227 (comment uni20E9)
   (CHARWD R 0.564)
   (CHARHT R 0.7)
   )
(CHARACTER O 230 (comment uni20F0)
   (CHARWD R 0.27)
   (CHARHT R 0.8)
   )
(CHARACTER O 231 (comment uni2A49)
   (CHARWD R 0.62)
   (CHARHT R 0.914)
   (CHARDP R 0.406)
   )
(CHARACTER O 232 (comment uni2A4A)
   (CHARWD R 1.078)
   (CHARHT R 0.528)
   (CHARDP R 0.039)
   )
(CHARACTER O 233 (comment uni2A4B)
   (CHARWD R 1.078)
   (CHARHT R 0.527)
   (CHARDP R 0.04)
   )
(CHARACTER O 234 (comment uni2A4C)
   (CHARWD R 0.62)
   (CHARHT R 0.602)
   (CHARDP R 0.031)
   )
(CHARACTER O 235 (comment uni2A4D)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.097)
   )
(CHARACTER O 236 (comment uni2A4E)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 237 (comment uni2A4F)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 240 (comment uni2A50)
   (CHARWD R 0.62)
   (CHARHT R 0.602)
   (CHARDP R 0.031)
   )
(CHARACTER O 241 (comment uni2A51)
   (CHARWD R 0.62)
   (CHARHT R 0.71)
   (CHARDP R 0.029)
   )
(CHARACTER O 242 (comment uni2A52)
   (CHARWD R 0.62)
   (CHARHT R 0.71)
   (CHARDP R 0.029)
   )
(CHARACTER O 243 (comment uni2A53)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 244 (comment uni2A54)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 245 (comment uni2A55)
   (CHARWD R 0.78)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 246 (comment uni2A56)
   (CHARWD R 0.78)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 247 (comment uni2A57)
   (CHARWD R 0.706)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 250 (comment uni2A58)
   (CHARWD R 0.706)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 251 (comment uni2A59)
   (CHARWD R 0.62)
   (CHARHT R 0.585)
   (CHARDP R 0.077)
   )
(CHARACTER O 252 (comment uni2A5A)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 253 (comment uni2A5B)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 254 (comment uni2A5C)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 255 (comment uni2A5D)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 256 (comment uni2A5E)
   (CHARWD R 0.64)
   (CHARHT R 0.887)
   (CHARDP R 0.028)
   )
(CHARACTER O 257 (comment uni2A5F)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.139)
   )
(CHARACTER O 260 (comment uni2A60)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.289)
   )
(CHARACTER O 261 (comment uni2A61)
   (CHARWD R 0.62)
   (CHARHT R 0.479)
   )
(CHARACTER O 262 (comment uni2A62)
   (CHARWD R 0.62)
   (CHARHT R 0.806)
   (CHARDP R 0.029)
   )
(CHARACTER O 263 (comment uni2A63)
   (CHARWD R 0.64)
   (CHARHT R 0.536)
   (CHARDP R 0.379)
   )
(CHARACTER O 264 (comment uni2A64)
   (CHARWD R 1.043)
   (CHARHT R 0.791)
   (CHARDP R 0.284)
   )
(CHARACTER O 265 (comment uni2A65)
   (CHARWD R 1.043)
   (CHARHT R 0.791)
   (CHARDP R 0.284)
   )
(CHARACTER O 266 (comment uni2A66)
   (CHARWD R 0.75)
   (CHARHT R 0.399)
   (CHARDP R 0.161)
   )
(CHARACTER O 267 (comment uni2A67)
   (CHARWD R 0.75)
   (CHARHT R 0.775)
   )
(CHARACTER O 270 (comment uni2A68)
   (CHARWD R 0.685)
   (CHARHT R 0.695)
   (CHARDP R 0.189)
   )
(CHARACTER O 271 (comment uni2A69)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 272 (comment uni2A6A)
   (CHARWD R 0.75)
   (CHARHT R 0.565)
   )
(CHARACTER O 273 (comment uni2A6B)
   (CHARWD R 0.685)
   (CHARHT R 0.521)
   (CHARDP R 0.013)
   )
(CHARACTER O 274 (comment uni2A6C)
   (CHARWD R 0.685)
   (CHARHT R 0.543)
   (CHARDP R 0.038)
   )
(CHARACTER O 275 (comment uni2A6D)
   (CHARWD R 0.75)
   (CHARHT R 0.759)
   (CHARDP R 0.06)
   )
(CHARACTER O 276 (comment uni2A6E)
   (CHARWD R 0.75)
   (CHARHT R 0.884)
   )
(CHARACTER O 277 (comment uni2A6F)
   (CHARWD R 0.75)
   (CHARHT R 0.752)
   )
(CHARACTER O 300 (comment uni2A70)
   (CHARWD R 0.75)
   (CHARHT R 0.68)
   (CHARDP R 0.176)
   )
(CHARACTER O 301 (comment uni2A71)
   (CHARWD R 0.75)
   (CHARHT R 0.665)
   (CHARDP R 0.159)
   )
(CHARACTER O 302 (comment uni2A72)
   (CHARWD R 0.75)
   (CHARHT R 0.665)
   (CHARDP R 0.159)
   )
(CHARACTER O 303 (comment uni2A73)
   (CHARWD R 0.75)
   (CHARHT R 0.568)
   (CHARDP R 0.06)
   )
(CHARACTER O 304 (comment uni2A74)
   (CHARWD R 1.015)
   (CHARHT R 0.417)
   )
(CHARACTER O 305 (comment uni2A75)
   (CHARWD R 0.997)
   (CHARHT R 0.386)
   )
(CHARACTER O 306 (comment uni2A76)
   (CHARWD R 1.436)
   (CHARHT R 0.386)
   )
(CHARACTER O 307 (comment uni2A77)
   (CHARWD R 0.685)
   (CHARHT R 0.611)
   (CHARDP R 0.106)
   )
(CHARACTER O 310 (comment uni2A78)
   (CHARWD R 0.685)
   (CHARHT R 0.703)
   )
(CHARACTER O 311 (comment uni2A79)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 312 (comment uni2A7A)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 313 (comment uni2A7B)
   (CHARWD R 0.685)
   (CHARHT R 0.806)
   (CHARDP R 0.026)
   )
(CHARACTER O 314 (comment uni2A7C)
   (CHARWD R 0.685)
   (CHARHT R 0.806)
   (CHARDP R 0.026)
   )
(CHARACTER O 315 (comment uni2A7D)
   (CHARWD R 0.75)
   (CHARHT R 0.648)
   (CHARDP R 0.14)
   )
(CHARACTER O 316 (comment uni2A7E)
   (CHARWD R 0.75)
   (CHARHT R 0.648)
   (CHARDP R 0.14)
   )
(CHARACTER O 317 (comment uni2A7F)
   (CHARWD R 0.685)
   (CHARHT R 0.625)
   (CHARDP R 0.137)
   )
(CHARACTER O 320 (comment uni2A80)
   (CHARWD R 0.685)
   (CHARHT R 0.625)
   (CHARDP R 0.137)
   )
(CHARACTER O 321 (comment uni2A81)
   (CHARWD R 0.685)
   (CHARHT R 0.625)
   (CHARDP R 0.137)
   )
(CHARACTER O 322 (comment uni2A82)
   (CHARWD R 0.685)
   (CHARHT R 0.625)
   (CHARDP R 0.137)
   )
(CHARACTER O 323 (comment uni2A83)
   (CHARWD R 0.685)
   (CHARHT R 0.777)
   (CHARDP R 0.137)
   )
(CHARACTER O 324 (comment uni2A84)
   (CHARWD R 0.685)
   (CHARHT R 0.777)
   (CHARDP R 0.137)
   )
(CHARACTER O 325 (comment uni2A85)
   (CHARWD R 0.685)
   (CHARHT R 0.746)
   (CHARDP R 0.275)
   )
(CHARACTER O 326 (comment uni2A86)
   (CHARWD R 0.685)
   (CHARHT R 0.746)
   (CHARDP R 0.275)
   )
(CHARACTER O 327 (comment uni2A87)
   (CHARWD R 0.75)
   (CHARHT R 0.646)
   (CHARDP R 0.213)
   )
(CHARACTER O 330 (comment uni2A88)
   (CHARWD R 0.75)
   (CHARHT R 0.646)
   (CHARDP R 0.213)
   )
(CHARACTER O 331 (comment uni2A89)
   (CHARWD R 0.75)
   (CHARHT R 0.792)
   (CHARDP R 0.305)
   )
(CHARACTER O 332 (comment uni2A8A)
   (CHARWD R 0.75)
   (CHARHT R 0.792)
   (CHARDP R 0.305)
   )
(CHARACTER O 333 (comment uni2A8B)
   (CHARWD R 0.685)
   (CHARHT R 0.93)
   (CHARDP R 0.424)
   )
(CHARACTER O 334 (comment uni2A8C)
   (CHARWD R 0.685)
   (CHARHT R 0.93)
   (CHARDP R 0.424)
   )
(CHARACTER O 335 (comment uni2A8D)
   (CHARWD R 0.685)
   (CHARHT R 0.746)
   (CHARDP R 0.176)
   )
(CHARACTER O 336 (comment uni2A8E)
   (CHARWD R 0.685)
   (CHARHT R 0.746)
   (CHARDP R 0.176)
   )
(CHARACTER O 337 (comment uni2A8F)
   (CHARWD R 0.685)
   (CHARHT R 0.867)
   (CHARDP R 0.361)
   )
(CHARACTER O 340 (comment uni2A90)
   (CHARWD R 0.685)
   (CHARHT R 0.867)
   (CHARDP R 0.361)
   )
(CHARACTER O 341 (comment uni2A91)
   (CHARWD R 0.685)
   (CHARHT R 0.844)
   (CHARDP R 0.338)
   )
(CHARACTER O 342 (comment uni2A92)
   (CHARWD R 0.685)
   (CHARHT R 0.844)
   (CHARDP R 0.338)
   )
(CHARACTER O 343 (comment uni2A93)
   (CHARWD R 0.685)
   (CHARHT R 0.866)
   (CHARDP R 0.361)
   )
(CHARACTER O 344 (comment uni2A94)
   (CHARWD R 0.685)
   (CHARHT R 0.866)
   (CHARDP R 0.361)
   )
(CHARACTER O 345 (comment uni2A95)
   (CHARWD R 0.75)
   (CHARHT R 0.648)
   (CHARDP R 0.14)
   )
(CHARACTER O 346 (comment uni2A96)
   (CHARWD R 0.75)
   (CHARHT R 0.648)
   (CHARDP R 0.14)
   )
(CHARACTER O 347 (comment uni2A97)
   (CHARWD R 0.685)
   (CHARHT R 0.64)
   (CHARDP R 0.122)
   )
(CHARACTER O 350 (comment uni2A98)
   (CHARWD R 0.685)
   (CHARHT R 0.64)
   (CHARDP R 0.122)
   )
(CHARACTER O 351 (comment uni2A99)
   (CHARWD R 0.685)
   (CHARHT R 0.718)
   (CHARDP R 0.211)
   )
(CHARACTER O 352 (comment uni2A9A)
   (CHARWD R 0.685)
   (CHARHT R 0.718)
   (CHARDP R 0.211)
   )
(CHARACTER O 353 (comment uni2A9B)
   (CHARWD R 0.685)
   (CHARHT R 0.726)
   (CHARDP R 0.22)
   )
(CHARACTER O 354 (comment uni2A9C)
   (CHARWD R 0.685)
   (CHARHT R 0.726)
   (CHARDP R 0.22)
   )
(CHARACTER O 355 (comment uni2A9D)
   (CHARWD R 0.75)
   (CHARHT R 0.689)
   (CHARDP R 0.183)
   )
(CHARACTER O 356 (comment uni2A9E)
   (CHARWD R 0.75)
   (CHARHT R 0.689)
   (CHARDP R 0.183)
   )
(CHARACTER O 357 (comment uni2A9F)
   (CHARWD R 0.685)
   (CHARHT R 0.774)
   (CHARDP R 0.267)
   )
(CHARACTER O 360 (comment uni2AA0)
   (CHARWD R 0.685)
   (CHARHT R 0.774)
   (CHARDP R 0.267)
   )
(CHARACTER O 361 (comment uni2AA1)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 362 (comment uni2AA2)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 363 (comment uni2AA3)
   (CHARWD R 0.933)
   (CHARHT R 0.609)
   (CHARDP R 0.103)
   )
(CHARACTER O 364 (comment uni2AA4)
   (CHARWD R 0.782)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 365 (comment uni2AA5)
   (CHARWD R 0.855)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 366 (comment uni2AA6)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 367 (comment uni2AA7)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 370 (comment uni2AA8)
   (CHARWD R 0.685)
   (CHARHT R 0.625)
   (CHARDP R 0.137)
   )
(CHARACTER O 371 (comment uni2AA9)
   (CHARWD R 0.685)
   (CHARHT R 0.626)
   (CHARDP R 0.137)
   )
(CHARACTER O 372 (comment uni2AAA)
   (CHARWD R 0.685)
   (CHARHT R 0.537)
   (CHARDP R 0.031)
   )
(CHARACTER O 373 (comment uni2AAB)
   (CHARWD R 0.685)
   (CHARHT R 0.537)
   (CHARDP R 0.031)
   )
(CHARACTER O 374 (comment uni2AAC)
   (CHARWD R 0.685)
   (CHARHT R 0.613)
   (CHARDP R 0.103)
   )
(CHARACTER O 375 (comment uni2AAD)
   (CHARWD R 0.685)
   (CHARHT R 0.613)
   (CHARDP R 0.103)
   )
(CHARACTER O 376 (comment uni2AAE)
   (CHARWD R 0.685)
   (CHARHT R 0.563)
   )
(CHARACTER O 377 (comment uni2AB1)
   (CHARWD R 0.685)
   (CHARHT R 0.628)
   (CHARDP R 0.216)
   )
