(FAMILY STIXMathTyperwriter)
(CODINGSCHEME STIXMATHTT)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   )
(LIGTABLE
   (LABEL O 101) (comment u1D670)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 102) (comment u1D671)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 103) (comment u1D672)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 104) (comment u1D673)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 105) (comment u1D674)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 106) (comment u1D675)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 107) (comment u1D676)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 110) (comment u1D677)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 111) (comment u1D678)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 112) (comment u1D679)
   (KRN O 177 R 0.0975) (comment uni2040)
   (STOP)
   (LABEL O 113) (comment u1D67A)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 114) (comment u1D67B)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 115) (comment u1D67C)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 116) (comment u1D67D)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 117) (comment u1D67E)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 120) (comment u1D67F)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 121) (comment u1D680)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 122) (comment u1D681)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 123) (comment u1D682)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 124) (comment u1D683)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 125) (comment u1D684)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 126) (comment u1D685)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 127) (comment u1D686)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 130) (comment u1D687)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 131) (comment u1D688)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 132) (comment u1D689)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 141) (comment u1D68A)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 142) (comment u1D68B)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 143) (comment u1D68C)
   (KRN O 177 R 0.0455) (comment uni2040)
   (STOP)
   (LABEL O 144) (comment u1D68D)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 145) (comment u1D68E)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 146) (comment u1D68F)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 147) (comment u1D690)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 150) (comment u1D691)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 151) (comment u1D692)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 152) (comment u1D693)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 153) (comment u1D694)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 154) (comment u1D695)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 155) (comment u1D696)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 156) (comment u1D697)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 157) (comment u1D698)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 160) (comment u1D699)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 161) (comment u1D69A)
   (KRN O 177 R -0.0255) (comment uni2040)
   (STOP)
   (LABEL O 162) (comment u1D69B)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 163) (comment u1D69C)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 164) (comment u1D69D)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 165) (comment u1D69E)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 166) (comment u1D69F)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 167) (comment u1D6A0)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 170) (comment u1D6A1)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 171) (comment u1D6A2)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 172) (comment u1D6A3)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 173) (comment u1D692.dtls)
   (KRN O 177 R -0.0565) (comment uni2040)
   (STOP)
   (LABEL O 174) (comment u1D693.dtls)
   (KRN O 177 R -0.0095) (comment uni2040)
   (STOP)
   )
(CHARACTER O 0 (comment uni27F3)
   (CHARWD R 0.974)
   (CHARHT R 0.626)
   (CHARDP R 0.116)
   )
(CHARACTER O 1 (comment uni27F4)
   (CHARWD R 1.2)
   (CHARHT R 0.569)
   (CHARDP R 0.061)
   )
(CHARACTER O 2 (comment uni27F5)
   (CHARWD R 1.574)
   (CHARHT R 0.449)
   )
(CHARACTER O 3 (comment uni27F6)
   (CHARWD R 1.574)
   (CHARHT R 0.449)
   )
(CHARACTER O 4 (comment uni27F7)
   (CHARWD R 1.574)
   (CHARHT R 0.449)
   )
(CHARACTER O 5 (comment uni27F8)
   (CHARWD R 1.574)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 6 (comment uni27F9)
   (CHARWD R 1.574)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 7 (comment uni27FA)
   (CHARWD R 1.574)
   (CHARHT R 0.517)
   (CHARDP R 0.01)
   )
(CHARACTER O 10 (comment uni27FB)
   (CHARWD R 1.574)
   (CHARHT R 0.45)
   )
(CHARACTER O 11 (comment uni27FC)
   (CHARWD R 1.574)
   (CHARHT R 0.45)
   )
(CHARACTER O 12 (comment uni27FD)
   (CHARWD R 1.574)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 13 (comment uni27FE)
   (CHARWD R 1.574)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 14 (comment uni27FF)
   (CHARWD R 1.574)
   (CHARHT R 0.449)
   )
(CHARACTER O 15 (comment uni27F2)
   (CHARWD R 0.974)
   (CHARHT R 0.626)
   (CHARDP R 0.116)
   )
(CHARACTER O 16 (comment uni2B47)
   (CHARWD R 0.926)
   (CHARHT R 0.508)
   )
(CHARACTER O 17 (comment uni2660)
   (CHARWD R 0.685)
   (CHARHT R 0.609)
   (CHARDP R 0.099)
   )
(CHARACTER O 20 (comment uni2661)
   (CHARWD R 0.685)
   (CHARHT R 0.603)
   (CHARDP R 0.105)
   )
(CHARACTER O 21 (comment uni2662)
   (CHARWD R 0.685)
   (CHARHT R 0.609)
   (CHARDP R 0.105)
   )
(CHARACTER O 22 (comment uni2663)
   (CHARWD R 0.685)
   (CHARHT R 0.603)
   (CHARDP R 0.099)
   )
(CHARACTER O 23 (comment paragraph)
   (CHARWD R 0.639)
   (CHARHT R 0.676)
   (CHARDP R 0.186)
   )
(CHARACTER O 24 (comment section)
   (CHARWD R 0.5)
   (CHARHT R 0.691)
   (CHARDP R 0.132)
   )
(CHARACTER O 25 (comment uni2967)
   (CHARWD R 0.926)
   (CHARHT R 0.386)
   (CHARDP R 0.033)
   )
(CHARACTER O 26 (comment uni2968)
   (CHARWD R 0.926)
   (CHARHT R 0.539)
   )
(CHARACTER O 27 (comment uni2969)
   (CHARWD R 0.926)
   (CHARHT R 0.386)
   (CHARDP R 0.033)
   )
(CHARACTER O 30 (comment uni296A)
   (CHARWD R 0.926)
   (CHARHT R 0.539)
   )
(CHARACTER O 31 (comment uni296B)
   (CHARWD R 0.926)
   (CHARHT R 0.386)
   (CHARDP R 0.033)
   )
(CHARACTER O 32 (comment uni296C)
   (CHARWD R 0.926)
   (CHARHT R 0.539)
   )
(CHARACTER O 33 (comment uni296D)
   (CHARWD R 0.926)
   (CHARHT R 0.386)
   (CHARDP R 0.033)
   )
(CHARACTER O 34 (comment uni296E)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 35 (comment uni296F)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 36 (comment uni2970)
   (CHARWD R 0.926)
   (CHARHT R 0.386)
   )
(CHARACTER O 37 (comment uni2971)
   (CHARWD R 0.926)
   (CHARHT R 0.565)
   )
(CHARACTER O 40 (comment uni2972)
   (CHARWD R 0.926)
   (CHARHT R 0.508)
   )
(CHARACTER O 41 (comment uni2973)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.002)
   )
(CHARACTER O 42 (comment uni2974)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.002)
   )
(CHARACTER O 43 (comment uni2975)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.141)
   )
(CHARACTER O 44 (comment uni2976)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.283)
   )
(CHARACTER O 45 (comment uni2977)
   (CHARWD R 0.926)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 46 (comment uni2978)
   (CHARWD R 0.685)
   (CHARHT R 0.608)
   (CHARDP R 0.282)
   )
(CHARACTER O 47 (comment uni2979)
   (CHARWD R 0.685)
   (CHARHT R 0.627)
   (CHARDP R 0.262)
   )
(CHARACTER O 50 (comment uni297A)
   (CHARWD R 0.926)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 51 (comment uni297B)
   (CHARWD R 0.685)
   (CHARHT R 0.627)
   (CHARDP R 0.262)
   )
(CHARACTER O 52 (comment uni297C)
   (CHARWD R 0.926)
   (CHARHT R 0.511)
   (CHARDP R 0.005)
   )
(CHARACTER O 53 (comment uni297D)
   (CHARWD R 0.926)
   (CHARHT R 0.511)
   (CHARDP R 0.005)
   )
(CHARACTER O 54 (comment uni297E)
   (CHARWD R 0.685)
   (CHARHT R 0.581)
   (CHARDP R 0.075)
   )
(CHARACTER O 55 (comment uni297F)
   (CHARWD R 0.685)
   (CHARHT R 0.581)
   (CHARDP R 0.075)
   )
(CHARACTER O 56 (comment uni2667)
   (CHARWD R 0.685)
   (CHARHT R 0.603)
   (CHARDP R 0.099)
   )
(CHARACTER O 57 (comment uni2669)
   (CHARWD R 0.39)
   (CHARHT R 0.714)
   (CHARDP R 0.125)
   )
(CHARACTER O 60 (comment u1D7F6)
   (CHARWD R 0.525)
   (CHARHT R 0.681)
   (CHARDP R 0.011)
   )
(CHARACTER O 61 (comment u1D7F7)
   (CHARWD R 0.525)
   (CHARHT R 0.681)
   )
(CHARACTER O 62 (comment u1D7F8)
   (CHARWD R 0.525)
   (CHARHT R 0.681)
   )
(CHARACTER O 63 (comment u1D7F9)
   (CHARWD R 0.525)
   (CHARHT R 0.681)
   (CHARDP R 0.011)
   )
(CHARACTER O 64 (comment u1D7FA)
   (CHARWD R 0.525)
   (CHARHT R 0.682)
   )
(CHARACTER O 65 (comment u1D7FB)
   (CHARWD R 0.525)
   (CHARHT R 0.67)
   (CHARDP R 0.011)
   )
(CHARACTER O 66 (comment u1D7FC)
   (CHARWD R 0.525)
   (CHARHT R 0.681)
   (CHARDP R 0.011)
   )
(CHARACTER O 67 (comment u1D7FD)
   (CHARWD R 0.525)
   (CHARHT R 0.686)
   (CHARDP R 0.011)
   )
(CHARACTER O 70 (comment u1D7FE)
   (CHARWD R 0.525)
   (CHARHT R 0.681)
   (CHARDP R 0.011)
   )
(CHARACTER O 71 (comment u1D7FF)
   (CHARWD R 0.525)
   (CHARHT R 0.681)
   (CHARDP R 0.011)
   )
(CHARACTER O 72 (comment uni266A)
   (CHARWD R 0.56)
   (CHARHT R 0.714)
   (CHARDP R 0.125)
   )
(CHARACTER O 73 (comment uni266B)
   (CHARWD R 0.84)
   (CHARHT R 0.842)
   (CHARDP R 0.125)
   )
(CHARACTER O 74 (comment uni2680)
   (CHARWD R 1.032)
   (CHARHT R 0.669)
   (CHARDP R 0.023)
   )
(CHARACTER O 75 (comment uni2681)
   (CHARWD R 1.032)
   (CHARHT R 0.669)
   (CHARDP R 0.023)
   )
(CHARACTER O 76 (comment uni2682)
   (CHARWD R 1.032)
   (CHARHT R 0.669)
   (CHARDP R 0.023)
   )
(CHARACTER O 77 (comment uni2683)
   (CHARWD R 1.032)
   (CHARHT R 0.669)
   (CHARDP R 0.023)
   )
(CHARACTER O 100 (comment uni2684)
   (CHARWD R 1.032)
   (CHARHT R 0.669)
   (CHARDP R 0.023)
   )
(CHARACTER O 101 (comment u1D670)
   (CHARWD R 0.525)
   (CHARHT R 0.673)
   )
(CHARACTER O 102 (comment u1D671)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 103 (comment u1D672)
   (CHARWD R 0.525)
   (CHARHT R 0.672)
   (CHARDP R 0.011)
   )
(CHARACTER O 104 (comment u1D673)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 105 (comment u1D674)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 106 (comment u1D675)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 107 (comment u1D676)
   (CHARWD R 0.525)
   (CHARHT R 0.672)
   (CHARDP R 0.011)
   )
(CHARACTER O 110 (comment u1D677)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 111 (comment u1D678)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 112 (comment u1D679)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   (CHARDP R 0.011)
   )
(CHARACTER O 113 (comment u1D67A)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 114 (comment u1D67B)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 115 (comment u1D67C)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 116 (comment u1D67D)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 117 (comment u1D67E)
   (CHARWD R 0.525)
   (CHARHT R 0.672)
   (CHARDP R 0.011)
   )
(CHARACTER O 120 (comment u1D67F)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 121 (comment u1D680)
   (CHARWD R 0.525)
   (CHARHT R 0.672)
   (CHARDP R 0.139)
   )
(CHARACTER O 122 (comment u1D681)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   (CHARDP R 0.011)
   )
(CHARACTER O 123 (comment u1D682)
   (CHARWD R 0.525)
   (CHARHT R 0.672)
   (CHARDP R 0.011)
   )
(CHARACTER O 124 (comment u1D683)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 125 (comment u1D684)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   (CHARDP R 0.011)
   )
(CHARACTER O 126 (comment u1D685)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   (CHARDP R 0.008)
   )
(CHARACTER O 127 (comment u1D686)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   (CHARDP R 0.008)
   )
(CHARACTER O 130 (comment u1D687)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 131 (comment u1D688)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 132 (comment u1D689)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 133 (comment uni2685)
   (CHARWD R 1.032)
   (CHARHT R 0.669)
   (CHARDP R 0.023)
   )
(CHARACTER O 134 (comment uni2686)
   (CHARWD R 1.032)
   (CHARHT R 0.687)
   (CHARDP R 0.042)
   )
(CHARACTER O 135 (comment uni2687)
   (CHARWD R 1.032)
   (CHARHT R 0.687)
   (CHARDP R 0.042)
   )
(CHARACTER O 136 (comment uni2688)
   (CHARWD R 1.032)
   (CHARHT R 0.687)
   (CHARDP R 0.042)
   )
(CHARACTER O 137 (comment uni2689)
   (CHARWD R 1.032)
   (CHARHT R 0.687)
   (CHARDP R 0.042)
   )
(CHARACTER O 140 (comment uni26A5)
   (CHARWD R 0.66)
   (CHARHT R 0.784)
   (CHARDP R 0.281)
   )
(CHARACTER O 141 (comment u1D68A)
   (CHARWD R 0.525)
   (CHARHT R 0.459)
   (CHARDP R 0.006)
   )
(CHARACTER O 142 (comment u1D68B)
   (CHARWD R 0.525)
   (CHARHT R 0.609)
   (CHARDP R 0.006)
   )
(CHARACTER O 143 (comment u1D68C)
   (CHARWD R 0.525)
   (CHARHT R 0.459)
   (CHARDP R 0.006)
   )
(CHARACTER O 144 (comment u1D68D)
   (CHARWD R 0.525)
   (CHARHT R 0.609)
   (CHARDP R 0.006)
   )
(CHARACTER O 145 (comment u1D68E)
   (CHARWD R 0.525)
   (CHARHT R 0.459)
   (CHARDP R 0.006)
   )
(CHARACTER O 146 (comment u1D68F)
   (CHARWD R 0.525)
   (CHARHT R 0.615)
   )
(CHARACTER O 147 (comment u1D690)
   (CHARWD R 0.525)
   (CHARHT R 0.461)
   (CHARDP R 0.228)
   )
(CHARACTER O 150 (comment u1D691)
   (CHARWD R 0.525)
   (CHARHT R 0.609)
   )
(CHARACTER O 151 (comment u1D692)
   (CHARWD R 0.525)
   (CHARHT R 0.61)
   )
(CHARACTER O 152 (comment u1D693)
   (CHARWD R 0.525)
   (CHARHT R 0.61)
   (CHARDP R 0.227)
   )
(CHARACTER O 153 (comment u1D694)
   (CHARWD R 0.525)
   (CHARHT R 0.609)
   )
(CHARACTER O 154 (comment u1D695)
   (CHARWD R 0.525)
   (CHARHT R 0.609)
   )
(CHARACTER O 155 (comment u1D696)
   (CHARWD R 0.525)
   (CHARHT R 0.456)
   )
(CHARACTER O 156 (comment u1D697)
   (CHARWD R 0.525)
   (CHARHT R 0.456)
   )
(CHARACTER O 157 (comment u1D698)
   (CHARWD R 0.525)
   (CHARHT R 0.459)
   (CHARDP R 0.006)
   )
(CHARACTER O 160 (comment u1D699)
   (CHARWD R 0.525)
   (CHARHT R 0.456)
   (CHARDP R 0.221)
   )
(CHARACTER O 161 (comment u1D69A)
   (CHARWD R 0.525)
   (CHARHT R 0.456)
   (CHARDP R 0.221)
   (CHARIC R 0.05)
   )
(CHARACTER O 162 (comment u1D69B)
   (CHARWD R 0.525)
   (CHARHT R 0.456)
   )
(CHARACTER O 163 (comment u1D69C)
   (CHARWD R 0.525)
   (CHARHT R 0.459)
   (CHARDP R 0.006)
   )
(CHARACTER O 164 (comment u1D69D)
   (CHARWD R 0.525)
   (CHARHT R 0.58)
   (CHARDP R 0.006)
   )
(CHARACTER O 165 (comment u1D69E)
   (CHARWD R 0.525)
   (CHARHT R 0.45)
   (CHARDP R 0.006)
   )
(CHARACTER O 166 (comment u1D69F)
   (CHARWD R 0.525)
   (CHARHT R 0.45)
   (CHARDP R 0.004)
   )
(CHARACTER O 167 (comment u1D6A0)
   (CHARWD R 0.525)
   (CHARHT R 0.45)
   (CHARDP R 0.004)
   )
(CHARACTER O 170 (comment u1D6A1)
   (CHARWD R 0.525)
   (CHARHT R 0.45)
   )
(CHARACTER O 171 (comment u1D6A2)
   (CHARWD R 0.525)
   (CHARHT R 0.45)
   (CHARDP R 0.227)
   )
(CHARACTER O 172 (comment u1D6A3)
   (CHARWD R 0.525)
   (CHARHT R 0.45)
   )
(CHARACTER O 173 (comment u1D692.dtls)
   (CHARWD R 0.525)
   (CHARHT R 0.45)
   )
(CHARACTER O 174 (comment u1D693.dtls)
   (CHARWD R 0.525)
   (CHARHT R 0.45)
   (CHARDP R 0.227)
   )
(CHARACTER O 175 (comment uni26AA)
   (CHARWD R 0.762)
   (CHARHT R 0.583)
   (CHARDP R 0.079)
   )
(CHARACTER O 176 (comment uni26AB)
   (CHARWD R 0.762)
   (CHARHT R 0.583)
   (CHARDP R 0.079)
   )
(CHARACTER O 177 (comment uni2040)
   (CHARWD R 0.798)
   (CHARHT R 0.725)
   )
(CHARACTER O 200 (comment uni26AC)
   (CHARWD R 0.565)
   (CHARHT R 0.487)
   )
(CHARACTER O 201 (comment uni26B2)
   (CHARWD R 0.603)
   (CHARHT R 0.638)
   (CHARDP R 0.135)
   )
(CHARACTER O 202 (comment uni2713)
   (CHARWD R 0.755)
   (CHARHT R 0.707)
   (CHARDP R 0.012)
   )
(CHARACTER O 203 (comment uni2720)
   (CHARWD R 0.767)
   (CHARHT R 0.592)
   (CHARDP R 0.087)
   )
(CHARACTER O 204 (comment uni272A)
   (CHARWD R 0.789)
   (CHARHT R 0.613)
   (CHARDP R 0.106)
   )
(CHARACTER O 205 (comment uni2736)
   (CHARWD R 0.695)
   (CHARHT R 0.616)
   (CHARDP R 0.108)
   )
(CHARACTER O 206 (comment uni273D)
   (CHARWD R 0.682)
   (CHARHT R 0.612)
   (CHARDP R 0.108)
   )
(CHARACTER O 210 (comment uni25E9)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 211 (comment uni25EA)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 212 (comment uni25EB)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 213 (comment uni25EC)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 214 (comment uni25ED)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 215 (comment uni25EE)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 216 (comment uni25EF)
   (CHARWD R 1.207)
   (CHARHT R 0.785)
   (CHARDP R 0.282)
   )
(CHARACTER O 217 (comment uni25F0)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 220 (comment uni25F1)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 221 (comment uni25F2)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 222 (comment uni25F3)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 223 (comment uni25F4)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 224 (comment uni25F5)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 225 (comment uni25F6)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 226 (comment uni25F7)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 227 (comment uni25F8)
   (CHARWD R 0.911)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 230 (comment uni25F9)
   (CHARWD R 0.911)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 231 (comment uni25FA)
   (CHARWD R 0.911)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 232 (comment uni25FB)
   (CHARWD R 0.746)
   (CHARHT R 0.58)
   (CHARDP R 0.076)
   )
(CHARACTER O 233 (comment uni25FC)
   (CHARWD R 0.746)
   (CHARHT R 0.58)
   (CHARDP R 0.076)
   )
(CHARACTER O 234 (comment uni25FD)
   (CHARWD R 0.601)
   (CHARHT R 0.513)
   (CHARDP R 0.012)
   )
(CHARACTER O 235 (comment uni25FE)
   (CHARWD R 0.601)
   (CHARHT R 0.514)
   (CHARDP R 0.011)
   )
(CHARACTER O 236 (comment uni25FF)
   (CHARWD R 0.911)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 237 (comment uni2605)
   (CHARWD R 0.87)
   (CHARHT R 0.655)
   (CHARDP R 0.066)
   )
(CHARACTER O 240 (comment uni2606)
   (CHARWD R 0.87)
   (CHARHT R 0.655)
   (CHARDP R 0.066)
   )
(CHARACTER O 241 (comment uni2A30)
   (CHARWD R 0.702)
   (CHARHT R 0.745)
   (CHARDP R 0.033)
   )
(CHARACTER O 242 (comment uni2A31)
   (CHARWD R 0.702)
   (CHARHT R 0.538)
   (CHARDP R 0.191)
   )
(CHARACTER O 243 (comment uni2A32)
   (CHARWD R 0.702)
   (CHARHT R 0.538)
   (CHARDP R 0.059)
   )
(CHARACTER O 244 (comment uni2A33)
   (CHARWD R 0.685)
   (CHARHT R 0.538)
   (CHARDP R 0.032)
   )
(CHARACTER O 245 (comment uni2A34)
   (CHARWD R 0.674)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 246 (comment uni2A35)
   (CHARWD R 0.674)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 247 (comment uni2A36)
   (CHARWD R 0.842)
   (CHARHT R 0.81)
   (CHARDP R 0.119)
   )
(CHARACTER O 250 (comment uni2A37)
   (CHARWD R 1.1)
   (CHARHT R 0.752)
   (CHARDP R 0.248)
   )
(CHARACTER O 251 (comment uni2A38)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 252 (comment uni2A39)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 253 (comment uni2A3A)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 254 (comment uni2A3B)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 255 (comment uni2A3C)
   (CHARWD R 0.6)
   (CHARHT R 0.393)
   )
(CHARACTER O 256 (comment uni2A3D)
   (CHARWD R 0.6)
   (CHARHT R 0.393)
   )
(CHARACTER O 257 (comment uni2A3E)
   (CHARWD R 0.3)
   (CHARHT R 0.488)
   (CHARDP R 0.17)
   )
(CHARACTER O 260 (comment uni2A3F)
   (CHARWD R 0.734)
   (CHARHT R 0.676)
   )
(CHARACTER O 261 (comment uni2A40)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 262 (comment uni2A41)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 263 (comment uni2A42)
   (CHARWD R 0.62)
   (CHARHT R 0.668)
   (CHARDP R 0.031)
   )
(CHARACTER O 264 (comment uni2A43)
   (CHARWD R 0.62)
   (CHARHT R 0.668)
   (CHARDP R 0.031)
   )
(CHARACTER O 265 (comment uni2A44)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 266 (comment uni2A45)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 267 (comment uni2A46)
   (CHARWD R 0.62)
   (CHARHT R 0.914)
   (CHARDP R 0.406)
   )
(CHARACTER O 270 (comment uni2A47)
   (CHARWD R 0.62)
   (CHARHT R 0.914)
   (CHARDP R 0.406)
   )
(CHARACTER O 271 (comment uni2A48)
   (CHARWD R 0.62)
   (CHARHT R 0.914)
   (CHARDP R 0.406)
   )
