(FAMILY stix-extra3)
(CODINGSCHEME STIXEXTRA3)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 63)
(FONTDIMEN
   (SLANT R 0.000000)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 450)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   )
(CHARACTER O 0 (comment uniE368)
   (CHARWD R 557)
   (CHARHT R 756)
   (CHARDP R 218)
   (CHARIC R 88)
   )
(CHARACTER O 4 (comment uniE36C)
   (CHARWD R 645)
   (CHARHT R 773)
   (CHARDP R 218)
   (CHARIC R 30)
   )
(CHARACTER O 10 (comment uniE370)
   (CHARWD R 708)
   (CHARHT R 756)
   (CHARDP R 218)
   )
(CHARACTER O 54 (comment uniE3C2)
   (CHARWD R 685)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 55 (comment uniE3C3)
   (CHARWD R 685)
   (CHARHT R 627)
   (CHARDP R 135)
   )
(CHARACTER O 56 (comment uniE3C4)
   (CHARWD R 685)
   (CHARHT R 627)
   (CHARDP R 135)
   )
(CHARACTER O 61 (comment uniE3C7)
   (CHARWD R 902)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 62 (comment uniE3C8)
   (CHARWD R 902)
   (CHARHT R 662)
   (CHARDP R 156)
   )
