(FAMILY stix-extra1-bold)
(CODINGSCHEME STIXEXTRA)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 377)
(FONTDIMEN
   (SLANT R 0.000000)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 461)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   )
(CHARACTER O 7 (comment uniE037)
   (CHARWD R 750)
   (CHARHT R 672)
   (CHARDP R 166)
   )
(CHARACTER O 15 (comment uniE04D)
   (CHARWD R 750)
   (CHARHT R 553)
   (CHARDP R 47)
   )
(CHARACTER O 24 (comment uniE05E)
   (CHARWD R 0)
   (CHARHT R 762)
   (CHARIC R 425)
   )
(CHARACTER O 25 (comment uniE061)
   (CHARWD R 0)
   (CHARDP R 437)
   (CHARIC R 330)
   )
(CHARACTER O 26 (comment uniE062)
   (CHARWD R 0)
   (CHARDP R 552)
   (CHARIC R 330)
   )
(CHARACTER O 30 (comment uniE064)
   (CHARWD R 333)
   (CHARHT R 837)
   (CHARIC R 16)
   )
(CHARACTER O 31 (comment uniE065)
   (CHARWD R 0)
   (CHARDP R 409)
   (CHARIC R 349)
   )
(CHARACTER O 32 (comment uniE066)
   (CHARWD R 0)
   (CHARHT R 801)
   (CHARIC R 430)
   )
(CHARACTER O 33 (comment uniE067)
   (CHARWD R 0)
   (CHARDP R 409)
   (CHARIC R 349)
   )
(CHARACTER O 37 (comment uniE06F)
   (CHARWD R 750)
   (CHARHT R 835)
   (CHARDP R 113)
   )
(CHARACTER O 40 (comment uniE070)
   (CHARWD R 750)
   (CHARHT R 835)
   (CHARDP R 113)
   )
(CHARACTER O 44 (comment uniE07E)
   (CHARWD R 750)
   (CHARHT R 738)
   (CHARDP R 230)
   )
(CHARACTER O 45 (comment uniE07F)
   (CHARWD R 750)
   (CHARHT R 742)
   (CHARDP R 234)
   )
(CHARACTER O 46 (comment uniE080)
   (CHARWD R 750)
   (CHARHT R 819)
   (CHARDP R 337)
   )
(CHARACTER O 47 (comment uniE081)
   (CHARWD R 750)
   (CHARHT R 820)
   (CHARDP R 342)
   )
(CHARACTER O 50 (comment uniE084)
   (CHARWD R 750)
   (CHARHT R 738)
   (CHARDP R 230)
   )
(CHARACTER O 51 (comment uniE085)
   (CHARWD R 750)
   (CHARHT R 742)
   (CHARDP R 234)
   )
(CHARACTER O 103 (comment uniE0B0)
   (CHARWD R 0)
   (CHARHT R 752)
   (CHARIC R 417)
   )
(CHARACTER O 104 (comment uniE0B1)
   (CHARWD R 0)
   (CHARDP R 271)
   (CHARIC R 417)
   )
(CHARACTER O 105 (comment uniE0B2)
   (CHARWD R 0)
   (CHARDP R 271)
   (CHARIC R 416)
   )
(CHARACTER O 106 (comment uniE0B3)
   (CHARWD R 556)
   (CHARHT R 691)
   (CHARDP R 203)
   )
(CHARACTER O 147 (comment uniE0D8)
   (CHARWD R 400)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER O 150 (comment uniE0D9)
   (CHARWD R 314)
   (CHARHT R 663)
   )
(CHARACTER O 151 (comment uniE0DA)
   (CHARWD R 425)
   (CHARHT R 663)
   )
(CHARACTER O 154 (comment uniE0DD)
   (CHARWD R 553)
   (CHARHT R 930)
   )
(CHARACTER O 155 (comment uniE0DE)
   (CHARWD R 549)
   (CHARHT R 926)
   )
(CHARACTER O 156 (comment uniE0DF)
   (CHARWD R 773)
   (CHARHT R 765)
   )
(CHARACTER O 157 (comment uniE0E0)
   (CHARWD R 552)
   (CHARHT R 920)
   )
(CHARACTER O 160 (comment uniE0E1)
   (CHARWD R 378)
   (CHARHT R 765)
   )
(CHARACTER O 161 (comment uniE0E2)
   (CHARWD R 481)
   (CHARHT R 754)
   )
(CHARACTER O 303 (comment uniE150)
   (CHARWD R 735)
   (CHARHT R 175)
   (CHARDP R 302)
   (CHARIC R 21)
   )
(CHARACTER O 304 (comment uniE151)
   (CHARWD R 735)
   (CHARHT R 175)
   (CHARDP R 302)
   (CHARIC R 40)
   )
(CHARACTER O 305 (comment uniE152)
   (CHARWD R 735)
   (CHARHT R 477)
   (CHARIC R 21)
   )
(CHARACTER O 306 (comment uniE153)
   (CHARWD R 735)
   (CHARHT R 477)
   (CHARIC R 40)
   )
