(FAMILY STIXMathSans)
(CODINGSCHEME STIXMATHSFIT)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0.3)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   )
(LIGTABLE
   (LABEL O 0) (comment uniE1C1)
   (KRN O 177 R 0.088) (comment uni2040)
   (STOP)
   (LABEL O 1) (comment uniE1C2)
   (KRN O 177 R 0.168) (comment uni2040)
   (STOP)
   (LABEL O 2) (comment uniE1C6)
   (KRN O 177 R 0.1) (comment uni2040)
   (STOP)
   (LABEL O 3) (comment uniE1C9)
   (KRN O 177 R 0.16) (comment uni2040)
   (STOP)
   (LABEL O 4) (comment uniE1CC)
   (KRN O 177 R 0.0955) (comment uni2040)
   (STOP)
   (LABEL O 5) (comment uniE1CE)
   (KRN O 177 R 0.114) (comment uni2040)
   (STOP)
   (LABEL O 6) (comment uniE1D1)
   (KRN O 177 R 0.0875) (comment uni2040)
   (STOP)
   (LABEL O 7) (comment uniE1D3)
   (KRN O 177 R 0.011) (comment uni2040)
   (STOP)
   (LABEL O 10) (comment uniE1D4)
   (KRN O 177 R 0.118) (comment uni2040)
   (STOP)
   (LABEL O 11) (comment uniE1D6)
   (KRN O 177 R 0.031) (comment uni2040)
   (STOP)
   (LABEL O 12) (comment uniE1D7)
   (KRN O 177 R 0.1415) (comment uni2040)
   (STOP)
   (LABEL O 13) (comment uniE1D8)
   (KRN O 177 R 0.0625) (comment uni2040)
   (STOP)
   (LABEL O 14) (comment uniE1D9)
   (KRN O 177 R 0.125) (comment uni2040)
   (STOP)
   (LABEL O 15) (comment uniE1DA)
   (KRN O 177 R 0.065) (comment uni2040)
   (STOP)
   (LABEL O 16) (comment uniE1DB)
   (KRN O 177 R 0.085) (comment uni2040)
   (STOP)
   (LABEL O 17) (comment uniE1F1)
   (KRN O 177 R 0.075) (comment uni2040)
   (STOP)
   (LABEL O 20) (comment uniE1DD)
   (KRN O 177 R 0.0865) (comment uni2040)
   (STOP)
   (LABEL O 21) (comment uniE1DE)
   (KRN O 177 R 0.0995) (comment uni2040)
   (STOP)
   (LABEL O 22) (comment uniE1DF)
   (KRN O 177 R 0.1) (comment uni2040)
   (STOP)
   (LABEL O 23) (comment uniE1E0)
   (KRN O 177 R 0.1) (comment uni2040)
   (STOP)
   (LABEL O 24) (comment uniE1E1)
   (KRN O 177 R 0.055) (comment uni2040)
   (STOP)
   (LABEL O 25) (comment uniE1E2)
   (KRN O 177 R 0.1) (comment uni2040)
   (STOP)
   (LABEL O 26) (comment uniE1E3)
   (KRN O 177 R 0.0995) (comment uni2040)
   (STOP)
   (LABEL O 27) (comment uniE1E4)
   (KRN O 177 R 0.0575) (comment uni2040)
   (STOP)
   (LABEL O 30) (comment uniE1E5)
   (KRN O 177 R 0.0945) (comment uni2040)
   (STOP)
   (LABEL O 31) (comment uniE1E7)
   (KRN O 177 R 0.065) (comment uni2040)
   (STOP)
   (LABEL O 32) (comment uniE1E8)
   (KRN O 177 R 0.1) (comment uni2040)
   (STOP)
   (LABEL O 33) (comment uniE1EA)
   (KRN O 177 R 0.068) (comment uni2040)
   (STOP)
   (LABEL O 34) (comment uniE1EB)
   (KRN O 177 R 0.0685) (comment uni2040)
   (STOP)
   (LABEL O 35) (comment uniE1EC)
   (KRN O 177 R 0.1) (comment uni2040)
   (STOP)
   (LABEL O 36) (comment uniE1F3)
   (KRN O 177 R 0.134) (comment uni2040)
   (STOP)
   (LABEL O 37) (comment uniE1EE)
   (KRN O 177 R 0.0585) (comment uni2040)
   (STOP)
   (LABEL O 40) (comment uniE1EF)
   (KRN O 177 R 0.052) (comment uni2040)
   (STOP)
   (LABEL O 41) (comment uniE1F0)
   (KRN O 177 R 0.0275) (comment uni2040)
   (STOP)
   (LABEL O 42) (comment uniE1DC)
   (KRN O 177 R 0.1) (comment uni2040)
   (STOP)
   (LABEL O 43) (comment uniE1F2)
   (KRN O 177 R 0.1) (comment uni2040)
   (STOP)
   (LABEL O 44) (comment uniE1F5)
   (KRN O 177 R 0.069) (comment uni2040)
   (STOP)
   (LABEL O 45) (comment uniE1F4)
   (KRN O 177 R 0.1) (comment uni2040)
   (STOP)
   (LABEL O 46) (comment uniE1E9)
   (KRN O 177 R 0.0455) (comment uni2040)
   (STOP)
   (LABEL O 47) (comment uniE1ED)
   (KRN O 177 R 0.0995) (comment uni2040)
   (STOP)
   (LABEL O 51) (comment uniE1BE)
   (KRN O 177 R 0.1215) (comment uni2040)
   (STOP)
   (LABEL O 101) (comment u1D608)
   (KRN O 177 R 0.166) (comment uni2040)
   (STOP)
   (LABEL O 102) (comment u1D609)
   (KRN O 177 R 0.0955) (comment uni2040)
   (STOP)
   (LABEL O 103) (comment u1D60A)
   (KRN O 177 R 0.1385) (comment uni2040)
   (STOP)
   (LABEL O 104) (comment u1D60B)
   (KRN O 177 R 0.016) (comment uni2040)
   (STOP)
   (LABEL O 105) (comment u1D60C)
   (KRN O 177 R 0.111) (comment uni2040)
   (STOP)
   (LABEL O 106) (comment u1D60D)
   (KRN O 177 R 0.1125) (comment uni2040)
   (STOP)
   (LABEL O 107) (comment u1D60E)
   (KRN O 177 R 0.1465) (comment uni2040)
   (STOP)
   (LABEL O 110) (comment u1D60F)
   (KRN O 177 R 0.078) (comment uni2040)
   (STOP)
   (LABEL O 111) (comment u1D610)
   (KRN O 177 R 0.0765) (comment uni2040)
   (STOP)
   (LABEL O 112) (comment u1D611)
   (KRN O 177 R 0.169) (comment uni2040)
   (STOP)
   (LABEL O 113) (comment u1D612)
   (KRN O 177 R 0.0835) (comment uni2040)
   (STOP)
   (LABEL O 114) (comment u1D613)
   (KRN O 177 R 0.1255) (comment uni2040)
   (STOP)
   (LABEL O 115) (comment u1D614)
   (KRN O 177 R 0.0975) (comment uni2040)
   (STOP)
   (LABEL O 116) (comment u1D615)
   (KRN O 177 R 0.1235) (comment uni2040)
   (STOP)
   (LABEL O 117) (comment u1D616)
   (KRN O 177 R 0.1175) (comment uni2040)
   (STOP)
   (LABEL O 120) (comment u1D617)
   (KRN O 177 R 0.097) (comment uni2040)
   (STOP)
   (LABEL O 121) (comment u1D618)
   (KRN O 177 R 0.1155) (comment uni2040)
   (STOP)
   (LABEL O 122) (comment u1D619)
   (KRN O 177 R 0.0805) (comment uni2040)
   (STOP)
   (LABEL O 123) (comment u1D61A)
   (KRN O 177 R 0.1075) (comment uni2040)
   (STOP)
   (LABEL O 124) (comment u1D61B)
   (KRN O 177 R 0.06) (comment uni2040)
   (STOP)
   (LABEL O 125) (comment u1D61C)
   (KRN O 177 R 0.1055) (comment uni2040)
   (STOP)
   (LABEL O 126) (comment u1D61D)
   (KRN O 177 R 0.078) (comment uni2040)
   (STOP)
   (LABEL O 127) (comment u1D61E)
   (KRN O 177 R 0.0775) (comment uni2040)
   (STOP)
   (LABEL O 130) (comment u1D61F)
   (KRN O 177 R 0.087) (comment uni2040)
   (STOP)
   (LABEL O 131) (comment u1D620)
   (KRN O 177 R 0.073) (comment uni2040)
   (STOP)
   (LABEL O 132) (comment u1D621)
   (KRN O 177 R 0.0845) (comment uni2040)
   (STOP)
   (LABEL O 141) (comment u1D622)
   (KRN O 177 R 0.077) (comment uni2040)
   (STOP)
   (LABEL O 142) (comment u1D623)
   (KRN O 177 R 0.014) (comment uni2040)
   (STOP)
   (LABEL O 143) (comment u1D624)
   (KRN O 177 R 0.081) (comment uni2040)
   (STOP)
   (LABEL O 144) (comment u1D625)
   (KRN O 177 R 0.131) (comment uni2040)
   (STOP)
   (LABEL O 145) (comment u1D626)
   (KRN O 177 R 0.084) (comment uni2040)
   (STOP)
   (LABEL O 146) (comment u1D627)
   (KRN O 177 R 0.126) (comment uni2040)
   (STOP)
   (LABEL O 147) (comment u1D628)
   (KRN O 177 R 0.044) (comment uni2040)
   (STOP)
   (LABEL O 150) (comment u1D629)
   (KRN O 177 R 0.0125) (comment uni2040)
   (STOP)
   (LABEL O 151) (comment u1D62A)
   (KRN O 177 R 0.0855) (comment uni2040)
   (STOP)
   (LABEL O 152) (comment u1D62B)
   (KRN O 177 R 0.106) (comment uni2040)
   (STOP)
   (LABEL O 153) (comment u1D62C)
   (KRN O 177 R 0.0225) (comment uni2040)
   (STOP)
   (LABEL O 154) (comment u1D62D)
   (KRN O 177 R 0.0855) (comment uni2040)
   (STOP)
   (LABEL O 155) (comment u1D62E)
   (KRN O 177 R 0.104) (comment uni2040)
   (STOP)
   (LABEL O 156) (comment u1D62F)
   (KRN O 177 R 0.0865) (comment uni2040)
   (STOP)
   (LABEL O 157) (comment u1D630)
   (KRN O 177 R 0.0755) (comment uni2040)
   (STOP)
   (LABEL O 160) (comment u1D631)
   (KRN O 177 R 0.107) (comment uni2040)
   (STOP)
   (LABEL O 161) (comment u1D632)
   (KRN O 177 R 0.066) (comment uni2040)
   (STOP)
   (LABEL O 162) (comment u1D633)
   (KRN O 177 R 0.097) (comment uni2040)
   (STOP)
   (LABEL O 163) (comment u1D634)
   (KRN O 177 R 0.0705) (comment uni2040)
   (STOP)
   (LABEL O 164) (comment u1D635)
   (KRN O 177 R 0.0725) (comment uni2040)
   (STOP)
   (LABEL O 165) (comment u1D636)
   (KRN O 177 R 0.0605) (comment uni2040)
   (STOP)
   (LABEL O 166) (comment u1D637)
   (KRN O 177 R 0.072) (comment uni2040)
   (STOP)
   (LABEL O 167) (comment u1D638)
   (KRN O 177 R 0.048) (comment uni2040)
   (STOP)
   (LABEL O 170) (comment u1D639)
   (KRN O 177 R 0.062) (comment uni2040)
   (STOP)
   (LABEL O 171) (comment u1D63A)
   (KRN O 177 R 0.073) (comment uni2040)
   (STOP)
   (LABEL O 172) (comment u1D63B)
   (KRN O 177 R 0.0875) (comment uni2040)
   (STOP)
   (LABEL O 173) (comment u1D62A.dtls)
   (KRN O 177 R 0.0635) (comment uni2040)
   (STOP)
   (LABEL O 174) (comment u1D62B.dtls)
   (KRN O 177 R 0.0745) (comment uni2040)
   (STOP)
   )
(CHARACTER O 0 (comment uniE1C1)
   (CHARWD R 0.562)
   (CHARHT R 0.662)
   (CHARIC R 0.148)
   )
(CHARACTER O 1 (comment uniE1C2)
   (CHARWD R 0.66)
   (CHARHT R 0.674)
   )
(CHARACTER O 2 (comment uniE1C6)
   (CHARWD R 0.78)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 3 (comment uniE1C9)
   (CHARWD R 0.664)
   (CHARHT R 0.674)
   )
(CHARACTER O 4 (comment uniE1CC)
   (CHARWD R 0.722)
   (CHARHT R 0.662)
   (CHARIC R 0.077)
   )
(CHARACTER O 5 (comment uniE1CE)
   (CHARWD R 0.7)
   (CHARHT R 0.662)
   (CHARIC R 0.08)
   )
(CHARACTER O 6 (comment uniE1D1)
   (CHARWD R 0.654)
   (CHARHT R 0.662)
   (CHARIC R 0.097)
   )
(CHARACTER O 7 (comment uniE1D3)
   (CHARWD R 0.593)
   (CHARHT R 0.676)
   (CHARIC R 0.177)
   )
(CHARACTER O 10 (comment uniE1D4)
   (CHARWD R 0.736)
   (CHARHT R 0.662)
   )
(CHARACTER O 11 (comment uniE1D6)
   (CHARWD R 0.712)
   (CHARHT R 0.681)
   (CHARIC R 0.138)
   )
(CHARACTER O 12 (comment uniE1D7)
   (CHARWD R 0.795)
   (CHARHT R 0.676)
   )
(CHARACTER O 13 (comment uniE1D8)
   (CHARWD R 0.586)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   (CHARIC R 0.075)
   )
(CHARACTER O 14 (comment uniE1D9)
   (CHARWD R 0.535)
   (CHARHT R 0.683)
   (CHARDP R 0.215)
   (CHARIC R 0.069)
   )
(CHARACTER O 15 (comment uniE1DA)
   (CHARWD R 0.503)
   (CHARHT R 0.463)
   (CHARDP R 0.216)
   (CHARIC R 0.069)
   )
(CHARACTER O 16 (comment uniE1DB)
   (CHARWD R 0.497)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   (CHARIC R 0.085)
   )
(CHARACTER O 17 (comment uniE1F1)
   (CHARWD R 0.462)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   (CHARIC R 0.05)
   )
(CHARACTER O 20 (comment uniE1DD)
   (CHARWD R 0.429)
   (CHARHT R 0.683)
   (CHARDP R 0.213)
   (CHARIC R 0.07)
   )
(CHARACTER O 21 (comment uniE1DE)
   (CHARWD R 0.493)
   (CHARHT R 0.463)
   (CHARDP R 0.215)
   )
(CHARACTER O 22 (comment uniE1DF)
   (CHARWD R 0.518)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 23 (comment uniE1E0)
   (CHARWD R 0.296)
   (CHARHT R 0.464)
   (CHARDP R 0.01)
   )
(CHARACTER O 24 (comment uniE1E1)
   (CHARWD R 0.472)
   (CHARHT R 0.464)
   (CHARIC R 0.09)
   )
(CHARACTER O 25 (comment uniE1E2)
   (CHARWD R 0.536)
   (CHARHT R 0.683)
   (CHARDP R 0.011)
   )
(CHARACTER O 26 (comment uniE1E3)
   (CHARWD R 0.561)
   (CHARHT R 0.453)
   (CHARDP R 0.215)
   )
(CHARACTER O 27 (comment uniE1E4)
   (CHARWD R 0.376)
   (CHARHT R 0.464)
   (CHARDP R 0.014)
   (CHARIC R 0.085)
   )
(CHARACTER O 30 (comment uniE1E5)
   (CHARWD R 0.434)
   (CHARHT R 0.683)
   (CHARDP R 0.215)
   (CHARIC R 0.075)
   )
(CHARACTER O 31 (comment uniE1E7)
   (CHARWD R 0.565)
   (CHARHT R 0.453)
   (CHARDP R 0.01)
   (CHARIC R 0.069)
   )
(CHARACTER O 32 (comment uniE1E8)
   (CHARWD R 0.534)
   (CHARHT R 0.462)
   (CHARDP R 0.216)
   )
(CHARACTER O 33 (comment uniE1EA)
   (CHARWD R 0.607)
   (CHARHT R 0.453)
   (CHARDP R 0.01)
   (CHARIC R 0.063)
   )
(CHARACTER O 34 (comment uniE1EB)
   (CHARWD R 0.468)
   (CHARHT R 0.453)
   (CHARDP R 0.01)
   (CHARIC R 0.063)
   )
(CHARACTER O 35 (comment uniE1EC)
   (CHARWD R 0.514)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   )
(CHARACTER O 36 (comment uniE1F3)
   (CHARWD R 0.648)
   (CHARHT R 0.684)
   (CHARDP R 0.216)
   )
(CHARACTER O 37 (comment uniE1EE)
   (CHARWD R 0.514)
   (CHARHT R 0.463)
   (CHARDP R 0.215)
   (CHARIC R 0.083)
   )
(CHARACTER O 40 (comment uniE1EF)
   (CHARWD R 0.654)
   (CHARHT R 0.461)
   (CHARDP R 0.216)
   (CHARIC R 0.096)
   )
(CHARACTER O 41 (comment uniE1F0)
   (CHARWD R 0.63)
   (CHARHT R 0.454)
   (CHARDP R 0.01)
   (CHARIC R 0.051)
   )
(CHARACTER O 42 (comment uniE1DC)
   (CHARWD R 0.494)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   )
(CHARACTER O 43 (comment uniE1F2)
   (CHARWD R 0.534)
   (CHARHT R 0.683)
   (CHARDP R 0.012)
   )
(CHARACTER O 44 (comment uniE1F5)
   (CHARWD R 0.795)
   (CHARHT R 0.453)
   (CHARDP R 0.01)
   (CHARIC R 0.061)
   )
(CHARACTER O 45 (comment uniE1F4)
   (CHARWD R 0.536)
   (CHARHT R 0.463)
   (CHARDP R 0.216)
   )
(CHARACTER O 46 (comment uniE1E9)
   (CHARWD R 0.436)
   (CHARHT R 0.463)
   (CHARDP R 0.212)
   (CHARIC R 0.109)
   )
(CHARACTER O 47 (comment uniE1ED)
   (CHARWD R 0.665)
   (CHARHT R 0.464)
   (CHARDP R 0.216)
   )
(CHARACTER O 50 (comment nabla.sfi)
   (CHARWD R 0.66)
   (CHARHT R 0.674)
   )
(CHARACTER O 51 (comment uniE1BE)
   (CHARWD R 0.536)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   (CHARIC R 0.051)
   )
(CHARACTER O 52 (comment uni2B32)
   (CHARWD R 1.2)
   (CHARHT R 0.569)
   (CHARDP R 0.061)
   )
(CHARACTER O 53 (comment uni2B33)
   (CHARWD R 1.574)
   (CHARHT R 0.449)
   )
(CHARACTER O 54 (comment uni2B34)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 55 (comment uni2B35)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 56 (comment uni2B36)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 57 (comment uni2B37)
   (CHARWD R 1.412)
   (CHARHT R 0.449)
   )
(CHARACTER O 60 (comment u1D7E2)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 61 (comment u1D7E3)
   (CHARWD R 0.5)
   (CHARHT R 0.677)
   )
(CHARACTER O 62 (comment u1D7E4)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 63 (comment u1D7E5)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 64 (comment u1D7E6)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 65 (comment u1D7E7)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 66 (comment u1D7E8)
   (CHARWD R 0.5)
   (CHARHT R 0.684)
   (CHARDP R 0.014)
   )
(CHARACTER O 67 (comment u1D7E9)
   (CHARWD R 0.5)
   (CHARHT R 0.662)
   (CHARDP R 0.008)
   )
(CHARACTER O 70 (comment u1D7EA)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 71 (comment u1D7EB)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.021)
   )
(CHARACTER O 72 (comment uni2B38)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 73 (comment uni2B39)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 74 (comment uni2B3A)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 75 (comment uni2B3B)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 76 (comment uni2B3C)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 77 (comment uni2B3D)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 100 (comment uni2B3E)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 101 (comment u1D608)
   (CHARWD R 0.666)
   (CHARHT R 0.674)
   )
(CHARACTER O 102 (comment u1D609)
   (CHARWD R 0.604)
   (CHARHT R 0.662)
   (CHARIC R 0.077)
   )
(CHARACTER O 103 (comment u1D60A)
   (CHARWD R 0.671)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   (CHARIC R 0.124)
   )
(CHARACTER O 104 (comment u1D60B)
   (CHARWD R 0.692)
   (CHARHT R 0.662)
   (CHARIC R 0.1)
   )
(CHARACTER O 105 (comment u1D60C)
   (CHARWD R 0.583)
   (CHARHT R 0.662)
   (CHARIC R 0.135)
   )
(CHARACTER O 106 (comment u1D60D)
   (CHARWD R 0.535)
   (CHARHT R 0.662)
   (CHARIC R 0.184)
   )
(CHARACTER O 107 (comment u1D60E)
   (CHARWD R 0.695)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   (CHARIC R 0.1)
   )
(CHARACTER O 110 (comment u1D60F)
   (CHARWD R 0.658)
   (CHARHT R 0.662)
   (CHARIC R 0.13)
   )
(CHARACTER O 111 (comment u1D610)
   (CHARWD R 0.401)
   (CHARHT R 0.662)
   (CHARIC R 0.15)
   )
(CHARACTER O 112 (comment u1D611)
   (CHARWD R 0.398)
   (CHARHT R 0.662)
   (CHARDP R 0.014)
   (CHARIC R 0.112)
   )
(CHARACTER O 113 (comment u1D612)
   (CHARWD R 0.634)
   (CHARHT R 0.662)
   (CHARIC R 0.135)
   )
(CHARACTER O 114 (comment u1D613)
   (CHARWD R 0.559)
   (CHARHT R 0.662)
   (CHARIC R 0.05)
   )
(CHARACTER O 115 (comment u1D614)
   (CHARWD R 0.843)
   (CHARHT R 0.662)
   (CHARIC R 0.13)
   )
(CHARACTER O 116 (comment u1D615)
   (CHARWD R 0.675)
   (CHARHT R 0.662)
   (CHARDP R 0.014)
   (CHARIC R 0.13)
   )
(CHARACTER O 117 (comment u1D616)
   (CHARWD R 0.714)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   (CHARIC R 0.105)
   )
(CHARACTER O 120 (comment u1D617)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   (CHARIC R 0.153)
   )
(CHARACTER O 121 (comment u1D618)
   (CHARWD R 0.716)
   (CHARHT R 0.676)
   (CHARDP R 0.175)
   (CHARIC R 0.103)
   )
(CHARACTER O 122 (comment u1D619)
   (CHARWD R 0.589)
   (CHARHT R 0.662)
   (CHARIC R 0.09)
   )
(CHARACTER O 123 (comment u1D61A)
   (CHARWD R 0.541)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   (CHARIC R 0.096)
   )
(CHARACTER O 124 (comment u1D61B)
   (CHARWD R 0.608)
   (CHARHT R 0.662)
   (CHARIC R 0.18)
   )
(CHARACTER O 125 (comment u1D61C)
   (CHARWD R 0.661)
   (CHARHT R 0.662)
   (CHARDP R 0.014)
   (CHARIC R 0.106)
   )
(CHARACTER O 126 (comment u1D61D)
   (CHARWD R 0.654)
   (CHARHT R 0.662)
   (CHARDP R 0.011)
   (CHARIC R 0.174)
   )
(CHARACTER O 127 (comment u1D61E)
   (CHARWD R 0.921)
   (CHARHT R 0.662)
   (CHARDP R 0.011)
   (CHARIC R 0.176)
   )
(CHARACTER O 130 (comment u1D61F)
   (CHARWD R 0.7)
   (CHARHT R 0.662)
   (CHARIC R 0.146)
   )
(CHARACTER O 131 (comment u1D620)
   (CHARWD R 0.63)
   (CHARHT R 0.662)
   (CHARIC R 0.184)
   )
(CHARACTER O 132 (comment u1D621)
   (CHARWD R 0.637)
   (CHARHT R 0.662)
   (CHARIC R 0.166)
   )
(CHARACTER O 133 (comment uni2B3F)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 134 (comment uni2B40)
   (CHARWD R 0.926)
   (CHARHT R 0.565)
   )
(CHARACTER O 135 (comment uni2B41)
   (CHARWD R 0.926)
   (CHARHT R 0.508)
   )
(CHARACTER O 136 (comment uni2B42)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.141)
   )
(CHARACTER O 137 (comment uni2B43)
   (CHARWD R 0.926)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 140 (comment uni2B44)
   (CHARWD R 0.926)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 141 (comment u1D622)
   (CHARWD R 0.448)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   (CHARIC R 0.064)
   )
(CHARACTER O 142 (comment u1D623)
   (CHARWD R 0.496)
   (CHARHT R 0.684)
   (CHARDP R 0.01)
   (CHARIC R 0.084)
   )
(CHARACTER O 143 (comment u1D624)
   (CHARWD R 0.456)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   (CHARIC R 0.092)
   )
(CHARACTER O 144 (comment u1D625)
   (CHARWD R 0.494)
   (CHARHT R 0.684)
   (CHARDP R 0.011)
   (CHARIC R 0.16)
   )
(CHARACTER O 145 (comment u1D626)
   (CHARWD R 0.444)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   (CHARIC R 0.088)
   )
(CHARACTER O 146 (comment u1D627)
   (CHARWD R 0.336)
   (CHARHT R 0.683)
   (CHARIC R 0.24)
   )
(CHARACTER O 147 (comment u1D628)
   (CHARWD R 0.496)
   (CHARHT R 0.463)
   (CHARDP R 0.216)
   (CHARIC R 0.12)
   )
(CHARACTER O 150 (comment u1D629)
   (CHARWD R 0.487)
   (CHARHT R 0.684)
   (CHARIC R 0.06)
   )
(CHARACTER O 151 (comment u1D62A)
   (CHARWD R 0.22)
   (CHARHT R 0.679)
   (CHARIC R 0.145)
   )
(CHARACTER O 152 (comment u1D62B)
   (CHARWD R 0.254)
   (CHARHT R 0.679)
   (CHARDP R 0.216)
   (CHARIC R 0.14)
   )
(CHARACTER O 153 (comment u1D62C)
   (CHARWD R 0.453)
   (CHARHT R 0.684)
   (CHARIC R 0.12)
   )
(CHARACTER O 154 (comment u1D62D)
   (CHARWD R 0.205)
   (CHARHT R 0.684)
   (CHARIC R 0.16)
   )
(CHARACTER O 155 (comment u1D62E)
   (CHARWD R 0.756)
   (CHARHT R 0.464)
   (CHARIC R 0.06)
   )
(CHARACTER O 156 (comment u1D62F)
   (CHARWD R 0.487)
   (CHARHT R 0.464)
   (CHARIC R 0.06)
   )
(CHARACTER O 157 (comment u1D630)
   (CHARWD R 0.499)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   (CHARIC R 0.07)
   )
(CHARACTER O 160 (comment u1D631)
   (CHARWD R 0.498)
   (CHARHT R 0.464)
   (CHARDP R 0.216)
   (CHARIC R 0.08)
   )
(CHARACTER O 161 (comment u1D632)
   (CHARWD R 0.498)
   (CHARHT R 0.464)
   (CHARDP R 0.216)
   (CHARIC R 0.09)
   )
(CHARACTER O 162 (comment u1D633)
   (CHARWD R 0.336)
   (CHARHT R 0.464)
   (CHARIC R 0.14)
   )
(CHARACTER O 163 (comment u1D634)
   (CHARWD R 0.389)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   (CHARIC R 0.09)
   )
(CHARACTER O 164 (comment u1D635)
   (CHARWD R 0.291)
   (CHARHT R 0.58)
   (CHARDP R 0.01)
   (CHARIC R 0.12)
   )
(CHARACTER O 165 (comment u1D636)
   (CHARWD R 0.491)
   (CHARHT R 0.453)
   (CHARDP R 0.011)
   (CHARIC R 0.08)
   )
(CHARACTER O 166 (comment u1D637)
   (CHARWD R 0.474)
   (CHARHT R 0.453)
   (CHARDP R 0.014)
   (CHARIC R 0.08)
   )
(CHARACTER O 167 (comment u1D638)
   (CHARWD R 0.702)
   (CHARHT R 0.453)
   (CHARDP R 0.014)
   (CHARIC R 0.08)
   )
(CHARACTER O 170 (comment u1D639)
   (CHARWD R 0.482)
   (CHARHT R 0.453)
   (CHARIC R 0.08)
   )
(CHARACTER O 171 (comment u1D63A)
   (CHARWD R 0.484)
   (CHARHT R 0.453)
   (CHARDP R 0.216)
   (CHARIC R 0.08)
   )
(CHARACTER O 172 (comment u1D63B)
   (CHARWD R 0.447)
   (CHARHT R 0.453)
   (CHARIC R 0.08)
   )
(CHARACTER O 173 (comment u1D62A.dtls)
   (CHARWD R 0.22)
   (CHARHT R 0.464)
   (CHARIC R 0.145)
   )
(CHARACTER O 174 (comment u1D62B.dtls)
   (CHARWD R 0.254)
   (CHARHT R 0.464)
   (CHARDP R 0.216)
   (CHARIC R 0.14)
   )
(CHARACTER O 175 (comment uni2B45)
   (CHARWD R 0.928)
   (CHARHT R 0.701)
   (CHARDP R 0.195)
   )
(CHARACTER O 176 (comment uni2B46)
   (CHARWD R 0.928)
   (CHARHT R 0.701)
   (CHARDP R 0.195)
   )
(CHARACTER O 177 (comment uni2040)
   (CHARWD R 0.798)
   (CHARHT R 0.7)
   )
(CHARACTER O 200 (comment uni0300)
   (CHARWD R 0.224)
   (CHARHT R 0.7)
   )
(CHARACTER O 201 (comment uni0301)
   (CHARWD R 0.224)
   (CHARHT R 0.7)
   )
(CHARACTER O 202 (comment uni0302)
   (CHARWD R 0.311)
   (CHARHT R 0.7)
   )
(CHARACTER O 203 (comment uni0303)
   (CHARWD R 0.33)
   (CHARHT R 0.6)
   )
(CHARACTER O 204 (comment uni0304)
   (CHARWD R 0.311)
   (CHARHT R 0.6)
   )
(CHARACTER O 205 (comment uni0306)
   (CHARWD R 0.281)
   (CHARHT R 0.7)
   )
(CHARACTER O 206 (comment uni0307)
   (CHARWD R 0.099)
   (CHARHT R 0.6)
   )
(CHARACTER O 207 (comment uni0308)
   (CHARWD R 0.298)
   (CHARHT R 0.6)
   )
(CHARACTER O 210 (comment uni0309)
   (CHARWD R 0.189)
   (CHARHT R 0.8)
   )
(CHARACTER O 211 (comment uni030A)
   (CHARWD R 0.199)
   (CHARHT R 0.7)
   )
(CHARACTER O 212 (comment uni030C)
   (CHARWD R 0.311)
   (CHARHT R 0.7)
   )
(CHARACTER O 213 (comment uni0310)
   (CHARWD R 0.281)
   (CHARHT R 0.8)
   )
(CHARACTER O 214 (comment uni0312)
   (CHARWD R 0.139)
   (CHARHT R 0.7)
   )
(CHARACTER O 215 (comment uni0315)
   (CHARWD R 0.139)
   (CHARHT R 0.7)
   )
(CHARACTER O 216 (comment uni031A)
   (CHARWD R 0.3)
   (CHARHT R 0.7)
   )
(CHARACTER O 217 (comment uni20D0)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 220 (comment uni20D1)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 221 (comment uni20D6)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 222 (comment uni20D7)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 223 (comment uni20DB)
   (CHARWD R 0.497)
   (CHARHT R 0.6)
   )
(CHARACTER O 224 (comment uni20DC)
   (CHARWD R 0.696)
   (CHARHT R 0.6)
   )
(CHARACTER O 225 (comment uni20E1)
   (CHARWD R 0.478)
   (CHARHT R 0.8)
   )
(CHARACTER O 226 (comment uni20E7)
   (CHARWD R 0.816)
   (CHARHT R 0.7)
   (CHARDP R 0.2)
   )
(CHARACTER O 227 (comment uni20E9)
   (CHARWD R 0.533)
   (CHARHT R 0.7)
   )
(CHARACTER O 230 (comment uni20F0)
   (CHARWD R 0.27)
   (CHARHT R 0.8)
   )
(CHARACTER O 231 (comment uni2900)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 232 (comment uni2901)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 233 (comment uni2902)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 234 (comment uni2903)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 235 (comment uni2904)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 236 (comment uni2905)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 237 (comment uni2906)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 240 (comment uni2907)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 241 (comment uni2908)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 242 (comment uni2909)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 243 (comment uni2B30)
   (CHARWD R 0.926)
   (CHARHT R 0.448)
   )
(CHARACTER O 244 (comment uni2B31)
   (CHARWD R 0.926)
   (CHARHT R 0.739)
   (CHARDP R 0.232)
   )
(CHARACTER O 245 (comment uni290C)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 246 (comment uni290D)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 247 (comment uni290E)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 250 (comment uni290F)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 251 (comment uni2910)
   (CHARWD R 1.412)
   (CHARHT R 0.449)
   )
(CHARACTER O 252 (comment uni2911)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 253 (comment uni2912)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 254 (comment uni2913)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 255 (comment uni2914)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 256 (comment uni2915)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 257 (comment uni2916)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 260 (comment uni2917)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 261 (comment uni2918)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 262 (comment uni2919)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 263 (comment uni291A)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 264 (comment uni291B)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 265 (comment uni291C)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 266 (comment uni291D)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 267 (comment uni291E)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 270 (comment uni291F)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 271 (comment uni2920)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 272 (comment uni2921)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 273 (comment uni2922)
   (CHARWD R 0.926)
   (CHARHT R 0.66)
   (CHARDP R 0.156)
   )
(CHARACTER O 274 (comment uni2923)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 275 (comment uni2924)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 276 (comment uni2925)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 277 (comment uni2926)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 300 (comment uni2927)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 301 (comment uni2928)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 302 (comment uni2929)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 303 (comment uni292A)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 304 (comment uni292B)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 305 (comment uni292C)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 306 (comment uni292D)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 307 (comment uni292E)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 310 (comment uni292F)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 311 (comment uni2930)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.154)
   )
(CHARACTER O 312 (comment uni2931)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 313 (comment uni2932)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 314 (comment uni2933)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 315 (comment uni2934)
   (CHARWD R 0.926)
   (CHARHT R 0.562)
   )
(CHARACTER O 316 (comment uni2935)
   (CHARWD R 0.926)
   (CHARHT R 0.562)
   )
(CHARACTER O 317 (comment uni2936)
   (CHARWD R 0.784)
   (CHARHT R 0.493)
   (CHARDP R 0.163)
   )
(CHARACTER O 320 (comment uni2937)
   (CHARWD R 0.784)
   (CHARHT R 0.493)
   (CHARDP R 0.163)
   )
(CHARACTER O 321 (comment uni2938)
   (CHARWD R 0.511)
   (CHARHT R 0.657)
   (CHARDP R 0.153)
   )
(CHARACTER O 322 (comment uni2939)
   (CHARWD R 0.511)
   (CHARHT R 0.657)
   (CHARDP R 0.153)
   )
(CHARACTER O 323 (comment uni293A)
   (CHARWD R 0.926)
   (CHARHT R 0.423)
   )
(CHARACTER O 324 (comment uni293B)
   (CHARWD R 0.926)
   (CHARHT R 0.423)
   )
(CHARACTER O 325 (comment uni293C)
   (CHARWD R 0.926)
   (CHARHT R 0.423)
   )
(CHARACTER O 326 (comment uni293D)
   (CHARWD R 0.926)
   (CHARHT R 0.423)
   (CHARDP R 0.029)
   )
(CHARACTER O 327 (comment uni293E)
   (CHARWD R 0.926)
   (CHARHT R 0.563)
   (CHARDP R 0.116)
   )
(CHARACTER O 330 (comment uni293F)
   (CHARWD R 0.926)
   (CHARHT R 0.563)
   (CHARDP R 0.116)
   )
(CHARACTER O 331 (comment uni2940)
   (CHARWD R 0.926)
   (CHARHT R 0.788)
   (CHARDP R 0.116)
   )
(CHARACTER O 332 (comment uni2941)
   (CHARWD R 0.926)
   (CHARHT R 0.788)
   (CHARDP R 0.116)
   )
(CHARACTER O 333 (comment uni2942)
   (CHARWD R 0.926)
   (CHARHT R 0.598)
   (CHARDP R 0.092)
   )
(CHARACTER O 334 (comment uni2943)
   (CHARWD R 0.926)
   (CHARHT R 0.598)
   (CHARDP R 0.092)
   )
(CHARACTER O 335 (comment uni2944)
   (CHARWD R 0.926)
   (CHARHT R 0.598)
   (CHARDP R 0.092)
   )
(CHARACTER O 336 (comment uni2945)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.069)
   )
(CHARACTER O 337 (comment uni2946)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.069)
   )
(CHARACTER O 340 (comment uni2947)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 341 (comment uni2948)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 342 (comment uni2949)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.154)
   )
(CHARACTER O 343 (comment uni294A)
   (CHARWD R 0.926)
   (CHARHT R 0.439)
   )
(CHARACTER O 344 (comment uni294B)
   (CHARWD R 0.926)
   (CHARHT R 0.439)
   )
(CHARACTER O 345 (comment uni294C)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 346 (comment uni294D)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 347 (comment uni294E)
   (CHARWD R 0.926)
   (CHARHT R 0.439)
   )
(CHARACTER O 350 (comment uni294F)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 351 (comment uni2950)
   (CHARWD R 0.926)
   (CHARHT R 0.286)
   )
(CHARACTER O 352 (comment uni2951)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 353 (comment uni2952)
   (CHARWD R 0.926)
   (CHARHT R 0.448)
   )
(CHARACTER O 354 (comment uni2953)
   (CHARWD R 0.926)
   (CHARHT R 0.448)
   )
(CHARACTER O 355 (comment uni2954)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 356 (comment uni2955)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 357 (comment uni2956)
   (CHARWD R 0.926)
   (CHARHT R 0.448)
   )
(CHARACTER O 360 (comment uni2957)
   (CHARWD R 0.926)
   (CHARHT R 0.448)
   )
(CHARACTER O 361 (comment uni2958)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 362 (comment uni2959)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 363 (comment uni295A)
   (CHARWD R 0.926)
   (CHARHT R 0.448)
   )
(CHARACTER O 364 (comment uni295B)
   (CHARWD R 0.926)
   (CHARHT R 0.448)
   )
(CHARACTER O 365 (comment uni295C)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 366 (comment uni295D)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 367 (comment uni295E)
   (CHARWD R 0.926)
   (CHARHT R 0.448)
   )
(CHARACTER O 370 (comment uni295F)
   (CHARWD R 0.926)
   (CHARHT R 0.448)
   )
(CHARACTER O 371 (comment uni2960)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 372 (comment uni2961)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 373 (comment uni2962)
   (CHARWD R 0.926)
   (CHARHT R 0.539)
   (CHARDP R 0.033)
   )
(CHARACTER O 374 (comment uni2963)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 375 (comment uni2964)
   (CHARWD R 0.926)
   (CHARHT R 0.539)
   (CHARDP R 0.033)
   )
(CHARACTER O 376 (comment uni2965)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 377 (comment uni2966)
   (CHARWD R 0.926)
   (CHARHT R 0.539)
   )
