(FAMILY stix-extra2-bold)
(CODINGSCHEME STIXEXTRA2)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 377)
(FONTDIMEN
   (SLANT R 0.000000)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 461)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   )
(CHARACTER O 44 (comment uniE28D)
   (CHARWD R 0)
   (CHARHT R 734)
   (CHARIC R 498)
   )
(CHARACTER O 46 (comment uniE28F)
   (CHARWD R 325)
   (CHARHT R 175)
   (CHARIC R 1)
   )
(CHARACTER O 47 (comment uniE290)
   (CHARWD R 633)
   (CHARHT R 175)
   (CHARIC R 1)
   )
(CHARACTER O 224 (comment uniE2FD)
   (CHARWD R 722)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 226 (comment uniE2FF)
   (CHARWD R 667)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 230 (comment uniE301)
   (CHARWD R 620)
   (CHARHT R 775)
   (CHARDP R 207)
   )
(CHARACTER O 232 (comment uniE303)
   (CHARWD R 722)
   (CHARHT R 775)
   (CHARDP R 207)
   )
(CHARACTER O 234 (comment uniE305)
   (CHARWD R 667)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 236 (comment uniE307)
   (CHARWD R 667)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 240 (comment uniE309)
   (CHARWD R 778)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 242 (comment uniE30B)
   (CHARWD R 778)
   (CHARHT R 775)
   (CHARDP R 207)
   )
(CHARACTER O 244 (comment uniE30D)
   (CHARWD R 389)
   (CHARHT R 775)
   (CHARDP R 235)
   (CHARIC R 47)
   )
(CHARACTER O 246 (comment uniE30F)
   (CHARWD R 778)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 250 (comment uniE311)
   (CHARWD R 707)
   (CHARHT R 775)
   (CHARDP R 207)
   )
(CHARACTER O 252 (comment uniE313)
   (CHARWD R 944)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 254 (comment uniE315)
   (CHARWD R 722)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 256 (comment uniE317)
   (CHARWD R 647)
   (CHARHT R 775)
   (CHARDP R 207)
   )
(CHARACTER O 260 (comment uniE319)
   (CHARWD R 778)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 262 (comment uniE31B)
   (CHARWD R 778)
   (CHARHT R 775)
   (CHARDP R 207)
   )
(CHARACTER O 264 (comment uniE31D)
   (CHARWD R 611)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 266 (comment uniE31F)
   (CHARWD R 671)
   (CHARHT R 775)
   (CHARDP R 207)
   )
(CHARACTER O 270 (comment uniE321)
   (CHARWD R 667)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 272 (comment uniE323)
   (CHARWD R 723)
   (CHARHT R 775)
   (CHARDP R 207)
   )
(CHARACTER O 274 (comment uniE325)
   (CHARWD R 836)
   (CHARHT R 775)
   (CHARDP R 207)
   )
(CHARACTER O 276 (comment uniE327)
   (CHARWD R 722)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 300 (comment uniE329)
   (CHARWD R 804)
   (CHARHT R 775)
   (CHARDP R 207)
   )
(CHARACTER O 302 (comment uniE32B)
   (CHARWD R 768)
   (CHARHT R 775)
   (CHARDP R 207)
   )
(CHARACTER O 374 (comment uniE365)
   (CHARWD R 669)
   (CHARHT R 775)
   (CHARDP R 235)
   )
