(FAMILY STIXMathExtensions)
(CODINGSCHEME STIXMATHEX)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   (DEFAULTRULETHICKNESS R 0.066)
   (BIGOPSPACING1 R 0.15)
   (BIGOPSPACING2 R 0.15)
   (BIGOPSPACING3 R 0.3)
   (BIGOPSPACING4 R 0.6)
   (BIGOPSPACING5 R 0.1)
   )
(LIGTABLE
   )
(CHARACTER O 0 (comment parenleft.s1)
   (CHARWD R 0.468)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 30)
   )
(CHARACTER O 1 (comment parenright.s1)
   (CHARWD R 0.468)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 31)
   )
(CHARACTER O 2 (comment uni2985.s1)
   (CHARWD R 0.632)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 32)
   )
(CHARACTER O 3 (comment uni2986.s1)
   (CHARWD R 0.632)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 33)
   )
(CHARACTER O 4 (comment bracketleft.s1)
   (CHARWD R 0.383)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 34)
   )
(CHARACTER O 5 (comment bracketright.s1)
   (CHARWD R 0.383)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 35)
   )
(CHARACTER O 6 (comment uni27E6.s1)
   (CHARWD R 0.515)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 36)
   )
(CHARACTER O 7 (comment uni27E7.s1)
   (CHARWD R 0.515)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 37)
   )
(CHARACTER O 10 (comment uni230A.s1)
   (CHARWD R 0.453)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 40)
   )
(CHARACTER O 11 (comment uni230B.s1)
   (CHARWD R 0.453)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 41)
   )
(CHARACTER O 12 (comment uni2308.s1)
   (CHARWD R 0.453)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 42)
   )
(CHARACTER O 13 (comment uni2309.s1)
   (CHARWD R 0.453)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 43)
   )
(CHARACTER O 14 (comment braceleft.s1)
   (CHARWD R 0.575)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 44)
   )
(CHARACTER O 15 (comment braceright.s1)
   (CHARWD R 0.575)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 45)
   )
(CHARACTER O 16 (comment uni2983.s1)
   (CHARWD R 0.712)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 46)
   )
(CHARACTER O 17 (comment uni2984.s1)
   (CHARWD R 0.712)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 47)
   )
(CHARACTER O 20 (comment uni27E8.s1)
   (CHARWD R 0.578)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 50)
   )
(CHARACTER O 21 (comment uni27E9.s1)
   (CHARWD R 0.578)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 51)
   )
(CHARACTER O 22 (comment uni27EA.s1)
   (CHARWD R 0.798)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 52)
   )
(CHARACTER O 23 (comment uni27EB.s1)
   (CHARWD R 0.798)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 53)
   )
(CHARACTER O 24 (comment uni2772.s1)
   (CHARWD R 0.566)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 54)
   )
(CHARACTER O 25 (comment uni2773.s1)
   (CHARWD R 0.566)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 55)
   )
(CHARACTER O 26 (comment slash.s1)
   (CHARWD R 0.579)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 56)
   )
(CHARACTER O 27 (comment uni005C.s1)
   (CHARWD R 0.579)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   (NEXTLARGER O 57)
   )
(CHARACTER O 30 (comment parenleft.s2)
   (CHARWD R 0.589)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 60)
   )
(CHARACTER O 31 (comment parenright.s2)
   (CHARWD R 0.608)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 61)
   )
(CHARACTER O 32 (comment uni2985.s2)
   (CHARWD R 0.793)
   (CHARHT R 0.066)
   (CHARDP R 1.782)
   (NEXTLARGER O 62)
   )
(CHARACTER O 33 (comment uni2986.s2)
   (CHARWD R 0.793)
   (CHARHT R 0.066)
   (CHARDP R 1.782)
   (NEXTLARGER O 63)
   )
(CHARACTER O 34 (comment bracketleft.s2)
   (CHARWD R 0.459)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 64)
   )
(CHARACTER O 35 (comment bracketright.s2)
   (CHARWD R 0.459)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 65)
   )
(CHARACTER O 36 (comment uni27E6.s2)
   (CHARWD R 0.555)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 66)
   )
(CHARACTER O 37 (comment uni27E7.s2)
   (CHARWD R 0.555)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 67)
   )
(CHARACTER O 40 (comment uni230A.s2)
   (CHARWD R 0.524)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 70)
   )
(CHARACTER O 41 (comment uni230B.s2)
   (CHARWD R 0.526)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 71)
   )
(CHARACTER O 42 (comment uni2308.s2)
   (CHARWD R 0.524)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 72)
   )
(CHARACTER O 43 (comment uni2309.s2)
   (CHARWD R 0.526)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 73)
   )
(CHARACTER O 44 (comment braceleft.s2)
   (CHARWD R 0.717)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 74)
   )
(CHARACTER O 45 (comment braceright.s2)
   (CHARWD R 0.717)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 75)
   )
(CHARACTER O 46 (comment uni2983.s2)
   (CHARWD R 0.827)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 76)
   )
(CHARACTER O 47 (comment uni2984.s2)
   (CHARWD R 0.827)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 77)
   )
(CHARACTER O 50 (comment uni27E8.s2)
   (CHARWD R 0.622)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 100)
   )
(CHARACTER O 51 (comment uni27E9.s2)
   (CHARWD R 0.622)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 101)
   )
(CHARACTER O 52 (comment uni27EA.s2)
   (CHARWD R 0.901)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 102)
   )
(CHARACTER O 53 (comment uni27EB.s2)
   (CHARWD R 0.901)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 103)
   )
(CHARACTER O 54 (comment uni2772.s2)
   (CHARWD R 0.688)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 104)
   )
(CHARACTER O 55 (comment uni2773.s2)
   (CHARWD R 0.688)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 105)
   )
(CHARACTER O 56 (comment slash.s2)
   (CHARWD R 0.806)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 106)
   )
(CHARACTER O 57 (comment uni005C.s2)
   (CHARWD R 0.806)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   (NEXTLARGER O 107)
   )
(CHARACTER O 60 (comment parenleft.s3)
   (CHARWD R 0.75)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 110)
   )
(CHARACTER O 61 (comment parenright.s3)
   (CHARWD R 0.75)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 111)
   )
(CHARACTER O 62 (comment uni2985.s3)
   (CHARWD R 1.029)
   (CHARHT R 0.066)
   (CHARDP R 2.393)
   (NEXTLARGER O 112)
   )
(CHARACTER O 63 (comment uni2986.s3)
   (CHARWD R 1.029)
   (CHARHT R 0.066)
   (CHARDP R 2.393)
   (NEXTLARGER O 113)
   )
(CHARACTER O 64 (comment bracketleft.s3)
   (CHARWD R 0.508)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 114)
   )
(CHARACTER O 65 (comment bracketright.s3)
   (CHARWD R 0.508)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 115)
   )
(CHARACTER O 66 (comment uni27E6.s3)
   (CHARWD R 0.647)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 116)
   )
(CHARACTER O 67 (comment uni27E7.s3)
   (CHARWD R 0.647)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 117)
   )
(CHARACTER O 70 (comment uni230A.s3)
   (CHARWD R 0.565)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 120)
   )
(CHARACTER O 71 (comment uni230B.s3)
   (CHARWD R 0.565)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 121)
   )
(CHARACTER O 72 (comment uni2308.s3)
   (CHARWD R 0.565)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 122)
   )
(CHARACTER O 73 (comment uni2309.s3)
   (CHARWD R 0.565)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 123)
   )
(CHARACTER O 74 (comment braceleft.s3)
   (CHARWD R 0.906)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 124)
   )
(CHARACTER O 75 (comment braceright.s3)
   (CHARWD R 0.906)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 125)
   )
(CHARACTER O 76 (comment uni2983.s3)
   (CHARWD R 1.031)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 126)
   )
(CHARACTER O 77 (comment uni2984.s3)
   (CHARWD R 1.031)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 127)
   )
(CHARACTER O 100 (comment uni27E8.s3)
   (CHARWD R 0.765)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 130)
   )
(CHARACTER O 101 (comment uni27E9.s3)
   (CHARWD R 0.765)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 131)
   )
(CHARACTER O 102 (comment uni27EA.s3)
   (CHARWD R 1.091)
   (CHARHT R 0.066)
   (CHARDP R 2.395)
   (NEXTLARGER O 132)
   )
(CHARACTER O 103 (comment uni27EB.s3)
   (CHARWD R 1.091)
   (CHARHT R 0.066)
   (CHARDP R 2.395)
   (NEXTLARGER O 133)
   )
(CHARACTER O 104 (comment uni2772.s3)
   (CHARWD R 0.842)
   (CHARHT R 0.066)
   (CHARDP R 2.393)
   (NEXTLARGER O 134)
   )
(CHARACTER O 105 (comment uni2773.s3)
   (CHARWD R 0.842)
   (CHARHT R 0.066)
   (CHARDP R 2.393)
   (NEXTLARGER O 135)
   )
(CHARACTER O 106 (comment slash.s3)
   (CHARWD R 1.101)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 136)
   )
(CHARACTER O 107 (comment uni005C.s3)
   (CHARWD R 1.101)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 137)
   )
(CHARACTER O 110 (comment parenleft.s4)
   (CHARWD R 0.808)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   (NEXTLARGER O 140)
   )
(CHARACTER O 111 (comment parenright.s4)
   (CHARWD R 0.808)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   (NEXTLARGER O 141)
   )
(CHARACTER O 112 (comment uni2985.s4)
   (CHARWD R 1.175)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 113 (comment uni2986.s4)
   (CHARWD R 1.175)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 114 (comment bracketleft.s4)
   (CHARWD R 0.661)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   (NEXTLARGER O 142)
   )
(CHARACTER O 115 (comment bracketright.s4)
   (CHARWD R 0.661)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   (NEXTLARGER O 143)
   )
(CHARACTER O 116 (comment uni27E6.s4)
   (CHARWD R 0.778)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 117 (comment uni27E7.s4)
   (CHARWD R 0.778)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 120 (comment uni230A.s4)
   (CHARWD R 0.682)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   (NEXTLARGER O 144)
   )
(CHARACTER O 121 (comment uni230B.s4)
   (CHARWD R 0.682)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   (NEXTLARGER O 145)
   )
(CHARACTER O 122 (comment uni2308.s4)
   (CHARWD R 0.682)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   (NEXTLARGER O 146)
   )
(CHARACTER O 123 (comment uni2309.s4)
   (CHARWD R 0.682)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   (NEXTLARGER O 147)
   )
(CHARACTER O 124 (comment braceleft.s4)
   (CHARWD R 1.076)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   (NEXTLARGER O 154)
   )
(CHARACTER O 125 (comment braceright.s4)
   (CHARWD R 1.076)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   (NEXTLARGER O 155)
   )
(CHARACTER O 126 (comment uni2983.s4)
   (CHARWD R 1.225)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 127 (comment uni2984.s4)
   (CHARWD R 1.225)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 130 (comment uni27E8.s4)
   (CHARWD R 0.908)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 131 (comment uni27E9.s4)
   (CHARWD R 0.908)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 132 (comment uni27EA.s4)
   (CHARWD R 1.273)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 133 (comment uni27EB.s4)
   (CHARWD R 1.273)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 134 (comment uni2772.s4)
   (CHARWD R 1.031)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 135 (comment uni2773.s4)
   (CHARWD R 1.031)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 136 (comment slash.s4)
   (CHARWD R 1.309)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 137 (comment uni005C.s4)
   (CHARWD R 1.309)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   )
(CHARACTER O 140 (comment uni239B)
   (CHARWD R 0.45)
   (CHARHT R 0.903)
   (CHARDP R 0.051)
   (VARCHAR
      (TOP O 140)
      (BOT O 160)
      (REP O 162)
      )
   )
(CHARACTER O 141 (comment uni239E)
   (CHARWD R 0.45)
   (CHARHT R 0.903)
   (CHARDP R 0.051)
   (VARCHAR
      (TOP O 141)
      (BOT O 161)
      (REP O 163)
      )
   )
(CHARACTER O 142 (comment uni23A1)
   (CHARWD R 0.45)
   (CHARHT R 0.903)
   (CHARDP R 0.051)
   (VARCHAR
      (TOP O 142)
      (BOT O 144)
      (REP O 146)
      )
   )
(CHARACTER O 143 (comment uni23A4)
   (CHARWD R 0.45)
   (CHARHT R 0.903)
   (CHARDP R 0.051)
   (VARCHAR
      (TOP O 143)
      (BOT O 145)
      (REP O 147)
      )
   )
(CHARACTER O 144 (comment uni23A3)
   (CHARWD R 0.45)
   (CHARHT R 0.687)
   (CHARDP R 0.267)
   (VARCHAR
      (BOT O 144)
      (REP O 146)
      )
   )
(CHARACTER O 145 (comment uni23A6)
   (CHARWD R 0.45)
   (CHARHT R 0.687)
   (CHARDP R 0.267)
   (VARCHAR
      (BOT O 145)
      (REP O 147)
      )
   )
(CHARACTER O 146 (comment uni23A2)
   (CHARWD R 0.45)
   (CHARHT R 0.908)
   (CHARDP R 0)
   (VARCHAR
      (TOP O 142)
      (REP O 146)
      )
   )
(CHARACTER O 147 (comment uni23A5)
   (CHARWD R 0.45)
   (CHARHT R 0.908)
   (CHARDP R 0)
   (VARCHAR
      (TOP O 143)
      (REP O 147)
      )
   )
(CHARACTER O 150 (comment uni23A7)
   (CHARWD R 0.64)
   (CHARHT R 0.903)
   (CHARDP R 0.051)
   )
(CHARACTER O 151 (comment uni23AB)
   (CHARWD R 0.64)
   (CHARHT R 0.903)
   (CHARDP R 0.051)
   )
(CHARACTER O 152 (comment uni23A9)
   (CHARWD R 0.64)
   (CHARHT R 0.705)
   (CHARDP R 0.249)
   )
(CHARACTER O 153 (comment uni23AD)
   (CHARWD R 0.64)
   (CHARHT R 0.705)
   (CHARDP R 0.249)
   )
(CHARACTER O 154 (comment uni23A8)
   (CHARWD R 0.64)
   (CHARHT R 0.908)
   (CHARDP R 0)
   (VARCHAR
      (TOP O 150)
      (MID O 154)
      (BOT O 152)
      (REP O 156)
      )
   )
(CHARACTER O 155 (comment uni23AC)
   (CHARWD R 0.64)
   (CHARHT R 0.908)
   (CHARDP R 0)
   (VARCHAR
      (TOP O 151)
      (MID O 155)
      (BOT O 153)
      (REP O 156)
      )
   )
(CHARACTER O 156 (comment uni23AA)
   (CHARWD R 0.64)
   (CHARHT R 0.908)
   (CHARDP R 0)
   )
(CHARACTER O 160 (comment uni239D)
   (CHARWD R 0.45)
   (CHARHT R 0.705)
   (CHARDP R 0.249)
   )
(CHARACTER O 161 (comment uni23A0)
   (CHARWD R 0.45)
   (CHARHT R 0.705)
   (CHARDP R 0.249)
   )
(CHARACTER O 162 (comment uni239C)
   (CHARWD R 0.45)
   (CHARHT R 0.908)
   (CHARDP R 0)
   )
(CHARACTER O 163 (comment uni239F)
   (CHARWD R 0.45)
   (CHARHT R 0.908)
   (CHARDP R 0)
   )
(CHARACTER O 164 (comment uni221A.s1)
   (CHARWD R 1.057)
   (CHARHT R 0.066)
   (CHARDP R 1.781)
   (NEXTLARGER O 165)
   )
(CHARACTER O 165 (comment uni221A.s2)
   (CHARWD R 1.124)
   (CHARHT R 0.066)
   (CHARDP R 2.394)
   (NEXTLARGER O 166)
   )
(CHARACTER O 166 (comment uni221A.s3)
   (CHARWD R 1.076)
   (CHARHT R 0.066)
   (CHARDP R 3.009)
   (NEXTLARGER O 167)
   )
(CHARACTER O 167 (comment uni221A.s4)
   (CHARWD R 1.184)
   (CHARHT R 0.066)
   (CHARDP R 1.789)
   (NEXTLARGER O 171)
   )
(CHARACTER O 170 (comment uni221A.x)
   (CHARWD R 1.184)
   (CHARHT R 0.015)
   (CHARDP R 0.518)
   )
(CHARACTER O 171 (comment uni221A.t)
   (CHARWD R 1.184)
   (CHARHT R 0.066)
   (CHARDP R 0.509)
   (VARCHAR
      (TOP O 171)
      (BOT O 167)
      (REP O 170)
      )
   )
(CHARACTER O 260 (comment uni2140)
   (CHARWD R 0.923)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 306)
   )
(CHARACTER O 261 (comment uni220F)
   (CHARWD R 1)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 307)
   )
(CHARACTER O 262 (comment uni2210)
   (CHARWD R 1)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 310)
   )
(CHARACTER O 263 (comment uni2211)
   (CHARWD R 0.914)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 311)
   )
(CHARACTER O 264 (comment uni22C0)
   (CHARWD R 0.924)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 312)
   )
(CHARACTER O 265 (comment uni22C1)
   (CHARWD R 0.924)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 313)
   )
(CHARACTER O 266 (comment uni22C2)
   (CHARWD R 0.924)
   (CHARHT R 0.066)
   (CHARDP R 0.966)
   (NEXTLARGER O 314)
   )
(CHARACTER O 267 (comment uni22C3)
   (CHARWD R 0.924)
   (CHARHT R 0.066)
   (CHARDP R 0.966)
   (NEXTLARGER O 315)
   )
(CHARACTER O 270 (comment uni29F8)
   (CHARWD R 0.602)
   (CHARHT R 0.066)
   (CHARDP R 0.954)
   (NEXTLARGER O 316)
   )
(CHARACTER O 271 (comment uni29F9)
   (CHARWD R 0.602)
   (CHARHT R 0.066)
   (CHARDP R 0.954)
   (NEXTLARGER O 317)
   )
(CHARACTER O 272 (comment uni2A00)
   (CHARWD R 1.126)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 320)
   )
(CHARACTER O 273 (comment uni2A01)
   (CHARWD R 1.126)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 321)
   )
(CHARACTER O 274 (comment uni2A02)
   (CHARWD R 1.126)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 322)
   )
(CHARACTER O 275 (comment uni2A03)
   (CHARWD R 0.924)
   (CHARHT R 0.066)
   (CHARDP R 0.966)
   (NEXTLARGER O 323)
   )
(CHARACTER O 276 (comment uni2A04)
   (CHARWD R 0.924)
   (CHARHT R 0.066)
   (CHARDP R 0.966)
   (NEXTLARGER O 324)
   )
(CHARACTER O 277 (comment uni2A05)
   (CHARWD R 0.924)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 325)
   )
(CHARACTER O 300 (comment uni2A06)
   (CHARWD R 0.924)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 326)
   )
(CHARACTER O 301 (comment uni2A07)
   (CHARWD R 1.18)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 327)
   )
(CHARACTER O 302 (comment uni2A08)
   (CHARWD R 1.18)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 330)
   )
(CHARACTER O 303 (comment uni2A09)
   (CHARWD R 1.021)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 331)
   )
(CHARACTER O 304 (comment uni2A0A)
   (CHARWD R 0.914)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 332)
   )
(CHARACTER O 305 (comment uni2AFF)
   (CHARWD R 0.478)
   (CHARHT R 0.066)
   (CHARDP R 0.956)
   (NEXTLARGER O 333)
   )
(CHARACTER O 306 (comment uni2140.s1)
   (CHARWD R 1.259)
   (CHARHT R 0.066)
   (CHARDP R 1.384)
   )
(CHARACTER O 307 (comment uni220F.s1)
   (CHARWD R 1.355)
   (CHARHT R 0.066)
   (CHARDP R 1.385)
   )
(CHARACTER O 310 (comment uni2210.s1)
   (CHARWD R 1.355)
   (CHARHT R 0.066)
   (CHARDP R 1.385)
   )
(CHARACTER O 311 (comment uni2211.s1)
   (CHARWD R 1.292)
   (CHARHT R 0.066)
   (CHARDP R 1.384)
   )
(CHARACTER O 312 (comment uni22C0.s1)
   (CHARWD R 1.265)
   (CHARHT R 0.066)
   (CHARDP R 1.385)
   )
(CHARACTER O 313 (comment uni22C1.s1)
   (CHARWD R 1.265)
   (CHARHT R 0.066)
   (CHARDP R 1.385)
   )
(CHARACTER O 314 (comment uni22C2.s1)
   (CHARWD R 1.265)
   (CHARHT R 0.066)
   (CHARDP R 1.395)
   )
(CHARACTER O 315 (comment uni22C3.s1)
   (CHARWD R 1.265)
   (CHARHT R 0.066)
   (CHARDP R 1.395)
   )
(CHARACTER O 316 (comment uni29F8.s1)
   (CHARWD R 0.806)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   )
(CHARACTER O 317 (comment uni29F9.s1)
   (CHARWD R 0.806)
   (CHARHT R 0.066)
   (CHARDP R 1.779)
   )
(CHARACTER O 320 (comment uni2A00.s1)
   (CHARWD R 1.555)
   (CHARHT R 0.066)
   (CHARDP R 1.385)
   )
(CHARACTER O 321 (comment uni2A01.s1)
   (CHARWD R 1.555)
   (CHARHT R 0.066)
   (CHARDP R 1.385)
   )
(CHARACTER O 322 (comment uni2A02.s1)
   (CHARWD R 1.555)
   (CHARHT R 0.066)
   (CHARDP R 1.385)
   )
(CHARACTER O 323 (comment uni2A03.s1)
   (CHARWD R 1.265)
   (CHARHT R 0.066)
   (CHARDP R 1.395)
   )
(CHARACTER O 324 (comment uni2A04.s1)
   (CHARWD R 1.265)
   (CHARHT R 0.066)
   (CHARDP R 1.395)
   )
(CHARACTER O 325 (comment uni2A05.s1)
   (CHARWD R 1.153)
   (CHARHT R 0.066)
   (CHARDP R 1.385)
   )
(CHARACTER O 326 (comment uni2A06.s1)
   (CHARWD R 1.153)
   (CHARHT R 0.066)
   (CHARDP R 1.385)
   )
(CHARACTER O 327 (comment uni2A07.s1)
   (CHARWD R 1.53)
   (CHARHT R 0.066)
   (CHARDP R 1.385)
   )
(CHARACTER O 330 (comment uni2A08.s1)
   (CHARWD R 1.53)
   (CHARHT R 0.066)
   (CHARDP R 1.385)
   )
(CHARACTER O 331 (comment uni2A09.s1)
   (CHARWD R 1.482)
   (CHARHT R 0.066)
   (CHARDP R 1.385)
   )
(CHARACTER O 332 (comment uni2A0A.s1)
   (CHARWD R 1.292)
   (CHARHT R 0.066)
   (CHARDP R 1.384)
   )
(CHARACTER O 333 (comment uni2AFF.s1)
   (CHARWD R 0.41)
   (CHARHT R 0.066)
   (CHARDP R 1.164)
   )
(CHARACTER O 334 (comment uni27EE)
   (CHARWD R 0.233)
   (CHARHT R 0.676)
   (CHARDP R 0.177)
   (VARCHAR
      (TOP O 150)
      (BOT O 152)
      (REP O 156)
      )
   )
(CHARACTER O 335 (comment uni27EF)
   (CHARWD R 0.233)
   (CHARHT R 0.676)
   (CHARDP R 0.177)
   (VARCHAR
      (TOP O 151)
      (BOT O 153)
      (REP O 156)
      )
   )
(CHARACTER O 336 (comment uni2985)
   (CHARWD R 0.463)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 337 (comment uni2986)
   (CHARWD R 0.463)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 340 (comment uni27E6)
   (CHARWD R 0.504)
   (CHARHT R 0.717)
   (CHARDP R 0.213)
   )
(CHARACTER O 341 (comment uni27E7)
   (CHARWD R 0.504)
   (CHARHT R 0.717)
   (CHARDP R 0.213)
   )
(CHARACTER O 342 (comment uni230A)
   (CHARWD R 0.469)
   (CHARHT R 0.713)
   (CHARDP R 0.213)
   )
(CHARACTER O 343 (comment uni230B)
   (CHARWD R 0.469)
   (CHARHT R 0.713)
   (CHARDP R 0.213)
   )
(CHARACTER O 344 (comment uni2308)
   (CHARWD R 0.469)
   (CHARHT R 0.713)
   (CHARDP R 0.213)
   )
(CHARACTER O 345 (comment uni2309)
   (CHARWD R 0.469)
   (CHARHT R 0.713)
   (CHARDP R 0.213)
   )
(CHARACTER O 346 (comment uni23B0)
   (CHARWD R 0.6)
   (CHARHT R 0.7)
   (CHARDP R 0.301)
   (VARCHAR
      (TOP O 150)
      (BOT O 153)
      (REP O 156)
      )
   )
(CHARACTER O 347 (comment uni23B1)
   (CHARWD R 0.6)
   (CHARHT R 0.7)
   (CHARDP R 0.301)
   (VARCHAR
      (TOP O 151)
      (BOT O 152)
      (REP O 156)
      )
   )
(CHARACTER O 350 (comment uni2983)
   (CHARWD R 0.596)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 351 (comment uni2984)
   (CHARWD R 0.596)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 352 (comment uni27E8)
   (CHARWD R 0.4)
   (CHARHT R 0.713)
   (CHARDP R 0.213)
   )
(CHARACTER O 353 (comment uni27E9)
   (CHARWD R 0.4)
   (CHARHT R 0.713)
   (CHARDP R 0.213)
   )
(CHARACTER O 354 (comment uni27EA)
   (CHARWD R 0.61)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 355 (comment uni27EB)
   (CHARWD R 0.61)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 356 (comment uni2772)
   (CHARWD R 0.488)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 357 (comment uni2773)
   (CHARWD R 0.488)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 360 (comment uni007C.var)
   (CHARWD R 0.32)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 361 (comment uni2016)
   (CHARWD R 0.523)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 362 (comment uni2980)
   (CHARWD R 0.594)
   (CHARHT R 0.695)
   (CHARDP R 0.189)
   )
(CHARACTER O 363 (comment uni007C.x)
   (CHARWD R 0.32)
   (CHARHT R 0.55)
   (CHARDP R 0)
   (VARCHAR
      (REP O 363)
      )
   )
(CHARACTER O 364 (comment uni2016.x)
   (CHARWD R 0.523)
   (CHARHT R 0.55)
   (CHARDP R 0)
   (VARCHAR
      (REP O 364)
      )
   )
(CHARACTER O 365 (comment uni2980.x)
   (CHARWD R 0.594)
   (CHARHT R 0.555)
   (CHARDP R 0)
   (VARCHAR
      (REP O 365)
      )
   )
(CHARACTER O 371 (comment uni221A)
   (CHARWD R 0.928)
   (CHARHT R 0.066)
   (CHARDP R 1.166)
   )
(CHARACTER O 372 (comment uni27CC)
   (CHARWD R 0.325)
   (CHARHT R 0.054)
   (CHARDP R 0.965)
   )
