(FAMILY STIXMathScript)
(CODINGSCHEME STIXMATHSCR-BOLD)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   (NUM1 R 0.58)
   (NUM2 R 0.48)
   (NUM3 R 0.48)
   (DENOM1 R 0.7)
   (DENOM2 R 0.48)
   (SUP1 R 0.4)
   (SUP2 R 0.35)
   (SUP3 R 0.275)
   (SUB1 R 0.25)
   (SUB2 R 0.35)
   (SUPDROP R 0.375)
   (SUBDROP R 0.05)
   (DELIM1 R 2.4)
   (DELIM2 R 1)
   (AXISHEIGHT R 0.25)
   )
(LIGTABLE
   (LABEL O 101) (comment u1D4D0)
   (KRN O 177 R 0.408) (comment uni2040)
   (STOP)
   (LABEL O 102) (comment u1D4D1)
   (KRN O 177 R 0.326) (comment uni2040)
   (STOP)
   (LABEL O 103) (comment u1D4D2)
   (KRN O 177 R 0.288) (comment uni2040)
   (STOP)
   (LABEL O 104) (comment u1D4D3)
   (KRN O 177 R 0.3035) (comment uni2040)
   (STOP)
   (LABEL O 105) (comment u1D4D4)
   (KRN O 177 R 0.244) (comment uni2040)
   (STOP)
   (LABEL O 106) (comment u1D4D5)
   (KRN O 177 R 0.198) (comment uni2040)
   (STOP)
   (LABEL O 107) (comment u1D4D6)
   (KRN O 177 R 0.25) (comment uni2040)
   (STOP)
   (LABEL O 110) (comment u1D4D7)
   (KRN O 177 R 0.2015) (comment uni2040)
   (STOP)
   (LABEL O 111) (comment u1D4D8)
   (KRN O 177 R 0.2275) (comment uni2040)
   (STOP)
   (LABEL O 112) (comment u1D4D9)
   (KRN O 177 R 0.178) (comment uni2040)
   (STOP)
   (LABEL O 113) (comment u1D4DA)
   (KRN O 177 R 0.266) (comment uni2040)
   (STOP)
   (LABEL O 114) (comment u1D4DB)
   (KRN O 177 R 0.388) (comment uni2040)
   (STOP)
   (LABEL O 115) (comment u1D4DC)
   (KRN O 177 R 0.356) (comment uni2040)
   (STOP)
   (LABEL O 116) (comment u1D4DD)
   (KRN O 177 R 0.2795) (comment uni2040)
   (STOP)
   (LABEL O 117) (comment u1D4DE)
   (KRN O 177 R 0.1575) (comment uni2040)
   (STOP)
   (LABEL O 120) (comment u1D4DF)
   (KRN O 177 R 0.3035) (comment uni2040)
   (STOP)
   (LABEL O 121) (comment u1D4E0)
   (KRN O 177 R 0.1575) (comment uni2040)
   (STOP)
   (LABEL O 122) (comment u1D4E1)
   (KRN O 177 R 0.292) (comment uni2040)
   (STOP)
   (LABEL O 123) (comment u1D4E2)
   (KRN O 177 R 0.198) (comment uni2040)
   (STOP)
   (LABEL O 124) (comment u1D4E3)
   (KRN O 177 R 0.2) (comment uni2040)
   (STOP)
   (LABEL O 125) (comment u1D4E4)
   (KRN O 177 R 0.142) (comment uni2040)
   (STOP)
   (LABEL O 126) (comment u1D4E5)
   (KRN O 177 R 0.202) (comment uni2040)
   (STOP)
   (LABEL O 127) (comment u1D4E6)
   (KRN O 177 R 0.276) (comment uni2040)
   (STOP)
   (LABEL O 130) (comment u1D4E7)
   (KRN O 177 R 0.1495) (comment uni2040)
   (STOP)
   (LABEL O 131) (comment u1D4E8)
   (KRN O 177 R 0.1395) (comment uni2040)
   (STOP)
   (LABEL O 132) (comment u1D4E9)
   (KRN O 177 R 0.178) (comment uni2040)
   (STOP)
   (LABEL O 141) (comment u1D4EA)
   (KRN O 177 R 0.114) (comment uni2040)
   (STOP)
   (LABEL O 142) (comment u1D4EB)
   (KRN O 177 R 0.202) (comment uni2040)
   (STOP)
   (LABEL O 143) (comment u1D4EC)
   (KRN O 177 R 0.178) (comment uni2040)
   (STOP)
   (LABEL O 144) (comment u1D4ED)
   (KRN O 177 R 0.3735) (comment uni2040)
   (STOP)
   (LABEL O 145) (comment u1D4EE)
   (KRN O 177 R 0.16) (comment uni2040)
   (STOP)
   (LABEL O 146) (comment u1D4EF)
   (KRN O 177 R 0.238) (comment uni2040)
   (STOP)
   (LABEL O 147) (comment u1D4F0)
   (KRN O 177 R 0.1475) (comment uni2040)
   (STOP)
   (LABEL O 150) (comment u1D4F1)
   (KRN O 177 R 0.138) (comment uni2040)
   (STOP)
   (LABEL O 151) (comment u1D4F2)
   (KRN O 177 R 0.17) (comment uni2040)
   (STOP)
   (LABEL O 152) (comment u1D4F3)
   (KRN O 177 R 0.318) (comment uni2040)
   (STOP)
   (LABEL O 153) (comment u1D4F4)
   (KRN O 177 R 0.15) (comment uni2040)
   (STOP)
   (LABEL O 154) (comment u1D4F5)
   (KRN O 177 R 0.18) (comment uni2040)
   (STOP)
   (LABEL O 155) (comment u1D4F6)
   (KRN O 177 R 0.0795) (comment uni2040)
   (STOP)
   (LABEL O 156) (comment u1D4F7)
   (KRN O 177 R 0.0555) (comment uni2040)
   (STOP)
   (LABEL O 157) (comment u1D4F8)
   (KRN O 177 R 0.152) (comment uni2040)
   (STOP)
   (LABEL O 160) (comment u1D4F9)
   (KRN O 177 R 0.1935) (comment uni2040)
   (STOP)
   (LABEL O 161) (comment u1D4FA)
   (KRN O 177 R 0.1055) (comment uni2040)
   (STOP)
   (LABEL O 162) (comment u1D4FB)
   (KRN O 177 R 0.1135) (comment uni2040)
   (STOP)
   (LABEL O 163) (comment u1D4FC)
   (KRN O 177 R 0.094) (comment uni2040)
   (STOP)
   (LABEL O 164) (comment u1D4FD)
   (KRN O 177 R 0.146) (comment uni2040)
   (STOP)
   (LABEL O 165) (comment u1D4FE)
   (KRN O 177 R 0.054) (comment uni2040)
   (STOP)
   (LABEL O 166) (comment u1D4FF)
   (KRN O 177 R 0.098) (comment uni2040)
   (STOP)
   (LABEL O 167) (comment u1D500)
   (KRN O 177 R 0.116) (comment uni2040)
   (STOP)
   (LABEL O 170) (comment u1D501)
   (KRN O 177 R 0.078) (comment uni2040)
   (STOP)
   (LABEL O 171) (comment u1D502)
   (KRN O 177 R 0.108) (comment uni2040)
   (STOP)
   (LABEL O 172) (comment u1D503)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 173) (comment u1D4F2.dtls)
   (KRN O 177 R 0.075) (comment uni2040)
   (STOP)
   (LABEL O 174) (comment u1D4F3.dtls)
   (KRN O 177 R 0.231) (comment uni2040)
   (STOP)
   )
(CHARACTER O 0 (comment uni22B5)
   (CHARWD R 0.75)
   (CHARHT R 0.621)
   (CHARDP R 0.113)
   )
(CHARACTER O 1 (comment uni22B6)
   (CHARWD R 1.216)
   (CHARHT R 0.436)
   )
(CHARACTER O 2 (comment uni22B7)
   (CHARWD R 1.216)
   (CHARHT R 0.436)
   )
(CHARACTER O 3 (comment uni22B8)
   (CHARWD R 0.884)
   (CHARHT R 0.436)
   )
(CHARACTER O 4 (comment uni22B9)
   (CHARWD R 0.75)
   (CHARHT R 0.563)
   (CHARDP R 0.057)
   )
(CHARACTER O 5 (comment uni22BA)
   (CHARWD R 0.498)
   (CHARHT R 0.461)
   (CHARDP R 0.216)
   )
(CHARACTER O 6 (comment uni22BB)
   (CHARWD R 0.64)
   (CHARHT R 0.536)
   (CHARDP R 0.189)
   )
(CHARACTER O 7 (comment uni22BC)
   (CHARWD R 0.64)
   (CHARHT R 0.697)
   (CHARDP R 0.028)
   )
(CHARACTER O 10 (comment uni22BD)
   (CHARWD R 0.64)
   (CHARHT R 0.697)
   (CHARDP R 0.028)
   )
(CHARACTER O 11 (comment uni22BE)
   (CHARWD R 0.75)
   (CHARHT R 0.63)
   )
(CHARACTER O 12 (comment uni22BF)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 13 (comment uni22C4)
   (CHARWD R 0.584)
   (CHARHT R 0.515)
   )
(CHARACTER O 14 (comment uni22C5)
   (CHARWD R 0.286)
   (CHARHT R 0.313)
   )
(CHARACTER O 15 (comment uni22C7)
   (CHARWD R 0.75)
   (CHARHT R 0.595)
   (CHARDP R 0.063)
   )
(CHARACTER O 16 (comment uni22C8)
   (CHARWD R 0.87)
   (CHARHT R 0.604)
   (CHARDP R 0.072)
   )
(CHARACTER O 17 (comment uni22C9)
   (CHARWD R 0.87)
   (CHARHT R 0.604)
   (CHARDP R 0.072)
   )
(CHARACTER O 20 (comment uni22CA)
   (CHARWD R 0.87)
   (CHARHT R 0.604)
   (CHARDP R 0.072)
   )
(CHARACTER O 21 (comment uni22CB)
   (CHARWD R 0.87)
   (CHARHT R 0.604)
   (CHARDP R 0.072)
   )
(CHARACTER O 22 (comment uni22CC)
   (CHARWD R 0.87)
   (CHARHT R 0.604)
   (CHARDP R 0.072)
   )
(CHARACTER O 23 (comment uni22CD)
   (CHARWD R 0.75)
   (CHARHT R 0.463)
   )
(CHARACTER O 24 (comment uni22CE)
   (CHARWD R 0.64)
   (CHARHT R 0.536)
   (CHARDP R 0.028)
   )
(CHARACTER O 25 (comment uni22CF)
   (CHARWD R 0.64)
   (CHARHT R 0.536)
   (CHARDP R 0.028)
   )
(CHARACTER O 26 (comment uni22D0)
   (CHARWD R 0.75)
   (CHARHT R 0.6)
   (CHARDP R 0.067)
   )
(CHARACTER O 27 (comment uni22D1)
   (CHARWD R 0.75)
   (CHARHT R 0.6)
   (CHARDP R 0.067)
   )
(CHARACTER O 30 (comment uni22D2)
   (CHARWD R 0.75)
   (CHARHT R 0.541)
   (CHARDP R 0.033)
   )
(CHARACTER O 31 (comment uni22D3)
   (CHARWD R 0.75)
   (CHARHT R 0.541)
   (CHARDP R 0.033)
   )
(CHARACTER O 32 (comment uni22D4)
   (CHARWD R 0.65)
   (CHARHT R 0.643)
   (CHARDP R 0.033)
   )
(CHARACTER O 33 (comment uni22D5)
   (CHARWD R 0.685)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 34 (comment uni22D6)
   (CHARWD R 0.75)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 35 (comment uni22D7)
   (CHARWD R 0.75)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 36 (comment uni22D8)
   (CHARWD R 1.336)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 37 (comment uni22D9)
   (CHARWD R 1.336)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 40 (comment uni22DA)
   (CHARWD R 0.75)
   (CHARHT R 0.916)
   (CHARDP R 0.408)
   )
(CHARACTER O 41 (comment uni22DB)
   (CHARWD R 0.75)
   (CHARHT R 0.916)
   (CHARDP R 0.408)
   )
(CHARACTER O 42 (comment uni22DC)
   (CHARWD R 0.75)
   (CHARHT R 0.627)
   (CHARDP R 0.12)
   )
(CHARACTER O 43 (comment uni22DD)
   (CHARWD R 0.75)
   (CHARHT R 0.627)
   (CHARDP R 0.12)
   )
(CHARACTER O 44 (comment uni22DE)
   (CHARWD R 0.75)
   (CHARHT R 0.645)
   (CHARDP R 0.138)
   )
(CHARACTER O 45 (comment uni22DF)
   (CHARWD R 0.75)
   (CHARHT R 0.645)
   (CHARDP R 0.138)
   )
(CHARACTER O 46 (comment uni22E0)
   (CHARWD R 0.75)
   (CHARHT R 0.735)
   (CHARDP R 0.199)
   )
(CHARACTER O 47 (comment uni22E1)
   (CHARWD R 0.75)
   (CHARHT R 0.735)
   (CHARDP R 0.199)
   )
(CHARACTER O 50 (comment uni22E2)
   (CHARWD R 0.75)
   (CHARHT R 0.792)
   (CHARDP R 0.241)
   )
(CHARACTER O 51 (comment uni22E3)
   (CHARWD R 0.75)
   (CHARHT R 0.792)
   (CHARDP R 0.241)
   )
(CHARACTER O 52 (comment uni22E4)
   (CHARWD R 0.685)
   (CHARHT R 0.627)
   (CHARDP R 0.216)
   )
(CHARACTER O 53 (comment uni22E5)
   (CHARWD R 0.685)
   (CHARHT R 0.627)
   (CHARDP R 0.216)
   )
(CHARACTER O 54 (comment uni22E6)
   (CHARWD R 0.75)
   (CHARHT R 0.69)
   (CHARDP R 0.2)
   )
(CHARACTER O 55 (comment uni22E7)
   (CHARWD R 0.75)
   (CHARHT R 0.69)
   (CHARDP R 0.2)
   )
(CHARACTER O 56 (comment uni22E8)
   (CHARWD R 0.75)
   (CHARHT R 0.676)
   (CHARDP R 0.187)
   )
(CHARACTER O 57 (comment uni22E9)
   (CHARWD R 0.75)
   (CHARHT R 0.676)
   (CHARDP R 0.187)
   )
(CHARACTER O 60 (comment uni22EA)
   (CHARWD R 0.75)
   (CHARHT R 0.625)
   (CHARDP R 0.115)
   )
(CHARACTER O 61 (comment uni22EB)
   (CHARWD R 0.75)
   (CHARHT R 0.625)
   (CHARDP R 0.115)
   )
(CHARACTER O 62 (comment uni22EC)
   (CHARWD R 0.75)
   (CHARHT R 0.711)
   (CHARDP R 0.228)
   )
(CHARACTER O 63 (comment uni22ED)
   (CHARWD R 0.75)
   (CHARHT R 0.711)
   (CHARDP R 0.228)
   )
(CHARACTER O 64 (comment uni22EE)
   (CHARWD R 0.584)
   (CHARHT R 0.678)
   (CHARDP R 0.174)
   )
(CHARACTER O 65 (comment uni22EF)
   (CHARWD R 0.977)
   (CHARHT R 0.351)
   )
(CHARACTER O 66 (comment uni22F0)
   (CHARWD R 0.977)
   (CHARHT R 0.579)
   (CHARDP R 0.075)
   )
(CHARACTER O 67 (comment uni22F1)
   (CHARWD R 0.977)
   (CHARHT R 0.579)
   (CHARDP R 0.075)
   )
(CHARACTER O 70 (comment uni22F2)
   (CHARWD R 0.823)
   (CHARHT R 0.531)
   (CHARDP R 0.027)
   )
(CHARACTER O 71 (comment uni22F3)
   (CHARWD R 0.685)
   (CHARHT R 0.531)
   (CHARDP R 0.027)
   )
(CHARACTER O 72 (comment uni22F4)
   (CHARWD R 0.486)
   (CHARHT R 0.459)
   )
(CHARACTER O 73 (comment uni22F5)
   (CHARWD R 0.685)
   (CHARHT R 0.716)
   (CHARDP R 0.027)
   )
(CHARACTER O 74 (comment uni22F6)
   (CHARWD R 0.75)
   (CHARHT R 0.735)
   (CHARDP R 0.013)
   )
(CHARACTER O 75 (comment uni22F7)
   (CHARWD R 0.486)
   (CHARHT R 0.613)
   )
(CHARACTER O 76 (comment uni22F8)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.18)
   )
(CHARACTER O 77 (comment uni22F9)
   (CHARWD R 0.685)
   (CHARHT R 0.531)
   (CHARDP R 0.027)
   )
(CHARACTER O 100 (comment uni22FA)
   (CHARWD R 0.823)
   (CHARHT R 0.531)
   (CHARDP R 0.027)
   )
(CHARACTER O 101 (comment u1D4D0)
   (CHARWD R 0.984)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 102 (comment u1D4D1)
   (CHARWD R 1.06)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 103 (comment u1D4D2)
   (CHARWD R 0.912)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 104 (comment u1D4D3)
   (CHARWD R 0.991)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 105 (comment u1D4D4)
   (CHARWD R 0.826)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 106 (comment u1D4D5)
   (CHARWD R 1.042)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 107 (comment u1D4D6)
   (CHARWD R 0.834)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 110 (comment u1D4D7)
   (CHARWD R 1.171)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 111 (comment u1D4D8)
   (CHARWD R 0.997)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 112 (comment u1D4D9)
   (CHARWD R 0.906)
   (CHARHT R 0.699)
   (CHARDP R 0.224)
   )
(CHARACTER O 113 (comment u1D4DA)
   (CHARWD R 1.154)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 114 (comment u1D4DB)
   (CHARWD R 1.036)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 115 (comment u1D4DC)
   (CHARWD R 1.3)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 116 (comment u1D4DD)
   (CHARWD R 1.095)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 117 (comment u1D4DE)
   (CHARWD R 0.809)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 120 (comment u1D4DF)
   (CHARWD R 1.025)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 121 (comment u1D4E0)
   (CHARWD R 0.809)
   (CHARHT R 0.699)
   (CHARDP R 0.052)
   )
(CHARACTER O 122 (comment u1D4E1)
   (CHARWD R 1.048)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 123 (comment u1D4E2)
   (CHARWD R 0.816)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 124 (comment u1D4E3)
   (CHARWD R 1.03)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 125 (comment u1D4E4)
   (CHARWD R 0.964)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 126 (comment u1D4E5)
   (CHARWD R 1.04)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 127 (comment u1D4E6)
   (CHARWD R 1.32)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 130 (comment u1D4E7)
   (CHARWD R 1.033)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 131 (comment u1D4E8)
   (CHARWD R 0.989)
   (CHARHT R 0.699)
   (CHARDP R 0.224)
   )
(CHARACTER O 132 (comment u1D4E9)
   (CHARWD R 0.996)
   (CHARHT R 0.699)
   (CHARDP R 0.021)
   )
(CHARACTER O 133 (comment uni22FB)
   (CHARWD R 0.685)
   (CHARHT R 0.531)
   (CHARDP R 0.027)
   )
(CHARACTER O 134 (comment uni22FC)
   (CHARWD R 0.486)
   (CHARHT R 0.459)
   )
(CHARACTER O 135 (comment uni22FD)
   (CHARWD R 0.75)
   (CHARHT R 0.735)
   (CHARDP R 0.013)
   )
(CHARACTER O 136 (comment uni22FE)
   (CHARWD R 0.486)
   (CHARHT R 0.613)
   )
(CHARACTER O 137 (comment uni22FF)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 140 (comment uni2300)
   (CHARWD R 0.606)
   (CHARHT R 0.487)
   )
(CHARACTER O 141 (comment u1D4EA)
   (CHARWD R 0.942)
   (CHARHT R 0.462)
   (CHARDP R 0.014)
   )
(CHARACTER O 142 (comment u1D4EB)
   (CHARWD R 0.646)
   (CHARHT R 0.699)
   (CHARDP R 0.014)
   )
(CHARACTER O 143 (comment u1D4EC)
   (CHARWD R 0.764)
   (CHARHT R 0.462)
   (CHARDP R 0.014)
   )
(CHARACTER O 144 (comment u1D4ED)
   (CHARWD R 0.949)
   (CHARHT R 0.699)
   (CHARDP R 0.014)
   )
(CHARACTER O 145 (comment u1D4EE)
   (CHARWD R 0.726)
   (CHARHT R 0.462)
   (CHARDP R 0.014)
   )
(CHARACTER O 146 (comment u1D4EF)
   (CHARWD R 0.768)
   (CHARHT R 0.699)
   (CHARDP R 0.205)
   (CHARIC R 0.04)
   )
(CHARACTER O 147 (comment u1D4F0)
   (CHARWD R 0.819)
   (CHARHT R 0.462)
   (CHARDP R 0.224)
   )
(CHARACTER O 150 (comment u1D4F1)
   (CHARWD R 0.838)
   (CHARHT R 0.699)
   (CHARDP R 0.014)
   )
(CHARACTER O 151 (comment u1D4F2)
   (CHARWD R 0.558)
   (CHARHT R 0.698)
   (CHARDP R 0.014)
   (CHARIC R 0.04)
   )
(CHARACTER O 152 (comment u1D4F3)
   (CHARWD R 0.84)
   (CHARHT R 0.698)
   (CHARDP R 0.224)
   (CHARIC R 0.04)
   )
(CHARACTER O 153 (comment u1D4F4)
   (CHARWD R 0.81)
   (CHARHT R 0.699)
   (CHARDP R 0.014)
   )
(CHARACTER O 154 (comment u1D4F5)
   (CHARWD R 0.65)
   (CHARHT R 0.699)
   (CHARDP R 0.014)
   (CHARIC R 0.04)
   )
(CHARACTER O 155 (comment u1D4F6)
   (CHARWD R 1.137)
   (CHARHT R 0.462)
   (CHARDP R 0.014)
   )
(CHARACTER O 156 (comment u1D4F7)
   (CHARWD R 0.851)
   (CHARHT R 0.462)
   (CHARDP R 0.014)
   )
(CHARACTER O 157 (comment u1D4F8)
   (CHARWD R 0.848)
   (CHARHT R 0.462)
   (CHARDP R 0.014)
   )
(CHARACTER O 160 (comment u1D4F9)
   (CHARWD R 0.885)
   (CHARHT R 0.462)
   (CHARDP R 0.205)
   )
(CHARACTER O 161 (comment u1D4FA)
   (CHARWD R 0.913)
   (CHARHT R 0.462)
   (CHARDP R 0.205)
   )
(CHARACTER O 162 (comment u1D4FB)
   (CHARWD R 0.677)
   (CHARHT R 0.462)
   )
(CHARACTER O 163 (comment u1D4FC)
   (CHARWD R 0.562)
   (CHARHT R 0.557)
   (CHARDP R 0.014)
   )
(CHARACTER O 164 (comment u1D4FD)
   (CHARWD R 0.618)
   (CHARHT R 0.669)
   (CHARDP R 0.014)
   (CHARIC R 0.04)
   )
(CHARACTER O 165 (comment u1D4FE)
   (CHARWD R 0.842)
   (CHARHT R 0.449)
   (CHARDP R 0.014)
   )
(CHARACTER O 166 (comment u1D4FF)
   (CHARWD R 0.732)
   (CHARHT R 0.458)
   (CHARDP R 0.014)
   )
(CHARACTER O 167 (comment u1D500)
   (CHARWD R 1.012)
   (CHARHT R 0.458)
   (CHARDP R 0.014)
   )
(CHARACTER O 170 (comment u1D501)
   (CHARWD R 0.82)
   (CHARHT R 0.462)
   (CHARDP R 0.014)
   )
(CHARACTER O 171 (comment u1D502)
   (CHARWD R 0.784)
   (CHARHT R 0.449)
   (CHARDP R 0.224)
   )
(CHARACTER O 172 (comment u1D503)
   (CHARWD R 0.782)
   (CHARHT R 0.493)
   (CHARDP R 0.014)
   )
(CHARACTER O 173 (comment u1D4F2.dtls)
   (CHARWD R 0.558)
   (CHARHT R 0.449)
   (CHARDP R 0.014)
   (CHARIC R 0.04)
   )
(CHARACTER O 174 (comment u1D4F3.dtls)
   (CHARWD R 0.84)
   (CHARHT R 0.449)
   (CHARDP R 0.224)
   (CHARIC R 0.04)
   )
(CHARACTER O 175 (comment uni2118)
   (CHARWD R 0.85)
   (CHARHT R 0.541)
   (CHARDP R 0.219)
   )
(CHARACTER O 176 (comment uni2302)
   (CHARWD R 0.926)
   (CHARHT R 0.774)
   )
(CHARACTER O 177 (comment uni2040)
   (CHARWD R 0.798)
   (CHARHT R 0.7)
   )
(CHARACTER O 200 (comment uni0300)
   (CHARWD R 0.238)
   (CHARHT R 0.7)
   )
(CHARACTER O 201 (comment uni0301)
   (CHARWD R 0.238)
   (CHARHT R 0.7)
   )
(CHARACTER O 202 (comment uni0302)
   (CHARWD R 0.337)
   (CHARHT R 0.7)
   )
(CHARACTER O 203 (comment uni0303)
   (CHARWD R 0.365)
   (CHARHT R 0.7)
   )
(CHARACTER O 204 (comment uni0304)
   (CHARWD R 0.33)
   (CHARHT R 0.6)
   )
(CHARACTER O 205 (comment uni0306)
   (CHARWD R 0.303)
   (CHARHT R 0.7)
   )
(CHARACTER O 206 (comment uni0307)
   (CHARWD R 0.129)
   (CHARHT R 0.7)
   )
(CHARACTER O 207 (comment uni0308)
   (CHARWD R 0.339)
   (CHARHT R 0.7)
   )
(CHARACTER O 210 (comment uni0309)
   (CHARWD R 0.205)
   (CHARHT R 0.8)
   )
(CHARACTER O 211 (comment uni030A)
   (CHARWD R 0.213)
   (CHARHT R 0.8)
   )
(CHARACTER O 212 (comment uni030C)
   (CHARWD R 0.337)
   (CHARHT R 0.7)
   )
(CHARACTER O 213 (comment uni0310)
   (CHARWD R 0.303)
   (CHARHT R 0.8)
   )
(CHARACTER O 214 (comment uni0312)
   (CHARWD R 0.184)
   (CHARHT R 0.9)
   )
(CHARACTER O 215 (comment uni0315)
   (CHARWD R 0.184)
   (CHARHT R 0.9)
   )
(CHARACTER O 216 (comment uni031A)
   (CHARWD R 0.317)
   (CHARHT R 0.8)
   )
(CHARACTER O 217 (comment uni20D0)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 220 (comment uni20D1)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 221 (comment uni20D6)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 222 (comment uni20D7)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 223 (comment uni20DB)
   (CHARWD R 0.549)
   (CHARHT R 0.7)
   )
(CHARACTER O 224 (comment uni20DC)
   (CHARWD R 0.759)
   (CHARHT R 0.7)
   )
(CHARACTER O 225 (comment uni20E1)
   (CHARWD R 0.594)
   (CHARHT R 0.8)
   )
(CHARACTER O 226 (comment uni20E7)
   (CHARWD R 0.843)
   (CHARHT R 0.8)
   (CHARDP R 0.2)
   )
(CHARACTER O 227 (comment uni20E9)
   (CHARWD R 0.564)
   (CHARHT R 0.7)
   )
(CHARACTER O 230 (comment uni20F0)
   (CHARWD R 0.27)
   (CHARHT R 0.8)
   )
(CHARACTER O 231 (comment uni2305)
   (CHARWD R 0.62)
   (CHARHT R 0.577)
   )
(CHARACTER O 232 (comment uni2306)
   (CHARWD R 0.62)
   (CHARHT R 0.728)
   )
(CHARACTER O 233 (comment uni2310)
   (CHARWD R 0.75)
   (CHARHT R 0.399)
   )
(CHARACTER O 234 (comment uni2311)
   (CHARWD R 0.523)
   (CHARHT R 0.439)
   )
(CHARACTER O 235 (comment uni2312)
   (CHARWD R 0.762)
   (CHARHT R 0.331)
   )
(CHARACTER O 236 (comment uni2313)
   (CHARWD R 0.762)
   (CHARHT R 0.331)
   )
(CHARACTER O 237 (comment uni2317)
   (CHARWD R 1.1)
   (CHARHT R 0.749)
   (CHARDP R 0.245)
   )
(CHARACTER O 240 (comment uni2319)
   (CHARWD R 0.75)
   (CHARHT R 0.399)
   )
(CHARACTER O 241 (comment uni231C)
   (CHARWD R 0.463)
   (CHARHT R 0.662)
   )
(CHARACTER O 242 (comment uni231D)
   (CHARWD R 0.463)
   (CHARHT R 0.662)
   )
(CHARACTER O 243 (comment uni231E)
   (CHARWD R 0.463)
   (CHARHT R 0.164)
   (CHARDP R 0.217)
   )
(CHARACTER O 244 (comment uni231F)
   (CHARWD R 0.463)
   (CHARHT R 0.164)
   (CHARDP R 0.217)
   )
(CHARACTER O 245 (comment uni232C)
   (CHARWD R 0.926)
   (CHARHT R 0.692)
   (CHARDP R 0.186)
   )
(CHARACTER O 246 (comment uni2332)
   (CHARWD R 0.889)
   (CHARHT R 0.562)
   (CHARDP R 0.056)
   )
(CHARACTER O 247 (comment uni2336)
   (CHARWD R 0.926)
   (CHARHT R 0.751)
   (CHARDP R 0.156)
   )
(CHARACTER O 250 (comment uni233D)
   (CHARWD R 0.924)
   (CHARHT R 0.694)
   (CHARDP R 0.19)
   )
(CHARACTER O 251 (comment uni233F)
   (CHARWD R 0.728)
   (CHARHT R 0.732)
   (CHARDP R 0.2)
   )
(CHARACTER O 252 (comment uni2340)
   (CHARWD R 0.683)
   (CHARHT R 0.703)
   (CHARDP R 0.176)
   )
(CHARACTER O 253 (comment uni2353)
   (CHARWD R 0.794)
   (CHARHT R 0.751)
   (CHARDP R 0.176)
   )
(CHARACTER O 254 (comment uni2370)
   (CHARWD R 0.794)
   (CHARHT R 0.751)
   (CHARDP R 0.176)
   )
(CHARACTER O 255 (comment uni237C)
   (CHARWD R 0.871)
   (CHARHT R 0.584)
   (CHARDP R 0.22)
   )
(CHARACTER O 256 (comment uni2394)
   (CHARWD R 0.926)
   (CHARHT R 0.633)
   (CHARDP R 0.127)
   )
(CHARACTER O 257 (comment uni23CE)
   (CHARWD R 0.926)
   (CHARHT R 0.731)
   (CHARDP R 0.225)
   )
(CHARACTER O 260 (comment uni23E2)
   (CHARWD R 1.144)
   (CHARHT R 0.558)
   (CHARDP R 0.053)
   )
(CHARACTER O 261 (comment uni23E3)
   (CHARWD R 0.91)
   (CHARHT R 0.68)
   (CHARDP R 0.178)
   )
(CHARACTER O 262 (comment uni23E4)
   (CHARWD R 1.094)
   (CHARHT R 0.286)
   )
(CHARACTER O 263 (comment uni23E5)
   (CHARWD R 1.018)
   (CHARHT R 0.527)
   (CHARDP R 0.02)
   )
(CHARACTER O 264 (comment uni23E6)
   (CHARWD R 0.926)
   (CHARHT R 0.434)
   )
(CHARACTER O 265 (comment uni23E7)
   (CHARWD R 0.798)
   (CHARHT R 0.606)
   (CHARDP R 0.097)
   )
(CHARACTER O 266 (comment uni2423)
   (CHARWD R 0.5)
   (CHARHT R 0.031)
   (CHARDP R 0.12)
   )
(CHARACTER O 267 (comment uni25A0)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 270 (comment uni25A1)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 271 (comment uni25A2)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 272 (comment uni25A3)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 273 (comment uni25A4)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 274 (comment uni25A5)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 275 (comment uni25A6)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 276 (comment uni25A7)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 277 (comment uni25A8)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 300 (comment uni25A9)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 301 (comment uni25AA)
   (CHARWD R 0.484)
   (CHARHT R 0.46)
   )
(CHARACTER O 302 (comment uni25AB)
   (CHARWD R 0.484)
   (CHARHT R 0.46)
   )
(CHARACTER O 303 (comment uni25AC)
   (CHARWD R 1.02)
   (CHARHT R 0.469)
   (CHARDP R 0.011)
   )
(CHARACTER O 304 (comment uni25AD)
   (CHARWD R 1.02)
   (CHARHT R 0.469)
   (CHARDP R 0.011)
   )
(CHARACTER O 305 (comment uni25AE)
   (CHARWD R 0.56)
   (CHARHT R 0.724)
   (CHARDP R 0.22)
   )
(CHARACTER O 306 (comment uni25AF)
   (CHARWD R 0.56)
   (CHARHT R 0.724)
   (CHARDP R 0.22)
   )
(CHARACTER O 307 (comment uni25B0)
   (CHARWD R 1.14)
   (CHARHT R 0.514)
   (CHARDP R 0.011)
   )
(CHARACTER O 310 (comment uni25B1)
   (CHARWD R 1.14)
   (CHARHT R 0.514)
   (CHARDP R 0.011)
   )
(CHARACTER O 311 (comment uni25B2)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 312 (comment uni25B3)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 313 (comment uni25B4)
   (CHARWD R 0.66)
   (CHARHT R 0.553)
   )
(CHARACTER O 314 (comment uni25B5)
   (CHARWD R 0.66)
   (CHARHT R 0.553)
   )
(CHARACTER O 315 (comment uni25B6)
   (CHARWD R 1.043)
   (CHARHT R 0.79)
   (CHARDP R 0.285)
   )
(CHARACTER O 316 (comment uni22B3)
   (CHARWD R 0.75)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 317 (comment uni25B8)
   (CHARWD R 0.66)
   (CHARHT R 0.556)
   (CHARDP R 0.049)
   )
(CHARACTER O 320 (comment uni25B9)
   (CHARWD R 0.66)
   (CHARHT R 0.555)
   (CHARDP R 0.05)
   )
(CHARACTER O 321 (comment uni25BA)
   (CHARWD R 0.93)
   (CHARHT R 0.555)
   (CHARDP R 0.05)
   )
(CHARACTER O 322 (comment uni25BB)
   (CHARWD R 0.93)
   (CHARHT R 0.555)
   (CHARDP R 0.05)
   )
(CHARACTER O 323 (comment uni25BC)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 324 (comment uni25BD)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 325 (comment uni25BE)
   (CHARWD R 0.66)
   (CHARHT R 0.477)
   (CHARDP R 0.048)
   )
(CHARACTER O 326 (comment uni25BF)
   (CHARWD R 0.66)
   (CHARHT R 0.477)
   (CHARDP R 0.048)
   )
(CHARACTER O 327 (comment uni25C0)
   (CHARWD R 1.043)
   (CHARHT R 0.79)
   (CHARDP R 0.285)
   )
(CHARACTER O 330 (comment uni22B2)
   (CHARWD R 0.75)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 331 (comment uni25C2)
   (CHARWD R 0.66)
   (CHARHT R 0.555)
   (CHARDP R 0.05)
   )
(CHARACTER O 332 (comment uni25C3)
   (CHARWD R 0.66)
   (CHARHT R 0.554)
   (CHARDP R 0.051)
   )
(CHARACTER O 333 (comment uni25C4)
   (CHARWD R 0.93)
   (CHARHT R 0.555)
   (CHARDP R 0.05)
   )
(CHARACTER O 334 (comment uni25C5)
   (CHARWD R 0.93)
   (CHARHT R 0.555)
   (CHARDP R 0.05)
   )
(CHARACTER O 335 (comment uni25C6)
   (CHARWD R 1.064)
   (CHARHT R 0.744)
   (CHARDP R 0.242)
   )
(CHARACTER O 336 (comment uni25C7)
   (CHARWD R 1.064)
   (CHARHT R 0.744)
   (CHARDP R 0.242)
   )
(CHARACTER O 337 (comment uni25C8)
   (CHARWD R 1.064)
   (CHARHT R 0.744)
   (CHARDP R 0.242)
   )
(CHARACTER O 340 (comment uni25C9)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 341 (comment uni25CA)
   (CHARWD R 0.79)
   (CHARHT R 0.795)
   (CHARDP R 0.289)
   )
(CHARACTER O 342 (comment uni25CB)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 343 (comment uni25CC)
   (CHARWD R 0.91)
   (CHARHT R 0.68)
   (CHARDP R 0.176)
   )
(CHARACTER O 344 (comment uni25CD)
   (CHARWD R 0.91)
   (CHARHT R 0.68)
   (CHARDP R 0.176)
   )
(CHARACTER O 345 (comment uni25CE)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 346 (comment uni25CF)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 347 (comment uni25D0)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 350 (comment uni25D1)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 351 (comment uni25D2)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 352 (comment uni25D3)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 353 (comment uni25D4)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 354 (comment uni25D5)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 355 (comment uni25D6)
   (CHARWD R 0.58)
   (CHARHT R 0.68)
   (CHARDP R 0.176)
   )
(CHARACTER O 356 (comment uni25D7)
   (CHARWD R 0.58)
   (CHARHT R 0.68)
   (CHARDP R 0.176)
   )
(CHARACTER O 357 (comment uni25D8)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 360 (comment uni25D9)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 361 (comment uni25DA)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   )
(CHARACTER O 362 (comment uni25DB)
   (CHARWD R 0.91)
   (CHARHT R 0.252)
   (CHARDP R 0.158)
   )
(CHARACTER O 363 (comment uni25DC)
   (CHARWD R 0.91)
   (CHARHT R 0.68)
   )
(CHARACTER O 364 (comment uni25DD)
   (CHARWD R 0.91)
   (CHARHT R 0.68)
   )
(CHARACTER O 365 (comment uni25DE)
   (CHARWD R 0.91)
   (CHARHT R 0.252)
   (CHARDP R 0.176)
   )
(CHARACTER O 366 (comment uni25DF)
   (CHARWD R 0.91)
   (CHARHT R 0.252)
   (CHARDP R 0.176)
   )
(CHARACTER O 367 (comment uni25E0)
   (CHARWD R 0.91)
   (CHARHT R 0.68)
   )
(CHARACTER O 370 (comment uni25E1)
   (CHARWD R 0.91)
   (CHARHT R 0.252)
   (CHARDP R 0.176)
   )
(CHARACTER O 371 (comment uni25E2)
   (CHARWD R 0.911)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 372 (comment uni25E3)
   (CHARWD R 0.911)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 373 (comment uni25E4)
   (CHARWD R 0.911)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 374 (comment uni25E5)
   (CHARWD R 0.911)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 375 (comment uni25E6)
   (CHARWD R 0.523)
   (CHARHT R 0.444)
   )
(CHARACTER O 376 (comment uni25E7)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 377 (comment uni25E8)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
