(FAMILY ot1-stixgbolditalic)
(CODINGSCHEME STIXOT1)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 40)
(FONTDIMEN
   (SLANT R 0.292989)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 449)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   (LABEL O 13) (comment ff)
   (LIG C l O 17)
   (LIG C i O 16)
   (STOP)
   (LABEL O 32) (comment ae)
   (KRN C v R -5)
   (KRN C w R -5)
   (KRN C y R -4)
   (STOP)
   (LABEL O 34) (comment oslash)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C y R -16)
   (KRN C x R -18)
   (KRN C w R -15)
   (KRN C v R -15)
   (KRN C t R 4)
   (KRN C T R -47)
   (STOP)
   (LABEL O 37) (comment Oslash)
   (KRN O 35 R -40) (comment AE)
   (KRN C Y R -36)
   (KRN C X R -35)
   (KRN C W R -30)
   (KRN C V R -31)
   (KRN C T R -15)
   (KRN C A R -30)
   (STOP)
   (LABEL O 41) (comment exclam)
   (LIG O 140 O 74)
   (STOP)
   (LABEL O 42) (comment quotedblright)
   (KRN C A R -39)
   (KRN C T R 13)
   (KRN C V R 14)
   (KRN C W R 15)
   (KRN C Y R 4)
   (KRN O 35 R -60) (comment AE)
   (STOP)
   (LABEL O 47) (comment quoteright)
   (LIG O 47 O 42)
   (KRN O 34 R -31) (comment oslash)
   (KRN O 54 R -42) (comment comma)
   (KRN O 56 R -42) (comment period)
   (KRN C A R -56)
   (KRN C d R -34)
   (KRN C o R -31)
   (KRN C r R -12)
   (KRN C s R -16)
   (KRN C t R -10)
   (KRN C v R -10)
   (KRN C w R -10)
   (KRN C y R -10)
   (KRN O 35 R -76) (comment AE)
   (STOP)
   (LABEL O 54) (comment comma)
   (KRN C 1 R -10)
   (KRN O 47 R -18) (comment quoteright)
   (KRN O 42 R -1) (comment quotedblright)
   (STOP)
   (LABEL O 55) (comment hyphen)
   (LIG O 55 O 173)
   (KRN C A R 6)
   (KRN C T R -34)
   (KRN C V R -37)
   (KRN C W R -34)
   (KRN C Y R -39)
   (KRN O 35 R -3) (comment AE)
   (STOP)
   (LABEL O 56) (comment period)
   (KRN O 47 R -21) (comment quoteright)
   (KRN O 42 R -4) (comment quotedblright)
   (STOP)
   (LABEL O 77) (comment question)
   (LIG O 140 O 76)
   (STOP)
   (LABEL C A)
   (KRN O 34 R -16) (comment oslash)
   (KRN O 37 R -36) (comment Oslash)
   (KRN O 54 R 13) (comment comma)
   (KRN O 55 R -6) (comment hyphen)
   (KRN O 56 R 18) (comment period)
   (KRN C C R -38)
   (KRN C G R -34)
   (KRN C O R -36)
   (KRN C Q R -36)
   (KRN C T R -55)
   (KRN C U R -65)
   (KRN C V R -105)
   (KRN C W R -105)
   (KRN C Y R -100)
   (KRN C a R -4)
   (KRN C b R -2)
   (KRN C c R -14)
   (KRN C d R -3)
   (KRN C e R -17)
   (KRN C g R -16)
   (KRN C o R -16)
   (KRN C q R -12)
   (KRN C t R -3)
   (KRN C u R -14)
   (KRN C v R -34)
   (KRN C w R -37)
   (KRN C y R -41)
   (KRN O 47 R -66) (comment quoteright)
   (KRN O 42 R -49) (comment quotedblright)
   (STOP)
   (LABEL C B)
   (KRN C A R -26)
   (KRN C O R -7)
   (KRN C V R -36)
   (KRN C W R -32)
   (KRN C Y R -38)
   (KRN O 35 R -27) (comment AE)
   (KRN O 37 R -7) (comment Oslash)
   (KRN O 36 R -2) (comment OE)
   (STOP)
   (LABEL C C)
   (KRN O 37 R -7) (comment Oslash)
   (KRN C A R -22)
   (KRN C H R -12)
   (KRN C K R -13)
   (KRN C O R -7)
   (KRN O 35 R -23) (comment AE)
   (STOP)
   (LABEL C D)
   (KRN C A R -29)
   (KRN C J R -50)
   (KRN C T R -21)
   (KRN C V R -34)
   (KRN C W R -33)
   (KRN C X R -38)
   (KRN C Y R -35)
   (STOP)
   (LABEL C F)
   (KRN O 37 R -34) (comment Oslash)
   (KRN O 54 R -59) (comment comma)
   (KRN O 55 R -28) (comment hyphen)
   (KRN O 56 R -61) (comment period)
   (KRN C A R -61)
   (KRN C J R -66)
   (KRN C O R -34)
   (KRN C a R -47)
   (KRN C e R -58)
   (KRN C i R -22)
   (KRN C j R -26)
   (KRN C o R -50)
   (KRN C r R -24)
   (KRN C u R -27)
   (KRN O 32 R -54) (comment ae)
   (KRN O 34 R -50) (comment oslash)
   (KRN O 33 R -58) (comment oe)
   (STOP)
   (LABEL C G)
   (KRN C A R -10)
   (KRN C T R -22)
   (KRN C V R -20)
   (KRN C W R -19)
   (KRN C Y R -22)
   (KRN O 35 R -12) (comment AE)
   (STOP)
   (LABEL C J)
   (KRN C A R -30)
   (KRN O 35 R -32) (comment AE)
   (STOP)
   (LABEL C K)
   (KRN O 34 R -8) (comment oslash)
   (KRN O 37 R -26) (comment Oslash)
   (KRN O 55 R -9) (comment hyphen)
   (KRN C C R -27)
   (KRN C G R -23)
   (KRN C O R -26)
   (KRN C S R -1)
   (KRN C a R 4)
   (KRN C e R -10)
   (KRN C o R -8)
   (KRN C u R -7)
   (KRN C y R -49)
   (KRN O 32 R -2) (comment ae)
   (KRN O 36 R -24) (comment OE)
   (STOP)
   (LABEL C L)
   (KRN O 37 R 4) (comment Oslash)
   (KRN O 55 R 66) (comment hyphen)
   (KRN C A R 31)
   (KRN C C R 1)
   (KRN C G R 6)
   (KRN C O R 4)
   (KRN C T R -23)
   (KRN C U R -13)
   (KRN C V R -47)
   (KRN C W R -42)
   (KRN C Y R -32)
   (KRN C u R 21)
   (KRN C y R -6)
   (KRN O 35 R 29) (comment AE)
   (KRN O 47 R -49) (comment quoteright)
   (KRN O 42 R -32) (comment quotedblright)
   (STOP)
   (LABEL C N)
   (KRN O 37 R -11) (comment Oslash)
   (KRN O 54 R -4) (comment comma)
   (KRN O 56 R -8) (comment period)
   (KRN C A R -29)
   (KRN C C R -10)
   (KRN C G R -6)
   (KRN C O R -11)
   (KRN C a R -8)
   (KRN C e R -18)
   (KRN C o R -11)
   (KRN C u R -15)
   (KRN O 35 R -30) (comment AE)
   (KRN O 32 R -14) (comment ae)
   (KRN O 34 R -15) (comment oslash)
   (STOP)
   (LABEL C O)
   (KRN C A R -30)
   (KRN C T R -15)
   (KRN C V R -31)
   (KRN C W R -30)
   (KRN C X R -35)
   (KRN C Y R -36)
   (KRN O 35 R -40) (comment AE)
   (STOP)
   (LABEL C P)
   (KRN O 54 R -70) (comment comma)
   (KRN O 55 R -32) (comment hyphen)
   (KRN O 56 R -70) (comment period)
   (KRN C A R -53)
   (KRN C J R -70)
   (KRN C a R -37)
   (KRN C e R -44)
   (KRN C o R -36)
   (KRN O 35 R -69) (comment AE)
   (KRN O 32 R -45) (comment ae)
   (KRN O 34 R -36) (comment oslash)
   (KRN O 33 R -42) (comment oe)
   (STOP)
   (LABEL C R)
   (KRN O 34 R -12) (comment oslash)
   (KRN O 37 R -15) (comment Oslash)
   (KRN O 55 R -12) (comment hyphen)
   (KRN C C R -14)
   (KRN C G R -10)
   (KRN C O R -15)
   (KRN C T R -18)
   (KRN C U R -22)
   (KRN C V R -36)
   (KRN C W R -35)
   (KRN C Y R -30)
   (KRN C a R -1)
   (KRN C e R -14)
   (KRN C o R -12)
   (KRN C u R -10)
   (KRN C y R -10)
   (KRN O 32 R -6) (comment ae)
   (KRN O 36 R -14) (comment OE)
   (KRN O 33 R -17) (comment oe)
   (STOP)
   (LABEL C S)
   (KRN C A R -11)
   (KRN C T R -24)
   (KRN C V R -15)
   (KRN C W R -14)
   (KRN C Y R -18)
   (KRN C t R 5)
   (KRN O 35 R -13) (comment AE)
   (STOP)
   (LABEL C T)
   (KRN O 54 R -46) (comment comma)
   (KRN O 55 R -43) (comment hyphen)
   (KRN O 56 R -47) (comment period)
   (KRN O 72 R -35) (comment colon)
   (KRN O 73 R -37) (comment semicolon)
   (KRN C A R -40)
   (KRN C C R -12)
   (KRN C G R -8)
   (KRN C J R -48)
   (KRN C O R -18)
   (KRN C S R -12)
   (KRN C V R 16)
   (KRN C W R 18)
   (KRN C Y R 14)
   (KRN C a R -56)
   (KRN C c R -58)
   (KRN C e R -61)
   (KRN C g R -63)
   (KRN C i R -2)
   (KRN C j R -6)
   (KRN C o R -58)
   (KRN C r R -56)
   (KRN C s R -57)
   (KRN C u R -61)
   (KRN C v R -66)
   (KRN C w R -66)
   (KRN C y R -65)
   (KRN O 35 R -41) (comment AE)
   (KRN O 37 R -18) (comment Oslash)
   (KRN O 32 R -62) (comment ae)
   (KRN O 34 R -58) (comment oslash)
   (KRN O 36 R -15) (comment OE)
   (STOP)
   (LABEL C U)
   (KRN O 54 R -18) (comment comma)
   (KRN O 56 R -17) (comment period)
   (KRN C A R -41)
   (KRN C m R -19)
   (KRN C n R -22)
   (KRN C p R -16)
   (KRN C r R -17)
   (KRN O 35 R -51) (comment AE)
   (STOP)
   (LABEL C V)
   (KRN O 54 R -58) (comment comma)
   (KRN O 55 R -35) (comment hyphen)
   (KRN O 56 R -58) (comment period)
   (KRN O 72 R -32) (comment colon)
   (KRN O 73 R -28) (comment semicolon)
   (KRN C A R -65)
   (KRN C C R -34)
   (KRN C G R -30)
   (KRN C O R -36)
   (KRN C S R -22)
   (KRN C T R 8)
   (KRN C a R -48)
   (KRN C e R -58)
   (KRN C g R -54)
   (KRN C i R -10)
   (KRN C o R -50)
   (KRN C r R -30)
   (KRN C u R -34)
   (KRN C y R -28)
   (KRN O 35 R -71) (comment AE)
   (KRN O 37 R -36) (comment Oslash)
   (KRN O 32 R -54) (comment ae)
   (KRN O 34 R -50) (comment oslash)
   (STOP)
   (LABEL C W)
   (KRN O 54 R -33) (comment comma)
   (KRN O 55 R -18) (comment hyphen)
   (KRN O 56 R -34) (comment period)
   (KRN O 72 R -13) (comment colon)
   (KRN O 73 R -13) (comment semicolon)
   (KRN C A R -49)
   (KRN C C R -22)
   (KRN C G R -17)
   (KRN C O R -23)
   (KRN C S R -21)
   (KRN C T R 9)
   (KRN C a R -30)
   (KRN C e R -39)
   (KRN C g R -40)
   (KRN C i R -8)
   (KRN C o R -32)
   (KRN C r R -23)
   (KRN C u R -26)
   (KRN C y R -21)
   (KRN O 35 R -60) (comment AE)
   (KRN O 37 R -23) (comment Oslash)
   (KRN O 32 R -36) (comment ae)
   (KRN O 34 R -32) (comment oslash)
   (STOP)
   (LABEL C X)
   (KRN O 34 R -18) (comment oslash)
   (KRN O 37 R -32) (comment Oslash)
   (KRN O 55 R -23) (comment hyphen)
   (KRN C C R -30)
   (KRN C O R -32)
   (KRN C Q R -32)
   (KRN C a R -7)
   (KRN C e R -20)
   (KRN C o R -18)
   (KRN C u R -17)
   (KRN C y R -57)
   (STOP)
   (LABEL C Y)
   (KRN O 54 R -38) (comment comma)
   (KRN O 55 R -35) (comment hyphen)
   (KRN O 56 R -39) (comment period)
   (KRN O 72 R -22) (comment colon)
   (KRN O 73 R -23) (comment semicolon)
   (KRN C A R -34)
   (KRN C C R -34)
   (KRN C G R -30)
   (KRN C O R -32)
   (KRN C S R -22)
   (KRN C T R 8)
   (KRN C a R -43)
   (KRN C e R -54)
   (KRN C g R -50)
   (KRN C i R -10)
   (KRN C o R -46)
   (KRN C p R -41)
   (KRN C u R -42)
   (KRN C v R -38)
   (KRN O 35 R -35) (comment AE)
   (KRN O 37 R -36) (comment Oslash)
   (KRN O 32 R -50) (comment ae)
   (KRN O 34 R -50) (comment oslash)
   (STOP)
   (LABEL C Z)
   (KRN C v R -14)
   (KRN C w R -14)
   (KRN C y R -22)
   (STOP)
   (LABEL O 134) (comment quotedblleft)
   (KRN C A R -44)
   (KRN C V R 3)
   (KRN C W R 4)
   (KRN O 35 R -60) (comment AE)
   (STOP)
   (LABEL O 140) (comment quoteleft)
   (LIG O 140 O 134)
   (KRN C A R -50)
   (KRN C T R -5)
   (KRN C V R -3)
   (KRN C W R -2)
   (KRN C Y R -6)
   (KRN O 35 R -65) (comment AE)
   (STOP)
   (LABEL C a)
   (KRN C j R 1)
   (KRN C v R -2)
   (KRN C w R -2)
   (KRN C y R -2)
   (KRN O 47 R -14) (comment quoteright)
   (STOP)
   (LABEL C b)
   (KRN C v R -12)
   (KRN C w R -12)
   (KRN C y R -11)
   (STOP)
   (LABEL C c)
   (KRN C h R -12)
   (KRN C k R -8)
   (STOP)
   (LABEL C e)
   (KRN C t R 1)
   (KRN C v R -4)
   (KRN C w R -4)
   (KRN C x R -11)
   (KRN C y R -2)
   (KRN O 47 R -8) (comment quoteright)
   (STOP)
   (LABEL C f)
   (LIG C f O 13)
   (LIG C l O 15)
   (LIG C i O 14)
   (KRN C a R -10)
   (KRN C e R -20)
   (KRN C j R 14)
   (KRN C o R -14)
   (KRN C s R -8)
   (KRN C t R 10)
   (KRN O 32 R -17) (comment ae)
   (KRN O 34 R -18) (comment oslash)
   (KRN O 33 R -21) (comment oe)
   (KRN O 47 R 14) (comment quoteright)
   (STOP)
   (LABEL C g)
   (KRN C a R -18)
   (KRN C e R -25)
   (KRN C l R -17)
   (KRN C r R 4)
   (KRN O 32 R -25) (comment ae)
   (STOP)
   (LABEL C h)
   (KRN C y R -14)
   (KRN O 47 R -25) (comment quoteright)
   (STOP)
   (LABEL C i)
   (KRN C T R -16)
   (STOP)
   (LABEL C k)
   (KRN O 34 R 4) (comment oslash)
   (KRN O 54 R 29) (comment comma)
   (KRN O 55 R 4) (comment hyphen)
   (KRN O 56 R 25) (comment period)
   (KRN C a R 14)
   (KRN C g R -10)
   (KRN C o R 4)
   (KRN C s R 3)
   (KRN C u R 3)
   (KRN O 32 R 4) (comment ae)
   (STOP)
   (LABEL C l)
   (KRN C v R -8)
   (KRN C y R -6)
   (STOP)
   (LABEL C m)
   (KRN C p R 5)
   (KRN C v R -11)
   (KRN C w R -13)
   (KRN C y R -11)
   (STOP)
   (LABEL C n)
   (KRN C T R -43)
   (KRN C p R 1)
   (KRN C v R -16)
   (KRN C w R -16)
   (KRN C y R -14)
   (KRN O 47 R -23) (comment quoteright)
   (STOP)
   (LABEL C o)
   (KRN C T R -47)
   (KRN C t R 4)
   (KRN C v R -15)
   (KRN C w R -15)
   (KRN C x R -18)
   (KRN C y R -16)
   (KRN O 47 R -14) (comment quoteright)
   (STOP)
   (LABEL C p)
   (KRN C t R 4)
   (KRN C y R -8)
   (STOP)
   (LABEL C q)
   (KRN C c R -2)
   (KRN C u R -2)
   (STOP)
   (LABEL C r)
   (KRN O 54 R -46) (comment comma)
   (KRN O 55 R -33) (comment hyphen)
   (KRN O 56 R -50) (comment period)
   (KRN O 72 R -12) (comment colon)
   (KRN O 73 R -14) (comment semicolon)
   (KRN C a R -10)
   (KRN C c R -12)
   (KRN C d R -10)
   (KRN C e R -17)
   (KRN C f R 9)
   (KRN C g R -3)
   (KRN C h R -12)
   (KRN C i R 20)
   (KRN C j R 14)
   (KRN C k R -10)
   (KRN C l R -10)
   (KRN C m R 13)
   (KRN C n R 8)
   (KRN C o R -9)
   (KRN C p R 19)
   (KRN C q R -18)
   (KRN C r R 18)
   (KRN C t R 15)
   (KRN C u R 13)
   (KRN C v R 23)
   (KRN C w R 23)
   (KRN C x R 8)
   (KRN C y R 25)
   (KRN C z R 11)
   (KRN O 32 R -18) (comment ae)
   (KRN O 34 R -10) (comment oslash)
   (KRN O 33 R -15) (comment oe)
   (KRN O 47 R 5) (comment quoteright)
   (STOP)
   (LABEL C s)
   (KRN C t R -2)
   (KRN O 47 R -14) (comment quoteright)
   (STOP)
   (LABEL C t)
   (KRN O 34 R 3) (comment oslash)
   (KRN O 72 R 24) (comment colon)
   (KRN O 73 R 21) (comment semicolon)
   (KRN C a R 14)
   (KRN C e R -1)
   (KRN C o R 3)
   (KRN O 32 R 4) (comment ae)
   (KRN O 47 R -10) (comment quoteright)
   (STOP)
   (LABEL C u)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL C v)
   (KRN O 54 R -35) (comment comma)
   (KRN O 56 R -37) (comment period)
   (KRN O 72 R -2) (comment colon)
   (KRN C a R -11)
   (KRN C c R -14)
   (KRN C e R -18)
   (KRN C g R -15)
   (KRN C l R -14)
   (KRN C o R -13)
   (KRN C s R -12)
   (KRN O 32 R -17) (comment ae)
   (KRN O 34 R -15) (comment oslash)
   (STOP)
   (LABEL C w)
   (KRN O 54 R -35) (comment comma)
   (KRN O 55 R -6) (comment hyphen)
   (KRN O 56 R -37) (comment period)
   (KRN O 72 R -5) (comment colon)
   (KRN O 73 R -3) (comment semicolon)
   (KRN C a R -15)
   (KRN C c R -18)
   (KRN C e R -22)
   (KRN C g R -20)
   (KRN C l R -18)
   (KRN C o R -16)
   (KRN C s R -16)
   (KRN O 32 R -21) (comment ae)
   (KRN O 34 R -16) (comment oslash)
   (STOP)
   (LABEL C x)
   (KRN O 34 R -10) (comment oslash)
   (KRN C a R -2)
   (KRN C c R -9)
   (KRN C e R -12)
   (KRN C o R -10)
   (KRN C q R -10)
   (STOP)
   (LABEL C y)
   (KRN O 54 R -14) (comment comma)
   (KRN O 55 R 4) (comment hyphen)
   (KRN O 56 R -16) (comment period)
   (KRN O 72 R 5) (comment colon)
   (KRN O 73 R 10) (comment semicolon)
   (KRN C a R -4)
   (KRN C c R -7)
   (KRN C e R -11)
   (KRN C g R -11)
   (KRN C l R -8)
   (KRN C o R -6)
   (KRN C s R -7)
   (KRN O 32 R -10) (comment ae)
   (KRN O 34 R -8) (comment oslash)
   (STOP)
   (LABEL O 173) (comment endash)
   (LIG O 55 O 174)
   (STOP)
   )
(CHARACTER O 0 (comment uni0393)
   (CHARWD R 585)
   (CHARHT R 669)
   (CHARIC R 85)
   )
(CHARACTER O 1 (comment uni0394)
   (CHARWD R 667)
   (CHARHT R 683)
   )
(CHARACTER O 2 (comment uni0398)
   (CHARWD R 718)
   (CHARHT R 685)
   (CHARDP R 18)
   )
(CHARACTER O 3 (comment uni039B)
   (CHARWD R 655)
   (CHARHT R 683)
   )
(CHARACTER O 4 (comment uni039E)
   (CHARWD R 746)
   (CHARHT R 669)
   )
(CHARACTER O 5 (comment uni03A0)
   (CHARWD R 778)
   (CHARHT R 669)
   (CHARIC R 21)
   )
(CHARACTER O 6 (comment uni03A3)
   (CHARWD R 633)
   (CHARHT R 669)
   )
(CHARACTER O 7 (comment uni03A5)
   (CHARWD R 611)
   (CHARHT R 685)
   (CHARIC R 86)
   )
(CHARACTER O 10 (comment uni03A6)
   (CHARWD R 771)
   (CHARHT R 669)
   )
(CHARACTER O 11 (comment uni03A8)
   (CHARWD R 661)
   (CHARHT R 685)
   (CHARIC R 119)
   )
(CHARACTER O 12 (comment uni03A9)
   (CHARWD R 808)
   (CHARHT R 685)
   )
(CHARACTER O 13 (comment ff)
   (CHARWD R 613)
   (CHARHT R 698)
   (CHARDP R 205)
   (CHARIC R 113)
   )
(CHARACTER O 14 (comment fi)
   (CHARWD R 556)
   (CHARHT R 703)
   (CHARDP R 205)
   )
(CHARACTER O 15 (comment fl)
   (CHARWD R 556)
   (CHARHT R 704)
   (CHARDP R 205)
   )
(CHARACTER O 16 (comment ffi)
   (CHARWD R 856)
   (CHARHT R 703)
   (CHARDP R 205)
   )
(CHARACTER O 17 (comment ffl)
   (CHARWD R 854)
   (CHARHT R 704)
   (CHARDP R 205)
   )
(CHARACTER O 20 (comment dotlessi)
   (CHARWD R 278)
   (CHARHT R 462)
   (CHARDP R 9)
   )
(CHARACTER O 21 (comment uni0237)
   (CHARWD R 278)
   (CHARHT R 462)
   (CHARDP R 207)
   )
(CHARACTER O 22 (comment grave)
   (CHARWD R 333)
   (CHARHT R 697)
   )
(CHARACTER O 23 (comment acute)
   (CHARWD R 333)
   (CHARHT R 697)
   (CHARIC R 46)
   )
(CHARACTER O 24 (comment caron)
   (CHARWD R 333)
   (CHARHT R 690)
   (CHARIC R 78)
   )
(CHARACTER O 25 (comment breve)
   (CHARWD R 333)
   (CHARHT R 678)
   (CHARIC R 54)
   )
(CHARACTER O 26 (comment macron)
   (CHARWD R 333)
   (CHARHT R 623)
   (CHARIC R 60)
   )
(CHARACTER O 27 (comment ring)
   (CHARWD R 333)
   (CHARHT R 754)
   (CHARIC R 7)
   )
(CHARACTER O 30 (comment cedilla)
   (CHARWD R 333)
   (CHARHT R 5)
   (CHARDP R 218)
   )
(CHARACTER O 31 (comment germandbls)
   (CHARWD R 500)
   (CHARHT R 705)
   (CHARDP R 200)
   )
(CHARACTER O 32 (comment ae)
   (CHARWD R 722)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER O 33 (comment oe)
   (CHARWD R 722)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER O 34 (comment oslash)
   (CHARWD R 500)
   (CHARHT R 560)
   (CHARDP R 119)
   )
(CHARACTER O 35 (comment AE)
   (CHARWD R 944)
   (CHARHT R 669)
   )
(CHARACTER O 36 (comment OE)
   (CHARWD R 944)
   (CHARHT R 677)
   (CHARDP R 8)
   (CHARIC R 2)
   )
(CHARACTER O 37 (comment Oslash)
   (CHARWD R 722)
   (CHARHT R 764)
   (CHARDP R 125)
   )
(CHARACTER O 40 (comment space)
   (CHARWD R 250)
   )
(CHARACTER O 41 (comment exclam)
   (CHARWD R 389)
   (CHARHT R 684)
   (CHARDP R 13)
   )
(CHARACTER O 42 (comment quotedblright)
   (CHARWD R 500)
   (CHARHT R 685)
   (CHARIC R 13)
   )
(CHARACTER O 43 (comment numbersign)
   (CHARWD R 500)
   (CHARHT R 700)
   (CHARIC R 32)
   )
(CHARACTER O 44 (comment dollar)
   (CHARWD R 500)
   (CHARHT R 733)
   (CHARDP R 100)
   )
(CHARACTER O 45 (comment percent)
   (CHARWD R 757)
   (CHARHT R 706)
   (CHARDP R 29)
   )
(CHARACTER O 46 (comment ampersand)
   (CHARWD R 849)
   (CHARHT R 682)
   (CHARDP R 19)
   )
(CHARACTER O 47 (comment quoteright)
   (CHARWD R 333)
   (CHARHT R 685)
   )
(CHARACTER O 50 (comment parenleft)
   (CHARWD R 333)
   (CHARHT R 685)
   (CHARDP R 179)
   (CHARIC R 11)
   )
(CHARACTER O 51 (comment parenright)
   (CHARWD R 333)
   (CHARHT R 685)
   (CHARDP R 179)
   )
(CHARACTER O 52 (comment asterisk)
   (CHARWD R 500)
   (CHARHT R 685)
   )
(CHARACTER O 53 (comment plus)
   (CHARWD R 570)
   (CHARHT R 506)
   )
(CHARACTER O 54 (comment comma)
   (CHARWD R 250)
   (CHARHT R 134)
   (CHARDP R 182)
   )
(CHARACTER O 55 (comment hyphen)
   (CHARWD R 333)
   (CHARHT R 282)
   )
(CHARACTER O 56 (comment period)
   (CHARWD R 250)
   (CHARHT R 135)
   (CHARDP R 13)
   )
(CHARACTER O 57 (comment slash)
   (CHARWD R 278)
   (CHARHT R 685)
   (CHARDP R 18)
   (CHARIC R 64)
   )
(CHARACTER C 0
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 14)
   )
(CHARACTER C 1
   (CHARWD R 500)
   (CHARHT R 683)
   )
(CHARACTER C 2
   (CHARWD R 500)
   (CHARHT R 683)
   )
(CHARACTER C 3
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 13)
   )
(CHARACTER C 4
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARIC R 3)
   )
(CHARACTER C 5
   (CHARWD R 500)
   (CHARHT R 669)
   (CHARDP R 13)
   )
(CHARACTER C 6
   (CHARWD R 500)
   (CHARHT R 679)
   (CHARDP R 15)
   (CHARIC R 9)
   )
(CHARACTER C 7
   (CHARWD R 500)
   (CHARHT R 669)
   (CHARIC R 25)
   )
(CHARACTER C 8
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 13)
   )
(CHARACTER C 9
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 10)
   )
(CHARACTER O 72 (comment colon)
   (CHARWD R 333)
   (CHARHT R 459)
   (CHARDP R 13)
   )
(CHARACTER O 73 (comment semicolon)
   (CHARWD R 333)
   (CHARHT R 459)
   (CHARDP R 183)
   )
(CHARACTER O 74 (comment exclamdown)
   (CHARWD R 389)
   (CHARHT R 494)
   (CHARDP R 205)
   )
(CHARACTER O 75 (comment equal)
   (CHARWD R 570)
   (CHARHT R 399)
   )
(CHARACTER O 76 (comment questiondown)
   (CHARWD R 500)
   (CHARHT R 492)
   (CHARDP R 205)
   )
(CHARACTER O 77 (comment question)
   (CHARWD R 500)
   (CHARHT R 684)
   (CHARDP R 13)
   )
(CHARACTER O 100 (comment at)
   (CHARWD R 939)
   (CHARHT R 685)
   (CHARDP R 18)
   )
(CHARACTER C A
   (CHARWD R 667)
   (CHARHT R 683)
   )
(CHARACTER C B
   (CHARWD R 667)
   (CHARHT R 669)
   )
(CHARACTER C C
   (CHARWD R 667)
   (CHARHT R 685)
   (CHARDP R 18)
   (CHARIC R 10)
   )
(CHARACTER C D
   (CHARWD R 722)
   (CHARHT R 669)
   )
(CHARACTER C E
   (CHARWD R 667)
   (CHARHT R 669)
   )
(CHARACTER C F
   (CHARWD R 667)
   (CHARHT R 669)
   )
(CHARACTER C G
   (CHARWD R 722)
   (CHARHT R 685)
   (CHARDP R 18)
   )
(CHARACTER C H
   (CHARWD R 778)
   (CHARHT R 669)
   (CHARIC R 21)
   )
(CHARACTER C I
   (CHARWD R 389)
   (CHARHT R 669)
   (CHARIC R 17)
   )
(CHARACTER C J
   (CHARWD R 500)
   (CHARHT R 669)
   (CHARDP R 99)
   (CHARIC R 24)
   )
(CHARACTER C K
   (CHARWD R 667)
   (CHARHT R 669)
   (CHARIC R 35)
   )
(CHARACTER C L
   (CHARWD R 611)
   (CHARHT R 669)
   )
(CHARACTER C M
   (CHARWD R 889)
   (CHARHT R 669)
   (CHARDP R 12)
   (CHARIC R 28)
   )
(CHARACTER C N
   (CHARWD R 722)
   (CHARHT R 669)
   (CHARDP R 15)
   (CHARIC R 26)
   )
(CHARACTER C O
   (CHARWD R 722)
   (CHARHT R 685)
   (CHARDP R 18)
   )
(CHARACTER C P
   (CHARWD R 611)
   (CHARHT R 669)
   (CHARIC R 2)
   )
(CHARACTER C Q
   (CHARWD R 722)
   (CHARHT R 685)
   (CHARDP R 208)
   )
(CHARACTER C R
   (CHARWD R 667)
   (CHARHT R 669)
   )
(CHARACTER C S
   (CHARWD R 556)
   (CHARHT R 685)
   (CHARDP R 18)
   )
(CHARACTER C T
   (CHARWD R 611)
   (CHARHT R 669)
   (CHARIC R 39)
   )
(CHARACTER C U
   (CHARWD R 722)
   (CHARHT R 669)
   (CHARDP R 18)
   (CHARIC R 22)
   )
(CHARACTER C V
   (CHARWD R 667)
   (CHARHT R 669)
   (CHARDP R 18)
   (CHARIC R 48)
   )
(CHARACTER C W
   (CHARWD R 889)
   (CHARHT R 669)
   (CHARDP R 18)
   (CHARIC R 51)
   )
(CHARACTER C X
   (CHARWD R 667)
   (CHARHT R 669)
   (CHARIC R 27)
   )
(CHARACTER C Y
   (CHARWD R 611)
   (CHARHT R 669)
   (CHARIC R 48)
   )
(CHARACTER C Z
   (CHARWD R 611)
   (CHARHT R 669)
   )
(CHARACTER O 133 (comment bracketleft)
   (CHARWD R 333)
   (CHARHT R 674)
   (CHARDP R 159)
   (CHARIC R 29)
   )
(CHARACTER O 134 (comment quotedblleft)
   (CHARWD R 500)
   (CHARHT R 685)
   (CHARIC R 13)
   )
(CHARACTER O 135 (comment bracketright)
   (CHARWD R 333)
   (CHARHT R 674)
   (CHARDP R 157)
   (CHARIC R 10)
   )
(CHARACTER O 136 (comment circumflex)
   (CHARWD R 333)
   (CHARHT R 690)
   (CHARIC R 34)
   )
(CHARACTER O 137 (comment dotaccent)
   (CHARWD R 333)
   (CHARHT R 655)
   )
(CHARACTER O 140 (comment quoteleft)
   (CHARWD R 333)
   (CHARHT R 685)
   )
(CHARACTER C a
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 14)
   )
(CHARACTER C b
   (CHARWD R 500)
   (CHARHT R 699)
   (CHARDP R 13)
   )
(CHARACTER C c
   (CHARWD R 444)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C d
   (CHARWD R 500)
   (CHARHT R 699)
   (CHARDP R 13)
   (CHARIC R 17)
   )
(CHARACTER C e
   (CHARWD R 444)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C f
   (CHARWD R 333)
   (CHARHT R 698)
   (CHARDP R 205)
   (CHARIC R 113)
   )
(CHARACTER C g
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 203)
   )
(CHARACTER C h
   (CHARWD R 556)
   (CHARHT R 699)
   (CHARDP R 9)
   )
(CHARACTER C i
   (CHARWD R 278)
   (CHARHT R 684)
   (CHARDP R 9)
   )
(CHARACTER C j
   (CHARWD R 278)
   (CHARHT R 685)
   (CHARDP R 207)
   (CHARIC R 1)
   )
(CHARACTER C k
   (CHARWD R 500)
   (CHARHT R 699)
   (CHARDP R 8)
   )
(CHARACTER C l
   (CHARWD R 278)
   (CHARHT R 699)
   (CHARDP R 9)
   (CHARIC R 12)
   )
(CHARACTER C m
   (CHARWD R 778)
   (CHARHT R 462)
   (CHARDP R 9)
   )
(CHARACTER C n
   (CHARWD R 556)
   (CHARHT R 462)
   (CHARDP R 9)
   )
(CHARACTER C o
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C p
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 205)
   )
(CHARACTER C q
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 205)
   )
(CHARACTER C r
   (CHARWD R 389)
   (CHARHT R 462)
   )
(CHARACTER C s
   (CHARWD R 389)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C t
   (CHARWD R 278)
   (CHARHT R 594)
   (CHARDP R 9)
   (CHARIC R 3)
   )
(CHARACTER C u
   (CHARWD R 556)
   (CHARHT R 462)
   (CHARDP R 9)
   )
(CHARACTER C v
   (CHARWD R 444)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C w
   (CHARWD R 667)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C x
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C y
   (CHARWD R 444)
   (CHARHT R 462)
   (CHARDP R 205)
   )
(CHARACTER C z
   (CHARWD R 389)
   (CHARHT R 449)
   (CHARDP R 78)
   )
(CHARACTER O 173 (comment endash)
   (CHARWD R 500)
   (CHARHT R 269)
   )
(CHARACTER O 174 (comment emdash)
   (CHARWD R 1000)
   (CHARHT R 269)
   )
(CHARACTER O 175 (comment hungarumlaut)
   (CHARWD R 333)
   (CHARHT R 697)
   (CHARIC R 165)
   )
(CHARACTER O 176 (comment tilde)
   (CHARWD R 333)
   (CHARHT R 655)
   (CHARIC R 74)
   )
(CHARACTER O 177 (comment dieresis)
   (CHARWD R 333)
   (CHARHT R 655)
   (CHARIC R 64)
   )
