(FAMILY stix-extra1)
(CODINGSCHEME STIXEXTRA)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 377)
(FONTDIMEN
   (SLANT R 0.000000)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 450)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   )
(CHARACTER O 0 (comment uniE002)
   (CHARWD R 1192)
   (CHARHT R 1022)
   )
(CHARACTER O 1 (comment uniE003)
   (CHARWD R 1311)
   (CHARHT R 1450)
   )
(CHARACTER O 2 (comment uniE00A)
   (CHARWD R 685)
   (CHARHT R 538)
   )
(CHARACTER O 3 (comment uniE00B)
   (CHARWD R 685)
   (CHARHT R 543)
   (CHARDP R 37)
   )
(CHARACTER O 4 (comment uniE026)
   (CHARWD R 685)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 5 (comment uniE027)
   (CHARWD R 685)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 6 (comment uniE02F)
   (CHARWD R 685)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 7 (comment uniE037)
   (CHARWD R 685)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 10 (comment uniE038)
   (CHARWD R 732)
   (CHARHT R 690)
   (CHARDP R 189)
   )
(CHARACTER O 11 (comment uniE039)
   (CHARWD R 685)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 12 (comment uniE040)
   (CHARWD R 685)
   (CHARHT R 415)
   )
(CHARACTER O 13 (comment uniE043)
   (CHARWD R 685)
   (CHARHT R 818)
   (CHARDP R 311)
   )
(CHARACTER O 14 (comment uniE044)
   (CHARWD R 685)
   (CHARHT R 818)
   (CHARDP R 311)
   )
(CHARACTER O 15 (comment uniE04D)
   (CHARWD R 685)
   (CHARHT R 534)
   (CHARDP R 19)
   )
(CHARACTER O 16 (comment uniE053)
   (CHARWD R 632)
   (CHARHT R 450)
   )
(CHARACTER O 17 (comment uniE054)
   (CHARWD R 688)
   (CHARHT R 516)
   (CHARDP R 10)
   )
(CHARACTER O 20 (comment uniE055)
   (CHARWD R 571)
   (CHARHT R 475)
   (CHARDP R 14)
   )
(CHARACTER O 21 (comment uniE056)
   (CHARWD R 632)
   (CHARHT R 459)
   (CHARDP R 11)
   )
(CHARACTER O 22 (comment uniE057)
   (CHARWD R 624)
   (CHARHT R 459)
   (CHARDP R 12)
   )
(CHARACTER O 23 (comment uniE05D)
   (CHARWD R 452)
   (CHARHT R 459)
   (CHARDP R 10)
   )
(CHARACTER O 24 (comment uniE05E)
   (CHARWD R 0)
   (CHARHT R 698)
   (CHARIC R 406)
   )
(CHARACTER O 25 (comment uniE061)
   (CHARWD R 0)
   (CHARDP R 390)
   (CHARIC R 322)
   )
(CHARACTER O 26 (comment uniE062)
   (CHARWD R 0)
   (CHARDP R 486)
   (CHARIC R 322)
   )
(CHARACTER O 27 (comment uniE063)
   (CHARWD R 0)
   (CHARHT R 734)
   (CHARIC R 485)
   )
(CHARACTER O 30 (comment uniE064)
   (CHARWD R 0)
   (CHARHT R 777)
   (CHARIC R 425)
   )
(CHARACTER O 31 (comment uniE065)
   (CHARWD R 0)
   (CHARDP R 371)
   (CHARIC R 331)
   )
(CHARACTER O 32 (comment uniE066)
   (CHARWD R 0)
   (CHARHT R 770)
   (CHARIC R 412)
   )
(CHARACTER O 33 (comment uniE067)
   (CHARWD R 0)
   (CHARDP R 371)
   (CHARIC R 331)
   )
(CHARACTER O 34 (comment uniE068)
   (CHARWD R 524)
   (CHARHT R 683)
   (CHARDP R 287)
   )
(CHARACTER O 35 (comment uniE06B)
   (CHARWD R 486)
   (CHARHT R 602)
   (CHARDP R 98)
   )
(CHARACTER O 36 (comment uniE06C)
   (CHARWD R 486)
   (CHARHT R 602)
   (CHARDP R 98)
   )
(CHARACTER O 37 (comment uniE06F)
   (CHARWD R 685)
   (CHARHT R 785)
   (CHARDP R 129)
   )
(CHARACTER O 40 (comment uniE070)
   (CHARWD R 685)
   (CHARHT R 785)
   (CHARDP R 129)
   )
(CHARACTER O 41 (comment uniE076)
   (CHARWD R 685)
   (CHARHT R 626)
   (CHARDP R 119)
   )
(CHARACTER O 42 (comment uniE077)
   (CHARWD R 685)
   (CHARHT R 725)
   (CHARDP R 236)
   )
(CHARACTER O 43 (comment uniE07D)
   (CHARWD R 685)
   (CHARHT R 758)
   (CHARDP R 252)
   )
(CHARACTER O 44 (comment uniE07E)
   (CHARWD R 685)
   (CHARHT R 732)
   (CHARDP R 227)
   )
(CHARACTER O 45 (comment uniE07F)
   (CHARWD R 685)
   (CHARHT R 732)
   (CHARDP R 227)
   )
(CHARACTER O 46 (comment uniE080)
   (CHARWD R 685)
   (CHARHT R 818)
   (CHARDP R 311)
   )
(CHARACTER O 47 (comment uniE081)
   (CHARWD R 685)
   (CHARHT R 818)
   (CHARDP R 311)
   )
(CHARACTER O 50 (comment uniE084)
   (CHARWD R 685)
   (CHARHT R 709)
   (CHARDP R 201)
   )
(CHARACTER O 51 (comment uniE085)
   (CHARWD R 685)
   (CHARHT R 709)
   (CHARDP R 201)
   )
(CHARACTER O 52 (comment uniE088)
   (CHARWD R 685)
   (CHARHT R 818)
   (CHARDP R 311)
   )
(CHARACTER O 53 (comment uniE089)
   (CHARWD R 685)
   (CHARHT R 818)
   (CHARDP R 311)
   )
(CHARACTER O 54 (comment uniE092)
   (CHARWD R 685)
   (CHARHT R 719)
   (CHARDP R 296)
   )
(CHARACTER O 55 (comment uniE093)
   (CHARWD R 685)
   (CHARHT R 719)
   (CHARDP R 296)
   )
(CHARACTER O 56 (comment uniE096)
   (CHARWD R 685)
   (CHARHT R 818)
   (CHARDP R 311)
   )
(CHARACTER O 57 (comment uniE097)
   (CHARWD R 685)
   (CHARHT R 818)
   (CHARDP R 311)
   )
(CHARACTER O 60 (comment uniE099)
   (CHARWD R 612)
   (CHARHT R 567)
   (CHARDP R 183)
   )
(CHARACTER O 61 (comment uniE09A)
   (CHARWD R 708)
   (CHARHT R 719)
   (CHARDP R 213)
   )
(CHARACTER O 62 (comment uniE09B)
   (CHARWD R 708)
   (CHARHT R 719)
   (CHARDP R 213)
   )
(CHARACTER O 66 (comment uniE0A2)
   (CHARWD R 561)
   (CHARHT R 460)
   (CHARDP R 218)
   )
(CHARACTER O 67 (comment uniE0A4)
   (CHARWD R 378)
   (CHARHT R 470)
   (CHARDP R 233)
   )
(CHARACTER O 70 (comment uniE0A5)
   (CHARWD R 397)
   (CHARHT R 669)
   )
(CHARACTER O 71 (comment uniE0A6)
   (CHARWD R 444)
   (CHARHT R 216)
   (CHARDP R 144)
   )
(CHARACTER O 72 (comment uniE0A7)
   (CHARWD R 376)
   (CHARHT R 702)
   )
(CHARACTER O 73 (comment uniE0A8)
   (CHARWD R 496)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 74 (comment uniE0A9)
   (CHARWD R 647)
   (CHARHT R 497)
   )
(CHARACTER O 75 (comment uniE0AA)
   (CHARWD R 376)
   (CHARHT R 702)
   )
(CHARACTER O 76 (comment uniE0AB)
   (CHARWD R 496)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 77 (comment uniE0AC)
   (CHARWD R 470)
   (CHARHT R 702)
   )
(CHARACTER O 100 (comment uniE0AD)
   (CHARWD R 638)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 101 (comment uniE0AE)
   (CHARWD R 423)
   (CHARHT R 662)
   )
(CHARACTER O 102 (comment uniE0AF)
   (CHARWD R 423)
   (CHARHT R 662)
   )
(CHARACTER O 103 (comment uniE0B0)
   (CHARWD R 0)
   (CHARHT R 735)
   (CHARIC R 400)
   )
(CHARACTER O 104 (comment uniE0B1)
   (CHARWD R 0)
   (CHARDP R 254)
   (CHARIC R 300)
   )
(CHARACTER O 105 (comment uniE0B2)
   (CHARWD R 0)
   (CHARDP R 254)
   (CHARIC R 300)
   )
(CHARACTER O 106 (comment uniE0B3)
   (CHARWD R 541)
   (CHARHT R 683)
   (CHARDP R 218)
   )
(CHARACTER O 107 (comment uniE0B7)
   (CHARWD R 281)
   (CHARHT R 324)
   )
(CHARACTER O 110 (comment uniE0B8)
   (CHARWD R 1344)
   (CHARHT R 943)
   (CHARDP R 11)
   )
(CHARACTER O 111 (comment uniE0B9)
   (CHARWD R 1344)
   (CHARHT R 943)
   (CHARDP R 11)
   )
(CHARACTER O 112 (comment uniE0BB)
   (CHARWD R 685)
   (CHARHT R 622)
   (CHARDP R 101)
   )
(CHARACTER O 113 (comment uniE0BC)
   (CHARWD R 685)
   (CHARHT R 547)
   (CHARDP R 41)
   )
(CHARACTER O 114 (comment uniE0BD)
   (CHARWD R 710)
   (CHARHT R 662)
   (CHARDP R 218)
   )
(CHARACTER O 115 (comment uniE0BE)
   (CHARWD R 1102)
   (CHARHT R 757)
   (CHARDP R 218)
   )
(CHARACTER O 116 (comment uniE0BF)
   (CHARWD R 636)
   (CHARHT R 836)
   (CHARDP R 236)
   )
(CHARACTER O 117 (comment uniE0C0)
   (CHARWD R 636)
   (CHARHT R 836)
   (CHARDP R 236)
   )
(CHARACTER O 120 (comment uniE0C1)
   (CHARWD R 636)
   (CHARHT R 836)
   (CHARDP R 236)
   )
(CHARACTER O 121 (comment uniE0C2)
   (CHARWD R 636)
   (CHARHT R 836)
   (CHARDP R 236)
   )
(CHARACTER O 122 (comment uniE0C3)
   (CHARWD R 750)
   (CHARHT R 386)
   )
(CHARACTER O 123 (comment uniE0C4)
   (CHARWD R 750)
   (CHARHT R 478)
   )
(CHARACTER O 124 (comment uniE0C5)
   (CHARWD R 750)
   (CHARHT R 478)
   )
(CHARACTER O 125 (comment uniE0C6)
   (CHARWD R 750)
   (CHARHT R 286)
   )
(CHARACTER O 126 (comment uniE0C7)
   (CHARWD R 750)
   (CHARHT R 402)
   )
(CHARACTER O 127 (comment uniE0C8)
   (CHARWD R 1000)
   (CHARHT R 386)
   )
(CHARACTER O 130 (comment uniE0C9)
   (CHARWD R 1000)
   (CHARHT R 478)
   )
(CHARACTER O 131 (comment uniE0CA)
   (CHARWD R 1000)
   (CHARHT R 544)
   (CHARDP R 38)
   )
(CHARACTER O 132 (comment uniE0CB)
   (CHARWD R 750)
   (CHARHT R 386)
   )
(CHARACTER O 133 (comment uniE0CC)
   (CHARWD R 750)
   (CHARHT R 478)
   )
(CHARACTER O 134 (comment uniE0CD)
   (CHARWD R 750)
   (CHARHT R 544)
   (CHARDP R 38)
   )
(CHARACTER O 135 (comment uniE0CE)
   (CHARWD R 636)
   (CHARHT R 836)
   (CHARDP R 236)
   )
(CHARACTER O 136 (comment uniE0CF)
   (CHARWD R 636)
   (CHARHT R 836)
   (CHARDP R 236)
   )
(CHARACTER O 137 (comment uniE0D0)
   (CHARWD R 636)
   (CHARHT R 836)
   (CHARDP R 236)
   )
(CHARACTER O 140 (comment uniE0D1)
   (CHARWD R 636)
   (CHARHT R 836)
   (CHARDP R 236)
   )
(CHARACTER O 141 (comment uniE0D2)
   (CHARWD R 926)
   (CHARHT R 692)
   (CHARDP R 186)
   )
(CHARACTER O 142 (comment uniE0D3)
   (CHARWD R 926)
   (CHARHT R 633)
   (CHARDP R 127)
   )
(CHARACTER O 143 (comment uniE0D4)
   (CHARWD R 926)
   (CHARHT R 633)
   (CHARDP R 127)
   )
(CHARACTER O 144 (comment uniE0D5)
   (CHARWD R 1000)
   (CHARHT R 286)
   )
(CHARACTER O 145 (comment uniE0D6)
   (CHARWD R 750)
   (CHARHT R 386)
   )
(CHARACTER O 146 (comment uniE0D7)
   (CHARWD R 762)
   (CHARHT R 583)
   (CHARDP R 79)
   )
(CHARACTER O 147 (comment uniE0D8)
   (CHARWD R 400)
   (CHARHT R 584)
   )
(CHARACTER O 150 (comment uniE0D9)
   (CHARWD R 255)
   (CHARHT R 665)
   )
(CHARACTER O 151 (comment uniE0DA)
   (CHARWD R 388)
   (CHARHT R 665)
   )
(CHARACTER O 152 (comment uniE0DB)
   (CHARWD R 1472)
   (CHARHT R 610)
   (CHARDP R 104)
   )
(CHARACTER O 153 (comment uniE0DC)
   (CHARWD R 1134)
   (CHARHT R 354)
   )
(CHARACTER O 154 (comment uniE0DD)
   (CHARWD R 516)
   (CHARHT R 933)
   )
(CHARACTER O 155 (comment uniE0DE)
   (CHARWD R 500)
   (CHARHT R 933)
   )
(CHARACTER O 156 (comment uniE0DF)
   (CHARWD R 778)
   (CHARHT R 754)
   )
(CHARACTER O 157 (comment uniE0E0)
   (CHARWD R 500)
   (CHARHT R 920)
   )
(CHARACTER O 160 (comment uniE0E1)
   (CHARWD R 389)
   (CHARHT R 757)
   )
(CHARACTER O 161 (comment uniE0E2)
   (CHARWD R 500)
   (CHARHT R 754)
   )
(CHARACTER O 162 (comment uniE0E3)
   (CHARWD R 842)
   (CHARHT R 638)
   (CHARDP R 134)
   )
(CHARACTER O 163 (comment uniE0E5)
   (CHARWD R 523)
   (CHARHT R 690)
   (CHARDP R 189)
   )
(CHARACTER O 164 (comment uniE0E6)
   (CHARWD R 523)
   (CHARHT R 690)
   (CHARDP R 189)
   )
(CHARACTER O 165 (comment uniE0E7)
   (CHARWD R 772)
   (CHARHT R 811)
   (CHARDP R 127)
   )
(CHARACTER O 166 (comment uniE0E8)
   (CHARWD R 1077)
   (CHARHT R 532)
   (CHARDP R 26)
   )
(CHARACTER O 167 (comment uniE0E9)
   (CHARWD R 685)
   (CHARHT R 547)
   (CHARDP R 41)
   )
(CHARACTER O 170 (comment uniE0EA)
   (CHARWD R 910)
   (CHARHT R 661)
   (CHARDP R 158)
   )
(CHARACTER O 171 (comment uniE0EB)
   (CHARWD R 716)
   (CHARHT R 567)
   (CHARDP R 58)
   )
(CHARACTER O 172 (comment uniE0EC)
   (CHARWD R 685)
   (CHARHT R 862)
   )
(CHARACTER O 173 (comment uniE0ED)
   (CHARWD R 511)
   (CHARHT R 819)
   (CHARDP R 312)
   )
(CHARACTER O 174 (comment uniE0EE)
   (CHARWD R 926)
   (CHARHT R 751)
   (CHARDP R 156)
   )
(CHARACTER O 175 (comment uniE0EF)
   (CHARWD R 686)
   (CHARHT R 547)
   (CHARDP R 41)
   )
(CHARACTER O 176 (comment uniE0F1)
   (CHARWD R 390)
   (CHARHT R 66)
   )
(CHARACTER O 177 (comment uniE0F2)
   (CHARWD R 1059)
   (CHARHT R 936)
   (CHARDP R 157)
   )
(CHARACTER O 200 (comment uniE0F3)
   (CHARWD R 1059)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 201 (comment uniE0F4)
   (CHARWD R 773)
   (CHARHT R 694)
   (CHARDP R 168)
   )
(CHARACTER O 202 (comment uniE0F5)
   (CHARWD R 926)
   (CHARHT R 672)
   (CHARDP R 146)
   )
(CHARACTER O 203 (comment uniE0F6)
   (CHARWD R 909)
   (CHARHT R 747)
   (CHARDP R 114)
   )
(CHARACTER O 204 (comment uniE0F7)
   (CHARWD R 956)
   (CHARHT R 727)
   (CHARDP R 102)
   )
(CHARACTER O 205 (comment uniE0F8)
   (CHARWD R 500)
   (CHARHT R 474)
   (CHARDP R 89)
   )
(CHARACTER O 206 (comment uniE0F9)
   (CHARWD R 767)
   (CHARHT R 680)
   )
(CHARACTER O 207 (comment uniE0FA)
   (CHARWD R 297)
   (CHARHT R 474)
   (CHARDP R 89)
   )
(CHARACTER O 210 (comment uniE0FB)
   (CHARWD R 1750)
   (CHARHT R 680)
   )
(CHARACTER O 211 (comment uniE0FC)
   (CHARWD R 1625)
   (CHARHT R 680)
   )
(CHARACTER O 212 (comment uniE0FD)
   (CHARWD R 1625)
   (CHARHT R 680)
   )
(CHARACTER O 213 (comment uniE0FE)
   (CHARWD R 1625)
   (CHARHT R 680)
   )
(CHARACTER O 214 (comment uniE0FF)
   (CHARWD R 1625)
   (CHARHT R 680)
   )
(CHARACTER O 215 (comment uniE100)
   (CHARWD R 2032)
   (CHARHT R 680)
   )
(CHARACTER O 216 (comment uniE101)
   (CHARWD R 1625)
   (CHARHT R 680)
   )
(CHARACTER O 217 (comment uniE102)
   (CHARWD R 1608)
   (CHARHT R 680)
   )
(CHARACTER O 220 (comment uniE103)
   (CHARWD R 2296)
   (CHARHT R 680)
   )
(CHARACTER O 221 (comment uniE104)
   (CHARWD R 100)
   (CHARHT R 409)
   (CHARIC R 64)
   )
(CHARACTER O 222 (comment uniE105)
   (CHARWD R 2032)
   (CHARHT R 680)
   )
(CHARACTER O 223 (comment uniE106)
   (CHARWD R 2032)
   (CHARHT R 680)
   )
(CHARACTER O 224 (comment uniE107)
   (CHARWD R 1625)
   (CHARHT R 680)
   )
(CHARACTER O 225 (comment uniE108)
   (CHARWD R 1625)
   (CHARHT R 680)
   )
(CHARACTER O 226 (comment uniE109)
   (CHARWD R 327)
   (CHARHT R 781)
   (CHARDP R 279)
   )
(CHARACTER O 227 (comment uniE10A)
   (CHARWD R 250)
   (CHARHT R 781)
   (CHARDP R 279)
   )
(CHARACTER O 230 (comment uniE10C)
   (CHARWD R 400)
   (CHARHT R 384)
   )
(CHARACTER O 231 (comment uniE10D)
   (CHARWD R 400)
   (CHARHT R 384)
   )
(CHARACTER O 232 (comment uniE110)
   (CHARWD R 652)
   (CHARHT R 432)
   )
(CHARACTER O 233 (comment uniE111)
   (CHARWD R 652)
   (CHARHT R 432)
   )
(CHARACTER O 234 (comment uniE112)
   (CHARWD R 926)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 235 (comment uniE113)
   (CHARWD R 926)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 236 (comment uniE114)
   (CHARWD R 926)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 237 (comment uniE115)
   (CHARWD R 926)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 240 (comment uniE116)
   (CHARWD R 511)
   (CHARHT R 214)
   )
(CHARACTER O 241 (comment uniE117)
   (CHARWD R 229)
   (CHARHT R 286)
   )
(CHARACTER O 242 (comment uniE118)
   (CHARWD R 277)
   (CHARHT R 271)
   )
(CHARACTER O 243 (comment uniE119)
   (CHARWD R 277)
   (CHARHT R 271)
   )
(CHARACTER O 244 (comment uniE11A)
   (CHARWD R 511)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 245 (comment uniE11B)
   (CHARWD R 511)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 246 (comment uniE11C)
   (CHARWD R 926)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 247 (comment uniE11D)
   (CHARWD R 926)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 250 (comment uniE11E)
   (CHARWD R 926)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 251 (comment uniE11F)
   (CHARWD R 926)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 252 (comment uniE120)
   (CHARWD R 511)
   (CHARHT R 411)
   )
(CHARACTER O 253 (comment uniE121)
   (CHARWD R 311)
   (CHARHT R 290)
   (CHARIC R 3)
   )
(CHARACTER O 254 (comment uniE122)
   (CHARWD R 367)
   (CHARHT R 382)
   )
(CHARACTER O 255 (comment uniE123)
   (CHARWD R 367)
   (CHARHT R 383)
   )
(CHARACTER O 256 (comment uniE124)
   (CHARWD R 511)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 257 (comment uniE125)
   (CHARWD R 511)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 260 (comment uniE126)
   (CHARWD R 926)
   (CHARHT R 449)
   )
(CHARACTER O 261 (comment uniE127)
   (CHARWD R 926)
   (CHARHT R 449)
   )
(CHARACTER O 262 (comment uniE128)
   (CHARWD R 926)
   (CHARHT R 662)
   (CHARDP R 155)
   )
(CHARACTER O 263 (comment uniE129)
   (CHARWD R 926)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 264 (comment uniE12A)
   (CHARWD R 926)
   (CHARHT R 662)
   (CHARDP R 156)
   )
(CHARACTER O 265 (comment uniE12B)
   (CHARWD R 926)
   (CHARHT R 661)
   (CHARDP R 156)
   )
(CHARACTER O 266 (comment uniE12C)
   (CHARWD R 511)
   (CHARHT R 404)
   )
(CHARACTER O 267 (comment uniE12D)
   (CHARWD R 511)
   (CHARHT R 403)
   )
(CHARACTER O 270 (comment uniE12E)
   (CHARWD R 371)
   (CHARHT R 290)
   )
(CHARACTER O 271 (comment uniE12F)
   (CHARWD R 371)
   (CHARHT R 290)
   )
(CHARACTER O 272 (comment uniE130)
   (CHARWD R 379)
   (CHARHT R 373)
   )
(CHARACTER O 273 (comment uniE131)
   (CHARWD R 379)
   (CHARHT R 373)
   )
(CHARACTER O 274 (comment uniE132)
   (CHARWD R 379)
   (CHARHT R 373)
   )
(CHARACTER O 275 (comment uniE133)
   (CHARWD R 379)
   (CHARHT R 373)
   )
(CHARACTER O 276 (comment uniE138)
   (CHARWD R 480)
   (CHARHT R 634)
   (CHARIC R 10)
   )
(CHARACTER O 277 (comment uniE139)
   (CHARWD R 480)
   (CHARDP R 177)
   (CHARIC R 10)
   )
(CHARACTER O 300 (comment uniE13A)
   (CHARWD R 735)
   (CHARHT R 943)
   (CHARDP R 11)
   (CHARIC R 567)
   )
(CHARACTER O 301 (comment uniE14A)
   (CHARWD R 633)
   (CHARHT R 955)
   (CHARIC R 1)
   )
(CHARACTER O 302 (comment uniE14B)
   (CHARWD R 633)
   (CHARDP R 261)
   (CHARIC R 1)
   )
(CHARACTER O 303 (comment uniE150)
   (CHARWD R 735)
   (CHARHT R 135)
   (CHARDP R 308)
   (CHARIC R 11)
   )
(CHARACTER O 304 (comment uniE151)
   (CHARWD R 735)
   (CHARHT R 135)
   (CHARDP R 308)
   (CHARIC R 25)
   )
(CHARACTER O 305 (comment uniE152)
   (CHARWD R 735)
   (CHARHT R 444)
   (CHARIC R 11)
   )
(CHARACTER O 306 (comment uniE153)
   (CHARWD R 735)
   (CHARHT R 444)
   (CHARIC R 25)
   )
(CHARACTER O 307 (comment uniE17D)
   (CHARWD R 666)
   (CHARHT R 674)
   )
(CHARACTER O 310 (comment uniE17E)
   (CHARWD R 604)
   (CHARHT R 662)
   )
(CHARACTER O 311 (comment uniE181)
   (CHARWD R 583)
   (CHARHT R 662)
   )
(CHARACTER O 312 (comment uniE182)
   (CHARWD R 637)
   (CHARHT R 662)
   )
(CHARACTER O 313 (comment uniE183)
   (CHARWD R 658)
   (CHARHT R 662)
   )
(CHARACTER O 314 (comment uniE185)
   (CHARWD R 401)
   (CHARHT R 662)
   )
(CHARACTER O 315 (comment uniE186)
   (CHARWD R 634)
   (CHARHT R 662)
   )
(CHARACTER O 316 (comment uniE188)
   (CHARWD R 843)
   (CHARHT R 662)
   )
(CHARACTER O 317 (comment uniE189)
   (CHARWD R 675)
   (CHARHT R 662)
   (CHARDP R 14)
   )
(CHARACTER O 320 (comment uniE18B)
   (CHARWD R 714)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER O 321 (comment uniE18D)
   (CHARWD R 525)
   (CHARHT R 662)
   )
(CHARACTER O 322 (comment uniE18E)
   (CHARWD R 714)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER O 323 (comment uniE190)
   (CHARWD R 608)
   (CHARHT R 662)
   )
(CHARACTER O 324 (comment uniE193)
   (CHARWD R 700)
   (CHARHT R 662)
   )
(CHARACTER O 325 (comment uniE1A4)
   (CHARWD R 499)
   (CHARHT R 463)
   (CHARDP R 10)
   )
