(FAMILY STIXMath)
(CODINGSCHEME STIXMATHRM)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   )
(LIGTABLE
   (LABEL O 101) (comment A)
   (KRN O 103 R -0.025) (comment C)
   (KRN O 107 R -0.025) (comment G)
   (KRN O 117 R -0.025) (comment O)
   (KRN O 121 R -0.025) (comment Q)
   (KRN O 124 R -0.054) (comment T)
   (KRN O 125 R -0.035) (comment U)
   (KRN O 126 R -0.083) (comment V)
   (KRN O 127 R -0.083) (comment W)
   (KRN O 131 R -0.052) (comment Y)
   (KRN O 141 R -0.004) (comment a)
   (KRN O 142 R -0.014) (comment b)
   (KRN O 143 R -0.01) (comment c)
   (KRN O 144 R -0.017) (comment d)
   (KRN O 145 R -0.016) (comment e)
   (KRN O 147 R -0.012) (comment g)
   (KRN O 157 R -0.026) (comment o)
   (KRN O 161 R -0.014) (comment q)
   (KRN O 164 R -0.013) (comment t)
   (KRN O 165 R -0.014) (comment u)
   (KRN O 166 R -0.058) (comment v)
   (KRN O 167 R -0.058) (comment w)
   (KRN O 171 R -0.072) (comment y)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 102) (comment B)
   (KRN O 101 R -0.033) (comment A)
   (KRN O 117 R -0.017) (comment O)
   (KRN O 126 R -0.05) (comment V)
   (KRN O 127 R -0.047) (comment W)
   (KRN O 131 R -0.06) (comment Y)
   (KRN O 177 R -0.0285) (comment quoteright)
   (STOP)
   (LABEL O 103) (comment C)
   (KRN O 177 R 0.0265) (comment quoteright)
   (KRN O 101 R -0.016) (comment A)
   (KRN O 113 R -0.009) (comment K)
   (KRN O 117 R -0.008) (comment O)
   (STOP)
   (LABEL O 104) (comment D)
   (KRN O 101 R -0.04) (comment A)
   (KRN O 112 R -0.02) (comment J)
   (KRN O 124 R -0.005) (comment T)
   (KRN O 126 R -0.038) (comment V)
   (KRN O 127 R -0.038) (comment W)
   (KRN O 130 R -0.042) (comment X)
   (KRN O 131 R -0.046) (comment Y)
   (KRN O 177 R -0.011) (comment quoteright)
   (STOP)
   (LABEL O 106) (comment F)
   (KRN O 141 R -0.011) (comment a)
   (KRN O 145 R -0.004) (comment e)
   (KRN O 101 R -0.035) (comment A)
   (KRN O 151 R -0.005) (comment i)
   (KRN O 152 R -0.005) (comment j)
   (KRN O 157 R -0.005) (comment o)
   (KRN O 162 R -0.001) (comment r)
   (KRN O 165 R -0.001) (comment u)
   (KRN O 117 R -0.001) (comment O)
   (KRN O 112 R -0.001) (comment J)
   (KRN O 177 R 0.016) (comment quoteright)
   (STOP)
   (LABEL O 107) (comment G)
   (KRN O 101 R -0.015) (comment A)
   (KRN O 124 R -0.013) (comment T)
   (KRN O 126 R -0.015) (comment V)
   (KRN O 127 R -0.015) (comment W)
   (KRN O 131 R -0.021) (comment Y)
   (KRN O 177 R 0.015) (comment quoteright)
   (STOP)
   (LABEL O 112) (comment J)
   (KRN O 101 R -0.035) (comment A)
   (KRN O 177 R 0.0275) (comment quoteright)
   (STOP)
   (LABEL O 113) (comment K)
   (KRN O 141 R 0.001) (comment a)
   (KRN O 103 R -0.019) (comment C)
   (KRN O 145 R -0.015) (comment e)
   (KRN O 107 R -0.019) (comment G)
   (KRN O 157 R -0.015) (comment o)
   (KRN O 123 R 0.001) (comment S)
   (KRN O 124 R -0.001) (comment T)
   (KRN O 165 R -0.01) (comment u)
   (KRN O 171 R -0.045) (comment y)
   (KRN O 117 R -0.019) (comment O)
   (KRN O 177 R -0.016) (comment quoteright)
   (STOP)
   (LABEL O 114) (comment L)
   (KRN O 101 R -0.001) (comment A)
   (KRN O 103 R -0.001) (comment C)
   (KRN O 107 R -0.003) (comment G)
   (KRN O 131 R -0.075) (comment Y)
   (KRN O 123 R 0.003) (comment S)
   (KRN O 124 R -0.06) (comment T)
   (KRN O 165 R -0.008) (comment u)
   (KRN O 126 R -0.074) (comment V)
   (KRN O 127 R -0.058) (comment W)
   (KRN O 171 R -0.037) (comment y)
   (KRN O 117 R -0.001) (comment O)
   (KRN O 125 R -0.018) (comment U)
   (KRN O 177 R -0.1545) (comment quoteright)
   (STOP)
   (LABEL O 116) (comment N)
   (KRN O 141 R -0.018) (comment a)
   (KRN O 103 R -0.01) (comment C)
   (KRN O 145 R -0.012) (comment e)
   (KRN O 101 R -0.018) (comment A)
   (KRN O 107 R -0.01) (comment G)
   (KRN O 117 R -0.01) (comment O)
   (KRN O 165 R -0.013) (comment u)
   (KRN O 157 R -0.013) (comment o)
   (KRN O 177 R -0.001) (comment quoteright)
   (STOP)
   (LABEL O 117) (comment O)
   (KRN O 101 R -0.025) (comment A)
   (KRN O 124 R -0.003) (comment T)
   (KRN O 126 R -0.03) (comment V)
   (KRN O 127 R -0.025) (comment W)
   (KRN O 130 R -0.025) (comment X)
   (KRN O 131 R -0.036) (comment Y)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 120) (comment P)
   (KRN O 141 R -0.01) (comment a)
   (KRN O 145 R -0.014) (comment e)
   (KRN O 101 R -0.059) (comment A)
   (KRN O 112 R -0.038) (comment J)
   (KRN O 157 R -0.016) (comment o)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 122) (comment R)
   (KRN O 141 R -0.002) (comment a)
   (KRN O 103 R -0.026) (comment C)
   (KRN O 145 R -0.014) (comment e)
   (KRN O 107 R -0.026) (comment G)
   (KRN O 127 R -0.06) (comment W)
   (KRN O 157 R -0.024) (comment o)
   (KRN O 124 R -0.024) (comment T)
   (KRN O 165 R -0.014) (comment u)
   (KRN O 126 R -0.065) (comment V)
   (KRN O 131 R -0.06) (comment Y)
   (KRN O 177 R -0.0615) (comment quoteright)
   (KRN O 171 R -0.032) (comment y)
   (KRN O 117 R -0.026) (comment O)
   (KRN O 125 R -0.037) (comment U)
   (STOP)
   (LABEL O 123) (comment S)
   (KRN O 164 R -0.011) (comment t)
   (KRN O 101 R -0.03) (comment A)
   (KRN O 124 R -0.018) (comment T)
   (KRN O 126 R -0.02) (comment V)
   (KRN O 127 R -0.02) (comment W)
   (KRN O 131 R -0.027) (comment Y)
   (KRN O 177 R -0.011) (comment quoteright)
   (STOP)
   (LABEL O 124) (comment T)
   (KRN O 73 R -0.026) (comment semicolon)
   (KRN O 101 R -0.053) (comment A)
   (KRN O 103 R -0.002) (comment C)
   (KRN O 107 R -0.002) (comment G)
   (KRN O 112 R -0.007) (comment J)
   (KRN O 117 R -0.005) (comment O)
   (KRN O 123 R -0.009) (comment S)
   (KRN O 126 R 0.014) (comment V)
   (KRN O 127 R 0.019) (comment W)
   (KRN O 131 R 0.01) (comment Y)
   (KRN O 141 R -0.038) (comment a)
   (KRN O 143 R -0.041) (comment c)
   (KRN O 145 R -0.041) (comment e)
   (KRN O 147 R -0.044) (comment g)
   (KRN O 151 R -0.009) (comment i)
   (KRN O 152 R -0.01) (comment j)
   (KRN O 157 R -0.032) (comment o)
   (KRN O 162 R -0.024) (comment r)
   (KRN O 163 R -0.036) (comment s)
   (KRN O 165 R -0.038) (comment u)
   (KRN O 166 R -0.051) (comment v)
   (KRN O 167 R -0.051) (comment w)
   (KRN O 171 R -0.049) (comment y)
   (KRN O 177 R -0.0005) (comment quoteright)
   (STOP)
   (LABEL O 125) (comment U)
   (KRN O 101 R -0.043) (comment A)
   (KRN O 155 R -0.02) (comment m)
   (KRN O 156 R -0.02) (comment n)
   (KRN O 160 R -0.018) (comment p)
   (KRN O 162 R -0.006) (comment r)
   (KRN O 177 R 0.029) (comment quoteright)
   (STOP)
   (LABEL O 126) (comment V)
   (KRN O 141 R -0.08) (comment a)
   (KRN O 103 R -0.038) (comment C)
   (KRN O 145 R -0.07) (comment e)
   (KRN O 101 R -0.084) (comment A)
   (KRN O 147 R -0.065) (comment g)
   (KRN O 151 R -0.02) (comment i)
   (KRN O 107 R -0.038) (comment G)
   (KRN O 157 R -0.075) (comment o)
   (KRN O 73 R -0.059) (comment semicolon)
   (KRN O 162 R -0.04) (comment r)
   (KRN O 123 R -0.035) (comment S)
   (KRN O 124 R 0.009) (comment T)
   (KRN O 165 R -0.05) (comment u)
   (KRN O 171 R -0.05) (comment y)
   (KRN O 117 R -0.038) (comment O)
   (KRN O 177 R 0.027) (comment quoteright)
   (STOP)
   (LABEL O 127) (comment W)
   (KRN O 141 R -0.06) (comment a)
   (KRN O 103 R -0.033) (comment C)
   (KRN O 145 R -0.06) (comment e)
   (KRN O 101 R -0.102) (comment A)
   (KRN O 147 R -0.057) (comment g)
   (KRN O 151 R -0.013) (comment i)
   (KRN O 107 R -0.038) (comment G)
   (KRN O 157 R -0.07) (comment o)
   (KRN O 73 R -0.047) (comment semicolon)
   (KRN O 162 R -0.03) (comment r)
   (KRN O 123 R -0.024) (comment S)
   (KRN O 124 R 0.016) (comment T)
   (KRN O 165 R -0.03) (comment u)
   (KRN O 171 R -0.045) (comment y)
   (KRN O 117 R -0.033) (comment O)
   (KRN O 177 R -0.016) (comment quoteright)
   (STOP)
   (LABEL O 130) (comment X)
   (KRN O 141 R -0.007) (comment a)
   (KRN O 103 R -0.035) (comment C)
   (KRN O 145 R -0.029) (comment e)
   (KRN O 157 R -0.027) (comment o)
   (KRN O 121 R -0.038) (comment Q)
   (KRN O 165 R -0.018) (comment u)
   (KRN O 171 R -0.063) (comment y)
   (KRN O 117 R -0.038) (comment O)
   (KRN O 177 R 0.036) (comment quoteright)
   (STOP)
   (LABEL O 131) (comment Y)
   (KRN O 141 R -0.08) (comment a)
   (KRN O 103 R -0.05) (comment C)
   (KRN O 145 R -0.066) (comment e)
   (KRN O 101 R -0.075) (comment A)
   (KRN O 147 R -0.073) (comment g)
   (KRN O 151 R -0.017) (comment i)
   (KRN O 107 R -0.051) (comment G)
   (KRN O 157 R -0.067) (comment o)
   (KRN O 160 R -0.057) (comment p)
   (KRN O 73 R -0.061) (comment semicolon)
   (KRN O 123 R -0.043) (comment S)
   (KRN O 124 R 0.012) (comment T)
   (KRN O 165 R -0.059) (comment u)
   (KRN O 166 R -0.062) (comment v)
   (KRN O 117 R -0.051) (comment O)
   (KRN O 177 R 0.035) (comment quoteright)
   (STOP)
   (LABEL O 132) (comment Z)
   (KRN O 171 R -0.033) (comment y)
   (KRN O 177 R -0.002) (comment quoteright)
   (KRN O 166 R -0.033) (comment v)
   (KRN O 167 R -0.034) (comment w)
   (STOP)
   (LABEL O 141) (comment a)
   (KRN O 171 R -0.027) (comment y)
   (KRN O 152 R -0.008) (comment j)
   (KRN O 167 R -0.033) (comment w)
   (KRN O 166 R -0.032) (comment v)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 142) (comment b)
   (KRN O 171 R -0.02) (comment y)
   (KRN O 177 R -0.138) (comment quoteright)
   (KRN O 166 R -0.018) (comment v)
   (KRN O 167 R -0.018) (comment w)
   (STOP)
   (LABEL O 143) (comment c)
   (KRN O 150 R -0.016) (comment h)
   (KRN O 153 R -0.022) (comment k)
   (KRN O 177 R 0.022) (comment quoteright)
   (STOP)
   (LABEL O 145) (comment e)
   (KRN O 164 R -0.009) (comment t)
   (KRN O 166 R -0.019) (comment v)
   (KRN O 167 R -0.019) (comment w)
   (KRN O 170 R -0.021) (comment x)
   (KRN O 171 R -0.021) (comment y)
   (KRN O 177 R 0.002) (comment quoteright)
   (STOP)
   (LABEL O 146) (comment f)
   (KRN O 141 R -0.026) (comment a)
   (KRN O 145 R -0.034) (comment e)
   (KRN O 146 R 0.006) (comment f)
   (KRN O 151 R 0.014) (comment i)
   (KRN O 152 R 0.007) (comment j)
   (KRN O 154 R 0.044) (comment l)
   (KRN O 157 R -0.032) (comment o)
   (KRN O 163 R -0.016) (comment s)
   (KRN O 164 R 0.01) (comment t)
   (KRN O 177 R 0.0475) (comment quoteright)
   (STOP)
   (LABEL O 147) (comment g)
   (KRN O 141 R -0.011) (comment a)
   (KRN O 162 R 0.01) (comment r)
   (KRN O 154 R -0.002) (comment l)
   (KRN O 145 R -0.015) (comment e)
   (KRN O 177 R -0.017) (comment quoteright)
   (STOP)
   (LABEL O 150) (comment h)
   (KRN O 171 R -0.02) (comment y)
   (KRN O 177 R -0.134) (comment quoteright)
   (STOP)
   (LABEL O 151) (comment i)
   (KRN O 152 R -0.034) (comment j)
   (KRN O 124 R -0.018) (comment T)
   (KRN O 177 R -0.007) (comment quoteright)
   (STOP)
   (LABEL O 153) (comment k)
   (KRN O 141 R 0.001) (comment a)
   (KRN O 145 R -0.013) (comment e)
   (KRN O 147 R -0.008) (comment g)
   (KRN O 157 R -0.021) (comment o)
   (KRN O 163 R 0.005) (comment s)
   (KRN O 165 R 0.014) (comment u)
   (KRN O 177 R -0.159) (comment quoteright)
   (STOP)
   (LABEL O 154) (comment l)
   (KRN O 171 R -0.021) (comment y)
   (KRN O 166 R -0.021) (comment v)
   (KRN O 177 R -0.001) (comment quoteright)
   (STOP)
   (LABEL O 155) (comment m)
   (KRN O 160 R -0.003) (comment p)
   (KRN O 171 R -0.02) (comment y)
   (KRN O 177 R 0.007) (comment quoteright)
   (KRN O 166 R -0.02) (comment v)
   (KRN O 167 R -0.02) (comment w)
   (STOP)
   (LABEL O 156) (comment n)
   (KRN O 160 R -0.001) (comment p)
   (KRN O 124 R -0.036) (comment T)
   (KRN O 166 R -0.031) (comment v)
   (KRN O 167 R -0.032) (comment w)
   (KRN O 171 R -0.024) (comment y)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 157) (comment o)
   (KRN O 124 R -0.087) (comment T)
   (KRN O 164 R -0.008) (comment t)
   (KRN O 166 R -0.022) (comment v)
   (KRN O 167 R -0.022) (comment w)
   (KRN O 170 R -0.022) (comment x)
   (KRN O 171 R -0.022) (comment y)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 160) (comment p)
   (KRN O 171 R -0.007) (comment y)
   (KRN O 164 R -0.001) (comment t)
   (KRN O 177 R -0.012) (comment quoteright)
   (STOP)
   (LABEL O 161) (comment q)
   (KRN O 143 R -0.003) (comment c)
   (KRN O 165 R -0.013) (comment u)
   (KRN O 177 R 0.006) (comment quoteright)
   (STOP)
   (LABEL O 162) (comment r)
   (KRN O 73 R -0.007) (comment semicolon)
   (KRN O 141 R -0.002) (comment a)
   (KRN O 143 R -0.002) (comment c)
   (KRN O 144 R -0.002) (comment d)
   (KRN O 145 R -0.002) (comment e)
   (KRN O 146 R 0.019) (comment f)
   (KRN O 147 R -0.016) (comment g)
   (KRN O 150 R -0.002) (comment h)
   (KRN O 151 R 0.019) (comment i)
   (KRN O 152 R 0.013) (comment j)
   (KRN O 153 R -0.007) (comment k)
   (KRN O 154 R -0.007) (comment l)
   (KRN O 155 R 0.02) (comment m)
   (KRN O 156 R 0.021) (comment n)
   (KRN O 157 R -0.006) (comment o)
   (KRN O 160 R 0.025) (comment p)
   (KRN O 161 R -0.01) (comment q)
   (KRN O 162 R 0.026) (comment r)
   (KRN O 164 R 0.023) (comment t)
   (KRN O 165 R 0.024) (comment u)
   (KRN O 166 R 0.02) (comment v)
   (KRN O 167 R 0.019) (comment w)
   (KRN O 170 R 0.016) (comment x)
   (KRN O 171 R 0.021) (comment y)
   (KRN O 172 R 0.002) (comment z)
   (KRN O 177 R -0.0265) (comment quoteright)
   (STOP)
   (LABEL O 163) (comment s)
   (KRN O 164 R -0.008) (comment t)
   (KRN O 177 R 0.0055) (comment quoteright)
   (STOP)
   (LABEL O 164) (comment t)
   (KRN O 141 R 0.01) (comment a)
   (KRN O 150 R 0.008) (comment h)
   (KRN O 157 R -0.002) (comment o)
   (KRN O 123 R 0.002) (comment S)
   (KRN O 73 R 0.006) (comment semicolon)
   (KRN O 177 R -0.053) (comment quoteright)
   (STOP)
   (LABEL O 165) (comment u)
   (KRN O 177 R -0.016) (comment quoteright)
   (STOP)
   (LABEL O 166) (comment v)
   (KRN O 141 R -0.02) (comment a)
   (KRN O 143 R -0.028) (comment c)
   (KRN O 145 R -0.024) (comment e)
   (KRN O 147 R -0.042) (comment g)
   (KRN O 154 R -0.031) (comment l)
   (KRN O 157 R -0.027) (comment o)
   (KRN O 163 R -0.013) (comment s)
   (KRN O 73 R -0.017) (comment semicolon)
   (KRN O 177 R 0.026) (comment quoteright)
   (STOP)
   (LABEL O 167) (comment w)
   (KRN O 141 R -0.028) (comment a)
   (KRN O 143 R -0.021) (comment c)
   (KRN O 145 R -0.018) (comment e)
   (KRN O 147 R -0.033) (comment g)
   (KRN O 154 R -0.034) (comment l)
   (KRN O 157 R -0.026) (comment o)
   (KRN O 163 R -0.023) (comment s)
   (KRN O 73 R -0.012) (comment semicolon)
   (KRN O 177 R -0.003) (comment quoteright)
   (STOP)
   (LABEL O 170) (comment x)
   (KRN O 141 R -0.011) (comment a)
   (KRN O 143 R -0.024) (comment c)
   (KRN O 145 R -0.024) (comment e)
   (KRN O 157 R -0.029) (comment o)
   (KRN O 161 R -0.017) (comment q)
   (KRN O 177 R 0.004) (comment quoteright)
   (STOP)
   (LABEL O 171) (comment y)
   (KRN O 141 R -0.015) (comment a)
   (KRN O 143 R -0.015) (comment c)
   (KRN O 145 R -0.023) (comment e)
   (KRN O 147 R -0.022) (comment g)
   (KRN O 154 R -0.018) (comment l)
   (KRN O 157 R -0.018) (comment o)
   (KRN O 163 R -0.013) (comment s)
   (KRN O 73 R -0.014) (comment semicolon)
   (KRN O 177 R 0.024) (comment quoteright)
   (STOP)
   (LABEL O 177) (comment quoteright)
   (KRN O 101 R -0.132) (comment A)
   (KRN O 144 R -0.058) (comment d)
   (KRN O 157 R -0.056) (comment o)
   (KRN O 162 R -0.038) (comment r)
   (KRN O 163 R -0.049) (comment s)
   (KRN O 164 R -0.042) (comment t)
   (KRN O 166 R -0.048) (comment v)
   (KRN O 167 R -0.043) (comment w)
   (KRN O 171 R -0.046) (comment y)
   (STOP)
   (LABEL O 0) (comment uni0393)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 1) (comment uni0394)
   (KRN O 177 R 0.001) (comment quoteright)
   (STOP)
   (LABEL O 2) (comment uni0398)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 3) (comment uni039B)
   (KRN O 177 R -0.002) (comment quoteright)
   (STOP)
   (LABEL O 4) (comment uni039E)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 5) (comment uni03A0)
   (KRN O 177 R -0.001) (comment quoteright)
   (STOP)
   (LABEL O 6) (comment uni03A3)
   (KRN O 177 R 0.003) (comment quoteright)
   (STOP)
   (LABEL O 7) (comment uni03A5)
   (KRN O 177 R 0.029) (comment quoteright)
   (STOP)
   (LABEL O 10) (comment uni03A6)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 11) (comment uni03A8)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 12) (comment uni03A9)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 13) (comment uni03B1)
   (KRN O 177 R 0.0075) (comment quoteright)
   (STOP)
   (LABEL O 14) (comment uni03B2)
   (KRN O 177 R 0.012) (comment quoteright)
   (STOP)
   (LABEL O 15) (comment uni03B3)
   (KRN O 177 R -0.01) (comment quoteright)
   (STOP)
   (LABEL O 16) (comment uni03B4)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 17) (comment uni03F5)
   (KRN O 177 R -0.0035) (comment quoteright)
   (STOP)
   (LABEL O 20) (comment uni03B6)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 21) (comment uni03B7)
   (KRN O 177 R -0.025) (comment quoteright)
   (STOP)
   (LABEL O 22) (comment uni03B8)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 23) (comment uni03B9)
   (KRN O 177 R 0.0065) (comment quoteright)
   (STOP)
   (LABEL O 24) (comment uni03BA)
   (KRN O 177 R -0.019) (comment quoteright)
   (STOP)
   (LABEL O 25) (comment uni03BB)
   (KRN O 177 R -0.1125) (comment quoteright)
   (STOP)
   (LABEL O 26) (comment uni03BC)
   (KRN O 177 R -0.01) (comment quoteright)
   (STOP)
   (LABEL O 27) (comment uni03BD)
   (KRN O 177 R 0.0045) (comment quoteright)
   (STOP)
   (LABEL O 30) (comment uni03BE)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 31) (comment uni03C0)
   (KRN O 177 R -0.0045) (comment quoteright)
   (STOP)
   (LABEL O 32) (comment uni03C1)
   (KRN O 177 R 0.012) (comment quoteright)
   (STOP)
   (LABEL O 33) (comment uni03C3)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 34) (comment uni03C4)
   (KRN O 177 R 0.0015) (comment quoteright)
   (STOP)
   (LABEL O 35) (comment uni03C5)
   (KRN O 177 R -0.007) (comment quoteright)
   (STOP)
   (LABEL O 36) (comment uni03D5)
   (KRN O 177 R -0.0005) (comment quoteright)
   (STOP)
   (LABEL O 37) (comment uni03C7)
   (KRN O 177 R 0.022) (comment quoteright)
   (STOP)
   (LABEL O 40) (comment uni03C8)
   (KRN O 177 R -0.015) (comment quoteright)
   (STOP)
   (LABEL O 41) (comment uni03C9)
   (KRN O 177 R -0.0005) (comment quoteright)
   (STOP)
   (LABEL O 42) (comment uni03B5)
   (KRN O 177 R -0.0035) (comment quoteright)
   (STOP)
   (LABEL O 43) (comment uni03D1)
   (KRN O 177 R -0.035) (comment quoteright)
   (STOP)
   (LABEL O 44) (comment uni03D6)
   (KRN O 177 R 0.025) (comment quoteright)
   (STOP)
   (LABEL O 45) (comment uni03F1)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 46) (comment uni03C2)
   (KRN O 177 R 0.0135) (comment quoteright)
   (STOP)
   (LABEL O 47) (comment uni03C6)
   (KRN O 177 R -0.0005) (comment quoteright)
   (STOP)
   (LABEL O 51) (comment uni2202)
   (KRN O 177 R -0.0035) (comment quoteright)
   (STOP)
   (LABEL O 105) (comment E)
   (KRN O 177 R -0.0015) (comment quoteright)
   (STOP)
   (LABEL O 110) (comment H)
   (KRN O 177 R -0.001) (comment quoteright)
   (STOP)
   (LABEL O 111) (comment I)
   (KRN O 177 R -0.0005) (comment quoteright)
   (STOP)
   (LABEL O 115) (comment M)
   (KRN O 177 R -0.0065) (comment quoteright)
   (STOP)
   (LABEL O 121) (comment Q)
   (KRN O 177 R -0.003) (comment quoteright)
   (STOP)
   (LABEL O 144) (comment d)
   (KRN O 177 R 0.117) (comment quoteright)
   (STOP)
   (LABEL O 152) (comment j)
   (KRN O 177 R 0.005) (comment quoteright)
   (STOP)
   (LABEL O 172) (comment z)
   (KRN O 177 R 0.024) (comment quoteright)
   (STOP)
   (LABEL O 173) (comment dotlessi)
   (KRN O 177 R -0.005) (comment quoteright)
   (STOP)
   (LABEL O 174) (comment uni0237)
   (KRN O 177 R 0.011) (comment quoteright)
   (STOP)
   )
(CHARACTER O 0 (comment uni0393)
   (CHARWD R 0.587)
   (CHARHT R 0.662)
   )
(CHARACTER O 1 (comment uni0394)
   (CHARWD R 0.722)
   (CHARHT R 0.674)
   )
(CHARACTER O 2 (comment uni0398)
   (CHARWD R 0.722)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 3 (comment uni039B)
   (CHARWD R 0.702)
   (CHARHT R 0.674)
   )
(CHARACTER O 4 (comment uni039E)
   (CHARWD R 0.643)
   (CHARHT R 0.662)
   )
(CHARACTER O 5 (comment uni03A0)
   (CHARWD R 0.722)
   (CHARHT R 0.662)
   )
(CHARACTER O 6 (comment uni03A3)
   (CHARWD R 0.624)
   (CHARHT R 0.662)
   )
(CHARACTER O 7 (comment uni03A5)
   (CHARWD R 0.722)
   (CHARHT R 0.674)
   )
(CHARACTER O 10 (comment uni03A6)
   (CHARWD R 0.763)
   (CHARHT R 0.662)
   )
(CHARACTER O 11 (comment uni03A8)
   (CHARWD R 0.746)
   (CHARHT R 0.69)
   )
(CHARACTER O 12 (comment uni03A9)
   (CHARWD R 0.744)
   (CHARHT R 0.676)
   )
(CHARACTER O 13 (comment uni03B1)
   (CHARWD R 0.543)
   (CHARHT R 0.46)
   (CHARDP R 0.01)
   )
(CHARACTER O 14 (comment uni03B2)
   (CHARWD R 0.496)
   (CHARHT R 0.683)
   (CHARDP R 0.217)
   )
(CHARACTER O 15 (comment uni03B3)
   (CHARWD R 0.474)
   (CHARHT R 0.457)
   (CHARDP R 0.218)
   )
(CHARACTER O 16 (comment uni03B4)
   (CHARWD R 0.5)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 17 (comment uni03F5)
   (CHARWD R 0.439)
   (CHARHT R 0.46)
   (CHARDP R 0.01)
   )
(CHARACTER O 20 (comment uni03B6)
   (CHARWD R 0.441)
   (CHARHT R 0.683)
   (CHARDP R 0.218)
   )
(CHARACTER O 21 (comment uni03B7)
   (CHARWD R 0.512)
   (CHARHT R 0.46)
   (CHARDP R 0.217)
   )
(CHARACTER O 22 (comment uni03B8)
   (CHARWD R 0.496)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 23 (comment uni03B9)
   (CHARWD R 0.275)
   (CHARHT R 0.46)
   (CHARDP R 0.01)
   )
(CHARACTER O 24 (comment uni03BA)
   (CHARWD R 0.5)
   (CHARHT R 0.46)
   (CHARIC R 0.048)
   )
(CHARACTER O 25 (comment uni03BB)
   (CHARWD R 0.497)
   (CHARHT R 0.683)
   (CHARDP R 0.011)
   )
(CHARACTER O 26 (comment uni03BC)
   (CHARWD R 0.528)
   (CHARHT R 0.45)
   (CHARDP R 0.217)
   )
(CHARACTER O 27 (comment uni03BD)
   (CHARWD R 0.455)
   (CHARHT R 0.46)
   (CHARDP R 0.014)
   )
(CHARACTER O 30 (comment uni03BE)
   (CHARWD R 0.441)
   (CHARHT R 0.683)
   (CHARDP R 0.218)
   )
(CHARACTER O 31 (comment uni03C0)
   (CHARWD R 0.501)
   (CHARHT R 0.45)
   (CHARDP R 0.014)
   )
(CHARACTER O 32 (comment uni03C1)
   (CHARWD R 0.496)
   (CHARHT R 0.46)
   (CHARDP R 0.217)
   )
(CHARACTER O 33 (comment uni03C3)
   (CHARWD R 0.548)
   (CHARHT R 0.45)
   (CHARDP R 0.01)
   )
(CHARACTER O 34 (comment uni03C4)
   (CHARWD R 0.477)
   (CHARHT R 0.45)
   (CHARDP R 0.01)
   )
(CHARACTER O 35 (comment uni03C5)
   (CHARWD R 0.524)
   (CHARHT R 0.46)
   (CHARDP R 0.01)
   )
(CHARACTER O 36 (comment uni03D5)
   (CHARWD R 0.623)
   (CHARHT R 0.683)
   (CHARDP R 0.217)
   )
(CHARACTER O 37 (comment uni03C7)
   (CHARWD R 0.5)
   (CHARHT R 0.46)
   (CHARDP R 0.22)
   )
(CHARACTER O 40 (comment uni03C8)
   (CHARWD R 0.694)
   (CHARHT R 0.46)
   (CHARDP R 0.217)
   (CHARIC R 0.04)
   )
(CHARACTER O 41 (comment uni03C9)
   (CHARWD R 0.625)
   (CHARHT R 0.46)
   (CHARDP R 0.01)
   )
(CHARACTER O 42 (comment uni03B5)
   (CHARWD R 0.439)
   (CHARHT R 0.46)
   (CHARDP R 0.01)
   )
(CHARACTER O 43 (comment uni03D1)
   (CHARWD R 0.554)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 44 (comment uni03D6)
   (CHARWD R 0.762)
   (CHARHT R 0.45)
   (CHARDP R 0.01)
   )
(CHARACTER O 45 (comment uni03F1)
   (CHARWD R 0.5)
   (CHARHT R 0.46)
   (CHARDP R 0.215)
   )
(CHARACTER O 46 (comment uni03C2)
   (CHARWD R 0.441)
   (CHARHT R 0.46)
   (CHARDP R 0.218)
   )
(CHARACTER O 47 (comment uni03C6)
   (CHARWD R 0.623)
   (CHARHT R 0.46)
   (CHARDP R 0.217)
   )
(CHARACTER O 50 (comment uni2207)
   (CHARWD R 0.731)
   (CHARHT R 0.662)
   (CHARDP R 0.012)
   )
(CHARACTER O 51 (comment uni2202)
   (CHARWD R 0.471)
   (CHARHT R 0.668)
   (CHARDP R 0.011)
   )
(CHARACTER O 52 (comment minus)
   (CHARWD R 0.685)
   (CHARHT R 0.286)
   )
(CHARACTER O 53 (comment plus)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   (CHARDP R 0.041)
   )
(CHARACTER O 54 (comment plusminus)
   (CHARWD R 0.685)
   (CHARHT R 0.502)
   (CHARDP R 0.087)
   )
(CHARACTER O 55 (comment uni2213)
   (CHARWD R 0.685)
   (CHARHT R 0.502)
   (CHARDP R 0.087)
   )
(CHARACTER O 56 (comment parenleft)
   (CHARWD R 0.333)
   (CHARHT R 0.676)
   (CHARDP R 0.177)
   )
(CHARACTER O 57 (comment parenright)
   (CHARWD R 0.333)
   (CHARHT R 0.676)
   (CHARDP R 0.177)
   )
(CHARACTER O 60 (comment zero)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 61 (comment one)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 62 (comment two)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 63 (comment three)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 64 (comment four)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 65 (comment five)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.014)
   )
(CHARACTER O 66 (comment six)
   (CHARWD R 0.5)
   (CHARHT R 0.684)
   (CHARDP R 0.014)
   )
(CHARACTER O 67 (comment seven)
   (CHARWD R 0.5)
   (CHARHT R 0.662)
   (CHARDP R 0.008)
   )
(CHARACTER O 70 (comment eight)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 71 (comment nine)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.022)
   )
(CHARACTER O 72 (comment uni2236)
   (CHARWD R 0.511)
   (CHARHT R 0.521)
   (CHARDP R 0.013)
   )
(CHARACTER O 73 (comment semicolon)
   (CHARWD R 0.278)
   (CHARHT R 0.459)
   (CHARDP R 0.141)
   )
(CHARACTER O 74 (comment uni2217)
   (CHARWD R 0.523)
   (CHARHT R 0.471)
   )
(CHARACTER O 75 (comment equal)
   (CHARWD R 0.685)
   (CHARHT R 0.386)
   )
(CHARACTER O 76 (comment dollar)
   (CHARWD R 0.5)
   (CHARHT R 0.727)
   (CHARDP R 0.087)
   )
(CHARACTER O 77 (comment question)
   (CHARWD R 0.444)
   (CHARHT R 0.676)
   (CHARDP R 0.008)
   )
(CHARACTER O 100 (comment exclam)
   (CHARWD R 0.333)
   (CHARHT R 0.676)
   (CHARDP R 0.009)
   )
(CHARACTER O 101 (comment A)
   (CHARWD R 0.722)
   (CHARHT R 0.674)
   )
(CHARACTER O 102 (comment B)
   (CHARWD R 0.667)
   (CHARHT R 0.662)
   )
(CHARACTER O 103 (comment C)
   (CHARWD R 0.667)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 104 (comment D)
   (CHARWD R 0.722)
   (CHARHT R 0.662)
   )
(CHARACTER O 105 (comment E)
   (CHARWD R 0.611)
   (CHARHT R 0.662)
   )
(CHARACTER O 106 (comment F)
   (CHARWD R 0.556)
   (CHARHT R 0.662)
   )
(CHARACTER O 107 (comment G)
   (CHARWD R 0.722)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 110 (comment H)
   (CHARWD R 0.722)
   (CHARHT R 0.662)
   )
(CHARACTER O 111 (comment I)
   (CHARWD R 0.333)
   (CHARHT R 0.662)
   )
(CHARACTER O 112 (comment J)
   (CHARWD R 0.373)
   (CHARHT R 0.662)
   (CHARDP R 0.014)
   )
(CHARACTER O 113 (comment K)
   (CHARWD R 0.722)
   (CHARHT R 0.662)
   (CHARIC R 0.046)
   )
(CHARACTER O 114 (comment L)
   (CHARWD R 0.611)
   (CHARHT R 0.662)
   )
(CHARACTER O 115 (comment M)
   (CHARWD R 0.889)
   (CHARHT R 0.662)
   )
(CHARACTER O 116 (comment N)
   (CHARWD R 0.722)
   (CHARHT R 0.662)
   (CHARDP R 0.011)
   )
(CHARACTER O 117 (comment O)
   (CHARWD R 0.722)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 120 (comment P)
   (CHARWD R 0.557)
   (CHARHT R 0.662)
   )
(CHARACTER O 121 (comment Q)
   (CHARWD R 0.722)
   (CHARHT R 0.676)
   (CHARDP R 0.177)
   )
(CHARACTER O 122 (comment R)
   (CHARWD R 0.667)
   (CHARHT R 0.662)
   )
(CHARACTER O 123 (comment S)
   (CHARWD R 0.556)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 124 (comment T)
   (CHARWD R 0.611)
   (CHARHT R 0.662)
   )
(CHARACTER O 125 (comment U)
   (CHARWD R 0.722)
   (CHARHT R 0.662)
   (CHARDP R 0.014)
   )
(CHARACTER O 126 (comment V)
   (CHARWD R 0.722)
   (CHARHT R 0.662)
   (CHARDP R 0.011)
   )
(CHARACTER O 127 (comment W)
   (CHARWD R 0.944)
   (CHARHT R 0.662)
   (CHARDP R 0.011)
   )
(CHARACTER O 130 (comment X)
   (CHARWD R 0.722)
   (CHARHT R 0.662)
   )
(CHARACTER O 131 (comment Y)
   (CHARWD R 0.722)
   (CHARHT R 0.662)
   )
(CHARACTER O 132 (comment Z)
   (CHARWD R 0.612)
   (CHARHT R 0.662)
   )
(CHARACTER O 133 (comment bracketleft)
   (CHARWD R 0.333)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 134 (comment uni2216.var)
   (CHARWD R 0.523)
   (CHARHT R 0.71)
   (CHARDP R 0.222)
   )
(CHARACTER O 135 (comment bracketright)
   (CHARWD R 0.333)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 136 (comment braceleft)
   (CHARWD R 0.48)
   (CHARHT R 0.68)
   (CHARDP R 0.181)
   )
(CHARACTER O 137 (comment uni2215)
   (CHARWD R 0.523)
   (CHARHT R 0.71)
   (CHARDP R 0.222)
   )
(CHARACTER O 140 (comment braceright)
   (CHARWD R 0.48)
   (CHARHT R 0.68)
   (CHARDP R 0.181)
   )
(CHARACTER O 141 (comment a)
   (CHARWD R 0.444)
   (CHARHT R 0.46)
   (CHARDP R 0.01)
   )
(CHARACTER O 142 (comment b)
   (CHARWD R 0.5)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 143 (comment c)
   (CHARWD R 0.444)
   (CHARHT R 0.46)
   (CHARDP R 0.01)
   )
(CHARACTER O 144 (comment d)
   (CHARWD R 0.5)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 145 (comment e)
   (CHARWD R 0.444)
   (CHARHT R 0.46)
   (CHARDP R 0.01)
   )
(CHARACTER O 146 (comment f)
   (CHARWD R 0.333)
   (CHARHT R 0.683)
   (CHARIC R 0.1)
   )
(CHARACTER O 147 (comment g)
   (CHARWD R 0.5)
   (CHARHT R 0.46)
   (CHARDP R 0.218)
   )
(CHARACTER O 150 (comment h)
   (CHARWD R 0.5)
   (CHARHT R 0.683)
   )
(CHARACTER O 151 (comment i)
   (CHARWD R 0.278)
   (CHARHT R 0.683)
   )
(CHARACTER O 152 (comment j)
   (CHARWD R 0.278)
   (CHARHT R 0.683)
   (CHARDP R 0.218)
   )
(CHARACTER O 153 (comment k)
   (CHARWD R 0.5)
   (CHARHT R 0.683)
   (CHARIC R 0.05)
   )
(CHARACTER O 154 (comment l)
   (CHARWD R 0.278)
   (CHARHT R 0.683)
   )
(CHARACTER O 155 (comment m)
   (CHARWD R 0.778)
   (CHARHT R 0.46)
   )
(CHARACTER O 156 (comment n)
   (CHARWD R 0.5)
   (CHARHT R 0.46)
   )
(CHARACTER O 157 (comment o)
   (CHARWD R 0.5)
   (CHARHT R 0.46)
   (CHARDP R 0.01)
   )
(CHARACTER O 160 (comment p)
   (CHARWD R 0.5)
   (CHARHT R 0.46)
   (CHARDP R 0.217)
   )
(CHARACTER O 161 (comment q)
   (CHARWD R 0.5)
   (CHARHT R 0.46)
   (CHARDP R 0.217)
   )
(CHARACTER O 162 (comment r)
   (CHARWD R 0.333)
   (CHARHT R 0.46)
   (CHARIC R 0.06)
   )
(CHARACTER O 163 (comment s)
   (CHARWD R 0.389)
   (CHARHT R 0.459)
   (CHARDP R 0.01)
   )
(CHARACTER O 164 (comment t)
   (CHARWD R 0.278)
   (CHARHT R 0.579)
   (CHARDP R 0.01)
   (CHARIC R 0.06)
   )
(CHARACTER O 165 (comment u)
   (CHARWD R 0.5)
   (CHARHT R 0.45)
   (CHARDP R 0.01)
   )
(CHARACTER O 166 (comment v)
   (CHARWD R 0.5)
   (CHARHT R 0.45)
   (CHARDP R 0.014)
   )
(CHARACTER O 167 (comment w)
   (CHARWD R 0.722)
   (CHARHT R 0.45)
   (CHARDP R 0.014)
   )
(CHARACTER O 170 (comment x)
   (CHARWD R 0.5)
   (CHARHT R 0.45)
   )
(CHARACTER O 171 (comment y)
   (CHARWD R 0.5)
   (CHARHT R 0.45)
   (CHARDP R 0.218)
   (CHARIC R 0.02)
   )
(CHARACTER O 172 (comment z)
   (CHARWD R 0.444)
   (CHARHT R 0.45)
   )
(CHARACTER O 173 (comment dotlessi)
   (CHARWD R 0.278)
   (CHARHT R 0.46)
   )
(CHARACTER O 174 (comment uni0237)
   (CHARWD R 0.278)
   (CHARHT R 0.46)
   (CHARDP R 0.218)
   )
(CHARACTER O 175 (comment numbersign)
   (CHARWD R 0.5)
   (CHARHT R 0.662)
   )
(CHARACTER O 176 (comment percent)
   (CHARWD R 0.747)
   (CHARHT R 0.706)
   (CHARDP R 0.019)
   )
(CHARACTER O 177 (comment quoteright)
   (CHARWD R 0.333)
   (CHARHT R 0.7)
   )
(CHARACTER O 200 (comment uni0300)
   (CHARWD R 0.224)
   (CHARHT R 0.7)
   )
(CHARACTER O 201 (comment uni0301)
   (CHARWD R 0.224)
   (CHARHT R 0.7)
   )
(CHARACTER O 202 (comment uni0302)
   (CHARWD R 0.311)
   (CHARHT R 0.7)
   )
(CHARACTER O 203 (comment uni0303)
   (CHARWD R 0.33)
   (CHARHT R 0.6)
   )
(CHARACTER O 204 (comment uni0304)
   (CHARWD R 0.311)
   (CHARHT R 0.6)
   )
(CHARACTER O 205 (comment uni0306)
   (CHARWD R 0.281)
   (CHARHT R 0.7)
   )
(CHARACTER O 206 (comment uni0307)
   (CHARWD R 0.099)
   (CHARHT R 0.6)
   )
(CHARACTER O 207 (comment uni0308)
   (CHARWD R 0.298)
   (CHARHT R 0.6)
   )
(CHARACTER O 210 (comment uni0309)
   (CHARWD R 0.189)
   (CHARHT R 0.8)
   )
(CHARACTER O 211 (comment uni030A)
   (CHARWD R 0.199)
   (CHARHT R 0.7)
   )
(CHARACTER O 212 (comment uni030C)
   (CHARWD R 0.311)
   (CHARHT R 0.7)
   )
(CHARACTER O 213 (comment uni0310)
   (CHARWD R 0.281)
   (CHARHT R 0.8)
   )
(CHARACTER O 214 (comment uni0312)
   (CHARWD R 0.139)
   (CHARHT R 0.7)
   )
(CHARACTER O 215 (comment uni0315)
   (CHARWD R 0.139)
   (CHARHT R 0.7)
   )
(CHARACTER O 216 (comment uni031A)
   (CHARWD R 0.3)
   (CHARHT R 0.7)
   )
(CHARACTER O 217 (comment uni20D0)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 220 (comment uni20D1)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 221 (comment uni20D6)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 222 (comment uni20D7)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 223 (comment uni20DB)
   (CHARWD R 0.497)
   (CHARHT R 0.6)
   )
(CHARACTER O 224 (comment uni20DC)
   (CHARWD R 0.696)
   (CHARHT R 0.6)
   )
(CHARACTER O 225 (comment uni20E1)
   (CHARWD R 0.478)
   (CHARHT R 0.8)
   )
(CHARACTER O 226 (comment uni20E7)
   (CHARWD R 0.816)
   (CHARHT R 0.7)
   (CHARDP R 0.2)
   )
(CHARACTER O 227 (comment uni20E9)
   (CHARWD R 0.533)
   (CHARHT R 0.7)
   )
(CHARACTER O 230 (comment uni20F0)
   (CHARWD R 0.27)
   (CHARHT R 0.8)
   )
(CHARACTER O 231 (comment ampersand)
   (CHARWD R 0.778)
   (CHARHT R 0.676)
   (CHARDP R 0.013)
   )
(CHARACTER O 232 (comment at)
   (CHARWD R 0.921)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 233 (comment logicalnot)
   (CHARWD R 0.6)
   (CHARHT R 0.393)
   )
(CHARACTER O 234 (comment periodcentered)
   (CHARWD R 0.25)
   (CHARHT R 0.31)
   )
(CHARACTER O 235 (comment multiply)
   (CHARWD R 0.64)
   (CHARHT R 0.529)
   (CHARDP R 0.025)
   )
(CHARACTER O 236 (comment uni2AAF)
   (CHARWD R 0.685)
   (CHARHT R 0.609)
   (CHARDP R 0.103)
   )
(CHARACTER O 237 (comment divide)
   (CHARWD R 0.564)
   (CHARHT R 0.516)
   (CHARDP R 0.01)
   )
(CHARACTER O 240 (comment uni01B5)
   (CHARWD R 0.612)
   (CHARHT R 0.662)
   )
(CHARACTER O 241 (comment uni0338)
   (CHARWD R 0)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 242 (comment uni03F6)
   (CHARWD R 0.444)
   (CHARHT R 0.46)
   (CHARDP R 0.01)
   )
(CHARACTER O 243 (comment dagger)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.149)
   )
(CHARACTER O 244 (comment daggerdbl)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.153)
   )
(CHARACTER O 245 (comment bullet)
   (CHARWD R 0.523)
   (CHARHT R 0.444)
   )
(CHARACTER O 246 (comment twodotenleader)
   (CHARWD R 0.667)
   (CHARHT R 0.1)
   (CHARDP R 0.011)
   )
(CHARACTER O 247 (comment ellipsis)
   (CHARWD R 1)
   (CHARHT R 0.1)
   (CHARDP R 0.011)
   )
(CHARACTER O 250 (comment uni2032.var)
   (CHARWD R 0.34)
   (CHARHT R 0.565)
   )
(CHARACTER O 251 (comment uni2033.var)
   (CHARWD R 0.605)
   (CHARHT R 0.565)
   )
(CHARACTER O 252 (comment uni2034.var)
   (CHARWD R 0.873)
   (CHARHT R 0.565)
   )
(CHARACTER O 253 (comment uni2035.var)
   (CHARWD R 0.34)
   (CHARHT R 0.565)
   )
(CHARACTER O 254 (comment uni2036.var)
   (CHARWD R 0.605)
   (CHARHT R 0.565)
   )
(CHARACTER O 255 (comment uni2037.var)
   (CHARWD R 0.873)
   (CHARHT R 0.565)
   )
(CHARACTER O 256 (comment uni2038)
   (CHARWD R 0.511)
   (CHARHT R 0.102)
   (CHARDP R 0.156)
   )
(CHARACTER O 257 (comment uni203C)
   (CHARWD R 0.549)
   (CHARHT R 0.676)
   (CHARDP R 0.009)
   )
(CHARACTER O 260 (comment uni2043)
   (CHARWD R 0.333)
   (CHARHT R 0.332)
   )
(CHARACTER O 261 (comment fraction)
   (CHARWD R 0.167)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 262 (comment uni2047)
   (CHARWD R 0.839)
   (CHARHT R 0.676)
   (CHARDP R 0.008)
   )
(CHARACTER O 263 (comment uni2050)
   (CHARWD R 0.79)
   (CHARHT R 0.691)
   (CHARDP R 0.04)
   )
(CHARACTER O 264 (comment uni2057.var)
   (CHARWD R 1.139)
   (CHARHT R 0.565)
   )
(CHARACTER O 265 (comment uni20D2)
   (CHARWD R 0)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 266 (comment uni20DD)
   (CHARWD R 0)
   (CHARHT R 0.725)
   (CHARDP R 0.221)
   )
(CHARACTER O 267 (comment uni20DE)
   (CHARWD R 0)
   (CHARHT R 0.78)
   (CHARDP R 0.18)
   )
(CHARACTER O 270 (comment uni20DF)
   (CHARWD R 0)
   (CHARHT R 0.843)
   (CHARDP R 0.341)
   )
(CHARACTER O 271 (comment uni20E4)
   (CHARWD R 0)
   (CHARHT R 1.023)
   (CHARDP R 0.155)
   )
(CHARACTER O 272 (comment uni2107)
   (CHARWD R 0.598)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 273 (comment uni2127)
   (CHARWD R 0.744)
   (CHARHT R 0.662)
   (CHARDP R 0.014)
   )
(CHARACTER O 274 (comment uni2129)
   (CHARWD R 0.36)
   (CHARHT R 0.463)
   )
(CHARACTER O 275 (comment uni212B)
   (CHARWD R 0.722)
   (CHARHT R 0.871)
   )
(CHARACTER O 276 (comment uni2132)
   (CHARWD R 0.535)
   (CHARHT R 0.662)
   )
(CHARACTER O 277 (comment uni2141)
   (CHARWD R 0.695)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 300 (comment uni2142)
   (CHARWD R 0.559)
   (CHARHT R 0.662)
   )
(CHARACTER O 301 (comment uni2143)
   (CHARWD R 0.559)
   (CHARHT R 0.662)
   )
(CHARACTER O 302 (comment uni2144)
   (CHARWD R 0.63)
   (CHARHT R 0.662)
   )
(CHARACTER O 303 (comment uni214A)
   (CHARWD R 0.664)
   (CHARHT R 0.692)
   )
(CHARACTER O 304 (comment uni214B)
   (CHARWD R 0.778)
   (CHARHT R 0.676)
   (CHARDP R 0.013)
   )
(CHARACTER O 305 (comment uni2200)
   (CHARWD R 0.56)
   (CHARHT R 0.662)
   )
(CHARACTER O 306 (comment uni2201)
   (CHARWD R 0.463)
   (CHARHT R 0.76)
   (CHARDP R 0.015)
   )
(CHARACTER O 307 (comment uni2203)
   (CHARWD R 0.56)
   (CHARHT R 0.662)
   )
(CHARACTER O 310 (comment uni2204)
   (CHARWD R 0.56)
   (CHARHT R 0.775)
   (CHARDP R 0.122)
   )
(CHARACTER O 311 (comment uni2205)
   (CHARWD R 0.762)
   (CHARHT R 0.583)
   (CHARDP R 0.079)
   )
(CHARACTER O 312 (comment uni2206)
   (CHARWD R 0.731)
   (CHARHT R 0.674)
   )
(CHARACTER O 313 (comment uni2208)
   (CHARWD R 0.685)
   (CHARHT R 0.531)
   (CHARDP R 0.027)
   )
(CHARACTER O 314 (comment uni2209)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 315 (comment uni220A)
   (CHARWD R 0.486)
   (CHARHT R 0.459)
   )
(CHARACTER O 316 (comment uni220B)
   (CHARWD R 0.685)
   (CHARHT R 0.531)
   (CHARDP R 0.027)
   )
(CHARACTER O 317 (comment uni220C)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 320 (comment uni220D)
   (CHARWD R 0.486)
   (CHARHT R 0.459)
   )
(CHARACTER O 321 (comment uni220E)
   (CHARWD R 0.545)
   (CHARHT R 0.64)
   )
(CHARACTER O 322 (comment uni2214)
   (CHARWD R 0.685)
   (CHARHT R 0.741)
   (CHARDP R 0.041)
   )
(CHARACTER O 323 (comment uni2AB0)
   (CHARWD R 0.685)
   (CHARHT R 0.609)
   (CHARDP R 0.103)
   )
(CHARACTER O 324 (comment uni2216)
   (CHARWD R 0.428)
   (CHARHT R 0.411)
   )
(CHARACTER O 325 (comment uni2218)
   (CHARWD R 0.35)
   (CHARHT R 0.387)
   )
(CHARACTER O 326 (comment uni2219)
   (CHARWD R 0.35)
   (CHARHT R 0.387)
   )
(CHARACTER O 327 (comment uni221D)
   (CHARWD R 0.685)
   (CHARHT R 0.43)
   )
(CHARACTER O 330 (comment uni221E)
   (CHARWD R 0.926)
   (CHARHT R 0.43)
   )
(CHARACTER O 331 (comment uni221F)
   (CHARWD R 0.685)
   (CHARHT R 0.584)
   )
(CHARACTER O 332 (comment uni2220)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   )
(CHARACTER O 333 (comment uni2221)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   (CHARDP R 0.072)
   )
(CHARACTER O 334 (comment uni2222)
   (CHARWD R 0.685)
   (CHARHT R 0.519)
   (CHARDP R 0.011)
   )
(CHARACTER O 335 (comment uni2223)
   (CHARWD R 0.266)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 336 (comment uni2224)
   (CHARWD R 0.404)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 337 (comment uni2225)
   (CHARWD R 0.523)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 340 (comment uni2226)
   (CHARWD R 0.609)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 341 (comment uni2227)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 342 (comment uni2228)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 343 (comment uni2229)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 344 (comment uni222A)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 345 (comment uni2234)
   (CHARWD R 0.62)
   (CHARHT R 0.521)
   (CHARDP R 0.016)
   )
(CHARACTER O 346 (comment uni2235)
   (CHARWD R 0.62)
   (CHARHT R 0.521)
   (CHARDP R 0.016)
   )
(CHARACTER O 347 (comment uni2205.var)
   (CHARWD R 0.523)
   (CHARHT R 0.729)
   (CHARDP R 0.074)
   )
(CHARACTER O 350 (comment uni2237)
   (CHARWD R 0.685)
   (CHARHT R 0.521)
   (CHARDP R 0.013)
   )
(CHARACTER O 351 (comment uni2238)
   (CHARWD R 0.685)
   (CHARHT R 0.511)
   )
(CHARACTER O 352 (comment uni2239)
   (CHARWD R 0.685)
   (CHARHT R 0.511)
   (CHARDP R 0.005)
   )
(CHARACTER O 353 (comment uni223A)
   (CHARWD R 0.685)
   (CHARHT R 0.511)
   (CHARDP R 0.005)
   )
(CHARACTER O 354 (comment uni223B)
   (CHARWD R 0.685)
   (CHARHT R 0.521)
   (CHARDP R 0.013)
   )
(CHARACTER O 355 (comment uni223C)
   (CHARWD R 0.685)
   (CHARHT R 0.362)
   )
(CHARACTER O 356 (comment uni223D)
   (CHARWD R 0.685)
   (CHARHT R 0.362)
   )
(CHARACTER O 357 (comment uni223E)
   (CHARWD R 0.685)
   (CHARHT R 0.413)
   )
(CHARACTER O 360 (comment uni223F)
   (CHARWD R 0.685)
   (CHARHT R 0.467)
   )
(CHARACTER O 361 (comment uni2240)
   (CHARWD R 0.286)
   (CHARHT R 0.547)
   (CHARDP R 0.042)
   )
(CHARACTER O 362 (comment uni2241)
   (CHARWD R 0.685)
   (CHARHT R 0.424)
   )
(CHARACTER O 363 (comment uni2242)
   (CHARWD R 0.685)
   (CHARHT R 0.445)
   )
(CHARACTER O 364 (comment uni2243)
   (CHARWD R 0.685)
   (CHARHT R 0.445)
   )
(CHARACTER O 365 (comment uni2244)
   (CHARWD R 0.685)
   (CHARHT R 0.519)
   (CHARDP R 0.035)
   )
(CHARACTER O 366 (comment uni2245)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.027)
   )
(CHARACTER O 367 (comment uni2246)
   (CHARWD R 0.685)
   (CHARHT R 0.604)
   (CHARDP R 0.107)
   )
(CHARACTER O 370 (comment uni2247)
   (CHARWD R 0.685)
   (CHARHT R 0.647)
   (CHARDP R 0.202)
   )
(CHARACTER O 371 (comment uni2248)
   (CHARWD R 0.685)
   (CHARHT R 0.475)
   )
(CHARACTER O 372 (comment uni2249)
   (CHARWD R 0.685)
   (CHARHT R 0.549)
   (CHARDP R 0.049)
   )
(CHARACTER O 373 (comment uni224A)
   (CHARWD R 0.685)
   (CHARHT R 0.552)
   (CHARDP R 0.045)
   )
(CHARACTER O 374 (comment uni224B)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 375 (comment uni224C)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.027)
   )
(CHARACTER O 376 (comment uni224D)
   (CHARWD R 0.685)
   (CHARHT R 0.498)
   )
(CHARACTER O 377 (comment uni224E)
   (CHARWD R 0.685)
   (CHARHT R 0.471)
   )
