(FAMILY ot2-stixgneral-bold)
(CODINGSCHEME STIXOT2)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 40)
(FONTDIMEN
   (SLANT R 0.000000)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 461)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   (LABEL O 47) (comment quoteright)
   (LIG O 47 O 42)
   (KRN O 54 R -32) (comment comma)
   (KRN O 56 R -33) (comment period)
   (STOP)
   (LABEL O 54) (comment comma)
   (KRN O 61 R -11) (comment one)
   (KRN O 47 R -22) (comment quoteright)
   (KRN O 42 R 7) (comment quotedblright)
   (STOP)
   (LABEL O 55) (comment hyphen)
   (LIG O 55 O 173)
   (STOP)
   (LABEL O 56) (comment period)
   (KRN O 47 R -27) (comment quoteright)
   (STOP)
   (LABEL O 140) (comment quoteleft)
   (LIG O 140 O 134)
   (STOP)
   (LABEL O 173) (comment endash)
   (LIG O 55 O 174)
   (STOP)
   )
(CHARACTER O 0 (comment uni040A)
   (CHARWD R 1054)
   (CHARHT R 676)
   )
(CHARACTER O 1 (comment uni0409)
   (CHARWD R 1005)
   (CHARHT R 676)
   (CHARDP R 18)
   )
(CHARACTER O 2 (comment uni040F)
   (CHARWD R 770)
   (CHARHT R 676)
   (CHARDP R 176)
   )
(CHARACTER O 3 (comment uni042D)
   (CHARWD R 685)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER O 4 (comment uni0406)
   (CHARWD R 389)
   (CHARHT R 676)
   )
(CHARACTER O 5 (comment uni0404)
   (CHARWD R 685)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER O 6 (comment uni0402)
   (CHARWD R 856)
   (CHARHT R 676)
   (CHARDP R 97)
   )
(CHARACTER O 7 (comment uni040B)
   (CHARWD R 883)
   (CHARHT R 676)
   )
(CHARACTER O 10 (comment uni045A)
   (CHARWD R 775)
   (CHARHT R 461)
   )
(CHARACTER O 11 (comment uni0459)
   (CHARWD R 760)
   (CHARHT R 461)
   (CHARDP R 11)
   )
(CHARACTER O 12 (comment uni045F)
   (CHARWD R 556)
   (CHARHT R 461)
   (CHARDP R 143)
   )
(CHARACTER O 13 (comment uni044D)
   (CHARWD R 453)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 14 (comment uni0456)
   (CHARWD R 278)
   (CHARHT R 691)
   )
(CHARACTER O 15 (comment uni0454)
   (CHARWD R 453)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 16 (comment uni0452)
   (CHARWD R 556)
   (CHARHT R 676)
   (CHARDP R 205)
   )
(CHARACTER O 17 (comment uni045B)
   (CHARWD R 556)
   (CHARHT R 676)
   )
(CHARACTER O 20 (comment uni042E)
   (CHARWD R 955)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER O 21 (comment uni0416)
   (CHARWD R 1130)
   (CHARHT R 684)
   )
(CHARACTER O 22 (comment uni0419)
   (CHARWD R 778)
   (CHARHT R 926)
   )
(CHARACTER O 23 (comment uni0401)
   (CHARWD R 667)
   (CHARHT R 916)
   )
(CHARACTER O 24 (comment uni0474)
   (CHARWD R 793)
   (CHARHT R 691)
   (CHARDP R 18)
   )
(CHARACTER O 25 (comment uni0472)
   (CHARWD R 778)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER O 26 (comment uni0405)
   (CHARWD R 556)
   (CHARHT R 692)
   (CHARDP R 19)
   )
(CHARACTER O 27 (comment uni042F)
   (CHARWD R 736)
   (CHARHT R 676)
   )
(CHARACTER O 30 (comment uni044E)
   (CHARWD R 785)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 31 (comment uni0436)
   (CHARWD R 762)
   (CHARHT R 467)
   )
(CHARACTER O 32 (comment uni0439)
   (CHARWD R 556)
   (CHARHT R 691)
   )
(CHARACTER O 33 (comment uni0451)
   (CHARWD R 444)
   (CHARHT R 666)
   (CHARDP R 14)
   )
(CHARACTER O 34 (comment uni0475)
   (CHARWD R 559)
   (CHARHT R 470)
   (CHARDP R 14)
   )
(CHARACTER O 35 (comment uni0473)
   (CHARWD R 500)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 36 (comment uni0455)
   (CHARWD R 389)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 37 (comment uni044F)
   (CHARWD R 526)
   (CHARHT R 461)
   )
(CHARACTER O 40 (comment dieresis)
   (CHARWD R 333)
   (CHARHT R 666)
   (CHARIC R 4)
   )
(CHARACTER O 41 (comment exclam)
   (CHARWD R 333)
   (CHARHT R 691)
   (CHARDP R 13)
   )
(CHARACTER O 42 (comment quotedblright)
   (CHARWD R 500)
   (CHARHT R 691)
   )
(CHARACTER O 43 (comment uni0462)
   (CHARWD R 793)
   (CHARHT R 676)
   )
(CHARACTER O 44 (comment cyrbreve)
   (CHARWD R 373)
   (CHARHT R 691)
   )
(CHARACTER O 45 (comment percent)
   (CHARWD R 749)
   (CHARHT R 706)
   (CHARDP R 29)
   )
(CHARACTER O 46 (comment acute)
   (CHARWD R 333)
   (CHARHT R 713)
   )
(CHARACTER O 47 (comment quoteright)
   (CHARWD R 333)
   (CHARHT R 691)
   )
(CHARACTER O 50 (comment parenleft)
   (CHARWD R 333)
   (CHARHT R 694)
   (CHARDP R 168)
   )
(CHARACTER O 51 (comment parenright)
   (CHARWD R 333)
   (CHARHT R 694)
   (CHARDP R 168)
   )
(CHARACTER O 52 (comment asterisk)
   (CHARWD R 500)
   (CHARHT R 691)
   )
(CHARACTER O 53 (comment uni0463)
   (CHARWD R 602)
   (CHARHT R 676)
   )
(CHARACTER O 54 (comment comma)
   (CHARWD R 250)
   (CHARHT R 155)
   (CHARDP R 180)
   )
(CHARACTER O 55 (comment hyphen)
   (CHARWD R 333)
   (CHARHT R 287)
   )
(CHARACTER O 56 (comment period)
   (CHARWD R 250)
   (CHARHT R 156)
   (CHARDP R 13)
   )
(CHARACTER O 57 (comment slash)
   (CHARWD R 278)
   (CHARHT R 691)
   (CHARDP R 19)
   (CHARIC R 24)
   )
(CHARACTER O 60 (comment zero)
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER O 61 (comment one)
   (CHARWD R 500)
   (CHARHT R 688)
   )
(CHARACTER O 62 (comment two)
   (CHARWD R 500)
   (CHARHT R 688)
   )
(CHARACTER O 63 (comment three)
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 14)
   )
(CHARACTER O 64 (comment four)
   (CHARWD R 500)
   (CHARHT R 688)
   )
(CHARACTER O 65 (comment five)
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 8)
   )
(CHARACTER O 66 (comment six)
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER O 67 (comment seven)
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER O 70 (comment eight)
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER O 71 (comment nine)
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER O 72 (comment colon)
   (CHARWD R 333)
   (CHARHT R 472)
   (CHARDP R 13)
   )
(CHARACTER O 73 (comment semicolon)
   (CHARWD R 333)
   (CHARHT R 472)
   (CHARDP R 180)
   )
(CHARACTER O 74 (comment guillemotleft)
   (CHARWD R 500)
   (CHARHT R 415)
   )
(CHARACTER O 75 (comment dotlessi)
   (CHARWD R 278)
   (CHARHT R 461)
   )
(CHARACTER O 76 (comment guillemotright)
   (CHARWD R 500)
   (CHARHT R 415)
   )
(CHARACTER O 77 (comment question)
   (CHARWD R 500)
   (CHARHT R 689)
   (CHARDP R 13)
   )
(CHARACTER O 100 (comment breve)
   (CHARWD R 333)
   (CHARHT R 691)
   )
(CHARACTER O 101 (comment uni0410)
   (CHARWD R 722)
   (CHARHT R 690)
   )
(CHARACTER O 102 (comment uni0411)
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER O 103 (comment uni0426)
   (CHARWD R 770)
   (CHARHT R 676)
   (CHARDP R 176)
   )
(CHARACTER O 104 (comment uni0414)
   (CHARWD R 715)
   (CHARHT R 676)
   (CHARDP R 176)
   )
(CHARACTER O 105 (comment uni0415)
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER O 106 (comment uni0424)
   (CHARWD R 850)
   (CHARHT R 676)
   )
(CHARACTER O 107 (comment uni0413)
   (CHARWD R 632)
   (CHARHT R 676)
   )
(CHARACTER O 110 (comment uni0425)
   (CHARWD R 722)
   (CHARHT R 676)
   )
(CHARACTER O 111 (comment uni0418)
   (CHARWD R 778)
   (CHARHT R 676)
   )
(CHARACTER O 112 (comment uni0408)
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 96)
   )
(CHARACTER O 113 (comment uni041A)
   (CHARWD R 759)
   (CHARHT R 684)
   )
(CHARACTER O 114 (comment uni041B)
   (CHARWD R 738)
   (CHARHT R 676)
   (CHARDP R 18)
   )
(CHARACTER O 115 (comment uni041C)
   (CHARWD R 944)
   (CHARHT R 676)
   )
(CHARACTER O 116 (comment uni041D)
   (CHARWD R 778)
   (CHARHT R 676)
   )
(CHARACTER O 117 (comment uni041E)
   (CHARWD R 778)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER O 120 (comment uni041F)
   (CHARWD R 762)
   (CHARHT R 676)
   )
(CHARACTER O 121 (comment uni0427)
   (CHARWD R 732)
   (CHARHT R 676)
   )
(CHARACTER O 122 (comment uni0420)
   (CHARWD R 611)
   (CHARHT R 676)
   )
(CHARACTER O 123 (comment uni0421)
   (CHARWD R 709)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER O 124 (comment uni0422)
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER O 125 (comment uni0423)
   (CHARWD R 722)
   (CHARHT R 676)
   (CHARDP R 22)
   )
(CHARACTER O 126 (comment uni0412)
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER O 127 (comment uni0429)
   (CHARWD R 1020)
   (CHARHT R 676)
   (CHARDP R 176)
   )
(CHARACTER O 130 (comment uni0428)
   (CHARWD R 1020)
   (CHARHT R 676)
   )
(CHARACTER O 131 (comment uni042B)
   (CHARWD R 1004)
   (CHARHT R 676)
   )
(CHARACTER O 132 (comment uni0417)
   (CHARWD R 570)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER O 133 (comment bracketleft)
   (CHARWD R 333)
   (CHARHT R 678)
   (CHARDP R 149)
   )
(CHARACTER O 134 (comment quotedblleft)
   (CHARWD R 500)
   (CHARHT R 691)
   )
(CHARACTER O 135 (comment bracketright)
   (CHARWD R 333)
   (CHARHT R 678)
   (CHARDP R 149)
   )
(CHARACTER O 136 (comment uni042C)
   (CHARWD R 672)
   (CHARHT R 676)
   )
(CHARACTER O 137 (comment uni042A)
   (CHARWD R 805)
   (CHARHT R 676)
   )
(CHARACTER O 140 (comment quoteleft)
   (CHARWD R 333)
   (CHARHT R 691)
   )
(CHARACTER O 141 (comment uni0430)
   (CHARWD R 517)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 142 (comment uni0431)
   (CHARWD R 500)
   (CHARHT R 691)
   (CHARDP R 14)
   )
(CHARACTER O 143 (comment uni0446)
   (CHARWD R 556)
   (CHARHT R 461)
   (CHARDP R 143)
   )
(CHARACTER O 144 (comment uni0434)
   (CHARWD R 541)
   (CHARHT R 461)
   (CHARDP R 143)
   )
(CHARACTER O 145 (comment uni0435)
   (CHARWD R 444)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 146 (comment uni0444)
   (CHARWD R 726)
   (CHARHT R 676)
   (CHARDP R 205)
   )
(CHARACTER O 147 (comment uni0433)
   (CHARWD R 451)
   (CHARHT R 461)
   )
(CHARACTER O 150 (comment uni0445)
   (CHARWD R 500)
   (CHARHT R 461)
   )
(CHARACTER O 151 (comment uni0438)
   (CHARWD R 556)
   (CHARHT R 461)
   )
(CHARACTER O 152 (comment uni0458)
   (CHARWD R 333)
   (CHARHT R 691)
   (CHARDP R 203)
   )
(CHARACTER O 153 (comment uni043A)
   (CHARWD R 556)
   (CHARHT R 467)
   )
(CHARACTER O 154 (comment uni043B)
   (CHARWD R 546)
   (CHARHT R 461)
   (CHARDP R 11)
   )
(CHARACTER O 155 (comment uni043C)
   (CHARWD R 657)
   (CHARHT R 461)
   )
(CHARACTER O 156 (comment uni043D)
   (CHARWD R 560)
   (CHARHT R 461)
   )
(CHARACTER O 157 (comment uni043E)
   (CHARWD R 500)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 160 (comment uni043F)
   (CHARWD R 556)
   (CHARHT R 461)
   )
(CHARACTER O 161 (comment uni0447)
   (CHARWD R 559)
   (CHARHT R 461)
   )
(CHARACTER O 162 (comment uni0440)
   (CHARWD R 556)
   (CHARHT R 473)
   (CHARDP R 205)
   )
(CHARACTER O 163 (comment uni0441)
   (CHARWD R 444)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 164 (comment uni0442)
   (CHARWD R 509)
   (CHARHT R 461)
   )
(CHARACTER O 165 (comment uni0443)
   (CHARWD R 520)
   (CHARHT R 461)
   (CHARDP R 205)
   )
(CHARACTER O 166 (comment uni0432)
   (CHARWD R 492)
   (CHARHT R 461)
   )
(CHARACTER O 167 (comment uni0449)
   (CHARWD R 841)
   (CHARHT R 461)
   (CHARDP R 143)
   )
(CHARACTER O 170 (comment uni0448)
   (CHARWD R 841)
   (CHARHT R 461)
   )
(CHARACTER O 171 (comment uni044B)
   (CHARWD R 759)
   (CHARHT R 461)
   )
(CHARACTER O 172 (comment uni0437)
   (CHARWD R 446)
   (CHARHT R 473)
   (CHARDP R 17)
   )
(CHARACTER O 173 (comment endash)
   (CHARWD R 500)
   (CHARHT R 271)
   )
(CHARACTER O 174 (comment emdash)
   (CHARWD R 1000)
   (CHARHT R 271)
   )
(CHARACTER O 175 (comment uni2116)
   (CHARWD R 1093)
   (CHARHT R 691)
   (CHARDP R 18)
   )
(CHARACTER O 176 (comment uni044C)
   (CHARWD R 498)
   (CHARHT R 461)
   )
(CHARACTER O 177 (comment uni044A)
   (CHARWD R 607)
   (CHARHT R 461)
   )
(CHARACTER O 222 (comment uni040E)
   (CHARWD R 722)
   (CHARHT R 926)
   (CHARDP R 22)
   )
(CHARACTER O 262 (comment uni045E)
   (CHARWD R 500)
   (CHARHT R 691)
   (CHARDP R 205)
   (CHARIC R 2)
   )
