(FAMILY t1-stixgeneral-bold)
(CODINGSCHEME STIXT1)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 27)
(FONTDIMEN
   (SLANT R 0.000000)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 461)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   (LABEL O 17) (comment guilsinglright)
   (KRN O 230 R -102) (comment Ydieresis)
   (KRN O 335 R -102) (comment Yacute)
   (KRN O 303 R -46) (comment Atilde)
   (KRN O 300 R -46) (comment Agrave)
   (KRN O 302 R -46) (comment Acircumflex)
   (KRN C A R -46)
   (KRN C T R -94)
   (KRN C V R -97)
   (KRN C W R -80)
   (KRN C Y R -102)
   (KRN O 301 R -46) (comment Aacute)
   (KRN O 304 R -46) (comment Adieresis)
   (KRN O 305 R -46) (comment Aring)
   (KRN O 306 R -52) (comment AE)
   (STOP)
   (LABEL O 20) (comment quotedblleft)
   (KRN O 230 R 16) (comment Ydieresis)
   (KRN O 335 R 16) (comment Yacute)
   (KRN O 303 R -50) (comment Atilde)
   (KRN O 300 R -50) (comment Agrave)
   (KRN O 302 R -50) (comment Acircumflex)
   (KRN C A R -50)
   (KRN C T R 9)
   (KRN C V R 14)
   (KRN C W R 12)
   (KRN C Y R 16)
   (KRN O 301 R -50) (comment Aacute)
   (KRN O 304 R -50) (comment Adieresis)
   (KRN O 305 R -50) (comment Aring)
   (KRN O 306 R -67) (comment AE)
   (STOP)
   (LABEL O 21) (comment quotedblright)
   (KRN O 230 R 4) (comment Ydieresis)
   (KRN O 335 R 4) (comment Yacute)
   (KRN O 303 R -58) (comment Atilde)
   (KRN O 300 R -58) (comment Agrave)
   (KRN O 302 R -58) (comment Acircumflex)
   (KRN C A R -58)
   (KRN C T R 6)
   (KRN C V R 4)
   (KRN C W R 3)
   (KRN C Y R 4)
   (KRN O 301 R -58) (comment Aacute)
   (KRN O 304 R -58) (comment Adieresis)
   (KRN O 305 R -58) (comment Aring)
   (KRN O 306 R -75) (comment AE)
   (STOP)
   (LABEL O 22) (comment quotedblbase)
   (KRN O 230 R -61) (comment Ydieresis)
   (KRN O 335 R -61) (comment Yacute)
   (KRN O 303 R 18) (comment Atilde)
   (KRN C A R 18)
   (KRN C T R -51)
   (KRN C V R -79)
   (KRN C W R -58)
   (KRN C Y R -61)
   (KRN O 300 R 18) (comment Agrave)
   (KRN O 301 R 18) (comment Aacute)
   (KRN O 302 R 18) (comment Acircumflex)
   (KRN O 304 R 18) (comment Adieresis)
   (KRN O 305 R 18) (comment Aring)
   (KRN O 306 R 18) (comment AE)
   (STOP)
   (LABEL O 24) (comment guillemotright)
   (KRN O 230 R -89) (comment Ydieresis)
   (KRN O 335 R -89) (comment Yacute)
   (KRN O 303 R -34) (comment Atilde)
   (KRN O 300 R -34) (comment Agrave)
   (KRN O 302 R -34) (comment Acircumflex)
   (KRN C A R -34)
   (KRN C T R -82)
   (KRN C V R -85)
   (KRN C W R -67)
   (KRN C Y R -89)
   (KRN O 301 R -34) (comment Aacute)
   (KRN O 304 R -34) (comment Adieresis)
   (KRN O 305 R -34) (comment Aring)
   (KRN O 306 R -40) (comment AE)
   (STOP)
   (LABEL O 25) (comment endash)
   (LIG O 55 O 26)
   (STOP)
   (LABEL O 33) (comment ff)
   (LIG C l O 37)
   (LIG C i O 36)
   (STOP)
   (LABEL O 41) (comment exclam)
   (LIG O 140 O 275)
   (STOP)
   (LABEL O 47) (comment quoteright)
   (LIG O 47 O 21)
   (KRN O 270 R -20) (comment ydieresis)
   (KRN O 375 R -20) (comment yacute)
   (KRN O 262 R -15) (comment scaron)
   (KRN O 365 R -28) (comment otilde)
   (KRN O 370 R -28) (comment oslash)
   (KRN O 362 R -28) (comment ograve)
   (KRN O 366 R -28) (comment odieresis)
   (KRN O 364 R -28) (comment ocircumflex)
   (KRN O 363 R -28) (comment oacute)
   (KRN O 303 R -75) (comment Atilde)
   (KRN O 54 R -32) (comment comma)
   (KRN O 56 R -33) (comment period)
   (KRN C A R -75)
   (KRN C d R -28)
   (KRN C o R -28)
   (KRN C r R -22)
   (KRN C s R -15)
   (KRN C t R -16)
   (KRN C v R -22)
   (KRN C w R -21)
   (KRN C y R -20)
   (KRN O 300 R -75) (comment Agrave)
   (KRN O 301 R -75) (comment Aacute)
   (KRN O 302 R -75) (comment Acircumflex)
   (KRN O 304 R -75) (comment Adieresis)
   (KRN O 305 R -75) (comment Aring)
   (KRN O 306 R -91) (comment AE)
   (STOP)
   (LABEL O 54) (comment comma)
   (KRN C 1 R -11)
   (KRN O 47 R -22) (comment quoteright)
   (KRN O 21 R 7) (comment quotedblright)
   (STOP)
   (LABEL O 55) (comment hyphen)
   (LIG O 55 O 25)
   (KRN O 230 R -67) (comment Ydieresis)
   (KRN O 335 R -67) (comment Yacute)
   (KRN O 303 R -13) (comment Atilde)
   (KRN O 300 R -13) (comment Agrave)
   (KRN O 302 R -13) (comment Acircumflex)
   (KRN C A R -13)
   (KRN C T R -61)
   (KRN C V R -59)
   (KRN C W R -45)
   (KRN C Y R -67)
   (KRN O 301 R -13) (comment Aacute)
   (KRN O 304 R -13) (comment Adieresis)
   (KRN O 305 R -13) (comment Aring)
   (KRN O 306 R -21) (comment AE)
   (STOP)
   (LABEL O 56) (comment period)
   (KRN O 47 R -27) (comment quoteright)
   (STOP)
   (LABEL O 74) (comment less)
   (LIG O 74 O 23)
   (STOP)
   (LABEL O 76) (comment greater)
   (LIG O 76 O 24)
   (STOP)
   (LABEL O 77) (comment question)
   (LIG O 140 O 276)
   (STOP)
   (LABEL C A)
   (KRN O 270 R -69) (comment ydieresis)
   (KRN O 230 R -64) (comment Ydieresis)
   (KRN O 375 R -69) (comment yacute)
   (KRN O 335 R -64) (comment Yacute)
   (KRN O 365 R -32) (comment otilde)
   (KRN O 325 R -46) (comment Otilde)
   (KRN O 370 R -32) (comment oslash)
   (KRN O 330 R -46) (comment Oslash)
   (KRN O 362 R -32) (comment ograve)
   (KRN O 322 R -46) (comment Ograve)
   (KRN O 364 R -32) (comment ocircumflex)
   (KRN O 324 R -46) (comment Ocircumflex)
   (KRN O 363 R -32) (comment oacute)
   (KRN O 323 R -46) (comment Oacute)
   (KRN O 350 R -28) (comment egrave)
   (KRN O 353 R -28) (comment edieresis)
   (KRN O 352 R -28) (comment ecircumflex)
   (KRN O 351 R -28) (comment eacute)
   (KRN O 343 R -3) (comment atilde)
   (KRN O 345 R -3) (comment aring)
   (KRN O 340 R -3) (comment agrave)
   (KRN O 344 R -3) (comment adieresis)
   (KRN O 342 R -3) (comment acircumflex)
   (KRN O 341 R -3) (comment aacute)
   (KRN O 54 R 1) (comment comma)
   (KRN O 55 R -25) (comment hyphen)
   (KRN C C R -50)
   (KRN C G R -46)
   (KRN C O R -46)
   (KRN C Q R -46)
   (KRN C T R -51)
   (KRN C U R -58)
   (KRN C V R -109)
   (KRN C W R -95)
   (KRN C Y R -64)
   (KRN C a R -3)
   (KRN C b R -20)
   (KRN C c R -28)
   (KRN C d R -24)
   (KRN C e R -28)
   (KRN C g R -7)
   (KRN C o R -32)
   (KRN C q R -28)
   (KRN C t R -24)
   (KRN C u R -25)
   (KRN C v R -71)
   (KRN C w R -67)
   (KRN C y R -69)
   (KRN O 23 R -45) (comment guillemotleft)
   (KRN O 307 R -50) (comment Ccedilla)
   (KRN O 326 R -46) (comment Odieresis)
   (KRN O 331 R -58) (comment Ugrave)
   (KRN O 332 R -58) (comment Uacute)
   (KRN O 333 R -58) (comment Ucircumflex)
   (KRN O 334 R -58) (comment Udieresis)
   (KRN O 347 R -32) (comment ccedilla)
   (KRN O 366 R -32) (comment odieresis)
   (KRN O 371 R -25) (comment ugrave)
   (KRN O 372 R -25) (comment uacute)
   (KRN O 373 R -25) (comment ucircumflex)
   (KRN O 374 R -25) (comment udieresis)
   (KRN O 47 R -89) (comment quoteright)
   (KRN O 21 R -61) (comment quotedblright)
   (KRN O 16 R -57) (comment guilsinglleft)
   (STOP)
   (LABEL C B)
   (KRN O 230 R -40) (comment Ydieresis)
   (KRN O 335 R -40) (comment Yacute)
   (KRN O 325 R -8) (comment Otilde)
   (KRN O 300 R -31) (comment Agrave)
   (KRN C A R -31)
   (KRN C O R -8)
   (KRN C V R -40)
   (KRN C W R -38)
   (KRN C Y R -40)
   (KRN O 301 R -31) (comment Aacute)
   (KRN O 302 R -31) (comment Acircumflex)
   (KRN O 303 R -31) (comment Atilde)
   (KRN O 304 R -31) (comment Adieresis)
   (KRN O 305 R -31) (comment Aring)
   (KRN O 306 R -28) (comment AE)
   (KRN O 322 R -8) (comment Ograve)
   (KRN O 323 R -8) (comment Oacute)
   (KRN O 324 R -8) (comment Ocircumflex)
   (KRN O 326 R -8) (comment Odieresis)
   (KRN O 330 R -8) (comment Oslash)
   (KRN O 327 R -3) (comment OE)
   (STOP)
   (LABEL C C)
   (KRN O 325 R -7) (comment Otilde)
   (KRN O 330 R -7) (comment Oslash)
   (KRN O 324 R -7) (comment Ocircumflex)
   (KRN O 303 R -23) (comment Atilde)
   (KRN O 302 R -23) (comment Acircumflex)
   (KRN C A R -23)
   (KRN C H R -2)
   (KRN C K R -5)
   (KRN C O R -7)
   (KRN O 300 R -23) (comment Agrave)
   (KRN O 301 R -23) (comment Aacute)
   (KRN O 304 R -23) (comment Adieresis)
   (KRN O 305 R -23) (comment Aring)
   (KRN O 306 R -22) (comment AE)
   (KRN O 322 R -7) (comment Ograve)
   (KRN O 323 R -7) (comment Oacute)
   (KRN O 326 R -7) (comment Odieresis)
   (STOP)
   (LABEL C D)
   (KRN O 230 R -53) (comment Ydieresis)
   (KRN O 335 R -53) (comment Yacute)
   (KRN C A R -34)
   (KRN C J R -40)
   (KRN C T R -6)
   (KRN C V R -53)
   (KRN C W R -42)
   (KRN C X R -41)
   (KRN C Y R -53)
   (KRN O 300 R -34) (comment Agrave)
   (KRN O 301 R -34) (comment Aacute)
   (KRN O 302 R -34) (comment Acircumflex)
   (KRN O 303 R -34) (comment Atilde)
   (KRN O 304 R -34) (comment Adieresis)
   (KRN O 305 R -34) (comment Aring)
   (STOP)
   (LABEL C F)
   (KRN O 371 R -9) (comment ugrave)
   (KRN O 374 R -9) (comment udieresis)
   (KRN O 373 R -9) (comment ucircumflex)
   (KRN O 372 R -9) (comment uacute)
   (KRN O 365 R -43) (comment otilde)
   (KRN O 325 R -8) (comment Otilde)
   (KRN O 330 R -8) (comment Oslash)
   (KRN O 362 R -43) (comment ograve)
   (KRN O 364 R -43) (comment ocircumflex)
   (KRN O 324 R -8) (comment Ocircumflex)
   (KRN O 354 R -1) (comment igrave)
   (KRN O 357 R -1) (comment idieresis)
   (KRN O 356 R -1) (comment icircumflex)
   (KRN O 355 R -1) (comment iacute)
   (KRN O 350 R -43) (comment egrave)
   (KRN O 353 R -43) (comment edieresis)
   (KRN O 352 R -43) (comment ecircumflex)
   (KRN O 340 R -43) (comment agrave)
   (KRN O 54 R -49) (comment comma)
   (KRN O 55 R -26) (comment hyphen)
   (KRN O 56 R -50) (comment period)
   (KRN C A R -66)
   (KRN C J R -37)
   (KRN C O R -8)
   (KRN C a R -43)
   (KRN C e R -43)
   (KRN C i R -1)
   (KRN C j R -23)
   (KRN C o R -43)
   (KRN C r R -6)
   (KRN C u R -9)
   (KRN O 300 R -49) (comment Agrave)
   (KRN O 301 R -49) (comment Aacute)
   (KRN O 302 R -49) (comment Acircumflex)
   (KRN O 303 R -49) (comment Atilde)
   (KRN O 304 R -49) (comment Adieresis)
   (KRN O 305 R -49) (comment Aring)
   (KRN O 322 R -8) (comment Ograve)
   (KRN O 323 R -8) (comment Oacute)
   (KRN O 326 R -8) (comment Odieresis)
   (KRN O 341 R -43) (comment aacute)
   (KRN O 342 R -26) (comment acircumflex)
   (KRN O 343 R -18) (comment atilde)
   (KRN O 344 R -23) (comment adieresis)
   (KRN O 345 R -43) (comment aring)
   (KRN O 346 R -46) (comment ae)
   (KRN O 351 R -43) (comment eacute)
   (KRN O 363 R -43) (comment oacute)
   (KRN O 366 R -22) (comment odieresis)
   (KRN O 370 R -43) (comment oslash)
   (KRN O 367 R -42) (comment oe)
   (STOP)
   (LABEL C G)
   (KRN O 230 R -29) (comment Ydieresis)
   (KRN O 335 R -29) (comment Yacute)
   (KRN C A R -24)
   (KRN C T R -35)
   (KRN C V R -29)
   (KRN C W R -31)
   (KRN C Y R -29)
   (KRN O 300 R -24) (comment Agrave)
   (KRN O 301 R -24) (comment Aacute)
   (KRN O 302 R -24) (comment Acircumflex)
   (KRN O 303 R -24) (comment Atilde)
   (KRN O 304 R -24) (comment Adieresis)
   (KRN O 305 R -24) (comment Aring)
   (KRN O 306 R -22) (comment AE)
   (STOP)
   (LABEL C J)
   (KRN O 303 R -25) (comment Atilde)
   (KRN O 300 R -25) (comment Agrave)
   (KRN O 302 R -25) (comment Acircumflex)
   (KRN O 301 R -25) (comment Aacute)
   (KRN C A R -25)
   (KRN O 304 R -25) (comment Adieresis)
   (KRN O 305 R -25) (comment Aring)
   (KRN O 306 R -22) (comment AE)
   (STOP)
   (LABEL C K)
   (KRN O 270 R -70) (comment ydieresis)
   (KRN O 375 R -70) (comment yacute)
   (KRN O 371 R -15) (comment ugrave)
   (KRN O 373 R -15) (comment ucircumflex)
   (KRN O 372 R -15) (comment uacute)
   (KRN O 222 R 12) (comment Scaron)
   (KRN O 365 R -22) (comment otilde)
   (KRN O 325 R -39) (comment Otilde)
   (KRN O 370 R -22) (comment oslash)
   (KRN O 330 R -39) (comment Oslash)
   (KRN O 362 R -22) (comment ograve)
   (KRN O 322 R -39) (comment Ograve)
   (KRN O 364 R -22) (comment ocircumflex)
   (KRN O 324 R -39) (comment Ocircumflex)
   (KRN O 350 R -17) (comment egrave)
   (KRN O 353 R -17) (comment edieresis)
   (KRN O 352 R -17) (comment ecircumflex)
   (KRN O 351 R -17) (comment eacute)
   (KRN O 307 R -52) (comment Ccedilla)
   (KRN O 343 R 8) (comment atilde)
   (KRN O 340 R 8) (comment agrave)
   (KRN O 342 R 8) (comment acircumflex)
   (KRN O 341 R 8) (comment aacute)
   (KRN O 55 R -40) (comment hyphen)
   (KRN C C R -52)
   (KRN C G R -49)
   (KRN C O R -39)
   (KRN C S R 12)
   (KRN C T R -3)
   (KRN C a R 8)
   (KRN C e R -17)
   (KRN C o R -22)
   (KRN C u R -15)
   (KRN C y R -70)
   (KRN O 323 R -39) (comment Oacute)
   (KRN O 326 R -39) (comment Odieresis)
   (KRN O 344 R 8) (comment adieresis)
   (KRN O 345 R 8) (comment aring)
   (KRN O 346 R 3) (comment ae)
   (KRN O 363 R -22) (comment oacute)
   (KRN O 366 R -22) (comment odieresis)
   (KRN O 374 R -15) (comment udieresis)
   (KRN O 327 R -39) (comment OE)
   (STOP)
   (LABEL C L)
   (KRN O 270 R -36) (comment ydieresis)
   (KRN O 230 R -77) (comment Ydieresis)
   (KRN O 375 R -36) (comment yacute)
   (KRN O 335 R -77) (comment Yacute)
   (KRN O 371 R -8) (comment ugrave)
   (KRN O 331 R -24) (comment Ugrave)
   (KRN O 373 R -8) (comment ucircumflex)
   (KRN O 333 R -24) (comment Ucircumflex)
   (KRN O 372 R -8) (comment uacute)
   (KRN O 332 R -24) (comment Uacute)
   (KRN O 222 R 2) (comment Scaron)
   (KRN O 330 R -3) (comment Oslash)
   (KRN O 303 R -2) (comment Atilde)
   (KRN O 300 R -2) (comment Agrave)
   (KRN O 302 R -2) (comment Acircumflex)
   (KRN O 55 R 29) (comment hyphen)
   (KRN C A R -2)
   (KRN C C R -8)
   (KRN C G R -4)
   (KRN C O R -3)
   (KRN C S R 2)
   (KRN C T R -65)
   (KRN C U R -24)
   (KRN C V R -87)
   (KRN C W R -72)
   (KRN C Y R -77)
   (KRN C u R -8)
   (KRN C y R -36)
   (KRN O 301 R -2) (comment Aacute)
   (KRN O 304 R -2) (comment Adieresis)
   (KRN O 305 R -2) (comment Aring)
   (KRN O 307 R -9) (comment Ccedilla)
   (KRN O 322 R -3) (comment Ograve)
   (KRN O 323 R -3) (comment Oacute)
   (KRN O 324 R -3) (comment Ocircumflex)
   (KRN O 325 R -3) (comment Otilde)
   (KRN O 326 R -3) (comment Odieresis)
   (KRN O 334 R -24) (comment Udieresis)
   (KRN O 374 R -11) (comment udieresis)
   (KRN O 47 R -55) (comment quoteright)
   (KRN O 21 R -27) (comment quotedblright)
   (STOP)
   (LABEL C N)
   (KRN O 371 R -13) (comment ugrave)
   (KRN O 373 R -13) (comment ucircumflex)
   (KRN O 372 R -13) (comment uacute)
   (KRN O 365 R -11) (comment otilde)
   (KRN O 325 R -10) (comment Otilde)
   (KRN O 330 R -10) (comment Oslash)
   (KRN O 362 R -11) (comment ograve)
   (KRN O 322 R -10) (comment Ograve)
   (KRN O 364 R -11) (comment ocircumflex)
   (KRN O 324 R -10) (comment Ocircumflex)
   (KRN O 350 R -11) (comment egrave)
   (KRN O 353 R -11) (comment edieresis)
   (KRN O 352 R -11) (comment ecircumflex)
   (KRN O 343 R -11) (comment atilde)
   (KRN O 303 R -16) (comment Atilde)
   (KRN O 340 R -11) (comment agrave)
   (KRN O 300 R -16) (comment Agrave)
   (KRN O 342 R -11) (comment acircumflex)
   (KRN O 302 R -16) (comment Acircumflex)
   (KRN O 54 R 1) (comment comma)
   (KRN C A R -16)
   (KRN C C R -16)
   (KRN C G R -11)
   (KRN C O R -10)
   (KRN C a R -11)
   (KRN C e R -11)
   (KRN C o R -11)
   (KRN C u R -13)
   (KRN O 301 R -16) (comment Aacute)
   (KRN O 304 R -16) (comment Adieresis)
   (KRN O 305 R -16) (comment Aring)
   (KRN O 306 R -14) (comment AE)
   (KRN O 307 R -16) (comment Ccedilla)
   (KRN O 323 R -10) (comment Oacute)
   (KRN O 326 R -10) (comment Odieresis)
   (KRN O 341 R -14) (comment aacute)
   (KRN O 344 R -14) (comment adieresis)
   (KRN O 345 R -14) (comment aring)
   (KRN O 346 R -14) (comment ae)
   (KRN O 351 R -11) (comment eacute)
   (KRN O 363 R -11) (comment oacute)
   (KRN O 366 R -11) (comment odieresis)
   (KRN O 370 R -11) (comment oslash)
   (KRN O 374 R -13) (comment udieresis)
   (STOP)
   (LABEL C O)
   (KRN O 230 R -54) (comment Ydieresis)
   (KRN O 335 R -54) (comment Yacute)
   (KRN O 303 R -36) (comment Atilde)
   (KRN O 300 R -36) (comment Agrave)
   (KRN O 302 R -36) (comment Acircumflex)
   (KRN C A R -36)
   (KRN C T R -9)
   (KRN C V R -54)
   (KRN C W R -40)
   (KRN C X R -42)
   (KRN C Y R -54)
   (KRN O 301 R -36) (comment Aacute)
   (KRN O 304 R -36) (comment Adieresis)
   (KRN O 305 R -36) (comment Aring)
   (KRN O 306 R -48) (comment AE)
   (STOP)
   (LABEL C P)
   (KRN O 365 R -28) (comment otilde)
   (KRN O 362 R -28) (comment ograve)
   (KRN O 364 R -28) (comment ocircumflex)
   (KRN O 350 R -25) (comment egrave)
   (KRN O 353 R -25) (comment edieresis)
   (KRN O 352 R -25) (comment ecircumflex)
   (KRN O 343 R -15) (comment atilde)
   (KRN O 303 R -67) (comment Atilde)
   (KRN O 300 R -67) (comment Agrave)
   (KRN O 342 R -15) (comment acircumflex)
   (KRN O 302 R -67) (comment Acircumflex)
   (KRN O 54 R -71) (comment comma)
   (KRN O 55 R -33) (comment hyphen)
   (KRN O 56 R -72) (comment period)
   (KRN C A R -67)
   (KRN C J R -58)
   (KRN C a R -15)
   (KRN C e R -25)
   (KRN C o R -28)
   (KRN O 301 R -67) (comment Aacute)
   (KRN O 304 R -67) (comment Adieresis)
   (KRN O 305 R -67) (comment Aring)
   (KRN O 306 R -79) (comment AE)
   (KRN O 340 R -15) (comment agrave)
   (KRN O 341 R -15) (comment aacute)
   (KRN O 344 R -15) (comment adieresis)
   (KRN O 345 R -15) (comment aring)
   (KRN O 346 R -19) (comment ae)
   (KRN O 351 R -25) (comment eacute)
   (KRN O 363 R -28) (comment oacute)
   (KRN O 366 R -22) (comment odieresis)
   (KRN O 370 R -28) (comment oslash)
   (KRN O 367 R -26) (comment oe)
   (STOP)
   (LABEL C R)
   (KRN O 270 R -25) (comment ydieresis)
   (KRN O 230 R -48) (comment Ydieresis)
   (KRN O 375 R -25) (comment yacute)
   (KRN O 335 R -48) (comment Yacute)
   (KRN O 371 R -13) (comment ugrave)
   (KRN O 331 R -30) (comment Ugrave)
   (KRN O 373 R -13) (comment ucircumflex)
   (KRN O 333 R -30) (comment Ucircumflex)
   (KRN O 332 R -30) (comment Uacute)
   (KRN O 365 R -21) (comment otilde)
   (KRN O 325 R -23) (comment Otilde)
   (KRN O 370 R -21) (comment oslash)
   (KRN O 330 R -23) (comment Oslash)
   (KRN O 362 R -21) (comment ograve)
   (KRN O 322 R -23) (comment Ograve)
   (KRN O 364 R -21) (comment ocircumflex)
   (KRN O 324 R -23) (comment Ocircumflex)
   (KRN O 350 R -16) (comment egrave)
   (KRN O 353 R -16) (comment edieresis)
   (KRN O 352 R -16) (comment ecircumflex)
   (KRN O 343 R 10) (comment atilde)
   (KRN O 340 R 10) (comment agrave)
   (KRN O 342 R 10) (comment acircumflex)
   (KRN O 55 R -23) (comment hyphen)
   (KRN C C R -30)
   (KRN C G R -24)
   (KRN C O R -23)
   (KRN C T R -22)
   (KRN C U R -30)
   (KRN C V R -48)
   (KRN C W R -45)
   (KRN C Y R -48)
   (KRN C a R 10)
   (KRN C e R -16)
   (KRN C o R -21)
   (KRN C u R -13)
   (KRN C y R -25)
   (KRN O 307 R -30) (comment Ccedilla)
   (KRN O 323 R -23) (comment Oacute)
   (KRN O 326 R -23) (comment Odieresis)
   (KRN O 334 R -30) (comment Udieresis)
   (KRN O 341 R 10) (comment aacute)
   (KRN O 344 R 10) (comment adieresis)
   (KRN O 345 R 10) (comment aring)
   (KRN O 346 R 4) (comment ae)
   (KRN O 351 R -16) (comment eacute)
   (KRN O 363 R -21) (comment oacute)
   (KRN O 366 R -21) (comment odieresis)
   (KRN O 372 R -13) (comment uacute)
   (KRN O 374 R -13) (comment udieresis)
   (KRN O 327 R -18) (comment OE)
   (KRN O 367 R -17) (comment oe)
   (STOP)
   (LABEL C S)
   (KRN O 230 R -7) (comment Ydieresis)
   (KRN O 335 R -7) (comment Yacute)
   (KRN O 303 R -22) (comment Atilde)
   (KRN O 300 R -22) (comment Agrave)
   (KRN O 302 R -22) (comment Acircumflex)
   (KRN C A R -22)
   (KRN C T R -14)
   (KRN C V R -8)
   (KRN C W R -9)
   (KRN C Y R -7)
   (KRN C t R -7)
   (KRN O 301 R -22) (comment Aacute)
   (KRN O 304 R -22) (comment Adieresis)
   (KRN O 305 R -22) (comment Aring)
   (KRN O 306 R -21) (comment AE)
   (STOP)
   (LABEL C T)
   (KRN O 270 R -90) (comment ydieresis)
   (KRN O 230 R 10) (comment Ydieresis)
   (KRN O 375 R -90) (comment yacute)
   (KRN O 335 R 10) (comment Yacute)
   (KRN O 371 R -76) (comment ugrave)
   (KRN O 374 R -76) (comment udieresis)
   (KRN O 373 R -76) (comment ucircumflex)
   (KRN O 372 R -76) (comment uacute)
   (KRN O 262 R -51) (comment scaron)
   (KRN O 222 R -3) (comment Scaron)
   (KRN O 365 R -76) (comment otilde)
   (KRN O 354 R -2) (comment igrave)
   (KRN O 357 R -2) (comment idieresis)
   (KRN O 356 R -2) (comment icircumflex)
   (KRN O 355 R -2) (comment iacute)
   (KRN O 350 R -72) (comment egrave)
   (KRN O 353 R -72) (comment edieresis)
   (KRN O 352 R -72) (comment ecircumflex)
   (KRN O 351 R -72) (comment eacute)
   (KRN O 347 R -72) (comment ccedilla)
   (KRN O 307 R -16) (comment Ccedilla)
   (KRN O 345 R -55) (comment aring)
   (KRN O 54 R -55) (comment comma)
   (KRN O 55 R -60) (comment hyphen)
   (KRN O 56 R -55) (comment period)
   (KRN O 72 R -42) (comment colon)
   (KRN O 73 R -42) (comment semicolon)
   (KRN C A R -40)
   (KRN C C R -16)
   (KRN C G R -12)
   (KRN C J R -38)
   (KRN C O R -9)
   (KRN C S R -3)
   (KRN C V R 10)
   (KRN C W R 9)
   (KRN C Y R 10)
   (KRN C a R -55)
   (KRN C c R -72)
   (KRN C e R -72)
   (KRN C g R -58)
   (KRN C i R -2)
   (KRN C j R -24)
   (KRN C o R -76)
   (KRN C r R -53)
   (KRN C s R -51)
   (KRN C u R -76)
   (KRN C v R -92)
   (KRN C w R -93)
   (KRN C y R -90)
   (KRN O 23 R -82) (comment guillemotleft)
   (KRN O 300 R -40) (comment Agrave)
   (KRN O 301 R -40) (comment Aacute)
   (KRN O 302 R -40) (comment Acircumflex)
   (KRN O 303 R -40) (comment Atilde)
   (KRN O 304 R -40) (comment Adieresis)
   (KRN O 305 R -40) (comment Aring)
   (KRN O 306 R -38) (comment AE)
   (KRN O 322 R -9) (comment Ograve)
   (KRN O 323 R -9) (comment Oacute)
   (KRN O 324 R -9) (comment Ocircumflex)
   (KRN O 325 R -9) (comment Otilde)
   (KRN O 326 R -9) (comment Odieresis)
   (KRN O 330 R -12) (comment Oslash)
   (KRN O 340 R -43) (comment agrave)
   (KRN O 341 R -44) (comment aacute)
   (KRN O 342 R -27) (comment acircumflex)
   (KRN O 343 R -20) (comment atilde)
   (KRN O 344 R -25) (comment adieresis)
   (KRN O 346 R -58) (comment ae)
   (KRN O 362 R -46) (comment ograve)
   (KRN O 363 R -48) (comment oacute)
   (KRN O 364 R -26) (comment ocircumflex)
   (KRN O 366 R -23) (comment odieresis)
   (KRN O 370 R -58) (comment oslash)
   (KRN O 327 R -5) (comment OE)
   (KRN O 16 R -94) (comment guilsinglleft)
   (STOP)
   (LABEL C U)
   (KRN O 361 R -12) (comment ntilde)
   (KRN O 300 R -36) (comment Agrave)
   (KRN O 54 R -9) (comment comma)
   (KRN O 56 R -13) (comment period)
   (KRN C A R -36)
   (KRN C m R -9)
   (KRN C n R -12)
   (KRN C p R -14)
   (KRN C r R -14)
   (KRN O 301 R -36) (comment Aacute)
   (KRN O 302 R -36) (comment Acircumflex)
   (KRN O 303 R -36) (comment Atilde)
   (KRN O 304 R -36) (comment Adieresis)
   (KRN O 305 R -36) (comment Aring)
   (KRN O 306 R -47) (comment AE)
   (STOP)
   (LABEL C V)
   (KRN O 270 R -50) (comment ydieresis)
   (KRN O 375 R -50) (comment yacute)
   (KRN O 371 R -50) (comment ugrave)
   (KRN O 374 R -50) (comment udieresis)
   (KRN O 373 R -50) (comment ucircumflex)
   (KRN O 372 R -50) (comment uacute)
   (KRN O 222 R -25) (comment Scaron)
   (KRN O 354 R -12) (comment igrave)
   (KRN O 357 R -12) (comment idieresis)
   (KRN O 356 R -12) (comment icircumflex)
   (KRN O 355 R -12) (comment iacute)
   (KRN O 353 R -72) (comment edieresis)
   (KRN O 352 R -72) (comment ecircumflex)
   (KRN O 307 R -58) (comment Ccedilla)
   (KRN O 54 R -76) (comment comma)
   (KRN O 55 R -57) (comment hyphen)
   (KRN O 56 R -76) (comment period)
   (KRN O 72 R -42) (comment colon)
   (KRN O 73 R -42) (comment semicolon)
   (KRN C A R -96)
   (KRN C C R -58)
   (KRN C G R -53)
   (KRN C O R -52)
   (KRN C S R -25)
   (KRN C T R 7)
   (KRN C a R -72)
   (KRN C e R -72)
   (KRN C g R -73)
   (KRN C i R -12)
   (KRN C o R -72)
   (KRN C r R -52)
   (KRN C u R -50)
   (KRN C y R -50)
   (KRN O 23 R -83) (comment guillemotleft)
   (KRN O 300 R -96) (comment Agrave)
   (KRN O 301 R -96) (comment Aacute)
   (KRN O 302 R -96) (comment Acircumflex)
   (KRN O 303 R -96) (comment Atilde)
   (KRN O 304 R -96) (comment Adieresis)
   (KRN O 305 R -96) (comment Aring)
   (KRN O 306 R -97) (comment AE)
   (KRN O 322 R -52) (comment Ograve)
   (KRN O 323 R -52) (comment Oacute)
   (KRN O 324 R -52) (comment Ocircumflex)
   (KRN O 325 R -52) (comment Otilde)
   (KRN O 326 R -52) (comment Odieresis)
   (KRN O 330 R -52) (comment Oslash)
   (KRN O 340 R -38) (comment agrave)
   (KRN O 341 R -72) (comment aacute)
   (KRN O 342 R -58) (comment acircumflex)
   (KRN O 343 R -36) (comment atilde)
   (KRN O 344 R -39) (comment adieresis)
   (KRN O 345 R -48) (comment aring)
   (KRN O 346 R -76) (comment ae)
   (KRN O 350 R -36) (comment egrave)
   (KRN O 351 R -72) (comment eacute)
   (KRN O 362 R -40) (comment ograve)
   (KRN O 363 R -72) (comment oacute)
   (KRN O 364 R -58) (comment ocircumflex)
   (KRN O 365 R -35) (comment otilde)
   (KRN O 366 R -37) (comment odieresis)
   (KRN O 370 R -72) (comment oslash)
   (KRN O 16 R -94) (comment guilsinglleft)
   (STOP)
   (LABEL C W)
   (KRN O 270 R -38) (comment ydieresis)
   (KRN O 375 R -38) (comment yacute)
   (KRN O 371 R -38) (comment ugrave)
   (KRN O 374 R -38) (comment udieresis)
   (KRN O 373 R -38) (comment ucircumflex)
   (KRN O 372 R -38) (comment uacute)
   (KRN O 222 R -21) (comment Scaron)
   (KRN O 354 R -10) (comment igrave)
   (KRN O 357 R -10) (comment idieresis)
   (KRN O 356 R -10) (comment icircumflex)
   (KRN O 355 R -10) (comment iacute)
   (KRN O 353 R -55) (comment edieresis)
   (KRN O 352 R -55) (comment ecircumflex)
   (KRN O 307 R -46) (comment Ccedilla)
   (KRN O 54 R -58) (comment comma)
   (KRN O 55 R -40) (comment hyphen)
   (KRN O 56 R -58) (comment period)
   (KRN O 72 R -25) (comment colon)
   (KRN O 73 R -25) (comment semicolon)
   (KRN C A R -80)
   (KRN C C R -46)
   (KRN C G R -40)
   (KRN C O R -40)
   (KRN C S R -21)
   (KRN C T R 9)
   (KRN C a R -58)
   (KRN C e R -55)
   (KRN C g R -56)
   (KRN C i R -10)
   (KRN C o R -55)
   (KRN C r R -40)
   (KRN C u R -38)
   (KRN C y R -38)
   (KRN O 23 R -63) (comment guillemotleft)
   (KRN O 300 R -80) (comment Agrave)
   (KRN O 301 R -80) (comment Aacute)
   (KRN O 302 R -80) (comment Acircumflex)
   (KRN O 303 R -80) (comment Atilde)
   (KRN O 304 R -80) (comment Adieresis)
   (KRN O 305 R -80) (comment Aring)
   (KRN O 306 R -87) (comment AE)
   (KRN O 322 R -40) (comment Ograve)
   (KRN O 323 R -40) (comment Oacute)
   (KRN O 324 R -40) (comment Ocircumflex)
   (KRN O 325 R -40) (comment Otilde)
   (KRN O 326 R -40) (comment Odieresis)
   (KRN O 330 R -40) (comment Oslash)
   (KRN O 340 R -37) (comment agrave)
   (KRN O 341 R -55) (comment aacute)
   (KRN O 342 R -55) (comment acircumflex)
   (KRN O 343 R -31) (comment atilde)
   (KRN O 344 R -27) (comment adieresis)
   (KRN O 345 R -47) (comment aring)
   (KRN O 346 R -62) (comment ae)
   (KRN O 350 R -35) (comment egrave)
   (KRN O 351 R -55) (comment eacute)
   (KRN O 362 R -40) (comment ograve)
   (KRN O 363 R -55) (comment oacute)
   (KRN O 364 R -54) (comment ocircumflex)
   (KRN O 365 R -31) (comment otilde)
   (KRN O 366 R -25) (comment odieresis)
   (KRN O 370 R -55) (comment oslash)
   (KRN O 16 R -76) (comment guilsinglleft)
   (STOP)
   (LABEL C X)
   (KRN O 270 R -53) (comment ydieresis)
   (KRN O 375 R -53) (comment yacute)
   (KRN O 371 R -21) (comment ugrave)
   (KRN O 374 R -21) (comment udieresis)
   (KRN O 373 R -21) (comment ucircumflex)
   (KRN O 372 R -21) (comment uacute)
   (KRN O 365 R -28) (comment otilde)
   (KRN O 325 R -49) (comment Otilde)
   (KRN O 370 R -28) (comment oslash)
   (KRN O 330 R -49) (comment Oslash)
   (KRN O 362 R -28) (comment ograve)
   (KRN O 322 R -49) (comment Ograve)
   (KRN O 366 R -28) (comment odieresis)
   (KRN O 364 R -28) (comment ocircumflex)
   (KRN O 324 R -49) (comment Ocircumflex)
   (KRN O 363 R -28) (comment oacute)
   (KRN O 323 R -49) (comment Oacute)
   (KRN O 350 R -23) (comment egrave)
   (KRN O 353 R -23) (comment edieresis)
   (KRN O 352 R -23) (comment ecircumflex)
   (KRN O 351 R -23) (comment eacute)
   (KRN O 307 R -51) (comment Ccedilla)
   (KRN O 343 R 1) (comment atilde)
   (KRN O 345 R 1) (comment aring)
   (KRN O 340 R 1) (comment agrave)
   (KRN O 344 R 1) (comment adieresis)
   (KRN O 342 R 1) (comment acircumflex)
   (KRN O 341 R 1) (comment aacute)
   (KRN O 55 R -34) (comment hyphen)
   (KRN C C R -51)
   (KRN C O R -49)
   (KRN C Q R -46)
   (KRN C a R 1)
   (KRN C e R -23)
   (KRN C o R -28)
   (KRN C u R -21)
   (KRN C y R -53)
   (KRN O 326 R -49) (comment Odieresis)
   (STOP)
   (LABEL C Y)
   (KRN O 371 R -65) (comment ugrave)
   (KRN O 374 R -65) (comment udieresis)
   (KRN O 373 R -65) (comment ucircumflex)
   (KRN O 372 R -65) (comment uacute)
   (KRN O 222 R -26) (comment Scaron)
   (KRN O 365 R -82) (comment otilde)
   (KRN O 362 R -82) (comment ograve)
   (KRN O 366 R -82) (comment odieresis)
   (KRN O 364 R -82) (comment ocircumflex)
   (KRN O 363 R -82) (comment oacute)
   (KRN O 354 R -13) (comment igrave)
   (KRN O 357 R -13) (comment idieresis)
   (KRN O 356 R -13) (comment icircumflex)
   (KRN O 355 R -13) (comment iacute)
   (KRN O 350 R -77) (comment egrave)
   (KRN O 353 R -77) (comment edieresis)
   (KRN O 352 R -77) (comment ecircumflex)
   (KRN O 351 R -77) (comment eacute)
   (KRN O 307 R -65) (comment Ccedilla)
   (KRN O 343 R -70) (comment atilde)
   (KRN O 345 R -70) (comment aring)
   (KRN O 340 R -70) (comment agrave)
   (KRN O 344 R -70) (comment adieresis)
   (KRN O 342 R -70) (comment acircumflex)
   (KRN O 341 R -70) (comment aacute)
   (KRN O 54 R -67) (comment comma)
   (KRN O 55 R -74) (comment hyphen)
   (KRN O 56 R -68) (comment period)
   (KRN O 72 R -48) (comment colon)
   (KRN O 73 R -48) (comment semicolon)
   (KRN C A R -56)
   (KRN C C R -65)
   (KRN C G R -60)
   (KRN C O R -59)
   (KRN C S R -26)
   (KRN C T R 6)
   (KRN C a R -70)
   (KRN C e R -77)
   (KRN C g R -74)
   (KRN C i R -13)
   (KRN C o R -82)
   (KRN C p R -64)
   (KRN C u R -65)
   (KRN C v R -67)
   (KRN O 23 R -93) (comment guillemotleft)
   (KRN O 300 R -56) (comment Agrave)
   (KRN O 301 R -56) (comment Aacute)
   (KRN O 302 R -56) (comment Acircumflex)
   (KRN O 303 R -56) (comment Atilde)
   (KRN O 304 R -56) (comment Adieresis)
   (KRN O 305 R -56) (comment Aring)
   (KRN O 306 R -53) (comment AE)
   (KRN O 322 R -59) (comment Ograve)
   (KRN O 323 R -59) (comment Oacute)
   (KRN O 324 R -59) (comment Ocircumflex)
   (KRN O 325 R -59) (comment Otilde)
   (KRN O 326 R -59) (comment Odieresis)
   (KRN O 330 R -61) (comment Oslash)
   (KRN O 346 R -74) (comment ae)
   (KRN O 370 R -82) (comment oslash)
   (KRN O 16 R -105) (comment guilsinglleft)
   (STOP)
   (LABEL C Z)
   (KRN O 270 R -38) (comment ydieresis)
   (KRN O 375 R -38) (comment yacute)
   (KRN C v R -40)
   (KRN C w R -34)
   (KRN C y R -38)
   (STOP)
   (LABEL O 140) (comment quoteleft)
   (LIG O 140 O 20)
   (KRN O 230 R -14) (comment Ydieresis)
   (KRN O 335 R -14) (comment Yacute)
   (KRN O 303 R -78) (comment Atilde)
   (KRN C A R -78)
   (KRN C T R -20)
   (KRN C V R -15)
   (KRN C W R -17)
   (KRN C Y R -14)
   (KRN O 300 R -78) (comment Agrave)
   (KRN O 301 R -78) (comment Aacute)
   (KRN O 302 R -78) (comment Acircumflex)
   (KRN O 304 R -78) (comment Adieresis)
   (KRN O 305 R -78) (comment Aring)
   (KRN O 306 R -94) (comment AE)
   (STOP)
   (LABEL C a)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN C j R -24)
   (KRN C v R -34)
   (KRN C w R -36)
   (KRN C y R -22)
   (KRN O 47 R -29) (comment quoteright)
   (STOP)
   (LABEL C b)
   (KRN O 270 R -24) (comment ydieresis)
   (KRN O 375 R -24) (comment yacute)
   (KRN C v R -33)
   (KRN C w R -35)
   (KRN C y R -24)
   (STOP)
   (LABEL C c)
   (KRN C h R -9)
   (KRN C k R -12)
   (STOP)
   (LABEL C e)
   (KRN O 270 R -17) (comment ydieresis)
   (KRN O 375 R -17) (comment yacute)
   (KRN C t R -9)
   (KRN C v R -19)
   (KRN C w R -19)
   (KRN C x R -10)
   (KRN C y R -17)
   (KRN O 47 R -20) (comment quoteright)
   (STOP)
   (LABEL C f)
   (LIG C f O 33)
   (LIG C l O 35)
   (LIG C i O 34)
   (KRN O 262 R -7) (comment scaron)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 353 R -6) (comment edieresis)
   (KRN O 343 R -11) (comment atilde)
   (KRN O 340 R -11) (comment agrave)
   (KRN O 342 R -11) (comment acircumflex)
   (KRN C a R -11)
   (KRN C e R -6)
   (KRN C j R -1)
   (KRN C o R -16)
   (KRN C s R -7)
   (KRN C t R -3)
   (KRN O 341 R -11) (comment aacute)
   (KRN O 344 R 9) (comment adieresis)
   (KRN O 345 R -11) (comment aring)
   (KRN O 346 R -14) (comment ae)
   (KRN O 350 R -3) (comment egrave)
   (KRN O 351 R -12) (comment eacute)
   (KRN O 352 R 11) (comment ecircumflex)
   (KRN O 362 R -7) (comment ograve)
   (KRN O 363 R -15) (comment oacute)
   (KRN O 364 R -4) (comment ocircumflex)
   (KRN O 366 R 21) (comment odieresis)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 367 R -24) (comment oe)
   (KRN O 47 R 18) (comment quoteright)
   (STOP)
   (LABEL C g)
   (KRN O 343 R -11) (comment atilde)
   (KRN O 340 R -11) (comment agrave)
   (KRN O 342 R -11) (comment acircumflex)
   (KRN O 341 R -11) (comment aacute)
   (KRN C a R -11)
   (KRN C e R -17)
   (KRN C l R -4)
   (KRN O 344 R -11) (comment adieresis)
   (KRN O 345 R -11) (comment aring)
   (KRN O 346 R -14) (comment ae)
   (KRN O 350 R -17) (comment egrave)
   (KRN O 351 R -17) (comment eacute)
   (KRN O 352 R -17) (comment ecircumflex)
   (KRN O 353 R -17) (comment edieresis)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 366 R -16) (comment odieresis)
   (STOP)
   (LABEL C h)
   (KRN O 270 R -27) (comment ydieresis)
   (KRN O 375 R -27) (comment yacute)
   (KRN C y R -27)
   (KRN O 47 R -29) (comment quoteright)
   (STOP)
   (LABEL C i)
   (KRN C T R -16)
   (KRN C j R -31)
   (STOP)
   (LABEL C k)
   (KRN O 371 R -4) (comment ugrave)
   (KRN O 373 R -4) (comment ucircumflex)
   (KRN O 372 R -4) (comment uacute)
   (KRN O 262 R 4) (comment scaron)
   (KRN O 365 R -29) (comment otilde)
   (KRN O 370 R -29) (comment oslash)
   (KRN O 362 R -29) (comment ograve)
   (KRN O 364 R -29) (comment ocircumflex)
   (KRN O 353 R -23) (comment edieresis)
   (KRN O 352 R -23) (comment ecircumflex)
   (KRN O 55 R -40) (comment hyphen)
   (KRN C e R -23)
   (KRN C g R -3)
   (KRN C o R -29)
   (KRN C s R 4)
   (KRN C u R -4)
   (KRN O 346 R -3) (comment ae)
   (KRN O 350 R -23) (comment egrave)
   (KRN O 351 R -23) (comment eacute)
   (KRN O 363 R -29) (comment oacute)
   (KRN O 366 R -29) (comment odieresis)
   (KRN O 374 R -4) (comment udieresis)
   (STOP)
   (LABEL C l)
   (KRN O 270 R -17) (comment ydieresis)
   (KRN O 375 R -17) (comment yacute)
   (KRN C v R -19)
   (KRN C y R -17)
   (STOP)
   (LABEL C m)
   (KRN O 270 R -26) (comment ydieresis)
   (KRN O 375 R -26) (comment yacute)
   (KRN C p R -16)
   (KRN C v R -29)
   (KRN C w R -30)
   (KRN C y R -26)
   (STOP)
   (LABEL C n)
   (KRN O 270 R -25) (comment ydieresis)
   (KRN O 375 R -25) (comment yacute)
   (KRN C T R -49)
   (KRN C p R -13)
   (KRN C v R -27)
   (KRN C w R -29)
   (KRN C y R -25)
   (KRN O 47 R -26) (comment quoteright)
   (STOP)
   (LABEL C o)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN C T R -76)
   (KRN C t R -3)
   (KRN C v R -26)
   (KRN C w R -21)
   (KRN C x R -17)
   (KRN C y R -22)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL C p)
   (KRN O 270 R -26) (comment ydieresis)
   (KRN O 375 R -26) (comment yacute)
   (KRN C t R -9)
   (KRN C y R -26)
   (STOP)
   (LABEL C q)
   (KRN O 371 R -15) (comment ugrave)
   (KRN O 374 R -15) (comment udieresis)
   (KRN O 373 R -15) (comment ucircumflex)
   (KRN O 372 R -15) (comment uacute)
   (KRN O 347 R -12) (comment ccedilla)
   (KRN C c R -12)
   (KRN C u R -15)
   (STOP)
   (LABEL C r)
   (KRN O 272 R -1) (comment zcaron)
   (KRN O 270 R 8) (comment ydieresis)
   (KRN O 375 R 8) (comment yacute)
   (KRN O 371 R 8) (comment ugrave)
   (KRN O 374 R 8) (comment udieresis)
   (KRN O 373 R 8) (comment ucircumflex)
   (KRN O 372 R 8) (comment uacute)
   (KRN O 365 R -12) (comment otilde)
   (KRN O 361 R 3) (comment ntilde)
   (KRN O 354 R 7) (comment igrave)
   (KRN O 357 R 7) (comment idieresis)
   (KRN O 356 R 7) (comment icircumflex)
   (KRN O 355 R 7) (comment iacute)
   (KRN O 353 R -10) (comment edieresis)
   (KRN O 343 R -4) (comment atilde)
   (KRN O 54 R -58) (comment comma)
   (KRN O 55 R -15) (comment hyphen)
   (KRN O 56 R -58) (comment period)
   (KRN O 72 R -10) (comment colon)
   (KRN O 73 R -10) (comment semicolon)
   (KRN C a R -4)
   (KRN C c R -13)
   (KRN C d R -10)
   (KRN C e R -10)
   (KRN C f R 10)
   (KRN C g R -5)
   (KRN C h R -13)
   (KRN C i R 7)
   (KRN C j R -11)
   (KRN C k R -13)
   (KRN C l R -12)
   (KRN C m R 7)
   (KRN C n R 3)
   (KRN C o R -12)
   (KRN C p R 6)
   (KRN C q R -16)
   (KRN C t R 10)
   (KRN C u R 8)
   (KRN C v R 6)
   (KRN C w R 4)
   (KRN C x R 8)
   (KRN C y R 8)
   (KRN C z R -1)
   (KRN O 340 R -4) (comment agrave)
   (KRN O 341 R -4) (comment aacute)
   (KRN O 342 R -4) (comment acircumflex)
   (KRN O 344 R -4) (comment adieresis)
   (KRN O 345 R -4) (comment aring)
   (KRN O 346 R -7) (comment ae)
   (KRN O 347 R -11) (comment ccedilla)
   (KRN O 350 R -10) (comment egrave)
   (KRN O 351 R -10) (comment eacute)
   (KRN O 352 R -10) (comment ecircumflex)
   (KRN O 362 R -12) (comment ograve)
   (KRN O 363 R -12) (comment oacute)
   (KRN O 364 R -12) (comment ocircumflex)
   (KRN O 366 R -12) (comment odieresis)
   (KRN O 370 R -12) (comment oslash)
   (KRN O 367 R -10) (comment oe)
   (KRN O 47 R -7) (comment quoteright)
   (STOP)
   (LABEL C s)
   (KRN C t R -7)
   (KRN O 47 R -16) (comment quoteright)
   (STOP)
   (LABEL C t)
   (KRN O 222 R 10) (comment Scaron)
   (KRN O 365 R -4) (comment otilde)
   (KRN O 370 R -4) (comment oslash)
   (KRN O 362 R -4) (comment ograve)
   (KRN O 364 R -4) (comment ocircumflex)
   (KRN O 350 R -2) (comment egrave)
   (KRN O 353 R -2) (comment edieresis)
   (KRN O 352 R -2) (comment ecircumflex)
   (KRN O 343 R 9) (comment atilde)
   (KRN O 340 R 9) (comment agrave)
   (KRN O 342 R 9) (comment acircumflex)
   (KRN O 72 R 10) (comment colon)
   (KRN O 73 R 13) (comment semicolon)
   (KRN C S R 10)
   (KRN C a R 9)
   (KRN C e R -2)
   (KRN C h R -1)
   (KRN C o R -4)
   (KRN O 341 R 9) (comment aacute)
   (KRN O 344 R 9) (comment adieresis)
   (KRN O 345 R 9) (comment aring)
   (KRN O 346 R 6) (comment ae)
   (KRN O 351 R -2) (comment eacute)
   (KRN O 363 R -4) (comment oacute)
   (KRN O 366 R -4) (comment odieresis)
   (KRN O 47 R -27) (comment quoteright)
   (STOP)
   (LABEL C u)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL C v)
   (KRN O 262 R -11) (comment scaron)
   (KRN O 365 R -25) (comment otilde)
   (KRN O 364 R -25) (comment ocircumflex)
   (KRN O 353 R -23) (comment edieresis)
   (KRN O 347 R -26) (comment ccedilla)
   (KRN O 54 R -50) (comment comma)
   (KRN O 55 R -26) (comment hyphen)
   (KRN O 56 R -51) (comment period)
   (KRN O 72 R -9) (comment colon)
   (KRN O 73 R -9) (comment semicolon)
   (KRN C a R -16)
   (KRN C c R -26)
   (KRN C e R -23)
   (KRN C g R -15)
   (KRN C l R -3)
   (KRN C o R -25)
   (KRN C s R -11)
   (KRN O 340 R -16) (comment agrave)
   (KRN O 341 R -16) (comment aacute)
   (KRN O 342 R -16) (comment acircumflex)
   (KRN O 343 R -16) (comment atilde)
   (KRN O 344 R -16) (comment adieresis)
   (KRN O 345 R -16) (comment aring)
   (KRN O 346 R -24) (comment ae)
   (KRN O 350 R -23) (comment egrave)
   (KRN O 351 R -23) (comment eacute)
   (KRN O 352 R -23) (comment ecircumflex)
   (KRN O 362 R -25) (comment ograve)
   (KRN O 363 R -25) (comment oacute)
   (KRN O 366 R -25) (comment odieresis)
   (KRN O 370 R -25) (comment oslash)
   (STOP)
   (LABEL C w)
   (KRN O 262 R -15) (comment scaron)
   (KRN O 365 R -31) (comment otilde)
   (KRN O 364 R -31) (comment ocircumflex)
   (KRN O 353 R -29) (comment edieresis)
   (KRN O 347 R -31) (comment ccedilla)
   (KRN O 54 R -43) (comment comma)
   (KRN O 55 R -23) (comment hyphen)
   (KRN O 56 R -48) (comment period)
   (KRN O 72 R -6) (comment colon)
   (KRN O 73 R -6) (comment semicolon)
   (KRN C a R -21)
   (KRN C c R -31)
   (KRN C e R -29)
   (KRN C g R -14)
   (KRN C l R -14)
   (KRN C o R -31)
   (KRN C s R -15)
   (KRN O 340 R -21) (comment agrave)
   (KRN O 341 R -21) (comment aacute)
   (KRN O 342 R -21) (comment acircumflex)
   (KRN O 343 R -21) (comment atilde)
   (KRN O 344 R -21) (comment adieresis)
   (KRN O 345 R -21) (comment aring)
   (KRN O 346 R -24) (comment ae)
   (KRN O 350 R -29) (comment egrave)
   (KRN O 351 R -29) (comment eacute)
   (KRN O 352 R -29) (comment ecircumflex)
   (KRN O 362 R -31) (comment ograve)
   (KRN O 363 R -31) (comment oacute)
   (KRN O 366 R -31) (comment odieresis)
   (KRN O 370 R -31) (comment oslash)
   (STOP)
   (LABEL C x)
   (KRN O 365 R -26) (comment otilde)
   (KRN O 370 R -26) (comment oslash)
   (KRN O 362 R -26) (comment ograve)
   (KRN O 366 R -26) (comment odieresis)
   (KRN O 364 R -26) (comment ocircumflex)
   (KRN O 363 R -26) (comment oacute)
   (KRN O 350 R -25) (comment egrave)
   (KRN O 353 R -25) (comment edieresis)
   (KRN O 352 R -25) (comment ecircumflex)
   (KRN O 347 R -24) (comment ccedilla)
   (KRN C c R -24)
   (KRN C e R -25)
   (KRN C o R -26)
   (KRN C q R -25)
   (KRN O 351 R -25) (comment eacute)
   (STOP)
   (LABEL C y)
   (KRN O 262 R -17) (comment scaron)
   (KRN O 365 R -24) (comment otilde)
   (KRN O 364 R -24) (comment ocircumflex)
   (KRN O 353 R -24) (comment edieresis)
   (KRN O 347 R -33) (comment ccedilla)
   (KRN O 54 R -48) (comment comma)
   (KRN O 55 R -25) (comment hyphen)
   (KRN O 56 R -49) (comment period)
   (KRN O 72 R -10) (comment colon)
   (KRN O 73 R -10) (comment semicolon)
   (KRN C a R -22)
   (KRN C c R -33)
   (KRN C e R -24)
   (KRN C g R -19)
   (KRN C l R -11)
   (KRN C o R -24)
   (KRN C s R -17)
   (KRN O 340 R -22) (comment agrave)
   (KRN O 341 R -22) (comment aacute)
   (KRN O 342 R -22) (comment acircumflex)
   (KRN O 343 R -22) (comment atilde)
   (KRN O 344 R -22) (comment adieresis)
   (KRN O 345 R -22) (comment aring)
   (KRN O 346 R -26) (comment ae)
   (KRN O 350 R -24) (comment egrave)
   (KRN O 351 R -24) (comment eacute)
   (KRN O 352 R -24) (comment ecircumflex)
   (KRN O 362 R -24) (comment ograve)
   (KRN O 363 R -24) (comment oacute)
   (KRN O 366 R -24) (comment odieresis)
   (KRN O 370 R -24) (comment oslash)
   (STOP)
   (LABEL O 222) (comment Scaron)
   (KRN O 230 R -7) (comment Ydieresis)
   (KRN O 335 R -7) (comment Yacute)
   (KRN O 306 R -21) (comment AE)
   (KRN O 305 R -22) (comment Aring)
   (KRN O 304 R -22) (comment Adieresis)
   (KRN O 301 R -22) (comment Aacute)
   (KRN C t R -7)
   (KRN C Y R -7)
   (KRN C W R -9)
   (KRN C V R -8)
   (KRN C T R -14)
   (KRN C A R -22)
   (KRN O 302 R -22) (comment Acircumflex)
   (KRN O 300 R -22) (comment Agrave)
   (KRN O 303 R -22) (comment Atilde)
   (STOP)
   (LABEL O 230) (comment Ydieresis)
   (KRN O 16 R -105) (comment guilsinglleft)
   (KRN O 370 R -82) (comment oslash)
   (KRN O 346 R -74) (comment ae)
   (KRN O 330 R -61) (comment Oslash)
   (KRN O 326 R -59) (comment Odieresis)
   (KRN O 325 R -59) (comment Otilde)
   (KRN O 324 R -59) (comment Ocircumflex)
   (KRN O 323 R -59) (comment Oacute)
   (KRN O 322 R -59) (comment Ograve)
   (KRN O 306 R -53) (comment AE)
   (KRN O 305 R -56) (comment Aring)
   (KRN O 304 R -56) (comment Adieresis)
   (KRN O 303 R -56) (comment Atilde)
   (KRN O 302 R -56) (comment Acircumflex)
   (KRN O 301 R -56) (comment Aacute)
   (KRN O 300 R -56) (comment Agrave)
   (KRN O 23 R -93) (comment guillemotleft)
   (KRN C v R -67)
   (KRN C u R -65)
   (KRN C p R -64)
   (KRN C o R -82)
   (KRN C i R -13)
   (KRN C g R -74)
   (KRN C e R -77)
   (KRN C a R -70)
   (KRN C T R 6)
   (KRN C S R -26)
   (KRN C O R -59)
   (KRN C G R -60)
   (KRN C C R -65)
   (KRN C A R -56)
   (KRN O 73 R -48) (comment semicolon)
   (KRN O 72 R -48) (comment colon)
   (KRN O 56 R -68) (comment period)
   (KRN O 55 R -74) (comment hyphen)
   (KRN O 54 R -67) (comment comma)
   (KRN O 341 R -70) (comment aacute)
   (KRN O 342 R -70) (comment acircumflex)
   (KRN O 344 R -70) (comment adieresis)
   (KRN O 340 R -70) (comment agrave)
   (KRN O 345 R -70) (comment aring)
   (KRN O 343 R -70) (comment atilde)
   (KRN O 307 R -65) (comment Ccedilla)
   (KRN O 351 R -77) (comment eacute)
   (KRN O 352 R -77) (comment ecircumflex)
   (KRN O 353 R -77) (comment edieresis)
   (KRN O 350 R -77) (comment egrave)
   (KRN O 355 R -13) (comment iacute)
   (KRN O 356 R -13) (comment icircumflex)
   (KRN O 357 R -13) (comment idieresis)
   (KRN O 354 R -13) (comment igrave)
   (KRN O 363 R -82) (comment oacute)
   (KRN O 364 R -82) (comment ocircumflex)
   (KRN O 366 R -82) (comment odieresis)
   (KRN O 362 R -82) (comment ograve)
   (KRN O 365 R -82) (comment otilde)
   (KRN O 222 R -26) (comment Scaron)
   (KRN O 372 R -65) (comment uacute)
   (KRN O 373 R -65) (comment ucircumflex)
   (KRN O 374 R -65) (comment udieresis)
   (KRN O 371 R -65) (comment ugrave)
   (STOP)
   (LABEL O 232) (comment Zcaron)
   (KRN C y R -38)
   (KRN C w R -34)
   (KRN C v R -40)
   (KRN O 375 R -38) (comment yacute)
   (KRN O 270 R -38) (comment ydieresis)
   (STOP)
   (LABEL O 262) (comment scaron)
   (KRN O 47 R -16) (comment quoteright)
   (KRN C t R -7)
   (STOP)
   (LABEL O 270) (comment ydieresis)
   (KRN O 370 R -24) (comment oslash)
   (KRN O 366 R -24) (comment odieresis)
   (KRN O 363 R -24) (comment oacute)
   (KRN O 362 R -24) (comment ograve)
   (KRN O 352 R -24) (comment ecircumflex)
   (KRN O 351 R -24) (comment eacute)
   (KRN O 350 R -24) (comment egrave)
   (KRN O 346 R -26) (comment ae)
   (KRN O 345 R -22) (comment aring)
   (KRN O 344 R -22) (comment adieresis)
   (KRN O 343 R -22) (comment atilde)
   (KRN O 342 R -22) (comment acircumflex)
   (KRN O 341 R -22) (comment aacute)
   (KRN O 340 R -22) (comment agrave)
   (KRN C s R -17)
   (KRN C o R -24)
   (KRN C l R -11)
   (KRN C g R -19)
   (KRN C e R -24)
   (KRN C c R -33)
   (KRN C a R -22)
   (KRN O 73 R -10) (comment semicolon)
   (KRN O 72 R -10) (comment colon)
   (KRN O 56 R -49) (comment period)
   (KRN O 55 R -25) (comment hyphen)
   (KRN O 54 R -48) (comment comma)
   (KRN O 347 R -33) (comment ccedilla)
   (KRN O 353 R -24) (comment edieresis)
   (KRN O 364 R -24) (comment ocircumflex)
   (KRN O 365 R -24) (comment otilde)
   (KRN O 262 R -17) (comment scaron)
   (STOP)
   (LABEL O 300) (comment Agrave)
   (KRN O 270 R -69) (comment ydieresis)
   (KRN O 230 R -64) (comment Ydieresis)
   (KRN O 375 R -69) (comment yacute)
   (KRN O 335 R -64) (comment Yacute)
   (KRN O 365 R -32) (comment otilde)
   (KRN O 325 R -50) (comment Otilde)
   (KRN O 370 R -32) (comment oslash)
   (KRN O 330 R -50) (comment Oslash)
   (KRN O 362 R -32) (comment ograve)
   (KRN O 322 R -50) (comment Ograve)
   (KRN O 364 R -32) (comment ocircumflex)
   (KRN O 324 R -50) (comment Ocircumflex)
   (KRN O 363 R -32) (comment oacute)
   (KRN O 323 R -50) (comment Oacute)
   (KRN O 350 R -28) (comment egrave)
   (KRN O 353 R -28) (comment edieresis)
   (KRN O 352 R -28) (comment ecircumflex)
   (KRN O 351 R -28) (comment eacute)
   (KRN O 343 R -3) (comment atilde)
   (KRN O 345 R -3) (comment aring)
   (KRN O 340 R -3) (comment agrave)
   (KRN O 16 R -57) (comment guilsinglleft)
   (KRN O 21 R -61) (comment quotedblright)
   (KRN O 47 R -89) (comment quoteright)
   (KRN O 374 R -25) (comment udieresis)
   (KRN O 373 R -25) (comment ucircumflex)
   (KRN O 372 R -25) (comment uacute)
   (KRN O 371 R -25) (comment ugrave)
   (KRN O 366 R -32) (comment odieresis)
   (KRN O 347 R -32) (comment ccedilla)
   (KRN O 334 R -58) (comment Udieresis)
   (KRN O 333 R -58) (comment Ucircumflex)
   (KRN O 332 R -58) (comment Uacute)
   (KRN O 331 R -58) (comment Ugrave)
   (KRN O 326 R -46) (comment Odieresis)
   (KRN O 307 R -50) (comment Ccedilla)
   (KRN O 23 R -45) (comment guillemotleft)
   (KRN C y R -69)
   (KRN C w R -67)
   (KRN C v R -71)
   (KRN C u R -25)
   (KRN C t R -24)
   (KRN C q R -28)
   (KRN C o R -32)
   (KRN C g R -7)
   (KRN C e R -28)
   (KRN C d R -24)
   (KRN C c R -28)
   (KRN C b R -20)
   (KRN C a R -3)
   (KRN O 55 R -25) (comment hyphen)
   (KRN O 341 R -3) (comment aacute)
   (KRN O 342 R -3) (comment acircumflex)
   (KRN O 344 R -3) (comment adieresis)
   (KRN O 54 R 1) (comment comma)
   (KRN C C R -50)
   (KRN C G R -50)
   (KRN C O R -50)
   (KRN C Q R -50)
   (KRN C T R -51)
   (KRN C U R -58)
   (KRN C V R -109)
   (KRN C W R -95)
   (KRN C Y R -64)
   (STOP)
   (LABEL O 301) (comment Aacute)
   (KRN O 270 R -69) (comment ydieresis)
   (KRN O 230 R -64) (comment Ydieresis)
   (KRN O 375 R -69) (comment yacute)
   (KRN O 335 R -64) (comment Yacute)
   (KRN O 365 R -32) (comment otilde)
   (KRN O 325 R -46) (comment Otilde)
   (KRN O 370 R -32) (comment oslash)
   (KRN O 330 R -46) (comment Oslash)
   (KRN O 362 R -32) (comment ograve)
   (KRN O 322 R -46) (comment Ograve)
   (KRN O 364 R -32) (comment ocircumflex)
   (KRN O 324 R -46) (comment Ocircumflex)
   (KRN O 363 R -32) (comment oacute)
   (KRN O 323 R -46) (comment Oacute)
   (KRN O 350 R -28) (comment egrave)
   (KRN O 353 R -28) (comment edieresis)
   (KRN O 352 R -28) (comment ecircumflex)
   (KRN O 351 R -28) (comment eacute)
   (KRN O 343 R -3) (comment atilde)
   (KRN O 345 R -3) (comment aring)
   (KRN O 340 R -3) (comment agrave)
   (KRN O 344 R -3) (comment adieresis)
   (KRN O 342 R -3) (comment acircumflex)
   (KRN O 341 R -3) (comment aacute)
   (KRN O 374 R -25) (comment udieresis)
   (KRN O 373 R -25) (comment ucircumflex)
   (KRN O 372 R -25) (comment uacute)
   (KRN O 371 R -25) (comment ugrave)
   (KRN O 366 R -32) (comment odieresis)
   (KRN O 347 R -32) (comment ccedilla)
   (KRN O 334 R -58) (comment Udieresis)
   (KRN O 333 R -58) (comment Ucircumflex)
   (KRN O 332 R -58) (comment Uacute)
   (KRN O 331 R -58) (comment Ugrave)
   (KRN O 326 R -46) (comment Odieresis)
   (KRN O 307 R -50) (comment Ccedilla)
   (KRN O 54 R 1) (comment comma)
   (KRN O 55 R -25) (comment hyphen)
   (KRN C C R -50)
   (KRN C G R -46)
   (KRN C O R -46)
   (KRN C Q R -46)
   (KRN C T R -51)
   (KRN C U R -58)
   (KRN C V R -109)
   (KRN C W R -95)
   (KRN C Y R -64)
   (KRN C a R -3)
   (KRN C b R -20)
   (KRN C c R -28)
   (KRN C d R -24)
   (KRN C e R -28)
   (KRN C g R -7)
   (KRN C o R -32)
   (KRN C q R -28)
   (KRN C t R -24)
   (KRN C u R -25)
   (KRN C v R -71)
   (KRN C w R -67)
   (KRN C y R -69)
   (KRN O 23 R -45) (comment guillemotleft)
   (KRN O 47 R -89) (comment quoteright)
   (KRN O 21 R -61) (comment quotedblright)
   (KRN O 16 R -57) (comment guilsinglleft)
   (STOP)
   (LABEL O 302) (comment Acircumflex)
   (KRN O 270 R -69) (comment ydieresis)
   (KRN O 230 R -64) (comment Ydieresis)
   (KRN O 375 R -69) (comment yacute)
   (KRN O 335 R -64) (comment Yacute)
   (KRN O 365 R -32) (comment otilde)
   (KRN O 325 R -46) (comment Otilde)
   (KRN O 370 R -32) (comment oslash)
   (KRN O 330 R -46) (comment Oslash)
   (KRN O 362 R -32) (comment ograve)
   (KRN O 322 R -46) (comment Ograve)
   (KRN O 364 R -32) (comment ocircumflex)
   (KRN O 324 R -46) (comment Ocircumflex)
   (KRN O 363 R -32) (comment oacute)
   (KRN O 323 R -46) (comment Oacute)
   (KRN O 350 R -28) (comment egrave)
   (KRN O 353 R -28) (comment edieresis)
   (KRN O 352 R -28) (comment ecircumflex)
   (KRN O 351 R -28) (comment eacute)
   (KRN O 343 R -3) (comment atilde)
   (KRN O 345 R -3) (comment aring)
   (KRN O 340 R -3) (comment agrave)
   (KRN O 344 R -3) (comment adieresis)
   (KRN O 342 R -3) (comment acircumflex)
   (KRN O 16 R -57) (comment guilsinglleft)
   (KRN O 21 R -61) (comment quotedblright)
   (KRN O 47 R -89) (comment quoteright)
   (KRN O 374 R -25) (comment udieresis)
   (KRN O 373 R -25) (comment ucircumflex)
   (KRN O 372 R -25) (comment uacute)
   (KRN O 371 R -25) (comment ugrave)
   (KRN O 366 R -32) (comment odieresis)
   (KRN O 347 R -32) (comment ccedilla)
   (KRN O 334 R -58) (comment Udieresis)
   (KRN O 333 R -58) (comment Ucircumflex)
   (KRN O 332 R -58) (comment Uacute)
   (KRN O 331 R -58) (comment Ugrave)
   (KRN O 326 R -46) (comment Odieresis)
   (KRN O 307 R -50) (comment Ccedilla)
   (KRN O 23 R -45) (comment guillemotleft)
   (KRN C y R -69)
   (KRN C w R -67)
   (KRN C v R -71)
   (KRN C u R -25)
   (KRN C t R -24)
   (KRN C q R -28)
   (KRN C o R -32)
   (KRN C g R -7)
   (KRN C e R -28)
   (KRN C d R -24)
   (KRN C c R -28)
   (KRN C b R -20)
   (KRN C a R -3)
   (KRN O 55 R -25) (comment hyphen)
   (KRN O 341 R -3) (comment aacute)
   (KRN O 54 R 1) (comment comma)
   (KRN C C R -50)
   (KRN C G R -50)
   (KRN C O R -46)
   (KRN C Q R -46)
   (KRN C T R -51)
   (KRN C U R -58)
   (KRN C V R -109)
   (KRN C W R -95)
   (KRN C Y R -64)
   (STOP)
   (LABEL O 303) (comment Atilde)
   (KRN O 270 R -69) (comment ydieresis)
   (KRN O 230 R -64) (comment Ydieresis)
   (KRN O 375 R -69) (comment yacute)
   (KRN O 335 R -64) (comment Yacute)
   (KRN O 365 R -32) (comment otilde)
   (KRN O 325 R -46) (comment Otilde)
   (KRN O 370 R -32) (comment oslash)
   (KRN O 330 R -46) (comment Oslash)
   (KRN O 362 R -32) (comment ograve)
   (KRN O 322 R -46) (comment Ograve)
   (KRN O 364 R -32) (comment ocircumflex)
   (KRN O 324 R -46) (comment Ocircumflex)
   (KRN O 363 R -32) (comment oacute)
   (KRN O 323 R -46) (comment Oacute)
   (KRN O 350 R -28) (comment egrave)
   (KRN O 353 R -28) (comment edieresis)
   (KRN O 352 R -28) (comment ecircumflex)
   (KRN O 351 R -28) (comment eacute)
   (KRN O 343 R -3) (comment atilde)
   (KRN O 16 R -57) (comment guilsinglleft)
   (KRN O 21 R -61) (comment quotedblright)
   (KRN O 47 R -89) (comment quoteright)
   (KRN O 374 R -25) (comment udieresis)
   (KRN O 373 R -25) (comment ucircumflex)
   (KRN O 372 R -25) (comment uacute)
   (KRN O 371 R -25) (comment ugrave)
   (KRN O 366 R -32) (comment odieresis)
   (KRN O 347 R -32) (comment ccedilla)
   (KRN O 334 R -58) (comment Udieresis)
   (KRN O 333 R -58) (comment Ucircumflex)
   (KRN O 332 R -58) (comment Uacute)
   (KRN O 331 R -58) (comment Ugrave)
   (KRN O 326 R -46) (comment Odieresis)
   (KRN O 307 R -50) (comment Ccedilla)
   (KRN O 23 R -45) (comment guillemotleft)
   (KRN C y R -69)
   (KRN C w R -67)
   (KRN C v R -71)
   (KRN C u R -25)
   (KRN C t R -24)
   (KRN C q R -28)
   (KRN C o R -32)
   (KRN C g R -7)
   (KRN C e R -28)
   (KRN C d R -24)
   (KRN C c R -28)
   (KRN C b R -20)
   (KRN C a R -3)
   (KRN O 55 R -25) (comment hyphen)
   (KRN O 341 R -3) (comment aacute)
   (KRN O 342 R -3) (comment acircumflex)
   (KRN O 344 R -3) (comment adieresis)
   (KRN O 340 R -3) (comment agrave)
   (KRN O 345 R -3) (comment aring)
   (KRN O 54 R 1) (comment comma)
   (KRN C C R -50)
   (KRN C G R -46)
   (KRN C O R -46)
   (KRN C Q R -46)
   (KRN C T R -51)
   (KRN C U R -58)
   (KRN C V R -109)
   (KRN C W R -95)
   (KRN C Y R -64)
   (STOP)
   (LABEL O 304) (comment Adieresis)
   (KRN O 270 R -69) (comment ydieresis)
   (KRN O 230 R -64) (comment Ydieresis)
   (KRN O 375 R -69) (comment yacute)
   (KRN O 335 R -64) (comment Yacute)
   (KRN O 365 R -32) (comment otilde)
   (KRN O 325 R -50) (comment Otilde)
   (KRN O 370 R -32) (comment oslash)
   (KRN O 330 R -50) (comment Oslash)
   (KRN O 362 R -32) (comment ograve)
   (KRN O 322 R -50) (comment Ograve)
   (KRN O 364 R -32) (comment ocircumflex)
   (KRN O 324 R -50) (comment Ocircumflex)
   (KRN O 363 R -32) (comment oacute)
   (KRN O 323 R -50) (comment Oacute)
   (KRN O 350 R -28) (comment egrave)
   (KRN O 353 R -28) (comment edieresis)
   (KRN O 352 R -28) (comment ecircumflex)
   (KRN O 351 R -28) (comment eacute)
   (KRN O 343 R -3) (comment atilde)
   (KRN O 345 R -3) (comment aring)
   (KRN O 340 R -3) (comment agrave)
   (KRN O 344 R -3) (comment adieresis)
   (KRN O 374 R -25) (comment udieresis)
   (KRN O 373 R -25) (comment ucircumflex)
   (KRN O 372 R -25) (comment uacute)
   (KRN O 371 R -25) (comment ugrave)
   (KRN O 366 R -32) (comment odieresis)
   (KRN O 347 R -32) (comment ccedilla)
   (KRN O 334 R -58) (comment Udieresis)
   (KRN O 333 R -58) (comment Ucircumflex)
   (KRN O 332 R -58) (comment Uacute)
   (KRN O 331 R -58) (comment Ugrave)
   (KRN O 326 R -46) (comment Odieresis)
   (KRN O 307 R -50) (comment Ccedilla)
   (KRN C e R -28)
   (KRN O 342 R -3) (comment acircumflex)
   (KRN O 341 R -3) (comment aacute)
   (KRN O 54 R 1) (comment comma)
   (KRN O 55 R -25) (comment hyphen)
   (KRN C C R -50)
   (KRN C G R -50)
   (KRN C O R -50)
   (KRN C Q R -50)
   (KRN C T R -51)
   (KRN C U R -58)
   (KRN C V R -109)
   (KRN C W R -95)
   (KRN C Y R -64)
   (KRN C a R -3)
   (KRN C b R -20)
   (KRN C c R -28)
   (KRN C d R -24)
   (KRN C g R -7)
   (KRN C o R -32)
   (KRN C q R -28)
   (KRN C t R -24)
   (KRN C u R -25)
   (KRN C v R -71)
   (KRN C w R -67)
   (KRN C y R -69)
   (KRN O 23 R -45) (comment guillemotleft)
   (KRN O 47 R -89) (comment quoteright)
   (KRN O 21 R -61) (comment quotedblright)
   (KRN O 16 R -57) (comment guilsinglleft)
   (STOP)
   (LABEL O 305) (comment Aring)
   (KRN O 270 R -69) (comment ydieresis)
   (KRN O 230 R -64) (comment Ydieresis)
   (KRN O 375 R -69) (comment yacute)
   (KRN O 335 R -64) (comment Yacute)
   (KRN O 365 R -32) (comment otilde)
   (KRN O 325 R -46) (comment Otilde)
   (KRN O 370 R -32) (comment oslash)
   (KRN O 330 R -46) (comment Oslash)
   (KRN O 362 R -32) (comment ograve)
   (KRN O 322 R -46) (comment Ograve)
   (KRN O 364 R -32) (comment ocircumflex)
   (KRN O 324 R -46) (comment Ocircumflex)
   (KRN O 363 R -32) (comment oacute)
   (KRN O 323 R -46) (comment Oacute)
   (KRN O 350 R -28) (comment egrave)
   (KRN O 353 R -28) (comment edieresis)
   (KRN O 352 R -28) (comment ecircumflex)
   (KRN O 351 R -28) (comment eacute)
   (KRN O 343 R -3) (comment atilde)
   (KRN O 345 R -3) (comment aring)
   (KRN O 374 R -25) (comment udieresis)
   (KRN O 373 R -25) (comment ucircumflex)
   (KRN O 372 R -25) (comment uacute)
   (KRN O 371 R -25) (comment ugrave)
   (KRN O 366 R -32) (comment odieresis)
   (KRN O 347 R -32) (comment ccedilla)
   (KRN O 334 R -58) (comment Udieresis)
   (KRN O 333 R -58) (comment Ucircumflex)
   (KRN O 332 R -58) (comment Uacute)
   (KRN O 331 R -58) (comment Ugrave)
   (KRN O 326 R -46) (comment Odieresis)
   (KRN O 307 R -50) (comment Ccedilla)
   (KRN O 340 R -3) (comment agrave)
   (KRN O 344 R -3) (comment adieresis)
   (KRN O 342 R -3) (comment acircumflex)
   (KRN O 341 R -3) (comment aacute)
   (KRN O 54 R 1) (comment comma)
   (KRN O 55 R -25) (comment hyphen)
   (KRN C C R -50)
   (KRN C G R -46)
   (KRN C O R -46)
   (KRN C Q R -46)
   (KRN C T R -51)
   (KRN C U R -58)
   (KRN C V R -109)
   (KRN C W R -95)
   (KRN C Y R -64)
   (KRN C a R -3)
   (KRN C b R -20)
   (KRN C c R -28)
   (KRN C d R -24)
   (KRN C e R -28)
   (KRN C g R -7)
   (KRN C o R -32)
   (KRN C q R -28)
   (KRN C t R -24)
   (KRN C u R -25)
   (KRN C v R -71)
   (KRN C w R -67)
   (KRN C y R -69)
   (KRN O 23 R -45) (comment guillemotleft)
   (KRN O 47 R -89) (comment quoteright)
   (KRN O 21 R -61) (comment quotedblright)
   (KRN O 16 R -57) (comment guilsinglleft)
   (STOP)
   (LABEL O 307) (comment Ccedilla)
   (KRN O 325 R -7) (comment Otilde)
   (KRN O 330 R -7) (comment Oslash)
   (KRN O 324 R -7) (comment Ocircumflex)
   (KRN O 326 R -7) (comment Odieresis)
   (KRN O 323 R -7) (comment Oacute)
   (KRN O 322 R -7) (comment Ograve)
   (KRN O 306 R -22) (comment AE)
   (KRN C O R -7)
   (KRN C K R -5)
   (KRN C H R -2)
   (KRN O 303 R -24) (comment Atilde)
   (KRN O 305 R -24) (comment Aring)
   (KRN O 300 R -24) (comment Agrave)
   (KRN O 304 R -24) (comment Adieresis)
   (KRN O 302 R -24) (comment Acircumflex)
   (KRN O 301 R -24) (comment Aacute)
   (KRN C A R -24)
   (STOP)
   (LABEL O 321) (comment Ntilde)
   (KRN O 371 R -13) (comment ugrave)
   (KRN O 373 R -13) (comment ucircumflex)
   (KRN O 372 R -13) (comment uacute)
   (KRN O 365 R -11) (comment otilde)
   (KRN O 325 R -10) (comment Otilde)
   (KRN O 330 R -10) (comment Oslash)
   (KRN O 362 R -11) (comment ograve)
   (KRN O 322 R -10) (comment Ograve)
   (KRN O 364 R -11) (comment ocircumflex)
   (KRN O 324 R -10) (comment Ocircumflex)
   (KRN O 374 R -13) (comment udieresis)
   (KRN O 370 R -11) (comment oslash)
   (KRN O 366 R -11) (comment odieresis)
   (KRN O 363 R -11) (comment oacute)
   (KRN O 351 R -11) (comment eacute)
   (KRN O 346 R -14) (comment ae)
   (KRN O 345 R -14) (comment aring)
   (KRN O 344 R -14) (comment adieresis)
   (KRN O 341 R -14) (comment aacute)
   (KRN O 326 R -10) (comment Odieresis)
   (KRN O 323 R -10) (comment Oacute)
   (KRN O 307 R -16) (comment Ccedilla)
   (KRN O 306 R -14) (comment AE)
   (KRN O 305 R -16) (comment Aring)
   (KRN O 304 R -16) (comment Adieresis)
   (KRN O 301 R -16) (comment Aacute)
   (KRN C u R -13)
   (KRN C o R -11)
   (KRN C e R -11)
   (KRN C a R -11)
   (KRN C O R -10)
   (KRN C G R -11)
   (KRN C C R -16)
   (KRN C A R -16)
   (KRN O 54 R 1) (comment comma)
   (KRN O 302 R -16) (comment Acircumflex)
   (KRN O 342 R -11) (comment acircumflex)
   (KRN O 300 R -16) (comment Agrave)
   (KRN O 340 R -11) (comment agrave)
   (KRN O 303 R -16) (comment Atilde)
   (KRN O 343 R -11) (comment atilde)
   (KRN O 352 R -11) (comment ecircumflex)
   (KRN O 353 R -11) (comment edieresis)
   (KRN O 350 R -11) (comment egrave)
   (STOP)
   (LABEL O 322) (comment Ograve)
   (KRN O 230 R -54) (comment Ydieresis)
   (KRN O 335 R -54) (comment Yacute)
   (KRN O 306 R -48) (comment AE)
   (KRN O 305 R -36) (comment Aring)
   (KRN O 304 R -36) (comment Adieresis)
   (KRN O 301 R -36) (comment Aacute)
   (KRN C X R -42)
   (KRN C W R -40)
   (KRN C A R -36)
   (KRN O 302 R -36) (comment Acircumflex)
   (KRN O 300 R -36) (comment Agrave)
   (KRN O 303 R -36) (comment Atilde)
   (KRN C T R -9)
   (KRN C V R -54)
   (KRN C Y R -54)
   (STOP)
   (LABEL O 323) (comment Oacute)
   (KRN O 230 R -54) (comment Ydieresis)
   (KRN O 335 R -54) (comment Yacute)
   (KRN O 306 R -48) (comment AE)
   (KRN C X R -42)
   (KRN O 303 R -36) (comment Atilde)
   (KRN O 305 R -36) (comment Aring)
   (KRN O 300 R -36) (comment Agrave)
   (KRN O 304 R -36) (comment Adieresis)
   (KRN O 302 R -36) (comment Acircumflex)
   (KRN O 301 R -36) (comment Aacute)
   (KRN C A R -36)
   (KRN C T R -9)
   (KRN C V R -54)
   (KRN C W R -40)
   (KRN C Y R -54)
   (STOP)
   (LABEL O 324) (comment Ocircumflex)
   (KRN O 230 R -54) (comment Ydieresis)
   (KRN O 335 R -54) (comment Yacute)
   (KRN O 306 R -48) (comment AE)
   (KRN O 305 R -36) (comment Aring)
   (KRN O 304 R -36) (comment Adieresis)
   (KRN O 301 R -36) (comment Aacute)
   (KRN C X R -42)
   (KRN C W R -40)
   (KRN C A R -36)
   (KRN O 302 R -36) (comment Acircumflex)
   (KRN O 300 R -36) (comment Agrave)
   (KRN O 303 R -36) (comment Atilde)
   (KRN C T R -9)
   (KRN C V R -54)
   (KRN C Y R -54)
   (STOP)
   (LABEL O 325) (comment Otilde)
   (KRN O 230 R -54) (comment Ydieresis)
   (KRN O 335 R -54) (comment Yacute)
   (KRN O 306 R -48) (comment AE)
   (KRN O 305 R -36) (comment Aring)
   (KRN O 304 R -36) (comment Adieresis)
   (KRN O 301 R -36) (comment Aacute)
   (KRN C X R -42)
   (KRN C W R -40)
   (KRN C A R -36)
   (KRN O 302 R -36) (comment Acircumflex)
   (KRN O 300 R -36) (comment Agrave)
   (KRN O 303 R -36) (comment Atilde)
   (KRN C T R -9)
   (KRN C V R -54)
   (KRN C Y R -54)
   (STOP)
   (LABEL O 326) (comment Odieresis)
   (KRN O 230 R -54) (comment Ydieresis)
   (KRN O 335 R -54) (comment Yacute)
   (KRN O 306 R -48) (comment AE)
   (KRN O 303 R -36) (comment Atilde)
   (KRN O 305 R -36) (comment Aring)
   (KRN O 300 R -36) (comment Agrave)
   (KRN O 304 R -36) (comment Adieresis)
   (KRN O 302 R -36) (comment Acircumflex)
   (KRN O 301 R -36) (comment Aacute)
   (KRN C A R -36)
   (KRN C T R -9)
   (KRN C V R -54)
   (KRN C W R -40)
   (KRN C X R -42)
   (KRN C Y R -54)
   (STOP)
   (LABEL O 330) (comment Oslash)
   (KRN O 230 R -54) (comment Ydieresis)
   (KRN O 335 R -54) (comment Yacute)
   (KRN O 306 R -48) (comment AE)
   (KRN C Y R -54)
   (KRN C X R -42)
   (KRN C W R -40)
   (KRN C V R -54)
   (KRN C T R -9)
   (KRN O 303 R -36) (comment Atilde)
   (KRN O 305 R -36) (comment Aring)
   (KRN O 300 R -36) (comment Agrave)
   (KRN O 304 R -36) (comment Adieresis)
   (KRN O 302 R -36) (comment Acircumflex)
   (KRN O 301 R -36) (comment Aacute)
   (KRN C A R -36)
   (STOP)
   (LABEL O 331) (comment Ugrave)
   (KRN O 306 R -47) (comment AE)
   (KRN O 361 R -12) (comment ntilde)
   (KRN O 303 R -36) (comment Atilde)
   (KRN O 305 R -36) (comment Aring)
   (KRN O 300 R -36) (comment Agrave)
   (KRN O 304 R -36) (comment Adieresis)
   (KRN O 302 R -36) (comment Acircumflex)
   (KRN O 301 R -36) (comment Aacute)
   (KRN O 54 R -9) (comment comma)
   (KRN O 56 R -13) (comment period)
   (KRN C A R -36)
   (KRN C m R -9)
   (KRN C n R -12)
   (KRN C p R -14)
   (KRN C r R -14)
   (STOP)
   (LABEL O 332) (comment Uacute)
   (KRN O 306 R -47) (comment AE)
   (KRN O 361 R -12) (comment ntilde)
   (KRN O 303 R -35) (comment Atilde)
   (KRN O 305 R -35) (comment Aring)
   (KRN O 300 R -35) (comment Agrave)
   (KRN O 304 R -35) (comment Adieresis)
   (KRN O 302 R -35) (comment Acircumflex)
   (KRN O 301 R -35) (comment Aacute)
   (KRN O 54 R -9) (comment comma)
   (KRN O 56 R -13) (comment period)
   (KRN C A R -35)
   (KRN C m R -9)
   (KRN C n R -12)
   (KRN C p R -14)
   (KRN C r R -14)
   (STOP)
   (LABEL O 333) (comment Ucircumflex)
   (KRN O 306 R -47) (comment AE)
   (KRN C r R -14)
   (KRN C p R -14)
   (KRN C n R -12)
   (KRN C m R -9)
   (KRN O 56 R -13) (comment period)
   (KRN O 54 R -9) (comment comma)
   (KRN O 361 R -12) (comment ntilde)
   (KRN O 303 R -36) (comment Atilde)
   (KRN O 305 R -36) (comment Aring)
   (KRN O 300 R -36) (comment Agrave)
   (KRN O 304 R -36) (comment Adieresis)
   (KRN O 302 R -36) (comment Acircumflex)
   (KRN O 301 R -36) (comment Aacute)
   (KRN C A R -36)
   (STOP)
   (LABEL O 334) (comment Udieresis)
   (KRN O 306 R -47) (comment AE)
   (KRN O 361 R -12) (comment ntilde)
   (KRN O 303 R -36) (comment Atilde)
   (KRN O 305 R -36) (comment Aring)
   (KRN O 300 R -36) (comment Agrave)
   (KRN O 304 R -36) (comment Adieresis)
   (KRN O 302 R -36) (comment Acircumflex)
   (KRN O 301 R -36) (comment Aacute)
   (KRN O 54 R -9) (comment comma)
   (KRN O 56 R -13) (comment period)
   (KRN C A R -36)
   (KRN C b R 10)
   (KRN C m R -9)
   (KRN C n R -12)
   (KRN C p R -14)
   (KRN C r R -14)
   (STOP)
   (LABEL O 335) (comment Yacute)
   (KRN O 16 R -105) (comment guilsinglleft)
   (KRN O 370 R -82) (comment oslash)
   (KRN O 346 R -74) (comment ae)
   (KRN O 330 R -61) (comment Oslash)
   (KRN O 326 R -59) (comment Odieresis)
   (KRN O 325 R -59) (comment Otilde)
   (KRN O 324 R -59) (comment Ocircumflex)
   (KRN O 323 R -59) (comment Oacute)
   (KRN O 322 R -59) (comment Ograve)
   (KRN O 306 R -53) (comment AE)
   (KRN O 305 R -56) (comment Aring)
   (KRN O 304 R -56) (comment Adieresis)
   (KRN O 303 R -56) (comment Atilde)
   (KRN O 302 R -56) (comment Acircumflex)
   (KRN O 301 R -56) (comment Aacute)
   (KRN O 300 R -56) (comment Agrave)
   (KRN O 23 R -93) (comment guillemotleft)
   (KRN C v R -67)
   (KRN C u R -65)
   (KRN C p R -64)
   (KRN C o R -82)
   (KRN C i R -13)
   (KRN C g R -74)
   (KRN C e R -77)
   (KRN C a R -70)
   (KRN C T R 6)
   (KRN C S R -26)
   (KRN C O R -59)
   (KRN C G R -60)
   (KRN C C R -65)
   (KRN C A R -56)
   (KRN O 73 R -48) (comment semicolon)
   (KRN O 72 R -48) (comment colon)
   (KRN O 56 R -68) (comment period)
   (KRN O 55 R -74) (comment hyphen)
   (KRN O 54 R -67) (comment comma)
   (KRN O 341 R -70) (comment aacute)
   (KRN O 342 R -70) (comment acircumflex)
   (KRN O 344 R -70) (comment adieresis)
   (KRN O 340 R -70) (comment agrave)
   (KRN O 345 R -70) (comment aring)
   (KRN O 343 R -70) (comment atilde)
   (KRN O 307 R -65) (comment Ccedilla)
   (KRN O 351 R -77) (comment eacute)
   (KRN O 352 R -77) (comment ecircumflex)
   (KRN O 353 R -77) (comment edieresis)
   (KRN O 350 R -77) (comment egrave)
   (KRN O 355 R -13) (comment iacute)
   (KRN O 356 R -13) (comment icircumflex)
   (KRN O 357 R -13) (comment idieresis)
   (KRN O 354 R -13) (comment igrave)
   (KRN O 363 R -82) (comment oacute)
   (KRN O 364 R -82) (comment ocircumflex)
   (KRN O 366 R -82) (comment odieresis)
   (KRN O 362 R -82) (comment ograve)
   (KRN O 365 R -82) (comment otilde)
   (KRN O 222 R -26) (comment Scaron)
   (KRN O 372 R -65) (comment uacute)
   (KRN O 373 R -65) (comment ucircumflex)
   (KRN O 374 R -65) (comment udieresis)
   (KRN O 371 R -65) (comment ugrave)
   (STOP)
   (LABEL O 340) (comment agrave)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 47 R -29) (comment quoteright)
   (KRN C j R -24)
   (KRN C v R -34)
   (KRN C w R -36)
   (KRN C y R -22)
   (STOP)
   (LABEL O 341) (comment aacute)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 47 R -29) (comment quoteright)
   (KRN C j R -24)
   (KRN C v R -34)
   (KRN C w R -36)
   (KRN C y R -22)
   (STOP)
   (LABEL O 342) (comment acircumflex)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 47 R -29) (comment quoteright)
   (KRN C y R -22)
   (KRN C w R -36)
   (KRN C v R -34)
   (KRN C j R -24)
   (STOP)
   (LABEL O 343) (comment atilde)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 47 R -29) (comment quoteright)
   (KRN C y R -22)
   (KRN C w R -36)
   (KRN C v R -34)
   (KRN C j R -24)
   (STOP)
   (LABEL O 344) (comment adieresis)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 47 R -29) (comment quoteright)
   (KRN C j R -24)
   (KRN C v R -34)
   (KRN C w R -36)
   (KRN C y R -22)
   (STOP)
   (LABEL O 345) (comment aring)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 47 R -29) (comment quoteright)
   (KRN C j R -24)
   (KRN C v R -34)
   (KRN C w R -36)
   (KRN C y R -22)
   (STOP)
   (LABEL O 346) (comment ae)
   (KRN O 270 R -27) (comment ydieresis)
   (KRN O 375 R -27) (comment yacute)
   (KRN C v R -29)
   (KRN C w R -31)
   (KRN C y R -27)
   (STOP)
   (LABEL O 347) (comment ccedilla)
   (KRN C k R -12)
   (KRN C h R -9)
   (STOP)
   (LABEL O 350) (comment egrave)
   (KRN O 270 R -17) (comment ydieresis)
   (KRN O 375 R -17) (comment yacute)
   (KRN O 47 R -20) (comment quoteright)
   (KRN C y R -17)
   (KRN C x R -10)
   (KRN C w R -19)
   (KRN C v R -19)
   (KRN C t R -9)
   (STOP)
   (LABEL O 351) (comment eacute)
   (KRN O 270 R -17) (comment ydieresis)
   (KRN O 375 R -17) (comment yacute)
   (KRN O 47 R -20) (comment quoteright)
   (KRN C x R -10)
   (KRN C t R -9)
   (KRN C v R -19)
   (KRN C w R -19)
   (KRN C y R -17)
   (STOP)
   (LABEL O 352) (comment ecircumflex)
   (KRN O 270 R -17) (comment ydieresis)
   (KRN O 375 R -17) (comment yacute)
   (KRN O 47 R -20) (comment quoteright)
   (KRN C x R -10)
   (KRN C t R -9)
   (KRN C v R -19)
   (KRN C w R -19)
   (KRN C y R -17)
   (STOP)
   (LABEL O 353) (comment edieresis)
   (KRN O 270 R -17) (comment ydieresis)
   (KRN O 375 R -17) (comment yacute)
   (KRN O 47 R -20) (comment quoteright)
   (KRN C y R -17)
   (KRN C x R -10)
   (KRN C w R -19)
   (KRN C v R -19)
   (KRN C t R -9)
   (STOP)
   (LABEL O 354) (comment igrave)
   (KRN C j R -31)
   (KRN C T R -16)
   (STOP)
   (LABEL O 355) (comment iacute)
   (KRN C j R -31)
   (KRN C T R -16)
   (STOP)
   (LABEL O 356) (comment icircumflex)
   (KRN C j R -31)
   (KRN C T R -16)
   (STOP)
   (LABEL O 357) (comment idieresis)
   (KRN C j R -31)
   (KRN C T R -16)
   (STOP)
   (LABEL O 361) (comment ntilde)
   (KRN O 270 R -25) (comment ydieresis)
   (KRN O 375 R -25) (comment yacute)
   (KRN O 47 R -26) (comment quoteright)
   (KRN C y R -25)
   (KRN C w R -29)
   (KRN C v R -27)
   (KRN C p R -13)
   (KRN C T R -49)
   (STOP)
   (LABEL O 362) (comment ograve)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 47 R -24) (comment quoteright)
   (KRN C x R -17)
   (KRN C t R -3)
   (KRN C T R -76)
   (KRN C v R -26)
   (KRN C w R -21)
   (KRN C y R -22)
   (STOP)
   (LABEL O 363) (comment oacute)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 47 R -24) (comment quoteright)
   (KRN C x R -17)
   (KRN C t R -3)
   (KRN C T R -76)
   (KRN C v R -26)
   (KRN C w R -21)
   (KRN C y R -22)
   (STOP)
   (LABEL O 364) (comment ocircumflex)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 47 R -24) (comment quoteright)
   (KRN C y R -22)
   (KRN C x R -17)
   (KRN C w R -21)
   (KRN C v R -26)
   (KRN C T R -76)
   (KRN C t R -3)
   (STOP)
   (LABEL O 365) (comment otilde)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 47 R -24) (comment quoteright)
   (KRN C y R -22)
   (KRN C x R -17)
   (KRN C w R -21)
   (KRN C v R -26)
   (KRN C t R -3)
   (KRN C T R -76)
   (STOP)
   (LABEL O 366) (comment odieresis)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 47 R -24) (comment quoteright)
   (KRN C T R -76)
   (KRN C t R -3)
   (KRN C v R -26)
   (KRN C w R -21)
   (KRN C x R -17)
   (KRN C y R -22)
   (STOP)
   (LABEL O 370) (comment oslash)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 47 R -24) (comment quoteright)
   (KRN C y R -22)
   (KRN C x R -17)
   (KRN C w R -21)
   (KRN C v R -26)
   (KRN C t R -3)
   (KRN C T R -76)
   (STOP)
   (LABEL O 371) (comment ugrave)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL O 372) (comment uacute)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL O 373) (comment ucircumflex)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL O 374) (comment udieresis)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL O 375) (comment yacute)
   (KRN O 370 R -24) (comment oslash)
   (KRN O 366 R -24) (comment odieresis)
   (KRN O 363 R -24) (comment oacute)
   (KRN O 362 R -24) (comment ograve)
   (KRN O 352 R -24) (comment ecircumflex)
   (KRN O 351 R -24) (comment eacute)
   (KRN O 350 R -24) (comment egrave)
   (KRN O 346 R -26) (comment ae)
   (KRN O 345 R -22) (comment aring)
   (KRN O 344 R -22) (comment adieresis)
   (KRN O 343 R -22) (comment atilde)
   (KRN O 342 R -22) (comment acircumflex)
   (KRN O 341 R -22) (comment aacute)
   (KRN O 340 R -22) (comment agrave)
   (KRN C s R -17)
   (KRN C o R -24)
   (KRN C l R -11)
   (KRN C g R -19)
   (KRN C e R -24)
   (KRN C c R -33)
   (KRN C a R -22)
   (KRN O 73 R -10) (comment semicolon)
   (KRN O 72 R -10) (comment colon)
   (KRN O 56 R -49) (comment period)
   (KRN O 55 R -25) (comment hyphen)
   (KRN O 54 R -48) (comment comma)
   (KRN O 347 R -33) (comment ccedilla)
   (KRN O 353 R -24) (comment edieresis)
   (KRN O 364 R -24) (comment ocircumflex)
   (KRN O 365 R -24) (comment otilde)
   (KRN O 262 R -17) (comment scaron)
   (STOP)
   )
(CHARACTER O 0 (comment grave)
   (CHARWD R 333)
   (CHARHT R 713)
   )
(CHARACTER O 1 (comment acute)
   (CHARWD R 333)
   (CHARHT R 713)
   )
(CHARACTER O 2 (comment circumflex)
   (CHARWD R 333)
   (CHARHT R 704)
   (CHARIC R 2)
   )
(CHARACTER O 3 (comment tilde)
   (CHARWD R 333)
   (CHARHT R 674)
   (CHARIC R 16)
   )
(CHARACTER O 4 (comment dieresis)
   (CHARWD R 333)
   (CHARHT R 666)
   (CHARIC R 4)
   )
(CHARACTER O 5 (comment hungarumlaut)
   (CHARWD R 333)
   (CHARHT R 713)
   (CHARIC R 92)
   )
(CHARACTER O 6 (comment ring)
   (CHARWD R 333)
   (CHARHT R 750)
   )
(CHARACTER O 7 (comment caron)
   (CHARWD R 333)
   (CHARHT R 704)
   (CHARIC R 2)
   )
(CHARACTER O 10 (comment breve)
   (CHARWD R 333)
   (CHARHT R 691)
   )
(CHARACTER O 11 (comment macron)
   (CHARWD R 333)
   (CHARHT R 637)
   )
(CHARACTER O 12 (comment dotaccent)
   (CHARWD R 333)
   (CHARHT R 666)
   )
(CHARACTER O 13 (comment cedilla)
   (CHARWD R 333)
   (CHARDP R 218)
   )
(CHARACTER O 14 (comment ogonek)
   (CHARWD R 333)
   (CHARHT R 44)
   (CHARDP R 173)
   )
(CHARACTER O 15 (comment quotesinglbase)
   (CHARWD R 333)
   (CHARHT R 155)
   (CHARDP R 180)
   )
(CHARACTER O 16 (comment guilsinglleft)
   (CHARWD R 333)
   (CHARHT R 415)
   )
(CHARACTER O 17 (comment guilsinglright)
   (CHARWD R 333)
   (CHARHT R 415)
   )
(CHARACTER O 20 (comment quotedblleft)
   (CHARWD R 500)
   (CHARHT R 691)
   )
(CHARACTER O 21 (comment quotedblright)
   (CHARWD R 500)
   (CHARHT R 691)
   )
(CHARACTER O 22 (comment quotedblbase)
   (CHARWD R 500)
   (CHARHT R 155)
   (CHARDP R 180)
   )
(CHARACTER O 23 (comment guillemotleft)
   (CHARWD R 500)
   (CHARHT R 415)
   )
(CHARACTER O 24 (comment guillemotright)
   (CHARWD R 500)
   (CHARHT R 415)
   )
(CHARACTER O 25 (comment endash)
   (CHARWD R 500)
   (CHARHT R 271)
   )
(CHARACTER O 26 (comment emdash)
   (CHARWD R 1000)
   (CHARHT R 271)
   )
(CHARACTER O 27 (comment uni200B)
   (CHARWD R 0)
   )
(CHARACTER O 30 (comment perthousandzero)
   (CHARWD R 361)
   (CHARHT R 333)
   (CHARDP R 18)
   )
(CHARACTER O 31 (comment dotlessi)
   (CHARWD R 278)
   (CHARHT R 461)
   )
(CHARACTER O 32 (comment uni0237)
   (CHARWD R 333)
   (CHARHT R 461)
   (CHARDP R 203)
   )
(CHARACTER O 33 (comment ff)
   (CHARWD R 610)
   (CHARHT R 691)
   (CHARIC R 56)
   )
(CHARACTER O 34 (comment fi)
   (CHARWD R 556)
   (CHARHT R 691)
   )
(CHARACTER O 35 (comment fl)
   (CHARWD R 556)
   (CHARHT R 691)
   )
(CHARACTER O 36 (comment ffi)
   (CHARWD R 833)
   (CHARHT R 691)
   )
(CHARACTER O 37 (comment ffl)
   (CHARWD R 833)
   (CHARHT R 691)
   )
(CHARACTER O 40 (comment uni2423)
   (CHARWD R 500)
   (CHARHT R 31)
   (CHARDP R 120)
   )
(CHARACTER O 41 (comment exclam)
   (CHARWD R 333)
   (CHARHT R 691)
   (CHARDP R 13)
   )
(CHARACTER O 42 (comment quotedbl)
   (CHARWD R 555)
   (CHARHT R 691)
   )
(CHARACTER O 43 (comment numbersign)
   (CHARWD R 500)
   (CHARHT R 700)
   )
(CHARACTER O 44 (comment dollar)
   (CHARWD R 500)
   (CHARHT R 750)
   (CHARDP R 99)
   )
(CHARACTER O 45 (comment percent)
   (CHARWD R 749)
   (CHARHT R 706)
   (CHARDP R 29)
   )
(CHARACTER O 46 (comment ampersand)
   (CHARWD R 833)
   (CHARHT R 691)
   (CHARDP R 16)
   )
(CHARACTER O 47 (comment quoteright)
   (CHARWD R 333)
   (CHARHT R 691)
   )
(CHARACTER O 50 (comment parenleft)
   (CHARWD R 333)
   (CHARHT R 694)
   (CHARDP R 168)
   )
(CHARACTER O 51 (comment parenright)
   (CHARWD R 333)
   (CHARHT R 694)
   (CHARDP R 168)
   )
(CHARACTER O 52 (comment asterisk)
   (CHARWD R 500)
   (CHARHT R 691)
   )
(CHARACTER O 53 (comment plus)
   (CHARWD R 750)
   (CHARHT R 563)
   (CHARDP R 57)
   )
(CHARACTER O 54 (comment comma)
   (CHARWD R 250)
   (CHARHT R 155)
   (CHARDP R 180)
   )
(CHARACTER O 55 (comment hyphen)
   (CHARWD R 333)
   (CHARHT R 287)
   )
(CHARACTER O 56 (comment period)
   (CHARWD R 250)
   (CHARHT R 156)
   (CHARDP R 13)
   )
(CHARACTER O 57 (comment slash)
   (CHARWD R 278)
   (CHARHT R 691)
   (CHARDP R 19)
   (CHARIC R 24)
   )
(CHARACTER C 0
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER C 1
   (CHARWD R 500)
   (CHARHT R 688)
   )
(CHARACTER C 2
   (CHARWD R 500)
   (CHARHT R 688)
   )
(CHARACTER C 3
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 14)
   )
(CHARACTER C 4
   (CHARWD R 500)
   (CHARHT R 688)
   )
(CHARACTER C 5
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 8)
   )
(CHARACTER C 6
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER C 7
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER C 8
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER C 9
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER O 72 (comment colon)
   (CHARWD R 333)
   (CHARHT R 472)
   (CHARDP R 13)
   )
(CHARACTER O 73 (comment semicolon)
   (CHARWD R 333)
   (CHARHT R 472)
   (CHARDP R 180)
   )
(CHARACTER O 74 (comment less)
   (CHARWD R 750)
   (CHARHT R 534)
   (CHARDP R 24)
   )
(CHARACTER O 75 (comment equal)
   (CHARWD R 750)
   (CHARHT R 399)
   )
(CHARACTER O 76 (comment greater)
   (CHARWD R 750)
   (CHARHT R 534)
   (CHARDP R 24)
   )
(CHARACTER O 77 (comment question)
   (CHARWD R 500)
   (CHARHT R 689)
   (CHARDP R 13)
   )
(CHARACTER O 100 (comment at)
   (CHARWD R 930)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER C A
   (CHARWD R 722)
   (CHARHT R 690)
   )
(CHARACTER C B
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER C C
   (CHARWD R 722)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER C D
   (CHARWD R 722)
   (CHARHT R 676)
   )
(CHARACTER C E
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER C F
   (CHARWD R 611)
   (CHARHT R 676)
   )
(CHARACTER C G
   (CHARWD R 778)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER C H
   (CHARWD R 778)
   (CHARHT R 676)
   )
(CHARACTER C I
   (CHARWD R 389)
   (CHARHT R 676)
   )
(CHARACTER C J
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 96)
   )
(CHARACTER C K
   (CHARWD R 778)
   (CHARHT R 676)
   )
(CHARACTER C L
   (CHARWD R 667)
   (CHARHT R 677)
   )
(CHARACTER C M
   (CHARWD R 944)
   (CHARHT R 676)
   )
(CHARACTER C N
   (CHARWD R 722)
   (CHARHT R 676)
   (CHARDP R 18)
   )
(CHARACTER C O
   (CHARWD R 778)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER C P
   (CHARWD R 611)
   (CHARHT R 676)
   )
(CHARACTER C Q
   (CHARWD R 778)
   (CHARHT R 691)
   (CHARDP R 176)
   )
(CHARACTER C R
   (CHARWD R 722)
   (CHARHT R 676)
   )
(CHARACTER C S
   (CHARWD R 556)
   (CHARHT R 692)
   (CHARDP R 19)
   )
(CHARACTER C T
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER C U
   (CHARWD R 722)
   (CHARHT R 676)
   (CHARDP R 19)
   )
(CHARACTER C V
   (CHARWD R 722)
   (CHARHT R 676)
   (CHARDP R 18)
   )
(CHARACTER C W
   (CHARWD R 1000)
   (CHARHT R 676)
   (CHARDP R 15)
   )
(CHARACTER C X
   (CHARWD R 722)
   (CHARHT R 676)
   )
(CHARACTER C Y
   (CHARWD R 722)
   (CHARHT R 676)
   )
(CHARACTER C Z
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER O 133 (comment bracketleft)
   (CHARWD R 333)
   (CHARHT R 678)
   (CHARDP R 149)
   )
(CHARACTER O 134 (comment backslash)
   (CHARWD R 278)
   (CHARHT R 691)
   (CHARDP R 19)
   (CHARIC R 25)
   )
(CHARACTER O 135 (comment bracketright)
   (CHARWD R 333)
   (CHARHT R 678)
   (CHARDP R 149)
   )
(CHARACTER O 136 (comment asciicircum)
   (CHARWD R 581)
   (CHARHT R 676)
   )
(CHARACTER O 137 (comment underscore)
   (CHARWD R 500)
   (CHARDP R 125)
   )
(CHARACTER O 140 (comment quoteleft)
   (CHARWD R 333)
   (CHARHT R 691)
   )
(CHARACTER C a
   (CHARWD R 500)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER C b
   (CHARWD R 556)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER C c
   (CHARWD R 444)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER C d
   (CHARWD R 556)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER C e
   (CHARWD R 444)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER C f
   (CHARWD R 333)
   (CHARHT R 691)
   (CHARIC R 56)
   )
(CHARACTER C g
   (CHARWD R 500)
   (CHARHT R 473)
   (CHARDP R 206)
   )
(CHARACTER C h
   (CHARWD R 556)
   (CHARHT R 676)
   )
(CHARACTER C i
   (CHARWD R 278)
   (CHARHT R 691)
   )
(CHARACTER C j
   (CHARWD R 333)
   (CHARHT R 691)
   (CHARDP R 203)
   )
(CHARACTER C k
   (CHARWD R 556)
   (CHARHT R 676)
   )
(CHARACTER C l
   (CHARWD R 278)
   (CHARHT R 676)
   )
(CHARACTER C m
   (CHARWD R 833)
   (CHARHT R 473)
   )
(CHARACTER C n
   (CHARWD R 556)
   (CHARHT R 473)
   )
(CHARACTER C o
   (CHARWD R 500)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER C p
   (CHARWD R 556)
   (CHARHT R 473)
   (CHARDP R 205)
   )
(CHARACTER C q
   (CHARWD R 556)
   (CHARHT R 473)
   (CHARDP R 205)
   )
(CHARACTER C r
   (CHARWD R 444)
   (CHARHT R 473)
   )
(CHARACTER C s
   (CHARWD R 389)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER C t
   (CHARWD R 333)
   (CHARHT R 630)
   (CHARDP R 12)
   )
(CHARACTER C u
   (CHARWD R 556)
   (CHARHT R 461)
   (CHARDP R 14)
   )
(CHARACTER C v
   (CHARWD R 500)
   (CHARHT R 461)
   (CHARDP R 14)
   )
(CHARACTER C w
   (CHARWD R 722)
   (CHARHT R 461)
   (CHARDP R 14)
   )
(CHARACTER C x
   (CHARWD R 500)
   (CHARHT R 461)
   )
(CHARACTER C y
   (CHARWD R 500)
   (CHARHT R 461)
   (CHARDP R 205)
   )
(CHARACTER C z
   (CHARWD R 444)
   (CHARHT R 461)
   )
(CHARACTER O 173 (comment braceleft)
   (CHARWD R 394)
   (CHARHT R 698)
   (CHARDP R 175)
   )
(CHARACTER O 174 (comment bar)
   (CHARWD R 220)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER O 175 (comment braceright)
   (CHARWD R 394)
   (CHARHT R 698)
   (CHARDP R 175)
   )
(CHARACTER O 176 (comment asciitilde)
   (CHARWD R 520)
   (CHARHT R 333)
   )
(CHARACTER O 177 (comment uni2010)
   (CHARWD R 333)
   (CHARHT R 287)
   )
(CHARACTER O 200 (comment uni0102)
   (CHARWD R 722)
   (CHARHT R 901)
   )
(CHARACTER O 201 (comment uni0104)
   (CHARWD R 722)
   (CHARHT R 690)
   (CHARDP R 205)
   )
(CHARACTER O 202 (comment uni0106)
   (CHARWD R 722)
   (CHARHT R 923)
   (CHARDP R 19)
   )
(CHARACTER O 203 (comment uni010C)
   (CHARWD R 722)
   (CHARHT R 914)
   (CHARDP R 19)
   )
(CHARACTER O 204 (comment uni010E)
   (CHARWD R 722)
   (CHARHT R 914)
   )
(CHARACTER O 205 (comment uni011A)
   (CHARWD R 667)
   (CHARHT R 914)
   )
(CHARACTER O 206 (comment uni0118)
   (CHARWD R 667)
   (CHARHT R 676)
   (CHARDP R 205)
   )
(CHARACTER O 207 (comment uni011E)
   (CHARWD R 778)
   (CHARHT R 901)
   (CHARDP R 19)
   )
(CHARACTER O 210 (comment uni0139)
   (CHARWD R 667)
   (CHARHT R 923)
   )
(CHARACTER O 211 (comment uni013D)
   (CHARWD R 667)
   (CHARHT R 691)
   )
(CHARACTER O 212 (comment Lslash)
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER O 213 (comment uni0143)
   (CHARWD R 722)
   (CHARHT R 923)
   (CHARDP R 18)
   )
(CHARACTER O 214 (comment uni0147)
   (CHARWD R 722)
   (CHARHT R 914)
   (CHARDP R 18)
   )
(CHARACTER O 215 (comment uni014A)
   (CHARWD R 732)
   (CHARHT R 676)
   (CHARDP R 96)
   )
(CHARACTER O 216 (comment uni0150)
   (CHARWD R 778)
   (CHARHT R 923)
   (CHARDP R 19)
   )
(CHARACTER O 217 (comment uni0154)
   (CHARWD R 722)
   (CHARHT R 923)
   )
(CHARACTER O 220 (comment uni0158)
   (CHARWD R 722)
   (CHARHT R 914)
   )
(CHARACTER O 221 (comment uni015A)
   (CHARWD R 556)
   (CHARHT R 923)
   (CHARDP R 19)
   )
(CHARACTER O 222 (comment Scaron)
   (CHARWD R 556)
   (CHARHT R 914)
   (CHARDP R 19)
   )
(CHARACTER O 223 (comment uni015E)
   (CHARWD R 556)
   (CHARHT R 692)
   (CHARDP R 218)
   )
(CHARACTER O 224 (comment uni0164)
   (CHARWD R 667)
   (CHARHT R 914)
   )
(CHARACTER O 225 (comment uni0162)
   (CHARWD R 667)
   (CHARHT R 676)
   (CHARDP R 218)
   )
(CHARACTER O 226 (comment uni0170)
   (CHARWD R 722)
   (CHARHT R 923)
   (CHARDP R 19)
   )
(CHARACTER O 227 (comment uni016E)
   (CHARWD R 722)
   (CHARHT R 935)
   (CHARDP R 19)
   )
(CHARACTER O 230 (comment Ydieresis)
   (CHARWD R 722)
   (CHARHT R 876)
   )
(CHARACTER O 231 (comment uni0179)
   (CHARWD R 667)
   (CHARHT R 923)
   )
(CHARACTER O 232 (comment Zcaron)
   (CHARWD R 667)
   (CHARHT R 914)
   )
(CHARACTER O 233 (comment uni017B)
   (CHARWD R 667)
   (CHARHT R 876)
   )
(CHARACTER O 234 (comment uni0132)
   (CHARWD R 838)
   (CHARHT R 676)
   (CHARDP R 96)
   (CHARIC R 79)
   )
(CHARACTER O 235 (comment uni0130)
   (CHARWD R 389)
   (CHARHT R 876)
   )
(CHARACTER O 236 (comment uni0111)
   (CHARWD R 556)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER O 237 (comment section)
   (CHARWD R 500)
   (CHARHT R 691)
   (CHARDP R 132)
   )
(CHARACTER O 240 (comment uni0103)
   (CHARWD R 500)
   (CHARHT R 691)
   (CHARDP R 14)
   )
(CHARACTER O 241 (comment uni0105)
   (CHARWD R 500)
   (CHARHT R 473)
   (CHARDP R 205)
   (CHARIC R 69)
   )
(CHARACTER O 242 (comment uni0107)
   (CHARWD R 444)
   (CHARHT R 713)
   (CHARDP R 14)
   )
(CHARACTER O 243 (comment uni010D)
   (CHARWD R 444)
   (CHARHT R 704)
   (CHARDP R 14)
   )
(CHARACTER O 244 (comment uni010F)
   (CHARWD R 680)
   (CHARHT R 709)
   (CHARDP R 14)
   (CHARIC R 30)
   )
(CHARACTER O 245 (comment uni011B)
   (CHARWD R 444)
   (CHARHT R 704)
   (CHARDP R 14)
   )
(CHARACTER O 246 (comment uni0119)
   (CHARWD R 444)
   (CHARHT R 473)
   (CHARDP R 205)
   )
(CHARACTER O 247 (comment uni011F)
   (CHARWD R 500)
   (CHARHT R 691)
   (CHARDP R 206)
   )
(CHARACTER O 250 (comment uni013A)
   (CHARWD R 278)
   (CHARHT R 923)
   )
(CHARACTER O 251 (comment uni013E)
   (CHARWD R 457)
   (CHARHT R 709)
   )
(CHARACTER O 252 (comment lslash)
   (CHARWD R 278)
   (CHARHT R 676)
   (CHARIC R 25)
   )
(CHARACTER O 253 (comment uni0144)
   (CHARWD R 556)
   (CHARHT R 713)
   )
(CHARACTER O 254 (comment uni0148)
   (CHARWD R 556)
   (CHARHT R 704)
   )
(CHARACTER O 255 (comment uni014B)
   (CHARWD R 556)
   (CHARHT R 473)
   (CHARDP R 205)
   )
(CHARACTER O 256 (comment uni0151)
   (CHARWD R 500)
   (CHARHT R 713)
   (CHARDP R 14)
   )
(CHARACTER O 257 (comment uni0155)
   (CHARWD R 444)
   (CHARHT R 713)
   )
(CHARACTER O 260 (comment uni0159)
   (CHARWD R 444)
   (CHARHT R 704)
   )
(CHARACTER O 261 (comment uni015B)
   (CHARWD R 389)
   (CHARHT R 713)
   (CHARDP R 14)
   )
(CHARACTER O 262 (comment scaron)
   (CHARWD R 389)
   (CHARHT R 704)
   (CHARDP R 14)
   )
(CHARACTER O 263 (comment uni015F)
   (CHARWD R 389)
   (CHARHT R 473)
   (CHARDP R 218)
   )
(CHARACTER O 264 (comment uni0165)
   (CHARWD R 415)
   (CHARHT R 709)
   (CHARDP R 12)
   (CHARIC R 30)
   )
(CHARACTER O 265 (comment uni0163)
   (CHARWD R 333)
   (CHARHT R 630)
   (CHARDP R 218)
   )
(CHARACTER O 266 (comment uni0171)
   (CHARWD R 556)
   (CHARHT R 713)
   (CHARDP R 14)
   )
(CHARACTER O 267 (comment uni016F)
   (CHARWD R 556)
   (CHARHT R 740)
   (CHARDP R 14)
   )
(CHARACTER O 270 (comment ydieresis)
   (CHARWD R 500)
   (CHARHT R 666)
   (CHARDP R 205)
   )
(CHARACTER O 271 (comment uni017A)
   (CHARWD R 444)
   (CHARHT R 713)
   )
(CHARACTER O 272 (comment zcaron)
   (CHARWD R 444)
   (CHARHT R 704)
   )
(CHARACTER O 273 (comment uni017C)
   (CHARWD R 444)
   (CHARHT R 666)
   )
(CHARACTER O 274 (comment uni0133)
   (CHARWD R 552)
   (CHARHT R 691)
   (CHARDP R 203)
   )
(CHARACTER O 275 (comment exclamdown)
   (CHARWD R 333)
   (CHARHT R 501)
   (CHARDP R 203)
   )
(CHARACTER O 276 (comment questiondown)
   (CHARWD R 500)
   (CHARHT R 501)
   (CHARDP R 201)
   )
(CHARACTER O 277 (comment sterling)
   (CHARWD R 500)
   (CHARHT R 684)
   (CHARDP R 16)
   )
(CHARACTER O 300 (comment Agrave)
   (CHARWD R 722)
   (CHARHT R 963)
   )
(CHARACTER O 301 (comment Aacute)
   (CHARWD R 722)
   (CHARHT R 963)
   )
(CHARACTER O 302 (comment Acircumflex)
   (CHARWD R 722)
   (CHARHT R 954)
   )
(CHARACTER O 303 (comment Atilde)
   (CHARWD R 722)
   (CHARHT R 924)
   )
(CHARACTER O 304 (comment Adieresis)
   (CHARWD R 722)
   (CHARHT R 916)
   )
(CHARACTER O 305 (comment Aring)
   (CHARWD R 722)
   (CHARHT R 1000)
   )
(CHARACTER O 306 (comment AE)
   (CHARWD R 1000)
   (CHARHT R 676)
   )
(CHARACTER O 307 (comment Ccedilla)
   (CHARWD R 722)
   (CHARHT R 691)
   (CHARDP R 218)
   )
(CHARACTER O 310 (comment Egrave)
   (CHARWD R 667)
   (CHARHT R 963)
   )
(CHARACTER O 311 (comment Eacute)
   (CHARWD R 667)
   (CHARHT R 963)
   )
(CHARACTER O 312 (comment Ecircumflex)
   (CHARWD R 667)
   (CHARHT R 954)
   )
(CHARACTER O 313 (comment Edieresis)
   (CHARWD R 667)
   (CHARHT R 916)
   )
(CHARACTER O 314 (comment Igrave)
   (CHARWD R 389)
   (CHARHT R 963)
   )
(CHARACTER O 315 (comment Iacute)
   (CHARWD R 389)
   (CHARHT R 963)
   )
(CHARACTER O 316 (comment Icircumflex)
   (CHARWD R 389)
   (CHARHT R 954)
   )
(CHARACTER O 317 (comment Idieresis)
   (CHARWD R 389)
   (CHARHT R 916)
   )
(CHARACTER O 320 (comment Eth)
   (CHARWD R 722)
   (CHARHT R 676)
   )
(CHARACTER O 321 (comment Ntilde)
   (CHARWD R 722)
   (CHARHT R 924)
   (CHARDP R 18)
   )
(CHARACTER O 322 (comment Ograve)
   (CHARWD R 778)
   (CHARHT R 963)
   (CHARDP R 19)
   )
(CHARACTER O 323 (comment Oacute)
   (CHARWD R 778)
   (CHARHT R 963)
   (CHARDP R 19)
   )
(CHARACTER O 324 (comment Ocircumflex)
   (CHARWD R 778)
   (CHARHT R 954)
   (CHARDP R 19)
   )
(CHARACTER O 325 (comment Otilde)
   (CHARWD R 778)
   (CHARHT R 924)
   (CHARDP R 19)
   )
(CHARACTER O 326 (comment Odieresis)
   (CHARWD R 778)
   (CHARHT R 916)
   (CHARDP R 19)
   )
(CHARACTER O 327 (comment OE)
   (CHARWD R 1000)
   (CHARHT R 684)
   (CHARDP R 5)
   )
(CHARACTER O 330 (comment Oslash)
   (CHARWD R 778)
   (CHARHT R 737)
   (CHARDP R 74)
   )
(CHARACTER O 331 (comment Ugrave)
   (CHARWD R 722)
   (CHARHT R 963)
   (CHARDP R 19)
   )
(CHARACTER O 332 (comment Uacute)
   (CHARWD R 722)
   (CHARHT R 963)
   (CHARDP R 19)
   )
(CHARACTER O 333 (comment Ucircumflex)
   (CHARWD R 722)
   (CHARHT R 954)
   (CHARDP R 19)
   )
(CHARACTER O 334 (comment Udieresis)
   (CHARWD R 722)
   (CHARHT R 916)
   (CHARDP R 19)
   )
(CHARACTER O 335 (comment Yacute)
   (CHARWD R 722)
   (CHARHT R 963)
   )
(CHARACTER O 336 (comment Thorn)
   (CHARWD R 611)
   (CHARHT R 676)
   )
(CHARACTER O 337 (comment uni1E9E)
   (CHARWD R 1112)
   (CHARHT R 692)
   (CHARDP R 19)
   )
(CHARACTER O 340 (comment agrave)
   (CHARWD R 500)
   (CHARHT R 713)
   (CHARDP R 14)
   )
(CHARACTER O 341 (comment aacute)
   (CHARWD R 500)
   (CHARHT R 713)
   (CHARDP R 14)
   )
(CHARACTER O 342 (comment acircumflex)
   (CHARWD R 500)
   (CHARHT R 704)
   (CHARDP R 14)
   )
(CHARACTER O 343 (comment atilde)
   (CHARWD R 500)
   (CHARHT R 674)
   (CHARDP R 14)
   )
(CHARACTER O 344 (comment adieresis)
   (CHARWD R 500)
   (CHARHT R 666)
   (CHARDP R 14)
   )
(CHARACTER O 345 (comment aring)
   (CHARWD R 500)
   (CHARHT R 752)
   (CHARDP R 14)
   )
(CHARACTER O 346 (comment ae)
   (CHARWD R 722)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 347 (comment ccedilla)
   (CHARWD R 444)
   (CHARHT R 473)
   (CHARDP R 218)
   )
(CHARACTER O 350 (comment egrave)
   (CHARWD R 444)
   (CHARHT R 713)
   (CHARDP R 14)
   )
(CHARACTER O 351 (comment eacute)
   (CHARWD R 444)
   (CHARHT R 713)
   (CHARDP R 14)
   )
(CHARACTER O 352 (comment ecircumflex)
   (CHARWD R 444)
   (CHARHT R 704)
   (CHARDP R 14)
   )
(CHARACTER O 353 (comment edieresis)
   (CHARWD R 444)
   (CHARHT R 666)
   (CHARDP R 14)
   )
(CHARACTER O 354 (comment igrave)
   (CHARWD R 278)
   (CHARHT R 713)
   )
(CHARACTER O 355 (comment iacute)
   (CHARWD R 278)
   (CHARHT R 713)
   )
(CHARACTER O 356 (comment icircumflex)
   (CHARWD R 278)
   (CHARHT R 704)
   (CHARIC R 30)
   )
(CHARACTER O 357 (comment idieresis)
   (CHARWD R 278)
   (CHARHT R 666)
   (CHARIC R 32)
   )
(CHARACTER O 360 (comment eth)
   (CHARWD R 500)
   (CHARHT R 691)
   (CHARDP R 14)
   )
(CHARACTER O 361 (comment ntilde)
   (CHARWD R 556)
   (CHARHT R 674)
   )
(CHARACTER O 362 (comment ograve)
   (CHARWD R 500)
   (CHARHT R 713)
   (CHARDP R 14)
   )
(CHARACTER O 363 (comment oacute)
   (CHARWD R 500)
   (CHARHT R 713)
   (CHARDP R 14)
   )
(CHARACTER O 364 (comment ocircumflex)
   (CHARWD R 500)
   (CHARHT R 704)
   (CHARDP R 14)
   )
(CHARACTER O 365 (comment otilde)
   (CHARWD R 500)
   (CHARHT R 674)
   (CHARDP R 14)
   )
(CHARACTER O 366 (comment odieresis)
   (CHARWD R 500)
   (CHARHT R 666)
   (CHARDP R 14)
   )
(CHARACTER O 367 (comment oe)
   (CHARWD R 722)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 370 (comment oslash)
   (CHARWD R 500)
   (CHARHT R 549)
   (CHARDP R 92)
   )
(CHARACTER O 371 (comment ugrave)
   (CHARWD R 556)
   (CHARHT R 713)
   (CHARDP R 14)
   )
(CHARACTER O 372 (comment uacute)
   (CHARWD R 556)
   (CHARHT R 713)
   (CHARDP R 14)
   )
(CHARACTER O 373 (comment ucircumflex)
   (CHARWD R 556)
   (CHARHT R 704)
   (CHARDP R 14)
   )
(CHARACTER O 374 (comment udieresis)
   (CHARWD R 556)
   (CHARHT R 666)
   (CHARDP R 14)
   )
(CHARACTER O 375 (comment yacute)
   (CHARWD R 500)
   (CHARHT R 713)
   (CHARDP R 205)
   )
(CHARACTER O 376 (comment thorn)
   (CHARWD R 556)
   (CHARHT R 676)
   (CHARDP R 205)
   )
(CHARACTER O 377 (comment germandbls)
   (CHARWD R 556)
   (CHARHT R 691)
   (CHARDP R 12)
   )
