(FAMILY stix-extra2)
(CODINGSCHEME STIXEXTRA2)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 377)
(FONTDIMEN
   (SLANT R 0.000000)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 450)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   )
(CHARACTER O 43 (comment uniE28C)
   (CHARWD R 0)
   (CHARHT R 474)
   (CHARIC R 397)
   )
(CHARACTER O 44 (comment uniE28D)
   (CHARWD R 0)
   (CHARHT R 734)
   (CHARIC R 460)
   )
(CHARACTER O 45 (comment uniE28E)
   (CHARWD R 685)
   (CHARHT R 622)
   (CHARDP R 101)
   )
(CHARACTER O 46 (comment uniE28F)
   (CHARWD R 325)
   (CHARHT R 135)
   (CHARIC R 1)
   )
(CHARACTER O 47 (comment uniE290)
   (CHARWD R 633)
   (CHARHT R 135)
   (CHARIC R 1)
   )
(CHARACTER O 50 (comment uniE291)
   (CHARWD R 325)
   (CHARHT R 955)
   (CHARIC R 1)
   )
(CHARACTER O 51 (comment uniE292)
   (CHARWD R 1388)
   (CHARHT R 662)
   )
(CHARACTER O 52 (comment uniE293)
   (CHARWD R 1797)
   (CHARHT R 763)
   (CHARDP R 260)
   )
(CHARACTER O 223 (comment uniE2FC)
   (CHARWD R 722)
   (CHARHT R 756)
   (CHARDP R 218)
   )
(CHARACTER O 225 (comment uniE2FE)
   (CHARWD R 667)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 227 (comment uniE300)
   (CHARWD R 587)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 231 (comment uniE302)
   (CHARWD R 722)
   (CHARHT R 756)
   (CHARDP R 218)
   )
(CHARACTER O 233 (comment uniE304)
   (CHARWD R 611)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 235 (comment uniE306)
   (CHARWD R 612)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 237 (comment uniE308)
   (CHARWD R 722)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 241 (comment uniE30A)
   (CHARWD R 722)
   (CHARHT R 756)
   (CHARDP R 218)
   )
(CHARACTER O 243 (comment uniE30C)
   (CHARWD R 333)
   (CHARHT R 756)
   (CHARDP R 218)
   (CHARIC R 105)
   )
(CHARACTER O 245 (comment uniE30E)
   (CHARWD R 731)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 247 (comment uniE310)
   (CHARWD R 702)
   (CHARHT R 756)
   (CHARDP R 218)
   )
(CHARACTER O 251 (comment uniE312)
   (CHARWD R 889)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 253 (comment uniE314)
   (CHARWD R 722)
   (CHARHT R 756)
   (CHARDP R 218)
   )
(CHARACTER O 255 (comment uniE316)
   (CHARWD R 643)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 257 (comment uniE318)
   (CHARWD R 722)
   (CHARHT R 756)
   (CHARDP R 218)
   )
(CHARACTER O 261 (comment uniE31A)
   (CHARWD R 722)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 263 (comment uniE31C)
   (CHARWD R 557)
   (CHARHT R 756)
   (CHARDP R 218)
   (CHARIC R 8)
   )
(CHARACTER O 265 (comment uniE31E)
   (CHARWD R 624)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 267 (comment uniE320)
   (CHARWD R 611)
   (CHARHT R 756)
   (CHARDP R 218)
   )
(CHARACTER O 271 (comment uniE322)
   (CHARWD R 722)
   (CHARHT R 756)
   (CHARDP R 218)
   )
(CHARACTER O 273 (comment uniE324)
   (CHARWD R 763)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 275 (comment uniE326)
   (CHARWD R 722)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 277 (comment uniE328)
   (CHARWD R 743)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 301 (comment uniE32A)
   (CHARWD R 744)
   (CHARHT R 756)
   (CHARDP R 217)
   )
(CHARACTER O 373 (comment uniE364)
   (CHARWD R 673)
   (CHARHT R 756)
   (CHARDP R 240)
   )
