(FAMILY STIXMathSans)
(CODINGSCHEME STIXMATHSF-BOLD)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   )
(LIGTABLE
   (LABEL O 101) (comment u1D5D4)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 102) (comment u1D5D5)
   (KRN O 177 R -0.045) (comment uni2040)
   (STOP)
   (LABEL O 103) (comment u1D5D6)
   (KRN O 177 R 0.0065) (comment uni2040)
   (STOP)
   (LABEL O 104) (comment u1D5D7)
   (KRN O 177 R 0.0225) (comment uni2040)
   (STOP)
   (LABEL O 105) (comment u1D5D8)
   (KRN O 177 R 0.0205) (comment uni2040)
   (STOP)
   (LABEL O 106) (comment u1D5D9)
   (KRN O 177 R 0.034) (comment uni2040)
   (STOP)
   (LABEL O 107) (comment u1D5DA)
   (KRN O 177 R 0.019) (comment uni2040)
   (STOP)
   (LABEL O 110) (comment u1D5DB)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 111) (comment u1D5DC)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 112) (comment u1D5DD)
   (KRN O 177 R 0.1035) (comment uni2040)
   (STOP)
   (LABEL O 113) (comment u1D5DE)
   (KRN O 177 R -0.023) (comment uni2040)
   (STOP)
   (LABEL O 114) (comment u1D5DF)
   (KRN O 177 R 0.0315) (comment uni2040)
   (STOP)
   (LABEL O 115) (comment u1D5E0)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 116) (comment u1D5E1)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 117) (comment u1D5E2)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 120) (comment u1D5E3)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 121) (comment u1D5E4)
   (KRN O 177 R 0.0045) (comment uni2040)
   (STOP)
   (LABEL O 122) (comment u1D5E5)
   (KRN O 177 R -0.037) (comment uni2040)
   (STOP)
   (LABEL O 123) (comment u1D5E6)
   (KRN O 177 R -0.004) (comment uni2040)
   (STOP)
   (LABEL O 124) (comment u1D5E7)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 125) (comment u1D5E8)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 126) (comment u1D5E9)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 127) (comment u1D5EA)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 130) (comment u1D5EB)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 131) (comment u1D5EC)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 132) (comment u1D5ED)
   (KRN O 177 R -0.0025) (comment uni2040)
   (STOP)
   (LABEL O 141) (comment u1D5EE)
   (KRN O 177 R -0.0195) (comment uni2040)
   (STOP)
   (LABEL O 142) (comment u1D5EF)
   (KRN O 177 R 0.015) (comment uni2040)
   (STOP)
   (LABEL O 143) (comment u1D5F0)
   (KRN O 177 R 0.002) (comment uni2040)
   (STOP)
   (LABEL O 144) (comment u1D5F1)
   (KRN O 177 R -0.015) (comment uni2040)
   (STOP)
   (LABEL O 145) (comment u1D5F2)
   (KRN O 177 R 0.003) (comment uni2040)
   (STOP)
   (LABEL O 146) (comment u1D5F3)
   (KRN O 177 R 0.022) (comment uni2040)
   (STOP)
   (LABEL O 147) (comment u1D5F4)
   (KRN O 177 R 0.007) (comment uni2040)
   (STOP)
   (LABEL O 150) (comment u1D5F5)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 151) (comment u1D5F6)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 152) (comment u1D5F7)
   (KRN O 177 R -0.056) (comment uni2040)
   (STOP)
   (LABEL O 153) (comment u1D5F8)
   (KRN O 177 R 0.0205) (comment uni2040)
   (STOP)
   (LABEL O 154) (comment u1D5F9)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 155) (comment u1D5FA)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 156) (comment u1D5FB)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 157) (comment u1D5FC)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 160) (comment u1D5FD)
   (KRN O 177 R 0.015) (comment uni2040)
   (STOP)
   (LABEL O 161) (comment u1D5FE)
   (KRN O 177 R -0.015) (comment uni2040)
   (STOP)
   (LABEL O 162) (comment u1D5FF)
   (KRN O 177 R 0.0245) (comment uni2040)
   (STOP)
   (LABEL O 163) (comment u1D600)
   (KRN O 177 R -0.0015) (comment uni2040)
   (STOP)
   (LABEL O 164) (comment u1D601)
   (KRN O 177 R -0.004) (comment uni2040)
   (STOP)
   (LABEL O 165) (comment u1D602)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 166) (comment u1D603)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 167) (comment u1D604)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 170) (comment u1D605)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 171) (comment u1D606)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 172) (comment u1D607)
   (KRN O 177 R -0.0015) (comment uni2040)
   (STOP)
   (LABEL O 173) (comment u1D5F6.dtls)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 174) (comment u1D5F7.dtls)
   (KRN O 177 R 0.033) (comment uni2040)
   (STOP)
   )
(CHARACTER O 0 (comment u1D758)
   (CHARWD R 0.591)
   (CHARHT R 0.676)
   )
(CHARACTER O 1 (comment u1D759)
   (CHARWD R 0.72)
   (CHARHT R 0.69)
   )
(CHARACTER O 2 (comment u1D75D)
   (CHARWD R 0.778)
   (CHARHT R 0.691)
   (CHARDP R 0.019)
   )
(CHARACTER O 3 (comment u1D760)
   (CHARWD R 0.706)
   (CHARHT R 0.69)
   )
(CHARACTER O 4 (comment u1D763)
   (CHARWD R 0.64)
   (CHARHT R 0.676)
   )
(CHARACTER O 5 (comment u1D765)
   (CHARWD R 0.715)
   (CHARHT R 0.676)
   )
(CHARACTER O 6 (comment u1D768)
   (CHARWD R 0.674)
   (CHARHT R 0.676)
   )
(CHARACTER O 7 (comment u1D76A)
   (CHARWD R 0.748)
   (CHARHT R 0.691)
   )
(CHARACTER O 10 (comment u1D76B)
   (CHARWD R 0.8)
   (CHARHT R 0.676)
   )
(CHARACTER O 11 (comment u1D76D)
   (CHARWD R 0.806)
   (CHARHT R 0.691)
   )
(CHARACTER O 12 (comment u1D76E)
   (CHARWD R 0.752)
   (CHARHT R 0.691)
   )
(CHARACTER O 13 (comment u1D770)
   (CHARWD R 0.662)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 14 (comment u1D771)
   (CHARWD R 0.512)
   (CHARHT R 0.692)
   (CHARDP R 0.205)
   )
(CHARACTER O 15 (comment u1D772)
   (CHARWD R 0.502)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 16 (comment u1D773)
   (CHARWD R 0.502)
   (CHARHT R 0.692)
   (CHARDP R 0.014)
   )
(CHARACTER O 17 (comment u1D78A)
   (CHARWD R 0.462)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 20 (comment u1D775)
   (CHARWD R 0.5)
   (CHARHT R 0.692)
   (CHARDP R 0.205)
   )
(CHARACTER O 21 (comment u1D776)
   (CHARWD R 0.51)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 22 (comment u1D777)
   (CHARWD R 0.5)
   (CHARHT R 0.692)
   (CHARDP R 0.014)
   )
(CHARACTER O 23 (comment u1D778)
   (CHARWD R 0.319)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 24 (comment u1D779)
   (CHARWD R 0.527)
   (CHARHT R 0.473)
   )
(CHARACTER O 25 (comment u1D77A)
   (CHARWD R 0.554)
   (CHARHT R 0.692)
   (CHARDP R 0.014)
   )
(CHARACTER O 26 (comment u1D77B)
   (CHARWD R 0.55)
   (CHARHT R 0.461)
   (CHARDP R 0.205)
   )
(CHARACTER O 27 (comment u1D77C)
   (CHARWD R 0.492)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 30 (comment u1D77D)
   (CHARWD R 0.501)
   (CHARHT R 0.692)
   (CHARDP R 0.205)
   )
(CHARACTER O 31 (comment u1D77F)
   (CHARWD R 0.594)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 32 (comment u1D780)
   (CHARWD R 0.511)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 33 (comment u1D782)
   (CHARWD R 0.52)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   (CHARIC R 0.077)
   )
(CHARACTER O 34 (comment u1D783)
   (CHARWD R 0.479)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 35 (comment u1D784)
   (CHARWD R 0.514)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 36 (comment u1D78D)
   (CHARWD R 0.634)
   (CHARHT R 0.692)
   (CHARDP R 0.205)
   )
(CHARACTER O 37 (comment u1D786)
   (CHARWD R 0.573)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 40 (comment u1D787)
   (CHARWD R 0.68)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   (CHARIC R 0.064)
   )
(CHARACTER O 41 (comment u1D788)
   (CHARWD R 0.74)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 42 (comment u1D774)
   (CHARWD R 0.451)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 43 (comment u1D78B)
   (CHARWD R 0.536)
   (CHARHT R 0.692)
   (CHARDP R 0.014)
   )
(CHARACTER O 44 (comment u1D78F)
   (CHARWD R 0.848)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 45 (comment u1D78E)
   (CHARWD R 0.494)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 46 (comment u1D781)
   (CHARWD R 0.498)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 47 (comment u1D785)
   (CHARWD R 0.634)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 50 (comment u1D76F)
   (CHARWD R 0.735)
   (CHARHT R 0.664)
   (CHARDP R 0.03)
   )
(CHARACTER O 51 (comment u1D789)
   (CHARWD R 0.501)
   (CHARHT R 0.691)
   (CHARDP R 0.014)
   )
(CHARACTER O 52 (comment uniE0B4)
   (CHARWD R 0.282)
   (CHARHT R 0.555)
   )
(CHARACTER O 53 (comment uniE0B5)
   (CHARWD R 0.282)
   (CHARHT R 0.555)
   )
(CHARACTER O 54 (comment uni2190.x)
   (CHARWD R 0.315)
   (CHARHT R 0.297)
   )
(CHARACTER O 55 (comment uni21D0.x)
   (CHARWD R 0.315)
   (CHARHT R 0.399)
   )
(CHARACTER O 56 (comment uni21DA.x)
   (CHARWD R 0.315)
   (CHARHT R 0.486)
   )
(CHARACTER O 57 (comment uni2B45.x)
   (CHARWD R 0.315)
   (CHARHT R 0.541)
   (CHARDP R 0.035)
   )
(CHARACTER O 60 (comment u1D7EC)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 61 (comment u1D7ED)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   )
(CHARACTER O 62 (comment u1D7EE)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   )
(CHARACTER O 63 (comment u1D7EF)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 64 (comment u1D7F0)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   )
(CHARACTER O 65 (comment u1D7F1)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.013)
   )
(CHARACTER O 66 (comment u1D7F2)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 67 (comment u1D7F3)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 70 (comment u1D7F4)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 71 (comment u1D7F5)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 72 (comment mapsfromchar)
   (CHARWD R 0)
   (CHARHT R 0.478)
   )
(CHARACTER O 73 (comment uniE0B6)
   (CHARWD R 0)
   (CHARHT R 0.478)
   )
(CHARACTER O 74 (comment uni23D0)
   (CHARWD R 0.584)
   (CHARHT R 0.202)
   (CHARDP R 0)
   (VARCHAR
      (REP O 74)
      )
   )
(CHARACTER O 75 (comment uni21D1.x)
   (CHARWD R 0.714)
   (CHARHT R 0.202)
   (CHARDP R 0)
   (VARCHAR
      (REP O 75)
      )
   )
(CHARACTER O 76 (comment uni290A.x)
   (CHARWD R 0.926)
   (CHARHT R 0.202)
   (CHARDP R 0)
   )
(CHARACTER O 77 (comment uni27F0.x)
   (CHARWD R 1.033)
   (CHARHT R 0.202)
   (CHARDP R 0)
   )
(CHARACTER O 100 (comment uni2B48)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.141)
   )
(CHARACTER O 101 (comment u1D5D4)
   (CHARWD R 0.69)
   (CHARHT R 0.69)
   )
(CHARACTER O 102 (comment u1D5D5)
   (CHARWD R 0.636)
   (CHARHT R 0.676)
   )
(CHARACTER O 103 (comment u1D5D6)
   (CHARWD R 0.723)
   (CHARHT R 0.691)
   (CHARDP R 0.019)
   )
(CHARACTER O 104 (comment u1D5D7)
   (CHARWD R 0.709)
   (CHARHT R 0.676)
   )
(CHARACTER O 105 (comment u1D5D8)
   (CHARWD R 0.635)
   (CHARHT R 0.676)
   )
(CHARACTER O 106 (comment u1D5D9)
   (CHARWD R 0.582)
   (CHARHT R 0.676)
   )
(CHARACTER O 107 (comment u1D5DA)
   (CHARWD R 0.746)
   (CHARHT R 0.691)
   (CHARDP R 0.019)
   )
(CHARACTER O 110 (comment u1D5DB)
   (CHARWD R 0.715)
   (CHARHT R 0.676)
   )
(CHARACTER O 111 (comment u1D5DC)
   (CHARWD R 0.44)
   (CHARHT R 0.676)
   )
(CHARACTER O 112 (comment u1D5DD)
   (CHARWD R 0.481)
   (CHARHT R 0.676)
   (CHARDP R 0.096)
   )
(CHARACTER O 113 (comment u1D5DE)
   (CHARWD R 0.712)
   (CHARHT R 0.676)
   )
(CHARACTER O 114 (comment u1D5DF)
   (CHARWD R 0.603)
   (CHARHT R 0.676)
   )
(CHARACTER O 115 (comment u1D5E0)
   (CHARWD R 0.913)
   (CHARHT R 0.676)
   )
(CHARACTER O 116 (comment u1D5E1)
   (CHARWD R 0.724)
   (CHARHT R 0.676)
   (CHARDP R 0.018)
   )
(CHARACTER O 117 (comment u1D5E2)
   (CHARWD R 0.778)
   (CHARHT R 0.692)
   (CHARDP R 0.018)
   )
(CHARACTER O 120 (comment u1D5E3)
   (CHARWD R 0.581)
   (CHARHT R 0.676)
   )
(CHARACTER O 121 (comment u1D5E4)
   (CHARWD R 0.779)
   (CHARHT R 0.691)
   (CHARDP R 0.176)
   )
(CHARACTER O 122 (comment u1D5E5)
   (CHARWD R 0.67)
   (CHARHT R 0.676)
   )
(CHARACTER O 123 (comment u1D5E6)
   (CHARWD R 0.554)
   (CHARHT R 0.691)
   (CHARDP R 0.019)
   )
(CHARACTER O 124 (comment u1D5E7)
   (CHARWD R 0.641)
   (CHARHT R 0.676)
   )
(CHARACTER O 125 (comment u1D5E8)
   (CHARWD R 0.699)
   (CHARHT R 0.676)
   (CHARDP R 0.019)
   )
(CHARACTER O 126 (comment u1D5E9)
   (CHARWD R 0.69)
   (CHARHT R 0.676)
   (CHARDP R 0.018)
   )
(CHARACTER O 127 (comment u1D5EA)
   (CHARWD R 0.997)
   (CHARHT R 0.676)
   (CHARDP R 0.015)
   )
(CHARACTER O 130 (comment u1D5EB)
   (CHARWD R 0.74)
   (CHARHT R 0.676)
   )
(CHARACTER O 131 (comment u1D5EC)
   (CHARWD R 0.694)
   (CHARHT R 0.676)
   )
(CHARACTER O 132 (comment u1D5ED)
   (CHARWD R 0.653)
   (CHARHT R 0.676)
   )
(CHARACTER O 133 (comment uni2B49)
   (CHARWD R 0.926)
   (CHARHT R 0.508)
   )
(CHARACTER O 134 (comment uni2B4A)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.141)
   )
(CHARACTER O 135 (comment uni2B4B)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.002)
   )
(CHARACTER O 136 (comment uni2B4C)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.002)
   )
(CHARACTER O 137 (comment uni290A)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   (VARCHAR
      (TOP O 137)
      (REP O 76)
      )
   )
(CHARACTER O 140 (comment uni290B)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   (VARCHAR
      (BOT O 140)
      (REP O 76)
      )
   )
(CHARACTER O 141 (comment u1D5EE)
   (CHARWD R 0.489)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 142 (comment u1D5EF)
   (CHARWD R 0.512)
   (CHARHT R 0.676)
   (CHARDP R 0.013)
   )
(CHARACTER O 143 (comment u1D5F0)
   (CHARWD R 0.462)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 144 (comment u1D5F1)
   (CHARWD R 0.518)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 145 (comment u1D5F2)
   (CHARWD R 0.452)
   (CHARHT R 0.473)
   (CHARDP R 0.013)
   )
(CHARACTER O 146 (comment u1D5F3)
   (CHARWD R 0.34)
   (CHARHT R 0.691)
   (CHARIC R 0.1)
   )
(CHARACTER O 147 (comment u1D5F4)
   (CHARWD R 0.504)
   (CHARHT R 0.473)
   (CHARDP R 0.206)
   )
(CHARACTER O 150 (comment u1D5F5)
   (CHARWD R 0.51)
   (CHARHT R 0.676)
   )
(CHARACTER O 151 (comment u1D5F6)
   (CHARWD R 0.245)
   (CHARHT R 0.688)
   )
(CHARACTER O 152 (comment u1D5F7)
   (CHARWD R 0.324)
   (CHARHT R 0.688)
   (CHARDP R 0.203)
   )
(CHARACTER O 153 (comment u1D5F8)
   (CHARWD R 0.519)
   (CHARHT R 0.676)
   )
(CHARACTER O 154 (comment u1D5F9)
   (CHARWD R 0.235)
   (CHARHT R 0.676)
   )
(CHARACTER O 155 (comment u1D5FA)
   (CHARWD R 0.776)
   (CHARHT R 0.473)
   )
(CHARACTER O 156 (comment u1D5FB)
   (CHARWD R 0.51)
   (CHARHT R 0.473)
   )
(CHARACTER O 157 (comment u1D5FC)
   (CHARWD R 0.501)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 160 (comment u1D5FD)
   (CHARWD R 0.512)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 161 (comment u1D5FE)
   (CHARWD R 0.512)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 162 (comment u1D5FF)
   (CHARWD R 0.411)
   (CHARHT R 0.473)
   )
(CHARACTER O 163 (comment u1D600)
   (CHARWD R 0.385)
   (CHARHT R 0.473)
   (CHARDP R 0.013)
   )
(CHARACTER O 164 (comment u1D601)
   (CHARWD R 0.386)
   (CHARHT R 0.63)
   (CHARDP R 0.012)
   )
(CHARACTER O 165 (comment u1D602)
   (CHARWD R 0.518)
   (CHARHT R 0.461)
   (CHARDP R 0.015)
   )
(CHARACTER O 166 (comment u1D603)
   (CHARWD R 0.462)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 167 (comment u1D604)
   (CHARWD R 0.701)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 170 (comment u1D605)
   (CHARWD R 0.506)
   (CHARHT R 0.461)
   )
(CHARACTER O 171 (comment u1D606)
   (CHARWD R 0.472)
   (CHARHT R 0.461)
   (CHARDP R 0.205)
   )
(CHARACTER O 172 (comment u1D607)
   (CHARWD R 0.441)
   (CHARHT R 0.461)
   )
(CHARACTER O 173 (comment u1D5F6.dtls)
   (CHARWD R 0.245)
   (CHARHT R 0.461)
   )
(CHARACTER O 174 (comment u1D5F7.dtls)
   (CHARWD R 0.324)
   (CHARHT R 0.461)
   (CHARDP R 0.203)
   )
(CHARACTER O 175 (comment uni2190)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 176 (comment uni2191)
   (CHARWD R 0.584)
   (CHARHT R 0.676)
   (CHARDP R 0.17)
   (VARCHAR
      (TOP O 176)
      (REP O 74)
      )
   )
(CHARACTER O 177 (comment uni2040)
   (CHARWD R 0.798)
   (CHARHT R 0.7)
   )
(CHARACTER O 200 (comment uni0300)
   (CHARWD R 0.238)
   (CHARHT R 0.7)
   )
(CHARACTER O 201 (comment uni0301)
   (CHARWD R 0.238)
   (CHARHT R 0.7)
   )
(CHARACTER O 202 (comment uni0302)
   (CHARWD R 0.337)
   (CHARHT R 0.7)
   )
(CHARACTER O 203 (comment uni0303)
   (CHARWD R 0.365)
   (CHARHT R 0.7)
   )
(CHARACTER O 204 (comment uni0304)
   (CHARWD R 0.33)
   (CHARHT R 0.6)
   )
(CHARACTER O 205 (comment uni0306)
   (CHARWD R 0.303)
   (CHARHT R 0.7)
   )
(CHARACTER O 206 (comment uni0307)
   (CHARWD R 0.129)
   (CHARHT R 0.7)
   )
(CHARACTER O 207 (comment uni0308)
   (CHARWD R 0.339)
   (CHARHT R 0.7)
   )
(CHARACTER O 210 (comment uni0309)
   (CHARWD R 0.205)
   (CHARHT R 0.8)
   )
(CHARACTER O 211 (comment uni030A)
   (CHARWD R 0.213)
   (CHARHT R 0.8)
   )
(CHARACTER O 212 (comment uni030C)
   (CHARWD R 0.337)
   (CHARHT R 0.7)
   )
(CHARACTER O 213 (comment uni0310)
   (CHARWD R 0.303)
   (CHARHT R 0.8)
   )
(CHARACTER O 214 (comment uni0312)
   (CHARWD R 0.184)
   (CHARHT R 0.9)
   )
(CHARACTER O 215 (comment uni0315)
   (CHARWD R 0.184)
   (CHARHT R 0.9)
   )
(CHARACTER O 216 (comment uni031A)
   (CHARWD R 0.317)
   (CHARHT R 0.8)
   )
(CHARACTER O 217 (comment uni20D0)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 220 (comment uni20D1)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 221 (comment uni20D6)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 222 (comment uni20D7)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 223 (comment uni20DB)
   (CHARWD R 0.549)
   (CHARHT R 0.7)
   )
(CHARACTER O 224 (comment uni20DC)
   (CHARWD R 0.759)
   (CHARHT R 0.7)
   )
(CHARACTER O 225 (comment uni20E1)
   (CHARWD R 0.594)
   (CHARHT R 0.8)
   )
(CHARACTER O 226 (comment uni20E7)
   (CHARWD R 0.843)
   (CHARHT R 0.8)
   (CHARDP R 0.2)
   )
(CHARACTER O 227 (comment uni20E9)
   (CHARWD R 0.564)
   (CHARHT R 0.7)
   )
(CHARACTER O 230 (comment uni20F0)
   (CHARWD R 0.27)
   (CHARHT R 0.8)
   )
(CHARACTER O 231 (comment uni2192)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 232 (comment uni2193)
   (CHARWD R 0.584)
   (CHARHT R 0.676)
   (CHARDP R 0.17)
   (VARCHAR
      (BOT O 232)
      (REP O 74)
      )
   )
(CHARACTER O 233 (comment uni2194)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 234 (comment uni2195)
   (CHARWD R 0.584)
   (CHARHT R 0.736)
   (CHARDP R 0.23)
   (VARCHAR
      (TOP O 176)
      (BOT O 232)
      (REP O 74)
      )
   )
(CHARACTER O 235 (comment uni2196)
   (CHARWD R 0.977)
   (CHARHT R 0.676)
   (CHARDP R 0.17)
   )
(CHARACTER O 236 (comment uni2197)
   (CHARWD R 0.977)
   (CHARHT R 0.676)
   (CHARDP R 0.17)
   )
(CHARACTER O 237 (comment uni2198)
   (CHARWD R 0.977)
   (CHARHT R 0.676)
   (CHARDP R 0.17)
   )
(CHARACTER O 240 (comment uni2199)
   (CHARWD R 0.977)
   (CHARHT R 0.676)
   (CHARDP R 0.17)
   )
(CHARACTER O 241 (comment uni219A)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 242 (comment uni219B)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 243 (comment uni219C)
   (CHARWD R 0.956)
   (CHARHT R 0.462)
   )
(CHARACTER O 244 (comment uni219D)
   (CHARWD R 0.956)
   (CHARHT R 0.462)
   )
(CHARACTER O 245 (comment uni219E)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 246 (comment uni219F)
   (CHARWD R 0.568)
   (CHARHT R 0.676)
   (CHARDP R 0.165)
   )
(CHARACTER O 247 (comment uni21A0)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 250 (comment uni21A1)
   (CHARWD R 0.568)
   (CHARHT R 0.676)
   (CHARDP R 0.165)
   )
(CHARACTER O 251 (comment uni21A2)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 252 (comment uni21A3)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 253 (comment uni21A4)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 254 (comment uni21A5)
   (CHARWD R 0.584)
   (CHARHT R 0.676)
   (CHARDP R 0.165)
   )
(CHARACTER O 255 (comment uni21A6)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 256 (comment uni21A7)
   (CHARWD R 0.584)
   (CHARHT R 0.676)
   (CHARDP R 0.165)
   )
(CHARACTER O 257 (comment uni21A8)
   (CHARWD R 0.584)
   (CHARHT R 0.732)
   (CHARDP R 0.196)
   )
(CHARACTER O 260 (comment uni21A9)
   (CHARWD R 0.966)
   (CHARHT R 0.539)
   )
(CHARACTER O 261 (comment uni21AA)
   (CHARWD R 0.966)
   (CHARHT R 0.539)
   )
(CHARACTER O 262 (comment uni21AB)
   (CHARWD R 0.966)
   (CHARHT R 0.54)
   (CHARDP R 0.006)
   )
(CHARACTER O 263 (comment uni21AC)
   (CHARWD R 0.966)
   (CHARHT R 0.54)
   (CHARDP R 0.006)
   )
(CHARACTER O 264 (comment uni21AD)
   (CHARWD R 1.297)
   (CHARHT R 0.451)
   )
(CHARACTER O 265 (comment uni21AE)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 266 (comment uni21AF)
   (CHARWD R 0.562)
   (CHARHT R 0.683)
   (CHARDP R 0.154)
   )
(CHARACTER O 267 (comment uni21B0)
   (CHARWD R 0.584)
   (CHARHT R 0.686)
   (CHARDP R 0.17)
   )
(CHARACTER O 270 (comment uni21B1)
   (CHARWD R 0.584)
   (CHARHT R 0.686)
   (CHARDP R 0.17)
   )
(CHARACTER O 271 (comment uni21B2)
   (CHARWD R 0.584)
   (CHARHT R 0.686)
   (CHARDP R 0.17)
   )
(CHARACTER O 272 (comment uni21B3)
   (CHARWD R 0.584)
   (CHARHT R 0.686)
   (CHARDP R 0.17)
   )
(CHARACTER O 273 (comment uni21B4)
   (CHARWD R 0.96)
   (CHARHT R 0.686)
   (CHARDP R 0.162)
   )
(CHARACTER O 274 (comment uni21B5)
   (CHARWD R 0.96)
   (CHARHT R 0.686)
   (CHARDP R 0.171)
   )
(CHARACTER O 275 (comment uni21B6)
   (CHARWD R 0.971)
   (CHARHT R 0.524)
   )
(CHARACTER O 276 (comment uni21B7)
   (CHARWD R 0.971)
   (CHARHT R 0.524)
   )
(CHARACTER O 277 (comment uni21B8)
   (CHARWD R 0.977)
   (CHARHT R 0.768)
   (CHARDP R 0.17)
   )
(CHARACTER O 300 (comment uni21B9)
   (CHARWD R 0.977)
   (CHARHT R 0.618)
   (CHARDP R 0.114)
   )
(CHARACTER O 301 (comment uni21BA)
   (CHARWD R 0.974)
   (CHARHT R 0.693)
   (CHARDP R 0.127)
   )
(CHARACTER O 302 (comment uni21BB)
   (CHARWD R 0.974)
   (CHARHT R 0.693)
   (CHARDP R 0.127)
   )
(CHARACTER O 303 (comment uni21BC)
   (CHARWD R 0.977)
   (CHARHT R 0.501)
   )
(CHARACTER O 304 (comment uni21BD)
   (CHARWD R 0.977)
   (CHARHT R 0.297)
   )
(CHARACTER O 305 (comment uni21BE)
   (CHARWD R 0.552)
   (CHARHT R 0.694)
   (CHARDP R 0.162)
   )
(CHARACTER O 306 (comment uni21BF)
   (CHARWD R 0.352)
   (CHARHT R 0.694)
   (CHARDP R 0.162)
   )
(CHARACTER O 307 (comment uni21C0)
   (CHARWD R 0.977)
   (CHARHT R 0.501)
   )
(CHARACTER O 310 (comment uni21C1)
   (CHARWD R 0.977)
   (CHARHT R 0.297)
   )
(CHARACTER O 311 (comment uni21C2)
   (CHARWD R 0.552)
   (CHARHT R 0.694)
   (CHARDP R 0.162)
   )
(CHARACTER O 312 (comment uni21C3)
   (CHARWD R 0.552)
   (CHARHT R 0.694)
   (CHARDP R 0.162)
   )
(CHARACTER O 313 (comment uni21C4)
   (CHARWD R 0.977)
   (CHARHT R 0.618)
   (CHARDP R 0.114)
   )
(CHARACTER O 314 (comment uni21C5)
   (CHARWD R 0.864)
   (CHARHT R 0.676)
   (CHARDP R 0.165)
   )
(CHARACTER O 315 (comment uni21C6)
   (CHARWD R 0.977)
   (CHARHT R 0.618)
   (CHARDP R 0.114)
   )
(CHARACTER O 316 (comment uni21C7)
   (CHARWD R 0.977)
   (CHARHT R 0.618)
   (CHARDP R 0.114)
   )
(CHARACTER O 317 (comment uni21C8)
   (CHARWD R 0.864)
   (CHARHT R 0.676)
   (CHARDP R 0.165)
   )
(CHARACTER O 320 (comment uni21C9)
   (CHARWD R 0.977)
   (CHARHT R 0.618)
   (CHARDP R 0.114)
   )
(CHARACTER O 321 (comment uni21CA)
   (CHARWD R 0.864)
   (CHARHT R 0.676)
   (CHARDP R 0.165)
   )
(CHARACTER O 322 (comment uni21CB)
   (CHARWD R 0.977)
   (CHARHT R 0.571)
   (CHARDP R 0.021)
   )
(CHARACTER O 323 (comment uni21CC)
   (CHARWD R 0.977)
   (CHARHT R 0.571)
   (CHARDP R 0.021)
   )
(CHARACTER O 324 (comment uni21CD)
   (CHARWD R 0.977)
   (CHARHT R 0.57)
   (CHARDP R 0.064)
   )
(CHARACTER O 325 (comment uni21CE)
   (CHARWD R 1.24)
   (CHARHT R 0.57)
   (CHARDP R 0.064)
   )
(CHARACTER O 326 (comment uni21CF)
   (CHARWD R 0.977)
   (CHARHT R 0.57)
   (CHARDP R 0.064)
   )
(CHARACTER O 327 (comment uni21D0)
   (CHARWD R 0.977)
   (CHARHT R 0.57)
   (CHARDP R 0.064)
   )
(CHARACTER O 330 (comment uni21D1)
   (CHARWD R 0.714)
   (CHARHT R 0.676)
   (CHARDP R 0.17)
   (VARCHAR
      (TOP O 330)
      (REP O 75)
      )
   )
(CHARACTER O 331 (comment uni21D2)
   (CHARWD R 0.977)
   (CHARHT R 0.57)
   (CHARDP R 0.064)
   )
(CHARACTER O 332 (comment uni21D3)
   (CHARWD R 0.714)
   (CHARHT R 0.676)
   (CHARDP R 0.17)
   (VARCHAR
      (BOT O 332)
      (REP O 75)
      )
   )
(CHARACTER O 333 (comment uni21D4)
   (CHARWD R 1.24)
   (CHARHT R 0.57)
   (CHARDP R 0.064)
   )
(CHARACTER O 334 (comment uni21D5)
   (CHARWD R 0.714)
   (CHARHT R 0.736)
   (CHARDP R 0.23)
   (VARCHAR
      (TOP O 330)
      (BOT O 332)
      (REP O 75)
      )
   )
(CHARACTER O 335 (comment uni21D6)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 336 (comment uni21D7)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 337 (comment uni21D8)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 340 (comment uni21D9)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 341 (comment uni21DA)
   (CHARWD R 0.926)
   (CHARHT R 0.644)
   (CHARDP R 0.139)
   )
(CHARACTER O 342 (comment uni21DB)
   (CHARWD R 0.926)
   (CHARHT R 0.645)
   (CHARDP R 0.138)
   )
(CHARACTER O 343 (comment uni21DC)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 344 (comment uni21DD)
   (CHARWD R 0.977)
   (CHARHT R 0.451)
   )
(CHARACTER O 345 (comment uni21DE)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 346 (comment uni21DF)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 347 (comment uni21E0)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 350 (comment uni21E1)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 351 (comment uni21E2)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 352 (comment uni21E3)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 353 (comment uni21E4)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 354 (comment uni21E5)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 355 (comment uni21E6)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 356 (comment uni21E7)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 357 (comment uni21E8)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 360 (comment uni21E9)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 361 (comment uni21EA)
   (CHARWD R 0.685)
   (CHARHT R 0.705)
   (CHARDP R 0.201)
   )
(CHARACTER O 362 (comment uni21F4)
   (CHARWD R 0.926)
   (CHARHT R 0.448)
   )
(CHARACTER O 363 (comment uni21F5)
   (CHARWD R 0.864)
   (CHARHT R 0.676)
   (CHARDP R 0.165)
   )
(CHARACTER O 364 (comment uni21F6)
   (CHARWD R 0.926)
   (CHARHT R 0.739)
   (CHARDP R 0.232)
   )
(CHARACTER O 365 (comment uni21F7)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 366 (comment uni21F8)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 367 (comment uni21F9)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 370 (comment uni21FA)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 371 (comment uni21FB)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 372 (comment uni21FC)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 373 (comment uni21FD)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 374 (comment uni21FE)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 375 (comment uni21FF)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 376 (comment uni27F0)
   (CHARWD R 1.033)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   (VARCHAR
      (TOP O 376)
      (REP O 77)
      )
   )
(CHARACTER O 377 (comment uni27F1)
   (CHARWD R 1.033)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   (VARCHAR
      (BOT O 377)
      (REP O 77)
      )
   )
