(FAMILY ot1-stixgral-italic)
(CODINGSCHEME STIXOT1)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 40)
(FONTDIMEN
   (SLANT R 0.292989)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 428)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   (LABEL O 13) (comment ff)
   (LIG C l O 17)
   (LIG C i O 16)
   (STOP)
   (LABEL O 32) (comment ae)
   (KRN C w R 3)
   (KRN C y R 5)
   (STOP)
   (LABEL O 34) (comment oslash)
   (KRN O 47 R -19) (comment quoteright)
   (KRN C y R -8)
   (KRN C x R -27)
   (KRN C w R -12)
   (KRN C v R -14)
   (KRN C t R -5)
   (KRN C T R -50)
   (STOP)
   (LABEL O 37) (comment Oslash)
   (KRN O 35 R -53) (comment AE)
   (KRN C Y R -34)
   (KRN C X R -26)
   (KRN C W R -23)
   (KRN C V R -29)
   (KRN C T R -5)
   (KRN C A R -16)
   (STOP)
   (LABEL O 41) (comment exclam)
   (LIG O 140 O 74)
   (STOP)
   (LABEL O 42) (comment quotedblright)
   (KRN C A R -75)
   (KRN C T R -9)
   (KRN C V R -12)
   (KRN C W R -9)
   (KRN C Y R -25)
   (KRN O 35 R -129) (comment AE)
   (STOP)
   (LABEL O 47) (comment quoteright)
   (LIG O 47 O 42)
   (KRN O 34 R -65) (comment oslash)
   (KRN O 54 R -63) (comment comma)
   (KRN O 56 R -69) (comment period)
   (KRN C A R -68)
   (KRN C d R -64)
   (KRN C o R -65)
   (KRN C r R -45)
   (KRN C s R -51)
   (KRN C t R -34)
   (KRN C v R -25)
   (KRN C w R -19)
   (KRN C y R -23)
   (KRN O 35 R -122) (comment AE)
   (STOP)
   (LABEL O 54) (comment comma)
   (KRN C 1 R -30)
   (KRN O 47 R -37) (comment quoteright)
   (KRN O 42 R -37) (comment quotedblright)
   (STOP)
   (LABEL O 55) (comment hyphen)
   (LIG O 55 O 173)
   (KRN C A R 14)
   (KRN C T R -34)
   (KRN C V R -28)
   (KRN C W R -22)
   (KRN C Y R -40)
   (KRN O 35 R -9) (comment AE)
   (STOP)
   (LABEL O 56) (comment period)
   (KRN O 47 R -35) (comment quoteright)
   (KRN O 42 R -35) (comment quotedblright)
   (STOP)
   (LABEL O 77) (comment question)
   (LIG O 140 O 76)
   (STOP)
   (LABEL C A)
   (KRN O 34 R -16) (comment oslash)
   (KRN O 37 R -37) (comment Oslash)
   (KRN O 54 R 19) (comment comma)
   (KRN O 56 R 19) (comment period)
   (KRN C C R -36)
   (KRN C G R -29)
   (KRN C O R -37)
   (KRN C Q R -36)
   (KRN C T R -14)
   (KRN C U R -46)
   (KRN C V R -65)
   (KRN C W R -59)
   (KRN C Y R -20)
   (KRN C a R -5)
   (KRN C c R -17)
   (KRN C d R -4)
   (KRN C e R -18)
   (KRN C g R -31)
   (KRN C o R -16)
   (KRN C q R -11)
   (KRN C t R -7)
   (KRN C u R -9)
   (KRN C v R -35)
   (KRN C w R -32)
   (KRN C y R -54)
   (KRN O 47 R -77) (comment quoteright)
   (KRN O 42 R -77) (comment quotedblright)
   (STOP)
   (LABEL C B)
   (KRN C A R -20)
   (KRN C V R -25)
   (KRN C W R -19)
   (KRN C Y R -34)
   (KRN O 35 R -32) (comment AE)
   (KRN O 36 R 8) (comment OE)
   (STOP)
   (LABEL C C)
   (KRN O 37 R -7) (comment Oslash)
   (KRN C A R -19)
   (KRN C H R -5)
   (KRN C K R -17)
   (KRN C O R -7)
   (KRN O 35 R -31) (comment AE)
   (STOP)
   (LABEL C D)
   (KRN C A R -20)
   (KRN C J R -27)
   (KRN C T R -9)
   (KRN C V R -28)
   (KRN C W R -22)
   (KRN C X R -26)
   (KRN C Y R -37)
   (STOP)
   (LABEL C F)
   (KRN O 37 R -32) (comment Oslash)
   (KRN O 54 R -77) (comment comma)
   (KRN O 55 R -32) (comment hyphen)
   (KRN O 56 R -80) (comment period)
   (KRN C A R -54)
   (KRN C J R -59)
   (KRN C O R -32)
   (KRN C a R -60)
   (KRN C e R -67)
   (KRN C i R -35)
   (KRN C j R -38)
   (KRN C o R -65)
   (KRN C r R -45)
   (KRN C u R -43)
   (KRN O 32 R -69) (comment ae)
   (KRN O 34 R -66) (comment oslash)
   (KRN O 33 R -62) (comment oe)
   (STOP)
   (LABEL C G)
   (KRN C A R -15)
   (KRN C T R -14)
   (KRN C V R -5)
   (KRN C W R -3)
   (KRN C Y R -13)
   (KRN O 35 R -29) (comment AE)
   (STOP)
   (LABEL C J)
   (KRN C A R -20)
   (KRN O 35 R -54) (comment AE)
   (STOP)
   (LABEL C K)
   (KRN O 34 R -16) (comment oslash)
   (KRN O 37 R -44) (comment Oslash)
   (KRN O 55 R -42) (comment hyphen)
   (KRN C C R -45)
   (KRN C G R -38)
   (KRN C O R -44)
   (KRN C S R 6)
   (KRN C T R 19)
   (KRN C a R -5)
   (KRN C e R -18)
   (KRN C o R -16)
   (KRN C u R -9)
   (KRN C y R -63)
   (KRN O 32 R -5) (comment ae)
   (KRN O 36 R -42) (comment OE)
   (STOP)
   (LABEL C L)
   (KRN O 37 R 10) (comment Oslash)
   (KRN O 55 R 56) (comment hyphen)
   (KRN C A R 41)
   (KRN C C R 5)
   (KRN C G R 11)
   (KRN C O R 10)
   (KRN C S R 18)
   (KRN C T R -15)
   (KRN C U R -9)
   (KRN C V R -41)
   (KRN C W R -34)
   (KRN C Y R -21)
   (KRN C u R 22)
   (KRN C y R -15)
   (KRN O 35 R 29) (comment AE)
   (KRN O 47 R -78) (comment quoteright)
   (KRN O 42 R -78) (comment quotedblright)
   (STOP)
   (LABEL C N)
   (KRN O 37 R -2) (comment Oslash)
   (KRN O 54 R 1) (comment comma)
   (KRN O 56 R -4) (comment period)
   (KRN C A R -19)
   (KRN C C R -5)
   (KRN C G R 1)
   (KRN C O R -2)
   (KRN C a R -8)
   (KRN C e R -14)
   (KRN C o R -12)
   (KRN C u R -11)
   (KRN O 35 R -31) (comment AE)
   (KRN O 32 R -11) (comment ae)
   (KRN O 34 R -13) (comment oslash)
   (STOP)
   (LABEL C O)
   (KRN C A R -16)
   (KRN C T R -5)
   (KRN C V R -29)
   (KRN C W R -23)
   (KRN C X R -26)
   (KRN C Y R -34)
   (KRN O 35 R -53) (comment AE)
   (STOP)
   (LABEL C P)
   (KRN O 54 R -96) (comment comma)
   (KRN O 55 R -46) (comment hyphen)
   (KRN O 56 R -99) (comment period)
   (KRN C A R -62)
   (KRN C J R -72)
   (KRN C a R -54)
   (KRN C e R -61)
   (KRN C o R -54)
   (KRN O 35 R -98) (comment AE)
   (KRN O 32 R -67) (comment ae)
   (KRN O 34 R -44) (comment oslash)
   (KRN O 33 R -60) (comment oe)
   (STOP)
   (LABEL C R)
   (KRN O 34 R -14) (comment oslash)
   (KRN O 37 R -14) (comment Oslash)
   (KRN O 55 R -16) (comment hyphen)
   (KRN C C R -13)
   (KRN C G R -6)
   (KRN C O R -14)
   (KRN C T R -1)
   (KRN C U R -23)
   (KRN C V R -36)
   (KRN C W R -30)
   (KRN C Y R -19)
   (KRN C a R -4)
   (KRN C e R -16)
   (KRN C o R -14)
   (KRN C u R -7)
   (KRN C y R -1)
   (KRN O 32 R -3) (comment ae)
   (KRN O 36 R -5) (comment OE)
   (KRN O 33 R -15) (comment oe)
   (STOP)
   (LABEL C S)
   (KRN C A R -3)
   (KRN C V R 4)
   (KRN C W R 7)
   (KRN C Y R -2)
   (KRN C t R -1)
   (KRN O 35 R -15) (comment AE)
   (STOP)
   (LABEL C T)
   (KRN O 54 R -56) (comment comma)
   (KRN O 55 R -53) (comment hyphen)
   (KRN O 56 R -59) (comment period)
   (KRN O 72 R -53) (comment colon)
   (KRN O 73 R -41) (comment semicolon)
   (KRN C A R -33)
   (KRN C C R -13)
   (KRN C G R -4)
   (KRN C J R -38)
   (KRN C O R -20)
   (KRN C S R -1)
   (KRN C V R 39)
   (KRN C W R 41)
   (KRN C Y R 31)
   (KRN C a R -68)
   (KRN C c R -68)
   (KRN C e R -75)
   (KRN C g R -80)
   (KRN C i R -15)
   (KRN C j R -17)
   (KRN C o R -73)
   (KRN C r R -81)
   (KRN C s R -73)
   (KRN C u R -68)
   (KRN C v R -69)
   (KRN C w R -67)
   (KRN C y R -68)
   (KRN O 35 R -45) (comment AE)
   (KRN O 37 R -23) (comment Oslash)
   (KRN O 32 R -71) (comment ae)
   (KRN O 34 R -73) (comment oslash)
   (KRN O 36 R -6) (comment OE)
   (STOP)
   (LABEL C U)
   (KRN O 54 R -16) (comment comma)
   (KRN O 56 R -22) (comment period)
   (KRN C A R -38)
   (KRN C m R -18)
   (KRN C n R -19)
   (KRN C p R -23)
   (KRN C r R -34)
   (KRN O 35 R -68) (comment AE)
   (STOP)
   (LABEL C V)
   (KRN O 54 R -56) (comment comma)
   (KRN O 55 R -31) (comment hyphen)
   (KRN O 56 R -65) (comment period)
   (KRN O 72 R -34) (comment colon)
   (KRN O 73 R -22) (comment semicolon)
   (KRN C A R -52)
   (KRN C C R -29)
   (KRN C G R -22)
   (KRN C O R -31)
   (KRN C S R -17)
   (KRN C T R 30)
   (KRN C a R -51)
   (KRN C e R -57)
   (KRN C g R -75)
   (KRN C i R -18)
   (KRN C o R -55)
   (KRN C r R -41)
   (KRN C u R -37)
   (KRN C y R -16)
   (KRN O 35 R -83) (comment AE)
   (KRN O 37 R -31) (comment Oslash)
   (KRN O 32 R -53) (comment ae)
   (KRN O 34 R -56) (comment oslash)
   (STOP)
   (LABEL C W)
   (KRN O 54 R -40) (comment comma)
   (KRN O 55 R -18) (comment hyphen)
   (KRN O 56 R -44) (comment period)
   (KRN O 72 R -24) (comment colon)
   (KRN O 73 R -12) (comment semicolon)
   (KRN C A R -42)
   (KRN C C R -21)
   (KRN C G R -14)
   (KRN C O R -23)
   (KRN C S R -17)
   (KRN C T R 28)
   (KRN C a R -42)
   (KRN C e R -43)
   (KRN C g R -60)
   (KRN C i R -19)
   (KRN C o R -41)
   (KRN C r R -37)
   (KRN C u R -32)
   (KRN C y R -12)
   (KRN O 35 R -79) (comment AE)
   (KRN O 37 R -23) (comment Oslash)
   (KRN O 32 R -44) (comment ae)
   (KRN O 34 R -41) (comment oslash)
   (STOP)
   (LABEL C X)
   (KRN O 34 R -14) (comment oslash)
   (KRN O 37 R -32) (comment Oslash)
   (KRN O 55 R -27) (comment hyphen)
   (KRN C C R -35)
   (KRN C O R -32)
   (KRN C Q R -37)
   (KRN C a R -3)
   (KRN C e R -16)
   (KRN C o R -14)
   (KRN C u R -7)
   (KRN C y R -65)
   (STOP)
   (LABEL C Y)
   (KRN O 54 R -50) (comment comma)
   (KRN O 55 R -47) (comment hyphen)
   (KRN O 56 R -53) (comment period)
   (KRN O 72 R -40) (comment colon)
   (KRN O 73 R -29) (comment semicolon)
   (KRN C A R -27)
   (KRN C C R -34)
   (KRN C G R -27)
   (KRN C O R -36)
   (KRN C S R -15)
   (KRN C T R 30)
   (KRN C a R -56)
   (KRN C e R -63)
   (KRN C g R -82)
   (KRN C i R -16)
   (KRN C o R -61)
   (KRN C p R -53)
   (KRN C u R -53)
   (KRN C v R -31)
   (KRN O 35 R -38) (comment AE)
   (KRN O 37 R -36) (comment Oslash)
   (KRN O 32 R -59) (comment ae)
   (KRN O 34 R -62) (comment oslash)
   (STOP)
   (LABEL C Z)
   (KRN C w R 5)
   (KRN C y R -7)
   (STOP)
   (LABEL O 134) (comment quotedblleft)
   (KRN C A R -73)
   (KRN C T R -5)
   (KRN C V R -7)
   (KRN C W R -5)
   (KRN C Y R -21)
   (KRN O 35 R -121) (comment AE)
   (STOP)
   (LABEL O 140) (comment quoteleft)
   (LIG O 140 O 134)
   (KRN C A R -64)
   (KRN C T R 3)
   (KRN C V R 1)
   (KRN C W R 3)
   (KRN C Y R -12)
   (KRN O 35 R -112) (comment AE)
   (STOP)
   (LABEL C a)
   (KRN C j R -3)
   (KRN C w R 3)
   (KRN C y R 2)
   (KRN O 47 R -22) (comment quoteright)
   (STOP)
   (LABEL C b)
   (KRN C v R -7)
   (KRN C w R -5)
   (KRN C y R -2)
   (STOP)
   (LABEL C c)
   (KRN C h R -26)
   (KRN C k R -28)
   (STOP)
   (LABEL C e)
   (KRN C t R -15)
   (KRN C w R 2)
   (KRN C x R -12)
   (KRN C y R 3)
   (KRN O 47 R -16) (comment quoteright)
   (STOP)
   (LABEL C f)
   (LIG C f O 13)
   (LIG C l O 15)
   (LIG C i O 14)
   (KRN C a R -14)
   (KRN C e R -21)
   (KRN C j R 14)
   (KRN C o R -14)
   (KRN C s R -17)
   (KRN C t R 18)
   (KRN O 32 R -17) (comment ae)
   (KRN O 34 R -20) (comment oslash)
   (KRN O 33 R -10) (comment oe)
   (KRN O 47 R 17) (comment quoteright)
   (STOP)
   (LABEL C g)
   (KRN C a R -30)
   (KRN C e R -33)
   (KRN C l R -34)
   (KRN C r R -21)
   (KRN O 32 R -33) (comment ae)
   (STOP)
   (LABEL C h)
   (KRN C y R -4)
   (KRN O 47 R -26) (comment quoteright)
   (STOP)
   (LABEL C i)
   (KRN C T R -11)
   (KRN C j R -23)
   (STOP)
   (LABEL C k)
   (KRN O 34 R 6) (comment oslash)
   (KRN O 54 R 29) (comment comma)
   (KRN O 55 R -34) (comment hyphen)
   (KRN O 56 R 26) (comment period)
   (KRN C a R 12)
   (KRN C e R 4)
   (KRN C g R -27)
   (KRN C o R 6)
   (KRN C s R 6)
   (KRN C u R 8)
   (KRN O 32 R 9) (comment ae)
   (STOP)
   (LABEL C l)
   (KRN C v R -11)
   (KRN C y R -10)
   (STOP)
   (LABEL C m)
   (KRN C p R 3)
   (KRN C v R -6)
   (KRN C w R -4)
   (KRN C y R -3)
   (STOP)
   (LABEL C n)
   (KRN C T R -41)
   (KRN C v R -10)
   (KRN C w R -7)
   (KRN C y R -7)
   (KRN O 47 R -28) (comment quoteright)
   (STOP)
   (LABEL C o)
   (KRN C T R -50)
   (KRN C t R -5)
   (KRN C v R -14)
   (KRN C w R -12)
   (KRN C x R -27)
   (KRN C y R -8)
   (KRN O 47 R -19) (comment quoteright)
   (STOP)
   (LABEL C p)
   (KRN C t R -5)
   (KRN C y R -4)
   (STOP)
   (LABEL C q)
   (KRN C c R -2)
   (KRN C u R -2)
   (STOP)
   (LABEL C r)
   (KRN O 54 R -57) (comment comma)
   (KRN O 55 R -44) (comment hyphen)
   (KRN O 56 R -62) (comment period)
   (KRN O 72 R -25) (comment colon)
   (KRN O 73 R -19) (comment semicolon)
   (KRN C a R -28)
   (KRN C c R -25)
   (KRN C d R -29)
   (KRN C e R -31)
   (KRN C f R 22)
   (KRN C g R -24)
   (KRN C h R -17)
   (KRN C i R 8)
   (KRN C j R 3)
   (KRN C k R -16)
   (KRN C l R -21)
   (KRN C m R 17)
   (KRN C n R 16)
   (KRN C o R -28)
   (KRN C p R 11)
   (KRN C q R -29)
   (KRN C r R 3)
   (KRN C s R -17)
   (KRN C t R 12)
   (KRN C u R 11)
   (KRN C v R 29)
   (KRN C w R 31)
   (KRN C x R 7)
   (KRN C y R 31)
   (KRN C z R -1)
   (KRN O 32 R -34) (comment ae)
   (KRN O 34 R -29) (comment oslash)
   (KRN O 33 R -23) (comment oe)
   (STOP)
   (LABEL C s)
   (KRN C t R -6)
   (KRN O 47 R -13) (comment quoteright)
   (STOP)
   (LABEL C t)
   (KRN O 34 R -8) (comment oslash)
   (KRN O 72 R 5) (comment colon)
   (KRN O 73 R 17) (comment semicolon)
   (KRN C S R -2)
   (KRN C a R -3)
   (KRN C e R -10)
   (KRN C h R -4)
   (KRN C o R -8)
   (KRN O 32 R -9) (comment ae)
   (KRN O 47 R -10) (comment quoteright)
   (STOP)
   (LABEL C u)
   (KRN O 47 R -21) (comment quoteright)
   (STOP)
   (LABEL C v)
   (KRN O 54 R -38) (comment comma)
   (KRN O 55 R 4) (comment hyphen)
   (KRN O 56 R -40) (comment period)
   (KRN O 72 R -7) (comment colon)
   (KRN O 73 R 4) (comment semicolon)
   (KRN C a R -14)
   (KRN C c R -16)
   (KRN C e R -20)
   (KRN C g R -37)
   (KRN C l R -22)
   (KRN C o R -15)
   (KRN C s R -24)
   (KRN O 32 R -20) (comment ae)
   (KRN O 34 R -19) (comment oslash)
   (STOP)
   (LABEL C w)
   (KRN O 54 R -38) (comment comma)
   (KRN O 55 R 1) (comment hyphen)
   (KRN O 56 R -41) (comment period)
   (KRN O 72 R -8) (comment colon)
   (KRN C a R -18)
   (KRN C c R -17)
   (KRN C e R -21)
   (KRN C g R -37)
   (KRN C l R -22)
   (KRN C o R -19)
   (KRN C s R -25)
   (KRN O 32 R -21) (comment ae)
   (KRN O 34 R -19) (comment oslash)
   (STOP)
   (LABEL C x)
   (KRN O 34 R -1) (comment oslash)
   (KRN C a R 4)
   (KRN C c R -3)
   (KRN C e R -3)
   (KRN C o R -1)
   (STOP)
   (LABEL C y)
   (KRN O 54 R -12) (comment comma)
   (KRN O 55 R 14) (comment hyphen)
   (KRN O 56 R -16) (comment period)
   (KRN O 72 R 5) (comment colon)
   (KRN O 73 R 12) (comment semicolon)
   (KRN C a R -3)
   (KRN C c R -3)
   (KRN C e R -7)
   (KRN C g R -24)
   (KRN C l R -9)
   (KRN C o R -5)
   (KRN C s R -13)
   (KRN O 32 R -6) (comment ae)
   (KRN O 34 R -5) (comment oslash)
   (STOP)
   (LABEL O 173) (comment endash)
   (LIG O 55 O 174)
   (STOP)
   )
(CHARACTER O 0 (comment uni0393)
   (CHARWD R 611)
   (CHARHT R 653)
   (CHARIC R 34)
   )
(CHARACTER O 1 (comment uni0394)
   (CHARWD R 611)
   (CHARHT R 668)
   )
(CHARACTER O 2 (comment uni0398)
   (CHARWD R 722)
   (CHARHT R 667)
   (CHARDP R 18)
   )
(CHARACTER O 3 (comment uni039B)
   (CHARWD R 611)
   (CHARHT R 668)
   )
(CHARACTER O 4 (comment uni039E)
   (CHARWD R 651)
   (CHARHT R 653)
   (CHARIC R 29)
   )
(CHARACTER O 5 (comment uni03A0)
   (CHARWD R 722)
   (CHARHT R 653)
   (CHARIC R 47)
   )
(CHARACTER O 6 (comment uni03A3)
   (CHARWD R 620)
   (CHARHT R 653)
   (CHARIC R 39)
   )
(CHARACTER O 7 (comment uni03A5)
   (CHARWD R 556)
   (CHARHT R 668)
   (CHARIC R 92)
   )
(CHARACTER O 10 (comment uni03A6)
   (CHARWD R 741)
   (CHARHT R 653)
   )
(CHARACTER O 11 (comment uni03A8)
   (CHARWD R 675)
   (CHARHT R 667)
   (CHARIC R 103)
   )
(CHARACTER O 12 (comment uni03A9)
   (CHARWD R 762)
   (CHARHT R 666)
   )
(CHARACTER O 13 (comment ff)
   (CHARWD R 527)
   (CHARHT R 678)
   (CHARDP R 207)
   (CHARIC R 146)
   )
(CHARACTER O 14 (comment fi)
   (CHARWD R 500)
   (CHARHT R 681)
   (CHARDP R 207)
   )
(CHARACTER O 15 (comment fl)
   (CHARWD R 500)
   (CHARHT R 682)
   (CHARDP R 204)
   (CHARIC R 18)
   )
(CHARACTER O 16 (comment ffi)
   (CHARWD R 744)
   (CHARHT R 681)
   (CHARDP R 207)
   )
(CHARACTER O 17 (comment ffl)
   (CHARWD R 745)
   (CHARHT R 682)
   (CHARDP R 207)
   (CHARIC R 18)
   )
(CHARACTER O 20 (comment dotlessi)
   (CHARWD R 278)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER O 21 (comment uni0237)
   (CHARWD R 278)
   (CHARHT R 441)
   (CHARDP R 207)
   )
(CHARACTER O 22 (comment grave)
   (CHARWD R 333)
   (CHARHT R 664)
   )
(CHARACTER O 23 (comment acute)
   (CHARWD R 333)
   (CHARHT R 664)
   (CHARIC R 70)
   )
(CHARACTER O 24 (comment caron)
   (CHARWD R 333)
   (CHARHT R 661)
   (CHARIC R 93)
   )
(CHARACTER O 25 (comment breve)
   (CHARWD R 333)
   (CHARHT R 650)
   (CHARIC R 85)
   )
(CHARACTER O 26 (comment macron)
   (CHARWD R 333)
   (CHARHT R 583)
   (CHARIC R 78)
   )
(CHARACTER O 27 (comment ring)
   (CHARWD R 333)
   (CHARHT R 707)
   (CHARIC R 22)
   )
(CHARACTER O 30 (comment cedilla)
   (CHARWD R 333)
   (CHARDP R 217)
   )
(CHARACTER O 31 (comment germandbls)
   (CHARWD R 500)
   (CHARHT R 679)
   (CHARDP R 207)
   )
(CHARACTER O 32 (comment ae)
   (CHARWD R 667)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER O 33 (comment oe)
   (CHARWD R 667)
   (CHARHT R 441)
   (CHARDP R 12)
   )
(CHARACTER O 34 (comment oslash)
   (CHARWD R 500)
   (CHARHT R 554)
   (CHARDP R 135)
   )
(CHARACTER O 35 (comment AE)
   (CHARWD R 889)
   (CHARHT R 653)
   (CHARIC R 22)
   )
(CHARACTER O 36 (comment OE)
   (CHARWD R 944)
   (CHARHT R 666)
   (CHARDP R 8)
   (CHARIC R 20)
   )
(CHARACTER O 37 (comment Oslash)
   (CHARWD R 722)
   (CHARHT R 722)
   (CHARDP R 105)
   )
(CHARACTER O 40 (comment space)
   (CHARWD R 250)
   )
(CHARACTER O 41 (comment exclam)
   (CHARWD R 333)
   (CHARHT R 667)
   (CHARDP R 11)
   )
(CHARACTER O 42 (comment quotedblright)
   (CHARWD R 556)
   (CHARHT R 666)
   )
(CHARACTER O 43 (comment numbersign)
   (CHARWD R 501)
   (CHARHT R 676)
   (CHARIC R 39)
   )
(CHARACTER O 44 (comment dollar)
   (CHARWD R 500)
   (CHARHT R 731)
   (CHARDP R 89)
   )
(CHARACTER O 45 (comment percent)
   (CHARWD R 755)
   (CHARHT R 706)
   (CHARDP R 19)
   )
(CHARACTER O 46 (comment ampersand)
   (CHARWD R 778)
   (CHARHT R 666)
   (CHARDP R 18)
   )
(CHARACTER O 47 (comment quoteright)
   (CHARWD R 333)
   (CHARHT R 666)
   )
(CHARACTER O 50 (comment parenleft)
   (CHARWD R 333)
   (CHARHT R 669)
   (CHARDP R 181)
   )
(CHARACTER O 51 (comment parenright)
   (CHARWD R 333)
   (CHARHT R 669)
   (CHARDP R 180)
   )
(CHARACTER O 52 (comment asterisk)
   (CHARWD R 500)
   (CHARHT R 666)
   )
(CHARACTER O 53 (comment plus)
   (CHARWD R 675)
   (CHARHT R 506)
   )
(CHARACTER O 54 (comment comma)
   (CHARWD R 250)
   (CHARHT R 101)
   (CHARDP R 129)
   )
(CHARACTER O 55 (comment hyphen)
   (CHARWD R 333)
   (CHARHT R 255)
   )
(CHARACTER O 56 (comment period)
   (CHARWD R 250)
   (CHARHT R 100)
   (CHARDP R 11)
   )
(CHARACTER O 57 (comment slash)
   (CHARWD R 278)
   (CHARHT R 666)
   (CHARDP R 18)
   (CHARIC R 108)
   )
(CHARACTER C 0
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 7)
   )
(CHARACTER C 1
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER C 2
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER C 3
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 7)
   )
(CHARACTER C 4
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER C 5
   (CHARWD R 500)
   (CHARHT R 666)
   (CHARDP R 7)
   )
(CHARACTER C 6
   (CHARWD R 500)
   (CHARHT R 686)
   (CHARDP R 7)
   (CHARIC R 21)
   )
(CHARACTER C 7
   (CHARWD R 500)
   (CHARHT R 666)
   (CHARDP R 8)
   (CHARIC R 37)
   )
(CHARACTER C 8
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 7)
   )
(CHARACTER C 9
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 17)
   )
(CHARACTER O 72 (comment colon)
   (CHARWD R 333)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER O 73 (comment semicolon)
   (CHARWD R 333)
   (CHARHT R 441)
   (CHARDP R 129)
   )
(CHARACTER O 74 (comment exclamdown)
   (CHARWD R 389)
   (CHARHT R 474)
   (CHARDP R 205)
   )
(CHARACTER O 75 (comment equal)
   (CHARWD R 675)
   (CHARHT R 386)
   )
(CHARACTER O 76 (comment questiondown)
   (CHARWD R 500)
   (CHARHT R 473)
   (CHARDP R 205)
   )
(CHARACTER O 77 (comment question)
   (CHARWD R 500)
   (CHARHT R 664)
   (CHARDP R 12)
   )
(CHARACTER O 100 (comment at)
   (CHARWD R 920)
   (CHARHT R 666)
   (CHARDP R 18)
   )
(CHARACTER C A
   (CHARWD R 611)
   (CHARHT R 668)
   )
(CHARACTER C B
   (CHARWD R 611)
   (CHARHT R 653)
   )
(CHARACTER C C
   (CHARWD R 667)
   (CHARHT R 666)
   (CHARDP R 18)
   (CHARIC R 22)
   )
(CHARACTER C D
   (CHARWD R 722)
   (CHARHT R 653)
   )
(CHARACTER C E
   (CHARWD R 611)
   (CHARHT R 653)
   (CHARIC R 23)
   )
(CHARACTER C F
   (CHARWD R 611)
   (CHARHT R 653)
   (CHARIC R 34)
   )
(CHARACTER C G
   (CHARWD R 722)
   (CHARHT R 666)
   (CHARDP R 18)
   )
(CHARACTER C H
   (CHARWD R 722)
   (CHARHT R 653)
   (CHARIC R 47)
   )
(CHARACTER C I
   (CHARWD R 333)
   (CHARHT R 653)
   (CHARIC R 51)
   )
(CHARACTER C J
   (CHARWD R 444)
   (CHARHT R 653)
   (CHARDP R 18)
   (CHARIC R 47)
   )
(CHARACTER C K
   (CHARWD R 667)
   (CHARHT R 653)
   (CHARIC R 55)
   )
(CHARACTER C L
   (CHARWD R 556)
   (CHARHT R 653)
   (CHARIC R 3)
   )
(CHARACTER C M
   (CHARWD R 833)
   (CHARHT R 653)
   (CHARIC R 39)
   )
(CHARACTER C N
   (CHARWD R 667)
   (CHARHT R 653)
   (CHARDP R 15)
   (CHARIC R 60)
   )
(CHARACTER C O
   (CHARWD R 722)
   (CHARHT R 667)
   (CHARDP R 18)
   )
(CHARACTER C P
   (CHARWD R 611)
   (CHARHT R 653)
   )
(CHARACTER C Q
   (CHARWD R 722)
   (CHARHT R 666)
   (CHARDP R 182)
   )
(CHARACTER C R
   (CHARWD R 611)
   (CHARHT R 653)
   )
(CHARACTER C S
   (CHARWD R 500)
   (CHARHT R 667)
   (CHARDP R 18)
   (CHARIC R 8)
   )
(CHARACTER C T
   (CHARWD R 556)
   (CHARHT R 653)
   (CHARIC R 77)
   )
(CHARACTER C U
   (CHARWD R 722)
   (CHARHT R 653)
   (CHARDP R 18)
   (CHARIC R 43)
   )
(CHARACTER C V
   (CHARWD R 611)
   (CHARHT R 653)
   (CHARDP R 18)
   (CHARIC R 77)
   )
(CHARACTER C W
   (CHARWD R 833)
   (CHARHT R 653)
   (CHARDP R 18)
   (CHARIC R 73)
   )
(CHARACTER C X
   (CHARWD R 611)
   (CHARHT R 653)
   (CHARIC R 44)
   )
(CHARACTER C Y
   (CHARWD R 556)
   (CHARHT R 653)
   (CHARIC R 77)
   )
(CHARACTER C Z
   (CHARWD R 556)
   (CHARHT R 653)
   (CHARIC R 50)
   )
(CHARACTER O 133 (comment bracketleft)
   (CHARWD R 389)
   (CHARHT R 663)
   (CHARDP R 153)
   (CHARIC R 2)
   )
(CHARACTER O 134 (comment quotedblleft)
   (CHARWD R 556)
   (CHARHT R 666)
   )
(CHARACTER O 135 (comment bracketright)
   (CHARWD R 389)
   (CHARHT R 663)
   (CHARDP R 153)
   )
(CHARACTER O 136 (comment circumflex)
   (CHARWD R 333)
   (CHARHT R 661)
   (CHARIC R 52)
   )
(CHARACTER O 137 (comment dotaccent)
   (CHARWD R 333)
   (CHARHT R 606)
   )
(CHARACTER O 140 (comment quoteleft)
   (CHARWD R 333)
   (CHARHT R 666)
   )
(CHARACTER C a
   (CHARWD R 501)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER C b
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 11)
   )
(CHARACTER C c
   (CHARWD R 444)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER C d
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 13)
   (CHARIC R 27)
   )
(CHARACTER C e
   (CHARWD R 444)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER C f
   (CHARWD R 278)
   (CHARHT R 678)
   (CHARDP R 207)
   (CHARIC R 146)
   )
(CHARACTER C g
   (CHARWD R 500)
   (CHARHT R 441)
   (CHARDP R 206)
   )
(CHARACTER C h
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 9)
   )
(CHARACTER C i
   (CHARWD R 278)
   (CHARHT R 654)
   (CHARDP R 11)
   )
(CHARACTER C j
   (CHARWD R 278)
   (CHARHT R 652)
   (CHARDP R 207)
   (CHARIC R 1)
   )
(CHARACTER C k
   (CHARWD R 444)
   (CHARHT R 683)
   (CHARDP R 11)
   (CHARIC R 17)
   )
(CHARACTER C l
   (CHARWD R 278)
   (CHARHT R 683)
   (CHARDP R 11)
   (CHARIC R 1)
   )
(CHARACTER C m
   (CHARWD R 722)
   (CHARHT R 441)
   (CHARDP R 9)
   )
(CHARACTER C n
   (CHARWD R 500)
   (CHARHT R 441)
   (CHARDP R 9)
   )
(CHARACTER C o
   (CHARWD R 500)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER C p
   (CHARWD R 504)
   (CHARHT R 441)
   (CHARDP R 205)
   )
(CHARACTER C q
   (CHARWD R 500)
   (CHARHT R 441)
   (CHARDP R 209)
   )
(CHARACTER C r
   (CHARWD R 389)
   (CHARHT R 441)
   (CHARIC R 23)
   )
(CHARACTER C s
   (CHARWD R 389)
   (CHARHT R 442)
   (CHARDP R 13)
   )
(CHARACTER C t
   (CHARWD R 278)
   (CHARHT R 546)
   (CHARDP R 11)
   (CHARIC R 18)
   )
(CHARACTER C u
   (CHARWD R 500)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER C v
   (CHARWD R 444)
   (CHARHT R 441)
   (CHARDP R 18)
   )
(CHARACTER C w
   (CHARWD R 667)
   (CHARHT R 441)
   (CHARDP R 18)
   )
(CHARACTER C x
   (CHARWD R 444)
   (CHARHT R 441)
   (CHARDP R 11)
   (CHARIC R 3)
   )
(CHARACTER C y
   (CHARWD R 444)
   (CHARHT R 441)
   (CHARDP R 206)
   )
(CHARACTER C z
   (CHARWD R 389)
   (CHARHT R 428)
   (CHARDP R 81)
   )
(CHARACTER O 173 (comment endash)
   (CHARWD R 500)
   (CHARHT R 243)
   (CHARIC R 5)
   )
(CHARACTER O 174 (comment emdash)
   (CHARWD R 889)
   (CHARHT R 243)
   (CHARIC R 5)
   )
(CHARACTER O 175 (comment hungarumlaut)
   (CHARWD R 333)
   (CHARHT R 664)
   (CHARIC R 153)
   )
(CHARACTER O 176 (comment tilde)
   (CHARWD R 333)
   (CHARHT R 624)
   (CHARIC R 94)
   )
(CHARACTER O 177 (comment dieresis)
   (CHARWD R 333)
   (CHARHT R 606)
   (CHARIC R 72)
   )
