(FAMILY STIXMath)
(CODINGSCHEME STIXMATHRMBOLD)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   )
(LIGTABLE
   (LABEL O 0) (comment u1D6AA)
   (KRN O 177 R -0.006) (comment quoteright)
   (STOP)
   (LABEL O 1) (comment u1D6AB)
   (KRN O 177 R -0.0195) (comment quoteright)
   (STOP)
   (LABEL O 2) (comment u1D6AF)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 3) (comment u1D6B2)
   (KRN O 177 R -0.0175) (comment quoteright)
   (STOP)
   (LABEL O 4) (comment u1D6B5)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 5) (comment u1D6B7)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 6) (comment u1D6BA)
   (KRN O 177 R -0.0125) (comment quoteright)
   (STOP)
   (LABEL O 7) (comment u1D6BC)
   (KRN O 177 R 0.042) (comment quoteright)
   (STOP)
   (LABEL O 10) (comment u1D6BD)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 11) (comment u1D6BF)
   (KRN O 177 R -0.006) (comment quoteright)
   (STOP)
   (LABEL O 12) (comment u1D6C0)
   (KRN O 177 R -0.01) (comment quoteright)
   (STOP)
   (LABEL O 13) (comment u1D6C2)
   (KRN O 177 R -0.066) (comment quoteright)
   (STOP)
   (LABEL O 14) (comment u1D6C3)
   (KRN O 177 R 0.006) (comment quoteright)
   (STOP)
   (LABEL O 15) (comment u1D6C4)
   (KRN O 177 R -0.003) (comment quoteright)
   (STOP)
   (LABEL O 16) (comment u1D6C5)
   (KRN O 177 R 0.001) (comment quoteright)
   (STOP)
   (LABEL O 17) (comment u1D6DC)
   (KRN O 177 R 0.006) (comment quoteright)
   (STOP)
   (LABEL O 20) (comment u1D6C7)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 21) (comment u1D6C8)
   (KRN O 177 R -0.012) (comment quoteright)
   (STOP)
   (LABEL O 22) (comment u1D6C9)
   (KRN O 177 R -0.0005) (comment quoteright)
   (STOP)
   (LABEL O 23) (comment u1D6CA)
   (KRN O 177 R -0.027) (comment quoteright)
   (STOP)
   (LABEL O 24) (comment u1D6CB)
   (KRN O 177 R -0.0005) (comment quoteright)
   (STOP)
   (LABEL O 25) (comment u1D6CC)
   (KRN O 177 R -0.132) (comment quoteright)
   (STOP)
   (LABEL O 26) (comment u1D6CD)
   (KRN O 177 R -0.023) (comment quoteright)
   (STOP)
   (LABEL O 27) (comment u1D6CE)
   (KRN O 177 R -0.004) (comment quoteright)
   (STOP)
   (LABEL O 30) (comment u1D6CF)
   (KRN O 177 R -0.0015) (comment quoteright)
   (STOP)
   (LABEL O 31) (comment u1D6D1)
   (KRN O 177 R -0.0015) (comment quoteright)
   (STOP)
   (LABEL O 32) (comment u1D6D2)
   (KRN O 177 R 0.0065) (comment quoteright)
   (STOP)
   (LABEL O 33) (comment u1D6D4)
   (KRN O 177 R -0.007) (comment quoteright)
   (STOP)
   (LABEL O 34) (comment u1D6D5)
   (KRN O 177 R -0.008) (comment quoteright)
   (STOP)
   (LABEL O 35) (comment u1D6D6)
   (KRN O 177 R -0.006) (comment quoteright)
   (STOP)
   (LABEL O 36) (comment u1D6DF)
   (KRN O 177 R -0.0005) (comment quoteright)
   (STOP)
   (LABEL O 37) (comment u1D6D8)
   (KRN O 177 R -0.002) (comment quoteright)
   (STOP)
   (LABEL O 40) (comment u1D6D9)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 41) (comment u1D6DA)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 42) (comment u1D6C6)
   (KRN O 177 R 0.006) (comment quoteright)
   (STOP)
   (LABEL O 43) (comment u1D6DD)
   (KRN O 177 R -0.0075) (comment quoteright)
   (STOP)
   (LABEL O 44) (comment u1D6E1)
   (KRN O 177 R 0.044) (comment quoteright)
   (STOP)
   (LABEL O 45) (comment u1D6E0)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 46) (comment u1D6D3)
   (KRN O 177 R 0.002) (comment quoteright)
   (STOP)
   (LABEL O 47) (comment u1D6D7)
   (KRN O 177 R -0.0005) (comment quoteright)
   (STOP)
   (LABEL O 51) (comment u1D6DB)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 101) (comment u1D400)
   (KRN O 177 R -0.016) (comment quoteright)
   (STOP)
   (LABEL O 102) (comment u1D401)
   (KRN O 177 R -0.0155) (comment quoteright)
   (STOP)
   (LABEL O 103) (comment u1D402)
   (KRN O 177 R 0.007) (comment quoteright)
   (STOP)
   (LABEL O 104) (comment u1D403)
   (KRN O 177 R -0.009) (comment quoteright)
   (STOP)
   (LABEL O 105) (comment u1D404)
   (KRN O 177 R -0.0055) (comment quoteright)
   (STOP)
   (LABEL O 106) (comment u1D405)
   (KRN O 177 R -0.0055) (comment quoteright)
   (STOP)
   (LABEL O 107) (comment u1D406)
   (KRN O 177 R 0.007) (comment quoteright)
   (STOP)
   (LABEL O 110) (comment u1D407)
   (KRN O 177 R 0.001) (comment quoteright)
   (STOP)
   (LABEL O 111) (comment u1D408)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 112) (comment u1D409)
   (KRN O 177 R 0.06) (comment quoteright)
   (STOP)
   (LABEL O 113) (comment u1D40A)
   (KRN O 177 R 0.021) (comment quoteright)
   (STOP)
   (LABEL O 114) (comment u1D40B)
   (KRN O 177 R -0.1415) (comment quoteright)
   (STOP)
   (LABEL O 115) (comment u1D40C)
   (KRN O 177 R -0.004) (comment quoteright)
   (STOP)
   (LABEL O 116) (comment u1D40D)
   (KRN O 177 R -0.003) (comment quoteright)
   (STOP)
   (LABEL O 117) (comment u1D40E)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 120) (comment u1D40F)
   (KRN O 177 R 0.0025) (comment quoteright)
   (STOP)
   (LABEL O 121) (comment u1D410)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 122) (comment u1D411)
   (KRN O 177 R -0.038) (comment quoteright)
   (STOP)
   (LABEL O 123) (comment u1D412)
   (KRN O 177 R -0.004) (comment quoteright)
   (STOP)
   (LABEL O 124) (comment u1D413)
   (KRN O 177 R 0.0005) (comment quoteright)
   (STOP)
   (LABEL O 125) (comment u1D414)
   (KRN O 177 R 0.059) (comment quoteright)
   (STOP)
   (LABEL O 126) (comment u1D415)
   (KRN O 177 R 0.063) (comment quoteright)
   (STOP)
   (LABEL O 127) (comment u1D416)
   (KRN O 177 R 0.04) (comment quoteright)
   (STOP)
   (LABEL O 130) (comment u1D417)
   (KRN O 177 R 0.041) (comment quoteright)
   (STOP)
   (LABEL O 131) (comment u1D418)
   (KRN O 177 R 0.054) (comment quoteright)
   (STOP)
   (LABEL O 132) (comment u1D419)
   (KRN O 177 R -0.0025) (comment quoteright)
   (STOP)
   (LABEL O 141) (comment u1D41A)
   (KRN O 177 R 0.006) (comment quoteright)
   (STOP)
   (LABEL O 142) (comment u1D41B)
   (KRN O 177 R -0.139) (comment quoteright)
   (STOP)
   (LABEL O 143) (comment u1D41C)
   (KRN O 177 R 0.039) (comment quoteright)
   (STOP)
   (LABEL O 144) (comment u1D41D)
   (KRN O 177 R 0.122) (comment quoteright)
   (STOP)
   (LABEL O 145) (comment u1D41E)
   (KRN O 177 R 0.013) (comment quoteright)
   (STOP)
   (LABEL O 146) (comment u1D41F)
   (KRN O 177 R 0.0295) (comment quoteright)
   (STOP)
   (LABEL O 147) (comment u1D420)
   (KRN O 177 R -0.01) (comment quoteright)
   (STOP)
   (LABEL O 150) (comment u1D421)
   (KRN O 177 R -0.148) (comment quoteright)
   (STOP)
   (LABEL O 151) (comment u1D422)
   (KRN O 177 R -0.003) (comment quoteright)
   (STOP)
   (LABEL O 152) (comment u1D423)
   (KRN O 177 R 0.0225) (comment quoteright)
   (STOP)
   (LABEL O 153) (comment u1D424)
   (KRN O 177 R -0.138) (comment quoteright)
   (STOP)
   (LABEL O 154) (comment u1D425)
   (KRN O 177 R -0.003) (comment quoteright)
   (STOP)
   (LABEL O 155) (comment u1D426)
   (KRN O 177 R -0.0025) (comment quoteright)
   (STOP)
   (LABEL O 156) (comment u1D427)
   (KRN O 177 R 0.002) (comment quoteright)
   (STOP)
   (LABEL O 157) (comment u1D428)
   (KRN O 177 R 0) (comment quoteright)
   (STOP)
   (LABEL O 160) (comment u1D429)
   (KRN O 177 R -0.006) (comment quoteright)
   (STOP)
   (LABEL O 161) (comment u1D42A)
   (KRN O 177 R 0.007) (comment quoteright)
   (STOP)
   (LABEL O 162) (comment u1D42B)
   (KRN O 177 R -0.021) (comment quoteright)
   (STOP)
   (LABEL O 163) (comment u1D42C)
   (KRN O 177 R -0.0015) (comment quoteright)
   (STOP)
   (LABEL O 164) (comment u1D42D)
   (KRN O 177 R -0.0205) (comment quoteright)
   (STOP)
   (LABEL O 165) (comment u1D42E)
   (KRN O 177 R -0.029) (comment quoteright)
   (STOP)
   (LABEL O 166) (comment u1D42F)
   (KRN O 177 R 0.038) (comment quoteright)
   (STOP)
   (LABEL O 167) (comment u1D430)
   (KRN O 177 R 0.046) (comment quoteright)
   (STOP)
   (LABEL O 170) (comment u1D431)
   (KRN O 177 R 0.002) (comment quoteright)
   (STOP)
   (LABEL O 171) (comment u1D432)
   (KRN O 177 R 0.005) (comment quoteright)
   (STOP)
   (LABEL O 172) (comment u1D433)
   (KRN O 177 R -0.012) (comment quoteright)
   (STOP)
   (LABEL O 173) (comment dotlessi)
   (KRN O 177 R -0.005) (comment quoteright)
   (STOP)
   (LABEL O 174) (comment uni0237)
   (KRN O 177 R -0.0165) (comment quoteright)
   (STOP)
   )
(CHARACTER O 0 (comment u1D6AA)
   (CHARWD R 0.62)
   (CHARHT R 0.676)
   )
(CHARACTER O 1 (comment u1D6AB)
   (CHARWD R 0.691)
   (CHARHT R 0.69)
   )
(CHARACTER O 2 (comment u1D6AF)
   (CHARWD R 0.778)
   (CHARHT R 0.692)
   (CHARDP R 0.018)
   )
(CHARACTER O 3 (comment u1D6B2)
   (CHARWD R 0.707)
   (CHARHT R 0.69)
   )
(CHARACTER O 4 (comment u1D6B5)
   (CHARWD R 0.623)
   (CHARHT R 0.676)
   )
(CHARACTER O 5 (comment u1D6B7)
   (CHARWD R 0.78)
   (CHARHT R 0.676)
   )
(CHARACTER O 6 (comment u1D6BA)
   (CHARWD R 0.665)
   (CHARHT R 0.676)
   )
(CHARACTER O 7 (comment u1D6BC)
   (CHARWD R 0.722)
   (CHARHT R 0.692)
   )
(CHARACTER O 10 (comment u1D6BD)
   (CHARWD R 0.836)
   (CHARHT R 0.676)
   )
(CHARACTER O 11 (comment u1D6BF)
   (CHARWD R 0.8)
   (CHARHT R 0.692)
   )
(CHARACTER O 12 (comment u1D6C0)
   (CHARWD R 0.778)
   (CHARHT R 0.692)
   )
(CHARACTER O 13 (comment u1D6C2)
   (CHARWD R 0.644)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 14 (comment u1D6C3)
   (CHARWD R 0.556)
   (CHARHT R 0.692)
   (CHARDP R 0.205)
   )
(CHARACTER O 15 (comment u1D6C4)
   (CHARWD R 0.518)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 16 (comment u1D6C5)
   (CHARWD R 0.502)
   (CHARHT R 0.692)
   (CHARDP R 0.014)
   )
(CHARACTER O 17 (comment u1D6DC)
   (CHARWD R 0.444)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 20 (comment u1D6C7)
   (CHARWD R 0.459)
   (CHARHT R 0.692)
   (CHARDP R 0.205)
   )
(CHARACTER O 21 (comment u1D6C8)
   (CHARWD R 0.58)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 22 (comment u1D6C9)
   (CHARWD R 0.501)
   (CHARHT R 0.692)
   (CHARDP R 0.014)
   )
(CHARACTER O 23 (comment u1D6CA)
   (CHARWD R 0.326)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 24 (comment u1D6CB)
   (CHARWD R 0.581)
   (CHARHT R 0.473)
   )
(CHARACTER O 25 (comment u1D6CC)
   (CHARWD R 0.546)
   (CHARHT R 0.692)
   (CHARDP R 0.018)
   )
(CHARACTER O 26 (comment u1D6CD)
   (CHARWD R 0.61)
   (CHARHT R 0.461)
   (CHARDP R 0.205)
   )
(CHARACTER O 27 (comment u1D6CE)
   (CHARWD R 0.518)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 30 (comment u1D6CF)
   (CHARWD R 0.465)
   (CHARHT R 0.692)
   (CHARDP R 0.205)
   )
(CHARACTER O 31 (comment u1D6D1)
   (CHARWD R 0.631)
   (CHARHT R 0.461)
   (CHARDP R 0.018)
   )
(CHARACTER O 32 (comment u1D6D2)
   (CHARWD R 0.547)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 33 (comment u1D6D4)
   (CHARWD R 0.568)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 34 (comment u1D6D5)
   (CHARWD R 0.492)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 35 (comment u1D6D6)
   (CHARWD R 0.576)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 36 (comment u1D6DF)
   (CHARWD R 0.653)
   (CHARHT R 0.676)
   (CHARDP R 0.205)
   )
(CHARACTER O 37 (comment u1D6D8)
   (CHARWD R 0.612)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 40 (comment u1D6D9)
   (CHARWD R 0.763)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 41 (comment u1D6DA)
   (CHARWD R 0.734)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 42 (comment u1D6C6)
   (CHARWD R 0.444)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 43 (comment u1D6DD)
   (CHARWD R 0.647)
   (CHARHT R 0.692)
   (CHARDP R 0.014)
   )
(CHARACTER O 44 (comment u1D6E1)
   (CHARWD R 0.864)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 45 (comment u1D6E0)
   (CHARWD R 0.511)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 46 (comment u1D6D3)
   (CHARWD R 0.464)
   (CHARHT R 0.473)
   (CHARDP R 0.203)
   )
(CHARACTER O 47 (comment u1D6D7)
   (CHARWD R 0.653)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 50 (comment u1D6C1)
   (CHARWD R 0.691)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 51 (comment u1D6DB)
   (CHARWD R 0.515)
   (CHARHT R 0.707)
   (CHARDP R 0.014)
   )
(CHARACTER O 52 (comment minus)
   (CHARWD R 0.75)
   (CHARHT R 0.297)
   )
(CHARACTER O 53 (comment plus)
   (CHARWD R 0.75)
   (CHARHT R 0.563)
   (CHARDP R 0.057)
   )
(CHARACTER O 54 (comment plusminus)
   (CHARWD R 0.77)
   (CHARHT R 0.518)
   (CHARDP R 0.151)
   )
(CHARACTER O 55 (comment uni2213)
   (CHARWD R 0.77)
   (CHARHT R 0.657)
   (CHARDP R 0.012)
   )
(CHARACTER O 56 (comment parenleft)
   (CHARWD R 0.333)
   (CHARHT R 0.694)
   (CHARDP R 0.168)
   )
(CHARACTER O 57 (comment parenright)
   (CHARWD R 0.333)
   (CHARHT R 0.694)
   (CHARDP R 0.168)
   )
(CHARACTER O 60 (comment u1D7CE)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 61 (comment u1D7CF)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   )
(CHARACTER O 62 (comment u1D7D0)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   )
(CHARACTER O 63 (comment u1D7D1)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.014)
   )
(CHARACTER O 64 (comment u1D7D2)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   )
(CHARACTER O 65 (comment u1D7D3)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.008)
   )
(CHARACTER O 66 (comment u1D7D4)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 67 (comment u1D7D5)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 70 (comment u1D7D6)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 71 (comment u1D7D7)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 72 (comment uni2236)
   (CHARWD R 0.554)
   (CHARHT R 0.575)
   (CHARDP R 0.041)
   )
(CHARACTER O 73 (comment semicolon)
   (CHARWD R 0.333)
   (CHARHT R 0.472)
   (CHARDP R 0.18)
   )
(CHARACTER O 74 (comment uni2217)
   (CHARWD R 0.585)
   (CHARHT R 0.502)
   )
(CHARACTER O 75 (comment equal)
   (CHARWD R 0.75)
   (CHARHT R 0.399)
   )
(CHARACTER O 76 (comment dollar)
   (CHARWD R 0.5)
   (CHARHT R 0.75)
   (CHARDP R 0.099)
   )
(CHARACTER O 77 (comment question)
   (CHARWD R 0.5)
   (CHARHT R 0.689)
   (CHARDP R 0.013)
   )
(CHARACTER O 100 (comment exclam)
   (CHARWD R 0.333)
   (CHARHT R 0.691)
   (CHARDP R 0.013)
   )
(CHARACTER O 101 (comment u1D400)
   (CHARWD R 0.722)
   (CHARHT R 0.69)
   )
(CHARACTER O 102 (comment u1D401)
   (CHARWD R 0.667)
   (CHARHT R 0.676)
   )
(CHARACTER O 103 (comment u1D402)
   (CHARWD R 0.722)
   (CHARHT R 0.691)
   (CHARDP R 0.019)
   )
(CHARACTER O 104 (comment u1D403)
   (CHARWD R 0.722)
   (CHARHT R 0.676)
   )
(CHARACTER O 105 (comment u1D404)
   (CHARWD R 0.667)
   (CHARHT R 0.676)
   )
(CHARACTER O 106 (comment u1D405)
   (CHARWD R 0.611)
   (CHARHT R 0.676)
   )
(CHARACTER O 107 (comment u1D406)
   (CHARWD R 0.778)
   (CHARHT R 0.691)
   (CHARDP R 0.019)
   )
(CHARACTER O 110 (comment u1D407)
   (CHARWD R 0.778)
   (CHARHT R 0.676)
   )
(CHARACTER O 111 (comment u1D408)
   (CHARWD R 0.389)
   (CHARHT R 0.676)
   )
(CHARACTER O 112 (comment u1D409)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.096)
   )
(CHARACTER O 113 (comment u1D40A)
   (CHARWD R 0.778)
   (CHARHT R 0.676)
   )
(CHARACTER O 114 (comment u1D40B)
   (CHARWD R 0.667)
   (CHARHT R 0.676)
   )
(CHARACTER O 115 (comment u1D40C)
   (CHARWD R 0.944)
   (CHARHT R 0.676)
   )
(CHARACTER O 116 (comment u1D40D)
   (CHARWD R 0.722)
   (CHARHT R 0.676)
   (CHARDP R 0.018)
   )
(CHARACTER O 117 (comment u1D40E)
   (CHARWD R 0.778)
   (CHARHT R 0.691)
   (CHARDP R 0.019)
   )
(CHARACTER O 120 (comment u1D40F)
   (CHARWD R 0.611)
   (CHARHT R 0.676)
   )
(CHARACTER O 121 (comment u1D410)
   (CHARWD R 0.778)
   (CHARHT R 0.691)
   (CHARDP R 0.176)
   )
(CHARACTER O 122 (comment u1D411)
   (CHARWD R 0.722)
   (CHARHT R 0.676)
   )
(CHARACTER O 123 (comment u1D412)
   (CHARWD R 0.556)
   (CHARHT R 0.692)
   (CHARDP R 0.019)
   )
(CHARACTER O 124 (comment u1D413)
   (CHARWD R 0.667)
   (CHARHT R 0.676)
   )
(CHARACTER O 125 (comment u1D414)
   (CHARWD R 0.722)
   (CHARHT R 0.676)
   (CHARDP R 0.019)
   )
(CHARACTER O 126 (comment u1D415)
   (CHARWD R 0.722)
   (CHARHT R 0.676)
   (CHARDP R 0.018)
   )
(CHARACTER O 127 (comment u1D416)
   (CHARWD R 1)
   (CHARHT R 0.676)
   (CHARDP R 0.015)
   )
(CHARACTER O 130 (comment u1D417)
   (CHARWD R 0.722)
   (CHARHT R 0.676)
   )
(CHARACTER O 131 (comment u1D418)
   (CHARWD R 0.722)
   (CHARHT R 0.676)
   )
(CHARACTER O 132 (comment u1D419)
   (CHARWD R 0.667)
   (CHARHT R 0.676)
   )
(CHARACTER O 133 (comment bracketleft)
   (CHARWD R 0.333)
   (CHARHT R 0.678)
   (CHARDP R 0.149)
   )
(CHARACTER O 134 (comment uni2216.var)
   (CHARWD R 0.518)
   (CHARHT R 0.732)
   (CHARDP R 0.193)
   )
(CHARACTER O 135 (comment bracketright)
   (CHARWD R 0.333)
   (CHARHT R 0.678)
   (CHARDP R 0.149)
   )
(CHARACTER O 136 (comment braceleft)
   (CHARWD R 0.394)
   (CHARHT R 0.698)
   (CHARDP R 0.175)
   )
(CHARACTER O 137 (comment uni2215)
   (CHARWD R 0.584)
   (CHARHT R 0.732)
   (CHARDP R 0.193)
   )
(CHARACTER O 140 (comment braceright)
   (CHARWD R 0.394)
   (CHARHT R 0.698)
   (CHARDP R 0.175)
   )
(CHARACTER O 141 (comment u1D41A)
   (CHARWD R 0.5)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 142 (comment u1D41B)
   (CHARWD R 0.556)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 143 (comment u1D41C)
   (CHARWD R 0.444)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 144 (comment u1D41D)
   (CHARWD R 0.556)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 145 (comment u1D41E)
   (CHARWD R 0.444)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 146 (comment u1D41F)
   (CHARWD R 0.333)
   (CHARHT R 0.691)
   (CHARIC R 0.1)
   )
(CHARACTER O 147 (comment u1D420)
   (CHARWD R 0.5)
   (CHARHT R 0.473)
   (CHARDP R 0.206)
   )
(CHARACTER O 150 (comment u1D421)
   (CHARWD R 0.556)
   (CHARHT R 0.676)
   )
(CHARACTER O 151 (comment u1D422)
   (CHARWD R 0.278)
   (CHARHT R 0.691)
   )
(CHARACTER O 152 (comment u1D423)
   (CHARWD R 0.333)
   (CHARHT R 0.691)
   (CHARDP R 0.203)
   )
(CHARACTER O 153 (comment u1D424)
   (CHARWD R 0.556)
   (CHARHT R 0.676)
   )
(CHARACTER O 154 (comment u1D425)
   (CHARWD R 0.278)
   (CHARHT R 0.676)
   )
(CHARACTER O 155 (comment u1D426)
   (CHARWD R 0.833)
   (CHARHT R 0.473)
   )
(CHARACTER O 156 (comment u1D427)
   (CHARWD R 0.556)
   (CHARHT R 0.473)
   )
(CHARACTER O 157 (comment u1D428)
   (CHARWD R 0.5)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 160 (comment u1D429)
   (CHARWD R 0.556)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 161 (comment u1D42A)
   (CHARWD R 0.556)
   (CHARHT R 0.473)
   (CHARDP R 0.205)
   )
(CHARACTER O 162 (comment u1D42B)
   (CHARWD R 0.444)
   (CHARHT R 0.473)
   (CHARIC R 0.06)
   )
(CHARACTER O 163 (comment u1D42C)
   (CHARWD R 0.389)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 164 (comment u1D42D)
   (CHARWD R 0.333)
   (CHARHT R 0.63)
   (CHARDP R 0.012)
   (CHARIC R 0.06)
   )
(CHARACTER O 165 (comment u1D42E)
   (CHARWD R 0.556)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 166 (comment u1D42F)
   (CHARWD R 0.5)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 167 (comment u1D430)
   (CHARWD R 0.722)
   (CHARHT R 0.461)
   (CHARDP R 0.014)
   )
(CHARACTER O 170 (comment u1D431)
   (CHARWD R 0.5)
   (CHARHT R 0.461)
   (CHARIC R 0.02)
   )
(CHARACTER O 171 (comment u1D432)
   (CHARWD R 0.5)
   (CHARHT R 0.461)
   (CHARDP R 0.205)
   (CHARIC R 0.02)
   )
(CHARACTER O 172 (comment u1D433)
   (CHARWD R 0.444)
   (CHARHT R 0.461)
   (CHARIC R 0.02)
   )
(CHARACTER O 173 (comment dotlessi)
   (CHARWD R 0.278)
   (CHARHT R 0.461)
   )
(CHARACTER O 174 (comment uni0237)
   (CHARWD R 0.333)
   (CHARHT R 0.461)
   (CHARDP R 0.203)
   )
(CHARACTER O 175 (comment numbersign)
   (CHARWD R 0.5)
   (CHARHT R 0.7)
   )
(CHARACTER O 176 (comment percent)
   (CHARWD R 0.749)
   (CHARHT R 0.706)
   (CHARDP R 0.029)
   )
(CHARACTER O 177 (comment quoteright)
   (CHARWD R 0.333)
   (CHARHT R 0.7)
   )
(CHARACTER O 200 (comment uni0300)
   (CHARWD R 0.238)
   (CHARHT R 0.7)
   )
(CHARACTER O 201 (comment uni0301)
   (CHARWD R 0.238)
   (CHARHT R 0.7)
   )
(CHARACTER O 202 (comment uni0302)
   (CHARWD R 0.337)
   (CHARHT R 0.7)
   )
(CHARACTER O 203 (comment uni0303)
   (CHARWD R 0.365)
   (CHARHT R 0.7)
   )
(CHARACTER O 204 (comment uni0304)
   (CHARWD R 0.33)
   (CHARHT R 0.6)
   )
(CHARACTER O 205 (comment uni0306)
   (CHARWD R 0.303)
   (CHARHT R 0.7)
   )
(CHARACTER O 206 (comment uni0307)
   (CHARWD R 0.129)
   (CHARHT R 0.7)
   )
(CHARACTER O 207 (comment uni0308)
   (CHARWD R 0.339)
   (CHARHT R 0.7)
   )
(CHARACTER O 210 (comment uni0309)
   (CHARWD R 0.205)
   (CHARHT R 0.8)
   )
(CHARACTER O 211 (comment uni030A)
   (CHARWD R 0.213)
   (CHARHT R 0.8)
   )
(CHARACTER O 212 (comment uni030C)
   (CHARWD R 0.337)
   (CHARHT R 0.7)
   )
(CHARACTER O 213 (comment uni0310)
   (CHARWD R 0.303)
   (CHARHT R 0.8)
   )
(CHARACTER O 214 (comment uni0312)
   (CHARWD R 0.184)
   (CHARHT R 0.9)
   )
(CHARACTER O 215 (comment uni0315)
   (CHARWD R 0.184)
   (CHARHT R 0.9)
   )
(CHARACTER O 216 (comment uni031A)
   (CHARWD R 0.317)
   (CHARHT R 0.8)
   )
(CHARACTER O 217 (comment uni20D0)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 220 (comment uni20D1)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 221 (comment uni20D6)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 222 (comment uni20D7)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 223 (comment uni20DB)
   (CHARWD R 0.549)
   (CHARHT R 0.7)
   )
(CHARACTER O 224 (comment uni20DC)
   (CHARWD R 0.759)
   (CHARHT R 0.7)
   )
(CHARACTER O 225 (comment uni20E1)
   (CHARWD R 0.594)
   (CHARHT R 0.8)
   )
(CHARACTER O 226 (comment uni20E7)
   (CHARWD R 0.843)
   (CHARHT R 0.8)
   (CHARDP R 0.2)
   )
(CHARACTER O 227 (comment uni20E9)
   (CHARWD R 0.564)
   (CHARHT R 0.7)
   )
(CHARACTER O 230 (comment uni20F0)
   (CHARWD R 0.27)
   (CHARHT R 0.8)
   )
(CHARACTER O 231 (comment ampersand)
   (CHARWD R 0.833)
   (CHARHT R 0.691)
   (CHARDP R 0.016)
   )
(CHARACTER O 232 (comment at)
   (CHARWD R 0.93)
   (CHARHT R 0.691)
   (CHARDP R 0.019)
   )
(CHARACTER O 233 (comment logicalnot)
   (CHARWD R 0.75)
   (CHARHT R 0.399)
   )
(CHARACTER O 234 (comment periodcentered)
   (CHARWD R 0.25)
   (CHARHT R 0.417)
   )
(CHARACTER O 235 (comment multiply)
   (CHARWD R 0.702)
   (CHARHT R 0.538)
   (CHARDP R 0.033)
   )
(CHARACTER O 236 (comment uni2AAF)
   (CHARWD R 0.75)
   (CHARHT R 0.619)
   (CHARDP R 0.111)
   )
(CHARACTER O 237 (comment divide)
   (CHARWD R 0.57)
   (CHARHT R 0.537)
   (CHARDP R 0.031)
   )
(CHARACTER O 240 (comment uni01B5)
   (CHARWD R 0.612)
   (CHARHT R 0.662)
   )
(CHARACTER O 241 (comment uni0338)
   (CHARWD R 0)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 242 (comment uni03F6)
   (CHARWD R 0.444)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 243 (comment dagger)
   (CHARWD R 0.5)
   (CHARHT R 0.691)
   (CHARDP R 0.134)
   )
(CHARACTER O 244 (comment daggerdbl)
   (CHARWD R 0.5)
   (CHARHT R 0.691)
   (CHARDP R 0.132)
   )
(CHARACTER O 245 (comment bullet)
   (CHARWD R 0.56)
   (CHARHT R 0.462)
   )
(CHARACTER O 246 (comment twodotenleader)
   (CHARWD R 0.666)
   (CHARHT R 0.156)
   (CHARDP R 0.013)
   )
(CHARACTER O 247 (comment ellipsis)
   (CHARWD R 1)
   (CHARHT R 0.156)
   (CHARDP R 0.013)
   )
(CHARACTER O 250 (comment uni2032.var)
   (CHARWD R 0.394)
   (CHARHT R 0.586)
   )
(CHARACTER O 251 (comment uni2033.var)
   (CHARWD R 0.713)
   (CHARHT R 0.586)
   )
(CHARACTER O 252 (comment uni2034.var)
   (CHARWD R 1.032)
   (CHARHT R 0.586)
   )
(CHARACTER O 253 (comment uni2035.var)
   (CHARWD R 0.394)
   (CHARHT R 0.586)
   )
(CHARACTER O 254 (comment uni2036.var)
   (CHARWD R 0.713)
   (CHARHT R 0.586)
   )
(CHARACTER O 255 (comment uni2037.var)
   (CHARWD R 1.032)
   (CHARHT R 0.586)
   )
(CHARACTER O 256 (comment uni2038)
   (CHARWD R 0.584)
   (CHARHT R 0.117)
   (CHARDP R 0.17)
   )
(CHARACTER O 257 (comment uni203C)
   (CHARWD R 0.625)
   (CHARHT R 0.691)
   (CHARDP R 0.013)
   )
(CHARACTER O 260 (comment uni2043)
   (CHARWD R 0.333)
   (CHARHT R 0.332)
   )
(CHARACTER O 261 (comment fraction)
   (CHARWD R 0.183)
   (CHARHT R 0.688)
   (CHARDP R 0.012)
   )
(CHARACTER O 262 (comment uni2047)
   (CHARWD R 0.947)
   (CHARHT R 0.689)
   (CHARDP R 0.013)
   )
(CHARACTER O 263 (comment uni2050)
   (CHARWD R 0.79)
   (CHARHT R 0.691)
   (CHARDP R 0.04)
   )
(CHARACTER O 264 (comment uni2057.var)
   (CHARWD R 1.351)
   (CHARHT R 0.586)
   )
(CHARACTER O 265 (comment uni20D2)
   (CHARWD R 0)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 266 (comment uni20DD)
   (CHARWD R 0)
   (CHARHT R 0.76)
   (CHARDP R 0.254)
   )
(CHARACTER O 267 (comment uni20DE)
   (CHARWD R 0)
   (CHARHT R 0.78)
   (CHARDP R 0.18)
   )
(CHARACTER O 270 (comment uni20DF)
   (CHARWD R 0)
   (CHARHT R 0.843)
   (CHARDP R 0.341)
   )
(CHARACTER O 271 (comment uni20E4)
   (CHARWD R 0)
   (CHARHT R 1.055)
   (CHARDP R 0.169)
   )
(CHARACTER O 272 (comment uni2107)
   (CHARWD R 0.699)
   (CHARHT R 0.691)
   (CHARDP R 0.019)
   )
(CHARACTER O 273 (comment uni2127)
   (CHARWD R 0.758)
   (CHARHT R 0.674)
   (CHARDP R 0.018)
   )
(CHARACTER O 274 (comment uni2129)
   (CHARWD R 0.312)
   (CHARHT R 0.475)
   )
(CHARACTER O 275 (comment uni212B)
   (CHARWD R 0.722)
   (CHARHT R 0.92)
   )
(CHARACTER O 276 (comment uni2132)
   (CHARWD R 0.616)
   (CHARHT R 0.676)
   )
(CHARACTER O 277 (comment uni2141)
   (CHARWD R 0.695)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 300 (comment uni2142)
   (CHARWD R 0.559)
   (CHARHT R 0.662)
   )
(CHARACTER O 301 (comment uni2143)
   (CHARWD R 0.559)
   (CHARHT R 0.662)
   )
(CHARACTER O 302 (comment uni2144)
   (CHARWD R 0.63)
   (CHARHT R 0.662)
   )
(CHARACTER O 303 (comment uni214A)
   (CHARWD R 0.664)
   (CHARHT R 0.692)
   )
(CHARACTER O 304 (comment uni214B)
   (CHARWD R 0.833)
   (CHARHT R 0.69)
   (CHARDP R 0.017)
   )
(CHARACTER O 305 (comment uni2200)
   (CHARWD R 0.599)
   (CHARHT R 0.676)
   )
(CHARACTER O 306 (comment uni2201)
   (CHARWD R 0.539)
   (CHARHT R 0.785)
   (CHARDP R 0.029)
   )
(CHARACTER O 307 (comment uni2203)
   (CHARWD R 0.599)
   (CHARHT R 0.676)
   )
(CHARACTER O 310 (comment uni2204)
   (CHARWD R 0.599)
   (CHARHT R 0.803)
   (CHARDP R 0.127)
   )
(CHARACTER O 311 (comment uni2205)
   (CHARWD R 0.787)
   (CHARHT R 0.594)
   (CHARDP R 0.09)
   )
(CHARACTER O 312 (comment uni2206)
   (CHARWD R 0.681)
   (CHARHT R 0.676)
   )
(CHARACTER O 313 (comment uni2208)
   (CHARWD R 0.75)
   (CHARHT R 0.547)
   (CHARDP R 0.013)
   )
(CHARACTER O 314 (comment uni2209)
   (CHARWD R 0.75)
   (CHARHT R 0.68)
   (CHARDP R 0.146)
   )
(CHARACTER O 315 (comment uni220A)
   (CHARWD R 0.5)
   (CHARHT R 0.499)
   )
(CHARACTER O 316 (comment uni220B)
   (CHARWD R 0.75)
   (CHARHT R 0.547)
   (CHARDP R 0.013)
   )
(CHARACTER O 317 (comment uni220C)
   (CHARWD R 0.75)
   (CHARHT R 0.68)
   (CHARDP R 0.146)
   )
(CHARACTER O 320 (comment uni220D)
   (CHARWD R 0.5)
   (CHARHT R 0.499)
   )
(CHARACTER O 321 (comment uni220E)
   (CHARWD R 0.545)
   (CHARHT R 0.64)
   )
(CHARACTER O 322 (comment uni2214)
   (CHARWD R 0.75)
   (CHARHT R 0.793)
   (CHARDP R 0.057)
   )
(CHARACTER O 323 (comment uni2AB0)
   (CHARWD R 0.75)
   (CHARHT R 0.619)
   (CHARDP R 0.111)
   )
(CHARACTER O 324 (comment uni2216)
   (CHARWD R 0.452)
   (CHARHT R 0.411)
   )
(CHARACTER O 325 (comment uni2218)
   (CHARWD R 0.394)
   (CHARHT R 0.409)
   )
(CHARACTER O 326 (comment uni2219)
   (CHARWD R 0.493)
   (CHARHT R 0.414)
   )
(CHARACTER O 327 (comment uni221D)
   (CHARWD R 0.772)
   (CHARHT R 0.45)
   )
(CHARACTER O 330 (comment uni221E)
   (CHARWD R 0.964)
   (CHARHT R 0.45)
   )
(CHARACTER O 331 (comment uni221F)
   (CHARWD R 0.685)
   (CHARHT R 0.584)
   )
(CHARACTER O 332 (comment uni2220)
   (CHARWD R 0.792)
   (CHARHT R 0.569)
   )
(CHARACTER O 333 (comment uni2221)
   (CHARWD R 0.792)
   (CHARHT R 0.569)
   (CHARDP R 0.074)
   )
(CHARACTER O 334 (comment uni2222)
   (CHARWD R 0.695)
   (CHARHT R 0.534)
   (CHARDP R 0.026)
   )
(CHARACTER O 335 (comment uni2223)
   (CHARWD R 0.288)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 336 (comment uni2224)
   (CHARWD R 0.411)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 337 (comment uni2225)
   (CHARWD R 0.487)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 340 (comment uni2226)
   (CHARWD R 0.617)
   (CHARHT R 0.69)
   (CHARDP R 0.189)
   )
(CHARACTER O 341 (comment uni2227)
   (CHARWD R 0.64)
   (CHARHT R 0.536)
   (CHARDP R 0.028)
   )
(CHARACTER O 342 (comment uni2228)
   (CHARWD R 0.64)
   (CHARHT R 0.536)
   (CHARDP R 0.028)
   )
(CHARACTER O 343 (comment uni2229)
   (CHARWD R 0.65)
   (CHARHT R 0.541)
   (CHARDP R 0.033)
   )
(CHARACTER O 344 (comment uni222A)
   (CHARWD R 0.65)
   (CHARHT R 0.541)
   (CHARDP R 0.033)
   )
(CHARACTER O 345 (comment uni2234)
   (CHARWD R 0.75)
   (CHARHT R 0.575)
   (CHARDP R 0.041)
   )
(CHARACTER O 346 (comment uni2235)
   (CHARWD R 0.75)
   (CHARHT R 0.575)
   (CHARDP R 0.041)
   )
(CHARACTER O 347 (comment uni2205.var)
   (CHARWD R 0.584)
   (CHARHT R 0.729)
   (CHARDP R 0.074)
   )
(CHARACTER O 350 (comment uni2237)
   (CHARWD R 0.75)
   (CHARHT R 0.575)
   (CHARDP R 0.041)
   )
(CHARACTER O 351 (comment uni2238)
   (CHARWD R 0.75)
   (CHARHT R 0.543)
   )
(CHARACTER O 352 (comment uni2239)
   (CHARWD R 0.75)
   (CHARHT R 0.543)
   (CHARDP R 0.037)
   )
(CHARACTER O 353 (comment uni223A)
   (CHARWD R 0.75)
   (CHARHT R 0.575)
   (CHARDP R 0.041)
   )
(CHARACTER O 354 (comment uni223B)
   (CHARWD R 0.75)
   (CHARHT R 0.565)
   (CHARDP R 0.059)
   )
(CHARACTER O 355 (comment uni223C)
   (CHARWD R 0.75)
   (CHARHT R 0.374)
   )
(CHARACTER O 356 (comment uni223D)
   (CHARWD R 0.75)
   (CHARHT R 0.374)
   )
(CHARACTER O 357 (comment uni223E)
   (CHARWD R 0.75)
   (CHARHT R 0.419)
   )
(CHARACTER O 360 (comment uni223F)
   (CHARWD R 0.75)
   (CHARHT R 0.484)
   )
(CHARACTER O 361 (comment uni2240)
   (CHARWD R 0.348)
   (CHARHT R 0.575)
   (CHARDP R 0.04)
   )
(CHARACTER O 362 (comment uni2241)
   (CHARWD R 0.75)
   (CHARHT R 0.444)
   )
(CHARACTER O 363 (comment uni2242)
   (CHARWD R 0.75)
   (CHARHT R 0.463)
   )
(CHARACTER O 364 (comment uni2243)
   (CHARWD R 0.75)
   (CHARHT R 0.463)
   )
(CHARACTER O 365 (comment uni2244)
   (CHARWD R 0.75)
   (CHARHT R 0.53)
   (CHARDP R 0.054)
   )
(CHARACTER O 366 (comment uni2245)
   (CHARWD R 0.75)
   (CHARHT R 0.568)
   (CHARDP R 0.06)
   )
(CHARACTER O 367 (comment uni2246)
   (CHARWD R 0.75)
   (CHARHT R 0.568)
   (CHARDP R 0.15)
   )
(CHARACTER O 370 (comment uni2247)
   (CHARWD R 0.75)
   (CHARHT R 0.642)
   (CHARDP R 0.152)
   )
(CHARACTER O 371 (comment uni2248)
   (CHARWD R 0.75)
   (CHARHT R 0.508)
   )
(CHARACTER O 372 (comment uni2249)
   (CHARWD R 0.75)
   (CHARHT R 0.583)
   (CHARDP R 0.048)
   )
(CHARACTER O 373 (comment uni224A)
   (CHARWD R 0.75)
   (CHARHT R 0.568)
   (CHARDP R 0.075)
   )
(CHARACTER O 374 (comment uni224B)
   (CHARWD R 0.75)
   (CHARHT R 0.613)
   (CHARDP R 0.109)
   )
(CHARACTER O 375 (comment uni224C)
   (CHARWD R 0.75)
   (CHARHT R 0.568)
   (CHARDP R 0.06)
   )
(CHARACTER O 376 (comment uni224D)
   (CHARWD R 0.75)
   (CHARHT R 0.518)
   (CHARDP R 0.013)
   )
(CHARACTER O 377 (comment uni224E)
   (CHARWD R 0.75)
   (CHARHT R 0.484)
   )
