(FAMILY STIXMath)
(CODINGSCHEME STIXMATHIT)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0.3)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   )
(LIGTABLE
   (LABEL O 0) (comment u1D6E4)
   (KRN O 177 R 0.1115) (comment uni2040)
   (STOP)
   (LABEL O 1) (comment u1D6E5)
   (KRN O 177 R 0.155) (comment uni2040)
   (STOP)
   (LABEL O 2) (comment u1D6E9)
   (KRN O 177 R 0.087) (comment uni2040)
   (STOP)
   (LABEL O 3) (comment u1D6EC)
   (KRN O 177 R 0.151) (comment uni2040)
   (STOP)
   (LABEL O 4) (comment u1D6EF)
   (KRN O 177 R 0.0855) (comment uni2040)
   (STOP)
   (LABEL O 5) (comment u1D6F1)
   (KRN O 177 R 0.0725) (comment uni2040)
   (STOP)
   (LABEL O 6) (comment u1D6F4)
   (KRN O 177 R 0.109) (comment uni2040)
   (STOP)
   (LABEL O 7) (comment u1D6F6)
   (KRN O 177 R -0.0285) (comment uni2040)
   (STOP)
   (LABEL O 10) (comment u1D6F7)
   (KRN O 177 R 0.0705) (comment uni2040)
   (STOP)
   (LABEL O 11) (comment u1D6F9)
   (KRN O 177 R -0.0055) (comment uni2040)
   (STOP)
   (LABEL O 12) (comment u1D6FA)
   (KRN O 177 R 0.136) (comment uni2040)
   (STOP)
   (LABEL O 13) (comment u1D6FC)
   (KRN O 177 R 0.002) (comment uni2040)
   (STOP)
   (LABEL O 14) (comment u1D6FD)
   (KRN O 177 R 0.145) (comment uni2040)
   (STOP)
   (LABEL O 15) (comment u1D6FE)
   (KRN O 177 R -0.008) (comment uni2040)
   (STOP)
   (LABEL O 16) (comment u1D6FF)
   (KRN O 177 R 0.0905) (comment uni2040)
   (STOP)
   (LABEL O 17) (comment u1D716)
   (KRN O 177 R 0.074) (comment uni2040)
   (STOP)
   (LABEL O 20) (comment u1D701)
   (KRN O 177 R 0.0665) (comment uni2040)
   (STOP)
   (LABEL O 21) (comment u1D702)
   (KRN O 177 R 0.038) (comment uni2040)
   (STOP)
   (LABEL O 22) (comment u1D703)
   (KRN O 177 R 0.061) (comment uni2040)
   (STOP)
   (LABEL O 23) (comment u1D704)
   (KRN O 177 R 0.0305) (comment uni2040)
   (STOP)
   (LABEL O 24) (comment u1D705)
   (KRN O 177 R 0.003) (comment uni2040)
   (STOP)
   (LABEL O 25) (comment u1D706)
   (KRN O 177 R 0.0775) (comment uni2040)
   (STOP)
   (LABEL O 26) (comment u1D707)
   (KRN O 177 R 0.0695) (comment uni2040)
   (STOP)
   (LABEL O 27) (comment u1D708)
   (KRN O 177 R 0.033) (comment uni2040)
   (STOP)
   (LABEL O 30) (comment u1D709)
   (KRN O 177 R 0.0665) (comment uni2040)
   (STOP)
   (LABEL O 31) (comment u1D70B)
   (KRN O 177 R 0.066) (comment uni2040)
   (STOP)
   (LABEL O 32) (comment u1D70C)
   (KRN O 177 R 0.082) (comment uni2040)
   (STOP)
   (LABEL O 33) (comment u1D70E)
   (KRN O 177 R 0.0005) (comment uni2040)
   (STOP)
   (LABEL O 34) (comment u1D70F)
   (KRN O 177 R 0.039) (comment uni2040)
   (STOP)
   (LABEL O 35) (comment u1D710)
   (KRN O 177 R 0.008) (comment uni2040)
   (STOP)
   (LABEL O 36) (comment u1D719)
   (KRN O 177 R 0.1195) (comment uni2040)
   (STOP)
   (LABEL O 37) (comment u1D712)
   (KRN O 177 R 0.0955) (comment uni2040)
   (STOP)
   (LABEL O 40) (comment u1D713)
   (KRN O 177 R -0.0055) (comment uni2040)
   (STOP)
   (LABEL O 41) (comment u1D714)
   (KRN O 177 R 0.0515) (comment uni2040)
   (STOP)
   (LABEL O 42) (comment u1D700)
   (KRN O 177 R 0.049) (comment uni2040)
   (STOP)
   (LABEL O 43) (comment u1D717)
   (KRN O 177 R 0.071) (comment uni2040)
   (STOP)
   (LABEL O 44) (comment u1D71B)
   (KRN O 177 R 0.046) (comment uni2040)
   (STOP)
   (LABEL O 45) (comment u1D71A)
   (KRN O 177 R 0.0955) (comment uni2040)
   (STOP)
   (LABEL O 46) (comment u1D70D)
   (KRN O 177 R -0.002) (comment uni2040)
   (STOP)
   (LABEL O 47) (comment u1D711)
   (KRN O 177 R 0.007) (comment uni2040)
   (STOP)
   (LABEL O 51) (comment u1D715)
   (KRN O 177 R 0.0585) (comment uni2040)
   (STOP)
   (LABEL O 75) (comment uni210F)
   (KRN O 177 R -0.0435) (comment uni2040)
   (STOP)
   (LABEL O 101) (comment u1D434)
   (KRN O 177 R 0.1515) (comment uni2040)
   (STOP)
   (LABEL O 102) (comment u1D435)
   (KRN O 177 R 0.108) (comment uni2040)
   (STOP)
   (LABEL O 103) (comment u1D436)
   (KRN O 177 R 0.1165) (comment uni2040)
   (STOP)
   (LABEL O 104) (comment u1D437)
   (KRN O 177 R 0.0915) (comment uni2040)
   (STOP)
   (LABEL O 105) (comment u1D438)
   (KRN O 177 R 0.103) (comment uni2040)
   (STOP)
   (LABEL O 106) (comment u1D439)
   (KRN O 177 R 0.1085) (comment uni2040)
   (STOP)
   (LABEL O 107) (comment u1D43A)
   (KRN O 177 R 0.111) (comment uni2040)
   (STOP)
   (LABEL O 110) (comment u1D43B)
   (KRN O 177 R 0.0745) (comment uni2040)
   (STOP)
   (LABEL O 111) (comment u1D43C)
   (KRN O 177 R 0.103) (comment uni2040)
   (STOP)
   (LABEL O 112) (comment u1D43D)
   (KRN O 177 R 0.148) (comment uni2040)
   (STOP)
   (LABEL O 113) (comment u1D43E)
   (KRN O 177 R 0.115) (comment uni2040)
   (STOP)
   (LABEL O 114) (comment u1D43F)
   (KRN O 177 R 0.033) (comment uni2040)
   (STOP)
   (LABEL O 115) (comment u1D440)
   (KRN O 177 R 0.0765) (comment uni2040)
   (STOP)
   (LABEL O 116) (comment u1D441)
   (KRN O 177 R 0.0655) (comment uni2040)
   (STOP)
   (LABEL O 117) (comment u1D442)
   (KRN O 177 R 0.099) (comment uni2040)
   (STOP)
   (LABEL O 120) (comment u1D443)
   (KRN O 177 R 0.105) (comment uni2040)
   (STOP)
   (LABEL O 121) (comment u1D444)
   (KRN O 177 R 0.0995) (comment uni2040)
   (STOP)
   (LABEL O 122) (comment u1D445)
   (KRN O 177 R 0.104) (comment uni2040)
   (STOP)
   (LABEL O 123) (comment u1D446)
   (KRN O 177 R 0.109) (comment uni2040)
   (STOP)
   (LABEL O 124) (comment u1D447)
   (KRN O 177 R 0.027) (comment uni2040)
   (STOP)
   (LABEL O 125) (comment u1D448)
   (KRN O 177 R 0.0325) (comment uni2040)
   (STOP)
   (LABEL O 126) (comment u1D449)
   (KRN O 177 R 0.038) (comment uni2040)
   (STOP)
   (LABEL O 127) (comment u1D44A)
   (KRN O 177 R 0.0035) (comment uni2040)
   (STOP)
   (LABEL O 130) (comment u1D44B)
   (KRN O 177 R 0.105) (comment uni2040)
   (STOP)
   (LABEL O 131) (comment u1D44C)
   (KRN O 177 R 0.0235) (comment uni2040)
   (STOP)
   (LABEL O 132) (comment u1D44D)
   (KRN O 177 R 0.1) (comment uni2040)
   (STOP)
   (LABEL O 141) (comment u1D44E)
   (KRN O 177 R 0.073) (comment uni2040)
   (STOP)
   (LABEL O 142) (comment u1D44F)
   (KRN O 177 R 0.005) (comment uni2040)
   (STOP)
   (LABEL O 143) (comment u1D450)
   (KRN O 177 R 0.0715) (comment uni2040)
   (STOP)
   (LABEL O 144) (comment u1D451)
   (KRN O 177 R 0.174) (comment uni2040)
   (STOP)
   (LABEL O 145) (comment u1D452)
   (KRN O 177 R 0.0765) (comment uni2040)
   (STOP)
   (LABEL O 146) (comment u1D453)
   (KRN O 177 R 0.1905) (comment uni2040)
   (STOP)
   (LABEL O 147) (comment u1D454)
   (KRN O 177 R 0.058) (comment uni2040)
   (STOP)
   (LABEL O 150) (comment uni210E)
   (KRN O 177 R -0.0425) (comment uni2040)
   (STOP)
   (LABEL O 151) (comment u1D456)
   (KRN O 177 R 0.0525) (comment uni2040)
   (STOP)
   (LABEL O 152) (comment u1D457)
   (KRN O 177 R 0.0975) (comment uni2040)
   (STOP)
   (LABEL O 153) (comment u1D458)
   (KRN O 177 R -0.037) (comment uni2040)
   (STOP)
   (LABEL O 154) (comment u1D459)
   (KRN O 177 R 0.053) (comment uni2040)
   (STOP)
   (LABEL O 155) (comment u1D45A)
   (KRN O 177 R 0.044) (comment uni2040)
   (STOP)
   (LABEL O 156) (comment u1D45B)
   (KRN O 177 R 0.0575) (comment uni2040)
   (STOP)
   (LABEL O 157) (comment u1D45C)
   (KRN O 177 R 0.064) (comment uni2040)
   (STOP)
   (LABEL O 160) (comment u1D45D)
   (KRN O 177 R 0.0755) (comment uni2040)
   (STOP)
   (LABEL O 161) (comment u1D45E)
   (KRN O 177 R 0.091) (comment uni2040)
   (STOP)
   (LABEL O 162) (comment u1D45F)
   (KRN O 177 R 0.04) (comment uni2040)
   (STOP)
   (LABEL O 163) (comment u1D460)
   (KRN O 177 R 0.048) (comment uni2040)
   (STOP)
   (LABEL O 164) (comment u1D461)
   (KRN O 177 R 0.0575) (comment uni2040)
   (STOP)
   (LABEL O 165) (comment u1D462)
   (KRN O 177 R 0.04) (comment uni2040)
   (STOP)
   (LABEL O 166) (comment u1D463)
   (KRN O 177 R 0.066) (comment uni2040)
   (STOP)
   (LABEL O 167) (comment u1D464)
   (KRN O 177 R 0.0935) (comment uni2040)
   (STOP)
   (LABEL O 170) (comment u1D465)
   (KRN O 177 R 0.029) (comment uni2040)
   (STOP)
   (LABEL O 171) (comment u1D466)
   (KRN O 177 R 0.071) (comment uni2040)
   (STOP)
   (LABEL O 172) (comment u1D467)
   (KRN O 177 R 0.0505) (comment uni2040)
   (STOP)
   (LABEL O 173) (comment u1D6A4)
   (KRN O 177 R 0.04) (comment uni2040)
   (STOP)
   (LABEL O 174) (comment u1D6A5)
   (KRN O 177 R 0.054) (comment uni2040)
   (STOP)
   )
(CHARACTER O 0 (comment u1D6E4)
   (CHARWD R 0.616)
   (CHARHT R 0.653)
   (CHARIC R 0.145)
   )
(CHARACTER O 1 (comment u1D6E5)
   (CHARWD R 0.596)
   (CHARHT R 0.667)
   )
(CHARACTER O 2 (comment u1D6E9)
   (CHARWD R 0.737)
   (CHARHT R 0.669)
   (CHARDP R 0.011)
   (CHARIC R 0.015)
   )
(CHARACTER O 3 (comment u1D6EC)
   (CHARWD R 0.718)
   (CHARHT R 0.667)
   )
(CHARACTER O 4 (comment u1D6EF)
   (CHARWD R 0.706)
   (CHARHT R 0.653)
   (CHARIC R 0.075)
   )
(CHARACTER O 5 (comment u1D6F1)
   (CHARWD R 0.873)
   (CHARHT R 0.653)
   (CHARIC R 0.09)
   )
(CHARACTER O 6 (comment u1D6F4)
   (CHARWD R 0.735)
   (CHARHT R 0.653)
   (CHARIC R 0.065)
   )
(CHARACTER O 7 (comment u1D6F6)
   (CHARWD R 0.613)
   (CHARHT R 0.668)
   (CHARIC R 0.16)
   )
(CHARACTER O 10 (comment u1D6F7)
   (CHARWD R 0.772)
   (CHARHT R 0.653)
   (CHARIC R 0.015)
   )
(CHARACTER O 11 (comment u1D6F9)
   (CHARWD R 0.67)
   (CHARHT R 0.667)
   (CHARIC R 0.113)
   )
(CHARACTER O 12 (comment u1D6FA)
   (CHARWD R 0.8)
   (CHARHT R 0.666)
   (CHARIC R 0.02)
   )
(CHARACTER O 13 (comment u1D6FC)
   (CHARWD R 0.524)
   (CHARHT R 0.441)
   (CHARDP R 0.01)
   (CHARIC R 0.04)
   )
(CHARACTER O 14 (comment u1D6FD)
   (CHARWD R 0.493)
   (CHARHT R 0.668)
   (CHARDP R 0.183)
   (CHARIC R 0.065)
   )
(CHARACTER O 15 (comment u1D6FE)
   (CHARWD R 0.428)
   (CHARHT R 0.441)
   (CHARDP R 0.187)
   (CHARIC R 0.08)
   )
(CHARACTER O 16 (comment u1D6FF)
   (CHARWD R 0.463)
   (CHARHT R 0.668)
   (CHARDP R 0.011)
   (CHARIC R 0.04)
   )
(CHARACTER O 17 (comment u1D716)
   (CHARWD R 0.43)
   (CHARHT R 0.441)
   (CHARDP R 0.011)
   (CHARIC R 0.04)
   )
(CHARACTER O 20 (comment u1D701)
   (CHARWD R 0.435)
   (CHARHT R 0.668)
   (CHARDP R 0.183)
   (CHARIC R 0.1)
   )
(CHARACTER O 21 (comment u1D702)
   (CHARWD R 0.46)
   (CHARHT R 0.441)
   (CHARDP R 0.183)
   (CHARIC R 0.04)
   )
(CHARACTER O 22 (comment u1D703)
   (CHARWD R 0.484)
   (CHARHT R 0.668)
   (CHARDP R 0.011)
   (CHARIC R 0.04)
   )
(CHARACTER O 23 (comment u1D704)
   (CHARWD R 0.267)
   (CHARHT R 0.441)
   (CHARDP R 0.011)
   )
(CHARACTER O 24 (comment u1D705)
   (CHARWD R 0.534)
   (CHARHT R 0.441)
   (CHARIC R 0.06)
   )
(CHARACTER O 25 (comment u1D706)
   (CHARWD R 0.541)
   (CHARHT R 0.668)
   (CHARDP R 0.016)
   )
(CHARACTER O 26 (comment u1D707)
   (CHARWD R 0.579)
   (CHARHT R 0.428)
   (CHARDP R 0.183)
   (CHARIC R 0.03)
   )
(CHARACTER O 27 (comment u1D708)
   (CHARWD R 0.452)
   (CHARHT R 0.446)
   (CHARDP R 0.009)
   (CHARIC R 0.05)
   )
(CHARACTER O 30 (comment u1D709)
   (CHARWD R 0.433)
   (CHARHT R 0.668)
   (CHARDP R 0.183)
   (CHARIC R 0.05)
   )
(CHARACTER O 31 (comment u1D70B)
   (CHARWD R 0.558)
   (CHARHT R 0.428)
   (CHARDP R 0.013)
   (CHARIC R 0.05)
   )
(CHARACTER O 32 (comment u1D70C)
   (CHARWD R 0.502)
   (CHARHT R 0.441)
   (CHARDP R 0.183)
   )
(CHARACTER O 33 (comment u1D70E)
   (CHARWD R 0.537)
   (CHARHT R 0.428)
   (CHARDP R 0.011)
   (CHARIC R 0.05)
   )
(CHARACTER O 34 (comment u1D70F)
   (CHARWD R 0.442)
   (CHARHT R 0.428)
   (CHARDP R 0.005)
   (CHARIC R 0.07)
   )
(CHARACTER O 35 (comment u1D710)
   (CHARWD R 0.46)
   (CHARHT R 0.439)
   (CHARDP R 0.011)
   )
(CHARACTER O 36 (comment u1D719)
   (CHARWD R 0.645)
   (CHARHT R 0.668)
   (CHARDP R 0.183)
   )
(CHARACTER O 37 (comment u1D712)
   (CHARWD R 0.595)
   (CHARHT R 0.441)
   (CHARDP R 0.202)
   (CHARIC R 0.09)
   )
(CHARACTER O 40 (comment u1D713)
   (CHARWD R 0.661)
   (CHARHT R 0.441)
   (CHARDP R 0.183)
   (CHARIC R 0.09)
   )
(CHARACTER O 41 (comment u1D714)
   (CHARWD R 0.681)
   (CHARHT R 0.441)
   (CHARDP R 0.011)
   )
(CHARACTER O 42 (comment u1D700)
   (CHARWD R 0.484)
   (CHARHT R 0.441)
   (CHARDP R 0.011)
   )
(CHARACTER O 43 (comment u1D717)
   (CHARWD R 0.554)
   (CHARHT R 0.678)
   (CHARDP R 0.01)
   )
(CHARACTER O 44 (comment u1D71B)
   (CHARWD R 0.856)
   (CHARHT R 0.428)
   (CHARDP R 0.011)
   (CHARIC R 0.06)
   )
(CHARACTER O 45 (comment u1D71A)
   (CHARWD R 0.509)
   (CHARHT R 0.441)
   (CHARDP R 0.187)
   )
(CHARACTER O 46 (comment u1D70D)
   (CHARWD R 0.439)
   (CHARHT R 0.49)
   (CHARDP R 0.183)
   (CHARIC R 0.065)
   )
(CHARACTER O 47 (comment u1D711)
   (CHARWD R 0.666)
   (CHARHT R 0.441)
   (CHARDP R 0.183)
   )
(CHARACTER O 50 (comment u1D6FB)
   (CHARWD R 0.627)
   (CHARHT R 0.653)
   (CHARDP R 0.015)
   (CHARIC R 0.015)
   )
(CHARACTER O 51 (comment u1D715)
   (CHARWD R 0.471)
   (CHARHT R 0.668)
   (CHARDP R 0.011)
   (CHARIC R 0.04)
   )
(CHARACTER O 52 (comment uni2135)
   (CHARWD R 0.682)
   (CHARHT R 0.677)
   (CHARDP R 0.013)
   )
(CHARACTER O 53 (comment uni2136)
   (CHARWD R 0.639)
   (CHARHT R 0.677)
   (CHARDP R 0.019)
   )
(CHARACTER O 54 (comment uni2137)
   (CHARWD R 0.505)
   (CHARHT R 0.677)
   (CHARDP R 0.019)
   )
(CHARACTER O 55 (comment uni2138)
   (CHARWD R 0.599)
   (CHARHT R 0.677)
   (CHARDP R 0.019)
   )
(CHARACTER O 56 (comment uni22B3)
   (CHARWD R 0.685)
   (CHARHT R 0.531)
   (CHARDP R 0.025)
   )
(CHARACTER O 57 (comment uni22B2)
   (CHARWD R 0.685)
   (CHARHT R 0.531)
   (CHARDP R 0.025)
   )
(CHARACTER O 60 (comment zero)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 61 (comment one)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 62 (comment two)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 63 (comment three)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 64 (comment four)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 65 (comment five)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.014)
   )
(CHARACTER O 66 (comment six)
   (CHARWD R 0.5)
   (CHARHT R 0.684)
   (CHARDP R 0.014)
   )
(CHARACTER O 67 (comment seven)
   (CHARWD R 0.5)
   (CHARHT R 0.662)
   (CHARDP R 0.008)
   )
(CHARACTER O 70 (comment eight)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 71 (comment nine)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.022)
   )
(CHARACTER O 72 (comment period)
   (CHARWD R 0.25)
   (CHARHT R 0.1)
   (CHARDP R 0.011)
   )
(CHARACTER O 73 (comment comma)
   (CHARWD R 0.25)
   (CHARHT R 0.102)
   (CHARDP R 0.141)
   )
(CHARACTER O 74 (comment less)
   (CHARWD R 0.685)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 75 (comment uni210F)
   (CHARWD R 0.579)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 76 (comment greater)
   (CHARWD R 0.685)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 77 (comment uni22C6)
   (CHARWD R 0.7)
   (CHARHT R 0.597)
   (CHARDP R 0.013)
   )
(CHARACTER O 100 (comment uni2268)
   (CHARWD R 0.685)
   (CHARHT R 0.746)
   (CHARDP R 0.26)
   )
(CHARACTER O 101 (comment u1D434)
   (CHARWD R 0.717)
   (CHARHT R 0.667)
   )
(CHARACTER O 102 (comment u1D435)
   (CHARWD R 0.696)
   (CHARHT R 0.653)
   (CHARIC R 0.04)
   )
(CHARACTER O 103 (comment u1D436)
   (CHARWD R 0.671)
   (CHARHT R 0.659)
   (CHARDP R 0.012)
   (CHARIC R 0.08)
   )
(CHARACTER O 104 (comment u1D437)
   (CHARWD R 0.79)
   (CHARHT R 0.653)
   (CHARIC R 0.015)
   )
(CHARACTER O 105 (comment u1D438)
   (CHARWD R 0.714)
   (CHARHT R 0.653)
   (CHARIC R 0.06)
   )
(CHARACTER O 106 (comment u1D439)
   (CHARWD R 0.618)
   (CHARHT R 0.653)
   (CHARIC R 0.145)
   )
(CHARACTER O 107 (comment u1D43A)
   (CHARWD R 0.734)
   (CHARHT R 0.668)
   (CHARDP R 0.012)
   (CHARIC R 0.02)
   )
(CHARACTER O 110 (comment u1D43B)
   (CHARWD R 0.873)
   (CHARHT R 0.653)
   (CHARIC R 0.09)
   )
(CHARACTER O 111 (comment u1D43C)
   (CHARWD R 0.48)
   (CHARHT R 0.653)
   (CHARIC R 0.09)
   )
(CHARACTER O 112 (comment u1D43D)
   (CHARWD R 0.54)
   (CHARHT R 0.653)
   (CHARDP R 0.012)
   (CHARIC R 0.12)
   )
(CHARACTER O 113 (comment u1D43E)
   (CHARWD R 0.762)
   (CHARHT R 0.653)
   (CHARIC R 0.08)
   )
(CHARACTER O 114 (comment u1D43F)
   (CHARWD R 0.708)
   (CHARHT R 0.653)
   )
(CHARACTER O 115 (comment u1D440)
   (CHARWD R 1.005)
   (CHARHT R 0.653)
   (CHARIC R 0.09)
   )
(CHARACTER O 116 (comment u1D441)
   (CHARWD R 0.851)
   (CHARHT R 0.653)
   (CHARIC R 0.09)
   )
(CHARACTER O 117 (comment u1D442)
   (CHARWD R 0.732)
   (CHARHT R 0.669)
   (CHARDP R 0.011)
   (CHARIC R 0.02)
   )
(CHARACTER O 120 (comment u1D443)
   (CHARWD R 0.594)
   (CHARHT R 0.653)
   (CHARIC R 0.15)
   )
(CHARACTER O 121 (comment u1D444)
   (CHARWD R 0.781)
   (CHARHT R 0.667)
   (CHARDP R 0.152)
   )
(CHARACTER O 122 (comment u1D445)
   (CHARWD R 0.74)
   (CHARHT R 0.653)
   )
(CHARACTER O 123 (comment u1D446)
   (CHARWD R 0.65)
   (CHARHT R 0.668)
   (CHARDP R 0.01)
   (CHARIC R 0.07)
   )
(CHARACTER O 124 (comment u1D447)
   (CHARWD R 0.55)
   (CHARHT R 0.653)
   (CHARIC R 0.16)
   )
(CHARACTER O 125 (comment u1D448)
   (CHARWD R 0.705)
   (CHARHT R 0.653)
   (CHARDP R 0.013)
   (CHARIC R 0.11)
   )
(CHARACTER O 126 (comment u1D449)
   (CHARWD R 0.575)
   (CHARHT R 0.653)
   (CHARDP R 0.016)
   (CHARIC R 0.225)
   )
(CHARACTER O 127 (comment u1D44A)
   (CHARWD R 0.916)
   (CHARHT R 0.653)
   (CHARDP R 0.016)
   (CHARIC R 0.225)
   )
(CHARACTER O 130 (comment u1D44B)
   (CHARWD R 0.79)
   (CHARHT R 0.653)
   (CHARIC R 0.06)
   )
(CHARACTER O 131 (comment u1D44C)
   (CHARWD R 0.535)
   (CHARHT R 0.653)
   (CHARIC R 0.2)
   )
(CHARACTER O 132 (comment u1D44D)
   (CHARWD R 0.772)
   (CHARHT R 0.653)
   (CHARIC R 0.07)
   )
(CHARACTER O 133 (comment uni266D)
   (CHARWD R 0.426)
   (CHARHT R 0.768)
   (CHARDP R 0.01)
   )
(CHARACTER O 134 (comment uni266E)
   (CHARWD R 0.426)
   (CHARHT R 0.768)
   (CHARDP R 0.181)
   )
(CHARACTER O 135 (comment uni266F)
   (CHARWD R 0.426)
   (CHARHT R 0.768)
   (CHARDP R 0.181)
   )
(CHARACTER O 136 (comment uni2323)
   (CHARWD R 1.019)
   (CHARHT R 0.36)
   )
(CHARACTER O 137 (comment uni2322)
   (CHARWD R 1.019)
   (CHARHT R 0.36)
   )
(CHARACTER O 140 (comment uni210F.var)
   (CHARWD R 0.579)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 141 (comment u1D44E)
   (CHARWD R 0.502)
   (CHARHT R 0.441)
   (CHARDP R 0.01)
   )
(CHARACTER O 142 (comment u1D44F)
   (CHARWD R 0.47)
   (CHARHT R 0.668)
   (CHARDP R 0.011)
   )
(CHARACTER O 143 (comment u1D450)
   (CHARWD R 0.415)
   (CHARHT R 0.441)
   (CHARDP R 0.011)
   (CHARIC R 0.05)
   )
(CHARACTER O 144 (comment u1D451)
   (CHARWD R 0.532)
   (CHARHT R 0.668)
   (CHARDP R 0.012)
   (CHARIC R 0.06)
   )
(CHARACTER O 145 (comment u1D452)
   (CHARWD R 0.445)
   (CHARHT R 0.441)
   (CHARDP R 0.011)
   )
(CHARACTER O 146 (comment u1D453)
   (CHARWD R 0.555)
   (CHARHT R 0.668)
   (CHARDP R 0.187)
   (CHARIC R 0.12)
   )
(CHARACTER O 147 (comment u1D454)
   (CHARWD R 0.492)
   (CHARHT R 0.441)
   (CHARDP R 0.187)
   (CHARIC R 0.04)
   )
(CHARACTER O 150 (comment uni210E)
   (CHARWD R 0.577)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 151 (comment u1D456)
   (CHARWD R 0.311)
   (CHARHT R 0.616)
   (CHARDP R 0.011)
   )
(CHARACTER O 152 (comment u1D457)
   (CHARWD R 0.389)
   (CHARHT R 0.616)
   (CHARDP R 0.187)
   (CHARIC R 0.06)
   )
(CHARACTER O 153 (comment u1D458)
   (CHARWD R 0.542)
   (CHARHT R 0.668)
   (CHARDP R 0.011)
   )
(CHARACTER O 154 (comment u1D459)
   (CHARWD R 0.318)
   (CHARHT R 0.668)
   (CHARDP R 0.01)
   (CHARIC R 0.02)
   )
(CHARACTER O 155 (comment u1D45A)
   (CHARWD R 0.71)
   (CHARHT R 0.441)
   (CHARDP R 0.008)
   )
(CHARACTER O 156 (comment u1D45B)
   (CHARWD R 0.497)
   (CHARHT R 0.441)
   (CHARDP R 0.008)
   )
(CHARACTER O 157 (comment u1D45C)
   (CHARWD R 0.458)
   (CHARHT R 0.441)
   (CHARDP R 0.011)
   )
(CHARACTER O 160 (comment u1D45D)
   (CHARWD R 0.489)
   (CHARHT R 0.441)
   (CHARDP R 0.183)
   )
(CHARACTER O 161 (comment u1D45E)
   (CHARWD R 0.458)
   (CHARHT R 0.441)
   (CHARDP R 0.183)
   (CHARIC R 0.04)
   )
(CHARACTER O 162 (comment u1D45F)
   (CHARWD R 0.408)
   (CHARHT R 0.441)
   )
(CHARACTER O 163 (comment u1D460)
   (CHARWD R 0.44)
   (CHARHT R 0.441)
   (CHARDP R 0.011)
   )
(CHARACTER O 164 (comment u1D461)
   (CHARWD R 0.313)
   (CHARHT R 0.567)
   (CHARDP R 0.009)
   )
(CHARACTER O 165 (comment u1D462)
   (CHARWD R 0.474)
   (CHARHT R 0.441)
   (CHARDP R 0.009)
   )
(CHARACTER O 166 (comment u1D463)
   (CHARWD R 0.506)
   (CHARHT R 0.458)
   (CHARDP R 0.009)
   )
(CHARACTER O 167 (comment u1D464)
   (CHARWD R 0.775)
   (CHARHT R 0.46)
   (CHARDP R 0.009)
   )
(CHARACTER O 170 (comment u1D465)
   (CHARWD R 0.55)
   (CHARHT R 0.441)
   (CHARDP R 0.009)
   )
(CHARACTER O 171 (comment u1D466)
   (CHARWD R 0.496)
   (CHARHT R 0.44)
   (CHARDP R 0.183)
   )
(CHARACTER O 172 (comment u1D467)
   (CHARWD R 0.499)
   (CHARHT R 0.45)
   (CHARDP R 0.014)
   )
(CHARACTER O 173 (comment u1D6A4)
   (CHARWD R 0.278)
   (CHARHT R 0.441)
   (CHARDP R 0.011)
   )
(CHARACTER O 174 (comment u1D6A5)
   (CHARWD R 0.278)
   (CHARHT R 0.441)
   (CHARDP R 0.207)
   )
(CHARACTER O 175 (comment uni2269)
   (CHARWD R 0.685)
   (CHARHT R 0.746)
   (CHARDP R 0.26)
   )
(CHARACTER O 176 (comment uni226A)
   (CHARWD R 0.933)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 177 (comment uni2040)
   (CHARWD R 0.798)
   (CHARHT R 0.7)
   )
(CHARACTER O 200 (comment uni0300)
   (CHARWD R 0.224)
   (CHARHT R 0.7)
   )
(CHARACTER O 201 (comment uni0301)
   (CHARWD R 0.224)
   (CHARHT R 0.7)
   )
(CHARACTER O 202 (comment uni0302)
   (CHARWD R 0.311)
   (CHARHT R 0.7)
   )
(CHARACTER O 203 (comment uni0303)
   (CHARWD R 0.33)
   (CHARHT R 0.6)
   )
(CHARACTER O 204 (comment uni0304)
   (CHARWD R 0.311)
   (CHARHT R 0.6)
   )
(CHARACTER O 205 (comment uni0306)
   (CHARWD R 0.281)
   (CHARHT R 0.7)
   )
(CHARACTER O 206 (comment uni0307)
   (CHARWD R 0.099)
   (CHARHT R 0.6)
   )
(CHARACTER O 207 (comment uni0308)
   (CHARWD R 0.298)
   (CHARHT R 0.6)
   )
(CHARACTER O 210 (comment uni0309)
   (CHARWD R 0.189)
   (CHARHT R 0.8)
   )
(CHARACTER O 211 (comment uni030A)
   (CHARWD R 0.199)
   (CHARHT R 0.7)
   )
(CHARACTER O 212 (comment uni030C)
   (CHARWD R 0.311)
   (CHARHT R 0.7)
   )
(CHARACTER O 213 (comment uni0310)
   (CHARWD R 0.281)
   (CHARHT R 0.8)
   )
(CHARACTER O 214 (comment uni0312)
   (CHARWD R 0.139)
   (CHARHT R 0.7)
   )
(CHARACTER O 215 (comment uni0315)
   (CHARWD R 0.139)
   (CHARHT R 0.7)
   )
(CHARACTER O 216 (comment uni031A)
   (CHARWD R 0.3)
   (CHARHT R 0.7)
   )
(CHARACTER O 217 (comment uni20D0)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 220 (comment uni20D1)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 221 (comment uni20D6)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 222 (comment uni20D7)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 223 (comment uni20DB)
   (CHARWD R 0.497)
   (CHARHT R 0.6)
   )
(CHARACTER O 224 (comment uni20DC)
   (CHARWD R 0.696)
   (CHARHT R 0.6)
   )
(CHARACTER O 225 (comment uni20E1)
   (CHARWD R 0.478)
   (CHARHT R 0.8)
   )
(CHARACTER O 226 (comment uni20E7)
   (CHARWD R 0.816)
   (CHARHT R 0.7)
   (CHARDP R 0)
   )
(CHARACTER O 227 (comment uni20E9)
   (CHARWD R 0.533)
   (CHARHT R 0.7)
   )
(CHARACTER O 230 (comment uni20F0)
   (CHARWD R 0.27)
   (CHARHT R 0.8)
   )
(CHARACTER O 231 (comment uni20D6.x)
   (CHARWD R 0.225)
   (CHARHT R 0.681)
   )
(CHARACTER O 232 (comment uni0302.s1)
   (CHARWD R 0.56)
   (CHARHT R 0.767)
   (NEXTLARGER O 235)
   )
(CHARACTER O 233 (comment uni0303.s1)
   (CHARWD R 0.56)
   (CHARHT R 0.75)
   (NEXTLARGER O 236)
   )
(CHARACTER O 234 (comment uni030C.s1)
   (CHARWD R 0.56)
   (CHARHT R 0.767)
   (NEXTLARGER O 237)
   )
(CHARACTER O 235 (comment uni0302.s2)
   (CHARWD R 0.979)
   (CHARHT R 0.777)
   (NEXTLARGER O 240)
   )
(CHARACTER O 236 (comment uni0303.s2)
   (CHARWD R 0.979)
   (CHARHT R 0.76)
   (NEXTLARGER O 241)
   )
(CHARACTER O 237 (comment uni030C.s2)
   (CHARWD R 0.979)
   (CHARHT R 0.777)
   (NEXTLARGER O 242)
   )
(CHARACTER O 240 (comment uni0302.s3)
   (CHARWD R 1.46)
   (CHARHT R 0.777)
   (NEXTLARGER O 243)
   )
(CHARACTER O 241 (comment uni0303.s3)
   (CHARWD R 1.46)
   (CHARHT R 0.774)
   (NEXTLARGER O 244)
   )
(CHARACTER O 242 (comment uni030C.s3)
   (CHARWD R 1.46)
   (CHARHT R 0.777)
   (NEXTLARGER O 245)
   )
(CHARACTER O 243 (comment uni0302.s4)
   (CHARWD R 1.886)
   (CHARHT R 0.796)
   (NEXTLARGER O 246)
   )
(CHARACTER O 244 (comment uni0303.s4)
   (CHARWD R 1.886)
   (CHARHT R 0.771)
   (NEXTLARGER O 247)
   )
(CHARACTER O 245 (comment uni030C.s4)
   (CHARWD R 1.886)
   (CHARHT R 0.796)
   (NEXTLARGER O 250)
   )
(CHARACTER O 246 (comment uni0302.s5)
   (CHARWD R 2.328)
   (CHARHT R 0.816)
   )
(CHARACTER O 247 (comment uni0303.s5)
   (CHARWD R 2.328)
   (CHARHT R 0.78)
   )
(CHARACTER O 250 (comment uni030C.s5)
   (CHARWD R 2.328)
   (CHARHT R 0.816)
   )
(CHARACTER O 251 (comment uni23DE.l)
   (CHARWD R 0.857)
   (CHARHT R 0.135)
   (CHARDP R 0.308)
   )
(CHARACTER O 252 (comment uni23DE.r)
   (CHARWD R 0.857)
   (CHARHT R 0.135)
   (CHARDP R 0.308)
   )
(CHARACTER O 253 (comment uni23DF.l)
   (CHARWD R 0.857)
   (CHARHT R 0.443)
   )
(CHARACTER O 254 (comment uni23DF.r)
   (CHARWD R 0.857)
   (CHARHT R 0.443)
   )
(CHARACTER O 255 (comment uni23DE.x)
   (CHARWD R 0.225)
   (CHARHT R 0.135)
   )
(CHARACTER O 256 (comment uni23DE.m)
   (CHARWD R 1.762)
   (CHARHT R 0.398)
   )
(CHARACTER O 257 (comment uni23DF.m)
   (CHARWD R 1.762)
   (CHARHT R 0.135)
   (CHARDP R 0.263)
   )
(CHARACTER O 260 (comment uni23DC.l)
   (CHARWD R 1.779)
   (CHARHT R 0.135)
   (CHARDP R 0.478)
   )
(CHARACTER O 261 (comment uni23DC.r)
   (CHARWD R 1.779)
   (CHARHT R 0.135)
   (CHARDP R 0.478)
   )
(CHARACTER O 262 (comment uni23DD.l)
   (CHARWD R 1.779)
   (CHARHT R 0.613)
   )
(CHARACTER O 263 (comment uni23DD.r)
   (CHARWD R 1.779)
   (CHARHT R 0.613)
   )
(CHARACTER O 264 (comment uni23B4.l)
   (CHARWD R 1.779)
   (CHARHT R 0.135)
   (CHARDP R 0.266)
   )
(CHARACTER O 265 (comment uni23B4.r)
   (CHARWD R 1.779)
   (CHARHT R 0.135)
   (CHARDP R 0.266)
   )
(CHARACTER O 266 (comment uni23B5.l)
   (CHARWD R 1.779)
   (CHARHT R 0.401)
   )
(CHARACTER O 267 (comment uni23B5.r)
   (CHARWD R 1.779)
   (CHARHT R 0.401)
   )
(CHARACTER O 270 (comment uni226B)
   (CHARWD R 0.933)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 271 (comment uni226C)
   (CHARWD R 0.466)
   (CHARHT R 0.73)
   (CHARDP R 0.224)
   )
(CHARACTER O 272 (comment uni226D)
   (CHARWD R 0.685)
   (CHARHT R 0.572)
   (CHARDP R 0.066)
   )
(CHARACTER O 273 (comment uni226E)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 274 (comment uni226F)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 275 (comment uni2270)
   (CHARWD R 0.685)
   (CHARHT R 0.73)
   (CHARDP R 0.229)
   )
(CHARACTER O 276 (comment uni2271)
   (CHARWD R 0.685)
   (CHARHT R 0.73)
   (CHARDP R 0.229)
   )
(CHARACTER O 277 (comment uni2272)
   (CHARWD R 0.685)
   (CHARHT R 0.664)
   (CHARDP R 0.164)
   )
(CHARACTER O 300 (comment uni2273)
   (CHARWD R 0.685)
   (CHARHT R 0.664)
   (CHARDP R 0.164)
   )
(CHARACTER O 301 (comment uni2274)
   (CHARWD R 0.685)
   (CHARHT R 0.731)
   (CHARDP R 0.228)
   )
(CHARACTER O 302 (comment uni2275)
   (CHARWD R 0.685)
   (CHARHT R 0.73)
   (CHARDP R 0.229)
   )
(CHARACTER O 303 (comment uni2276)
   (CHARWD R 0.685)
   (CHARHT R 0.705)
   (CHARDP R 0.204)
   )
(CHARACTER O 304 (comment uni2277)
   (CHARWD R 0.685)
   (CHARHT R 0.705)
   (CHARDP R 0.204)
   )
(CHARACTER O 305 (comment uni2278)
   (CHARWD R 0.685)
   (CHARHT R 0.75)
   (CHARDP R 0.25)
   )
(CHARACTER O 306 (comment uni2279)
   (CHARWD R 0.685)
   (CHARHT R 0.75)
   (CHARDP R 0.25)
   )
(CHARACTER O 307 (comment uni227A)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 310 (comment uni227B)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.026)
   )
(CHARACTER O 311 (comment uni227C)
   (CHARWD R 0.685)
   (CHARHT R 0.628)
   (CHARDP R 0.12)
   )
(CHARACTER O 312 (comment uni227D)
   (CHARWD R 0.685)
   (CHARHT R 0.629)
   (CHARDP R 0.119)
   )
(CHARACTER O 313 (comment uni227E)
   (CHARWD R 0.685)
   (CHARHT R 0.664)
   (CHARDP R 0.164)
   )
(CHARACTER O 314 (comment uni227F)
   (CHARWD R 0.685)
   (CHARHT R 0.664)
   (CHARDP R 0.164)
   )
(CHARACTER O 315 (comment uni2280)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 316 (comment uni2281)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 317 (comment uni2282)
   (CHARWD R 0.685)
   (CHARHT R 0.531)
   (CHARDP R 0.025)
   )
(CHARACTER O 320 (comment uni2283)
   (CHARWD R 0.685)
   (CHARHT R 0.531)
   (CHARDP R 0.025)
   )
(CHARACTER O 321 (comment uni2284)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 322 (comment uni2285)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 323 (comment uni2286)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.103)
   )
(CHARACTER O 324 (comment uni2287)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.103)
   )
(CHARACTER O 325 (comment uni2288)
   (CHARWD R 0.685)
   (CHARHT R 0.73)
   (CHARDP R 0.229)
   )
(CHARACTER O 326 (comment uni2289)
   (CHARWD R 0.685)
   (CHARHT R 0.73)
   (CHARDP R 0.229)
   )
(CHARACTER O 327 (comment uni228A)
   (CHARWD R 0.685)
   (CHARHT R 0.627)
   (CHARDP R 0.216)
   )
(CHARACTER O 330 (comment uni228B)
   (CHARWD R 0.685)
   (CHARHT R 0.627)
   (CHARDP R 0.216)
   )
(CHARACTER O 331 (comment uni228C)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 332 (comment uni228D)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 333 (comment uni228E)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 334 (comment uni228F)
   (CHARWD R 0.685)
   (CHARHT R 0.531)
   (CHARDP R 0.025)
   )
(CHARACTER O 335 (comment uni2290)
   (CHARWD R 0.685)
   (CHARHT R 0.531)
   (CHARDP R 0.025)
   )
(CHARACTER O 336 (comment uni2291)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.103)
   )
(CHARACTER O 337 (comment uni2292)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.103)
   )
(CHARACTER O 340 (comment uni2293)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 341 (comment uni2294)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 342 (comment uni2295)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 343 (comment uni2296)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 344 (comment uni2297)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 345 (comment uni2298)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 346 (comment uni2299)
   (CHARWD R 0.762)
   (CHARHT R 0.583)
   (CHARDP R 0.079)
   )
(CHARACTER O 347 (comment uni229A)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 350 (comment uni229B)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 351 (comment uni229C)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 352 (comment uni229D)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 353 (comment uni229E)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 354 (comment uni229F)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 355 (comment uni22A0)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 356 (comment uni22A1)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 357 (comment uni22A2)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   )
(CHARACTER O 360 (comment uni22A3)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   )
(CHARACTER O 361 (comment uni22A4)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   )
(CHARACTER O 362 (comment uni22A5)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   )
(CHARACTER O 363 (comment uni22A6)
   (CHARWD R 0.497)
   (CHARHT R 0.662)
   )
(CHARACTER O 364 (comment uni22A7)
   (CHARWD R 0.498)
   (CHARHT R 0.662)
   )
(CHARACTER O 365 (comment uni22A8)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   )
(CHARACTER O 366 (comment uni22A9)
   (CHARWD R 0.86)
   (CHARHT R 0.662)
   )
(CHARACTER O 367 (comment uni22AA)
   (CHARWD R 0.86)
   (CHARHT R 0.662)
   )
(CHARACTER O 370 (comment uni22AB)
   (CHARWD R 0.86)
   (CHARHT R 0.662)
   )
(CHARACTER O 371 (comment uni22AC)
   (CHARWD R 0.786)
   (CHARHT R 0.662)
   )
(CHARACTER O 372 (comment uni22AD)
   (CHARWD R 0.786)
   (CHARHT R 0.662)
   )
(CHARACTER O 373 (comment uni22AE)
   (CHARWD R 0.968)
   (CHARHT R 0.662)
   )
(CHARACTER O 374 (comment uni22AF)
   (CHARWD R 0.968)
   (CHARHT R 0.662)
   )
(CHARACTER O 375 (comment uni22B0)
   (CHARWD R 0.685)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 376 (comment uni22B1)
   (CHARWD R 0.685)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 377 (comment uni22B4)
   (CHARWD R 0.685)
   (CHARHT R 0.607)
   (CHARDP R 0.103)
   )
