(FAMILY stix-extra3-bold)
(CODINGSCHEME STIXEXTRA3)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 63)
(FONTDIMEN
   (SLANT R 0.000000)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 461)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   )
(CHARACTER O 1 (comment uniE369)
   (CHARWD R 667)
   (CHARHT R 775)
   (CHARDP R 235)
   (CHARIC R 3)
   )
(CHARACTER O 5 (comment uniE36D)
   (CHARWD R 757)
   (CHARHT R 793)
   (CHARDP R 235)
   (CHARIC R 1)
   )
(CHARACTER O 11 (comment uniE371)
   (CHARWD R 734)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 24 (comment uniE37C)
   (CHARWD R 667)
   (CHARHT R 775)
   (CHARDP R 235)
   )
(CHARACTER O 42 (comment uniE3B7)
   (CHARWD R 525)
   (CHARHT R 681)
   (CHARDP R 11)
   )
(CHARACTER O 43 (comment uniE3B8)
   (CHARWD R 525)
   (CHARHT R 681)
   )
(CHARACTER O 44 (comment uniE3B9)
   (CHARWD R 525)
   (CHARHT R 681)
   )
(CHARACTER O 45 (comment uniE3BA)
   (CHARWD R 525)
   (CHARHT R 681)
   (CHARDP R 11)
   )
(CHARACTER O 46 (comment uniE3BB)
   (CHARWD R 525)
   (CHARHT R 682)
   )
(CHARACTER O 47 (comment uniE3BC)
   (CHARWD R 525)
   (CHARHT R 670)
   (CHARDP R 11)
   )
(CHARACTER O 50 (comment uniE3BD)
   (CHARWD R 525)
   (CHARHT R 681)
   (CHARDP R 11)
   )
(CHARACTER O 51 (comment uniE3BE)
   (CHARWD R 525)
   (CHARHT R 686)
   (CHARDP R 11)
   )
(CHARACTER O 52 (comment uniE3BF)
   (CHARWD R 525)
   (CHARHT R 681)
   (CHARDP R 11)
   )
(CHARACTER O 53 (comment uniE3C0)
   (CHARWD R 525)
   (CHARHT R 681)
   (CHARDP R 11)
   )
(CHARACTER O 55 (comment uniE3C3)
   (CHARWD R 750)
   (CHARHT R 747)
   (CHARDP R 243)
   )
(CHARACTER O 56 (comment uniE3C4)
   (CHARWD R 750)
   (CHARHT R 747)
   (CHARDP R 243)
   )
