(FAMILY STIXMath)
(CODINGSCHEME STIXMATHITBOLD)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0.3)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   )
(LIGTABLE
   (LABEL O 0) (comment u1D71E)
   (KRN O 177 R 0.1375) (comment uni2040)
   (STOP)
   (LABEL O 1) (comment u1D71F)
   (KRN O 177 R 0.148) (comment uni2040)
   (STOP)
   (LABEL O 2) (comment u1D723)
   (KRN O 177 R 0.0595) (comment uni2040)
   (STOP)
   (LABEL O 3) (comment u1D726)
   (KRN O 177 R 0.1405) (comment uni2040)
   (STOP)
   (LABEL O 4) (comment u1D729)
   (KRN O 177 R 0.096) (comment uni2040)
   (STOP)
   (LABEL O 5) (comment u1D72B)
   (KRN O 177 R 0.067) (comment uni2040)
   (STOP)
   (LABEL O 6) (comment u1D72E)
   (KRN O 177 R 0.1125) (comment uni2040)
   (STOP)
   (LABEL O 7) (comment u1D730)
   (KRN O 177 R -0.0305) (comment uni2040)
   (STOP)
   (LABEL O 10) (comment u1D731)
   (KRN O 177 R 0.0625) (comment uni2040)
   (STOP)
   (LABEL O 11) (comment u1D733)
   (KRN O 177 R -0.0045) (comment uni2040)
   (STOP)
   (LABEL O 12) (comment u1D734)
   (KRN O 177 R 0.125) (comment uni2040)
   (STOP)
   (LABEL O 13) (comment u1D736)
   (KRN O 177 R 0.005) (comment uni2040)
   (STOP)
   (LABEL O 14) (comment u1D737)
   (KRN O 177 R 0.1495) (comment uni2040)
   (STOP)
   (LABEL O 15) (comment u1D738)
   (KRN O 177 R 0.0025) (comment uni2040)
   (STOP)
   (LABEL O 16) (comment u1D739)
   (KRN O 177 R 0.1) (comment uni2040)
   (STOP)
   (LABEL O 17) (comment u1D750)
   (KRN O 177 R 0.0655) (comment uni2040)
   (STOP)
   (LABEL O 20) (comment u1D73B)
   (KRN O 177 R 0.088) (comment uni2040)
   (STOP)
   (LABEL O 21) (comment u1D73C)
   (KRN O 177 R 0.0775) (comment uni2040)
   (STOP)
   (LABEL O 22) (comment u1D73D)
   (KRN O 177 R 0.095) (comment uni2040)
   (STOP)
   (LABEL O 23) (comment u1D73E)
   (KRN O 177 R 0.005) (comment uni2040)
   (STOP)
   (LABEL O 24) (comment u1D73F)
   (KRN O 177 R 0.011) (comment uni2040)
   (STOP)
   (LABEL O 25) (comment u1D740)
   (KRN O 177 R 0.061) (comment uni2040)
   (STOP)
   (LABEL O 26) (comment u1D741)
   (KRN O 177 R 0.086) (comment uni2040)
   (STOP)
   (LABEL O 27) (comment u1D742)
   (KRN O 177 R 0.0855) (comment uni2040)
   (STOP)
   (LABEL O 30) (comment u1D743)
   (KRN O 177 R 0.085) (comment uni2040)
   (STOP)
   (LABEL O 31) (comment u1D745)
   (KRN O 177 R 0.0695) (comment uni2040)
   (STOP)
   (LABEL O 32) (comment u1D746)
   (KRN O 177 R 0.1005) (comment uni2040)
   (STOP)
   (LABEL O 33) (comment u1D748)
   (KRN O 177 R 0.003) (comment uni2040)
   (STOP)
   (LABEL O 34) (comment u1D749)
   (KRN O 177 R 0.0335) (comment uni2040)
   (STOP)
   (LABEL O 35) (comment u1D74A)
   (KRN O 177 R 0.008) (comment uni2040)
   (STOP)
   (LABEL O 36) (comment u1D753)
   (KRN O 177 R 0.1125) (comment uni2040)
   (STOP)
   (LABEL O 37) (comment u1D74C)
   (KRN O 177 R 0.086) (comment uni2040)
   (STOP)
   (LABEL O 40) (comment u1D74D)
   (KRN O 177 R -0.004) (comment uni2040)
   (STOP)
   (LABEL O 41) (comment u1D74E)
   (KRN O 177 R 0.0545) (comment uni2040)
   (STOP)
   (LABEL O 42) (comment u1D73A)
   (KRN O 177 R 0.0325) (comment uni2040)
   (STOP)
   (LABEL O 43) (comment u1D751)
   (KRN O 177 R 0.0945) (comment uni2040)
   (STOP)
   (LABEL O 44) (comment u1D755)
   (KRN O 177 R 0.047) (comment uni2040)
   (STOP)
   (LABEL O 45) (comment u1D754)
   (KRN O 177 R 0.0775) (comment uni2040)
   (STOP)
   (LABEL O 46) (comment u1D747)
   (KRN O 177 R 0.129) (comment uni2040)
   (STOP)
   (LABEL O 47) (comment u1D74B)
   (KRN O 177 R 0.076) (comment uni2040)
   (STOP)
   (LABEL O 51) (comment u1D74F)
   (KRN O 177 R 0.1045) (comment uni2040)
   (STOP)
   (LABEL O 75) (comment uni210F)
   (KRN O 177 R -0.042) (comment uni2040)
   (STOP)
   (LABEL O 101) (comment u1D468)
   (KRN O 177 R 0.1385) (comment uni2040)
   (STOP)
   (LABEL O 102) (comment u1D469)
   (KRN O 177 R 0.103) (comment uni2040)
   (STOP)
   (LABEL O 103) (comment u1D46A)
   (KRN O 177 R 0.1015) (comment uni2040)
   (STOP)
   (LABEL O 104) (comment u1D46B)
   (KRN O 177 R 0.035) (comment uni2040)
   (STOP)
   (LABEL O 105) (comment u1D46C)
   (KRN O 177 R 0.095) (comment uni2040)
   (STOP)
   (LABEL O 106) (comment u1D46D)
   (KRN O 177 R 0.096) (comment uni2040)
   (STOP)
   (LABEL O 107) (comment u1D46E)
   (KRN O 177 R 0.116) (comment uni2040)
   (STOP)
   (LABEL O 110) (comment u1D46F)
   (KRN O 177 R 0.071) (comment uni2040)
   (STOP)
   (LABEL O 111) (comment u1D470)
   (KRN O 177 R 0.1055) (comment uni2040)
   (STOP)
   (LABEL O 112) (comment u1D471)
   (KRN O 177 R 0.147) (comment uni2040)
   (STOP)
   (LABEL O 113) (comment u1D472)
   (KRN O 177 R 0.1145) (comment uni2040)
   (STOP)
   (LABEL O 114) (comment u1D473)
   (KRN O 177 R 0.027) (comment uni2040)
   (STOP)
   (LABEL O 115) (comment u1D474)
   (KRN O 177 R 0.0745) (comment uni2040)
   (STOP)
   (LABEL O 116) (comment u1D475)
   (KRN O 177 R 0.055) (comment uni2040)
   (STOP)
   (LABEL O 117) (comment u1D476)
   (KRN O 177 R 0.0945) (comment uni2040)
   (STOP)
   (LABEL O 120) (comment u1D477)
   (KRN O 177 R 0.0735) (comment uni2040)
   (STOP)
   (LABEL O 121) (comment u1D478)
   (KRN O 177 R 0.078) (comment uni2040)
   (STOP)
   (LABEL O 122) (comment u1D479)
   (KRN O 177 R 0.042) (comment uni2040)
   (STOP)
   (LABEL O 123) (comment u1D47A)
   (KRN O 177 R 0.102) (comment uni2040)
   (STOP)
   (LABEL O 124) (comment u1D47B)
   (KRN O 177 R 0.034) (comment uni2040)
   (STOP)
   (LABEL O 125) (comment u1D47C)
   (KRN O 177 R 0.048) (comment uni2040)
   (STOP)
   (LABEL O 126) (comment u1D47D)
   (KRN O 177 R 0.0435) (comment uni2040)
   (STOP)
   (LABEL O 127) (comment u1D47E)
   (KRN O 177 R 0.0135) (comment uni2040)
   (STOP)
   (LABEL O 130) (comment u1D47F)
   (KRN O 177 R 0.094) (comment uni2040)
   (STOP)
   (LABEL O 131) (comment u1D480)
   (KRN O 177 R 0.0275) (comment uni2040)
   (STOP)
   (LABEL O 132) (comment u1D481)
   (KRN O 177 R 0.077) (comment uni2040)
   (STOP)
   (LABEL O 141) (comment u1D482)
   (KRN O 177 R 0.0395) (comment uni2040)
   (STOP)
   (LABEL O 142) (comment u1D483)
   (KRN O 177 R -0.0105) (comment uni2040)
   (STOP)
   (LABEL O 143) (comment u1D484)
   (KRN O 177 R 0.0645) (comment uni2040)
   (STOP)
   (LABEL O 144) (comment u1D485)
   (KRN O 177 R 0.1845) (comment uni2040)
   (STOP)
   (LABEL O 145) (comment u1D486)
   (KRN O 177 R 0.089) (comment uni2040)
   (STOP)
   (LABEL O 146) (comment u1D487)
   (KRN O 177 R 0.182) (comment uni2040)
   (STOP)
   (LABEL O 147) (comment u1D488)
   (KRN O 177 R 0.0745) (comment uni2040)
   (STOP)
   (LABEL O 150) (comment u1D489)
   (KRN O 177 R -0.042) (comment uni2040)
   (STOP)
   (LABEL O 151) (comment u1D48A)
   (KRN O 177 R 0.0555) (comment uni2040)
   (STOP)
   (LABEL O 152) (comment u1D48B)
   (KRN O 177 R 0.1125) (comment uni2040)
   (STOP)
   (LABEL O 153) (comment u1D48C)
   (KRN O 177 R -0.043) (comment uni2040)
   (STOP)
   (LABEL O 154) (comment u1D48D)
   (KRN O 177 R 0.065) (comment uni2040)
   (STOP)
   (LABEL O 155) (comment u1D48E)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 156) (comment u1D48F)
   (KRN O 177 R 0.0385) (comment uni2040)
   (STOP)
   (LABEL O 157) (comment u1D490)
   (KRN O 177 R 0.0595) (comment uni2040)
   (STOP)
   (LABEL O 160) (comment u1D491)
   (KRN O 177 R 0.0685) (comment uni2040)
   (STOP)
   (LABEL O 161) (comment u1D492)
   (KRN O 177 R 0.085) (comment uni2040)
   (STOP)
   (LABEL O 162) (comment u1D493)
   (KRN O 177 R 0.0435) (comment uni2040)
   (STOP)
   (LABEL O 163) (comment u1D494)
   (KRN O 177 R 0.052) (comment uni2040)
   (STOP)
   (LABEL O 164) (comment u1D495)
   (KRN O 177 R 0.0675) (comment uni2040)
   (STOP)
   (LABEL O 165) (comment u1D496)
   (KRN O 177 R 0.0305) (comment uni2040)
   (STOP)
   (LABEL O 166) (comment u1D497)
   (KRN O 177 R 0.065) (comment uni2040)
   (STOP)
   (LABEL O 167) (comment u1D498)
   (KRN O 177 R 0.079) (comment uni2040)
   (STOP)
   (LABEL O 170) (comment u1D499)
   (KRN O 177 R 0.0385) (comment uni2040)
   (STOP)
   (LABEL O 171) (comment u1D49A)
   (KRN O 177 R 0.0515) (comment uni2040)
   (STOP)
   (LABEL O 172) (comment u1D49B)
   (KRN O 177 R 0.0425) (comment uni2040)
   (STOP)
   (LABEL O 173) (comment u1D48A.dtls)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 174) (comment u1D48B.dtls)
   (KRN O 177 R 0.1295) (comment uni2040)
   (STOP)
   )
(CHARACTER O 0 (comment u1D71E)
   (CHARWD R 0.634)
   (CHARHT R 0.669)
   (CHARIC R 0.155)
   )
(CHARACTER O 1 (comment u1D71F)
   (CHARWD R 0.632)
   (CHARHT R 0.685)
   )
(CHARACTER O 2 (comment u1D723)
   (CHARWD R 0.783)
   (CHARHT R 0.685)
   (CHARDP R 0.016)
   (CHARIC R 0.068)
   )
(CHARACTER O 3 (comment u1D726)
   (CHARWD R 0.759)
   (CHARHT R 0.685)
   )
(CHARACTER O 4 (comment u1D729)
   (CHARWD R 0.718)
   (CHARHT R 0.669)
   (CHARIC R 0.08)
   )
(CHARACTER O 5 (comment u1D72B)
   (CHARWD R 0.887)
   (CHARHT R 0.669)
   (CHARIC R 0.095)
   )
(CHARACTER O 6 (comment u1D72E)
   (CHARWD R 0.759)
   (CHARHT R 0.669)
   (CHARIC R 0.068)
   )
(CHARACTER O 7 (comment u1D730)
   (CHARWD R 0.641)
   (CHARHT R 0.685)
   (CHARIC R 0.172)
   )
(CHARACTER O 10 (comment u1D731)
   (CHARWD R 0.827)
   (CHARHT R 0.669)
   (CHARIC R 0.012)
   )
(CHARACTER O 11 (comment u1D733)
   (CHARWD R 0.694)
   (CHARHT R 0.685)
   (CHARIC R 0.127)
   )
(CHARACTER O 12 (comment u1D734)
   (CHARWD R 0.826)
   (CHARHT R 0.685)
   (CHARIC R 0.02)
   )
(CHARACTER O 13 (comment u1D736)
   (CHARWD R 0.624)
   (CHARHT R 0.461)
   (CHARDP R 0.012)
   (CHARIC R 0.04)
   )
(CHARACTER O 14 (comment u1D737)
   (CHARWD R 0.555)
   (CHARHT R 0.685)
   (CHARDP R 0.205)
   (CHARIC R 0.07)
   )
(CHARACTER O 15 (comment u1D738)
   (CHARWD R 0.49)
   (CHARHT R 0.462)
   (CHARDP R 0.203)
   (CHARIC R 0.053)
   )
(CHARACTER O 16 (comment u1D739)
   (CHARWD R 0.538)
   (CHARHT R 0.685)
   (CHARDP R 0.008)
   )
(CHARACTER O 17 (comment u1D750)
   (CHARWD R 0.481)
   (CHARHT R 0.461)
   (CHARDP R 0.01)
   (CHARIC R 0.04)
   )
(CHARACTER O 20 (comment u1D73B)
   (CHARWD R 0.472)
   (CHARHT R 0.685)
   (CHARDP R 0.203)
   (CHARIC R 0.09)
   )
(CHARACTER O 21 (comment u1D73C)
   (CHARWD R 0.517)
   (CHARHT R 0.462)
   (CHARDP R 0.205)
   )
(CHARACTER O 22 (comment u1D73D)
   (CHARWD R 0.566)
   (CHARHT R 0.685003)
   (CHARDP R 0.011)
   )
(CHARACTER O 23 (comment u1D73E)
   (CHARWD R 0.318)
   (CHARHT R 0.462)
   (CHARDP R 0.009)
   )
(CHARACTER O 24 (comment u1D73F)
   (CHARWD R 0.56)
   (CHARHT R 0.462)
   (CHARIC R 0.05)
   )
(CHARACTER O 25 (comment u1D740)
   (CHARWD R 0.57)
   (CHARHT R 0.685)
   (CHARDP R 0.016)
   )
(CHARACTER O 26 (comment u1D741)
   (CHARWD R 0.636)
   (CHARHT R 0.449)
   (CHARDP R 0.205)
   )
(CHARACTER O 27 (comment u1D742)
   (CHARWD R 0.523)
   (CHARHT R 0.459)
   (CHARDP R 0.01)
   (CHARIC R 0.05)
   )
(CHARACTER O 30 (comment u1D743)
   (CHARWD R 0.476)
   (CHARHT R 0.685)
   (CHARDP R 0.203)
   (CHARIC R 0.05)
   )
(CHARACTER O 31 (comment u1D745)
   (CHARWD R 0.579)
   (CHARHT R 0.449)
   (CHARDP R 0.013)
   (CHARIC R 0.05)
   )
(CHARACTER O 32 (comment u1D746)
   (CHARWD R 0.595)
   (CHARHT R 0.462)
   (CHARDP R 0.205)
   )
(CHARACTER O 33 (comment u1D748)
   (CHARWD R 0.592)
   (CHARHT R 0.449)
   (CHARDP R 0.01)
   (CHARIC R 0.05)
   )
(CHARACTER O 34 (comment u1D749)
   (CHARWD R 0.469)
   (CHARHT R 0.449)
   (CHARDP R 0.007)
   (CHARIC R 0.08)
   )
(CHARACTER O 35 (comment u1D74A)
   (CHARWD R 0.552)
   (CHARHT R 0.462)
   (CHARDP R 0.01)
   )
(CHARACTER O 36 (comment u1D753)
   (CHARWD R 0.683)
   (CHARHT R 0.685)
   (CHARDP R 0.205)
   )
(CHARACTER O 37 (comment u1D74C)
   (CHARWD R 0.621)
   (CHARHT R 0.462)
   (CHARDP R 0.204)
   (CHARIC R 0.095)
   )
(CHARACTER O 40 (comment u1D74D)
   (CHARWD R 0.701)
   (CHARHT R 0.462)
   (CHARDP R 0.205)
   (CHARIC R 0.095)
   )
(CHARACTER O 41 (comment u1D74E)
   (CHARWD R 0.687)
   (CHARHT R 0.462)
   (CHARDP R 0.01)
   )
(CHARACTER O 42 (comment u1D73A)
   (CHARWD R 0.495)
   (CHARHT R 0.462)
   (CHARDP R 0.01)
   )
(CHARACTER O 43 (comment u1D751)
   (CHARWD R 0.607)
   (CHARHT R 0.698)
   (CHARDP R 0.013)
   )
(CHARACTER O 44 (comment u1D755)
   (CHARWD R 0.868)
   (CHARHT R 0.449)
   (CHARDP R 0.01)
   (CHARIC R 0.05)
   )
(CHARACTER O 45 (comment u1D754)
   (CHARWD R 0.585)
   (CHARHT R 0.462)
   (CHARDP R 0.205)
   )
(CHARACTER O 46 (comment u1D747)
   (CHARWD R 0.48)
   (CHARHT R 0.462)
   (CHARDP R 0.203)
   (CHARIC R 0.07)
   )
(CHARACTER O 47 (comment u1D74B)
   (CHARWD R 0.706)
   (CHARHT R 0.462)
   (CHARDP R 0.205)
   )
(CHARACTER O 50 (comment u1D735)
   (CHARWD R 0.632)
   (CHARHT R 0.669)
   (CHARDP R 0.016)
   (CHARIC R 0.01)
   )
(CHARACTER O 51 (comment u1D74F)
   (CHARWD R 0.559)
   (CHARHT R 0.686)
   (CHARDP R 0.01)
   (CHARIC R 0.04)
   )
(CHARACTER O 52 (comment uni2135)
   (CHARWD R 0.766)
   (CHARHT R 0.694)
   (CHARDP R 0.034)
   )
(CHARACTER O 53 (comment uni2136)
   (CHARWD R 0.703)
   (CHARHT R 0.694)
   (CHARDP R 0.034)
   )
(CHARACTER O 54 (comment uni2137)
   (CHARWD R 0.562)
   (CHARHT R 0.694)
   (CHARDP R 0.034)
   )
(CHARACTER O 55 (comment uni2138)
   (CHARWD R 0.599)
   (CHARHT R 0.694)
   (CHARDP R 0.034)
   )
(CHARACTER O 56 (comment uni22B3)
   (CHARWD R 0.75)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 57 (comment uni22B2)
   (CHARWD R 0.75)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 60 (comment u1D7CE)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 61 (comment u1D7CF)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   )
(CHARACTER O 62 (comment u1D7D0)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   )
(CHARACTER O 63 (comment u1D7D1)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.014)
   )
(CHARACTER O 64 (comment u1D7D2)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   )
(CHARACTER O 65 (comment u1D7D3)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.008)
   )
(CHARACTER O 66 (comment u1D7D4)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 67 (comment u1D7D5)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 70 (comment u1D7D6)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 71 (comment u1D7D7)
   (CHARWD R 0.5)
   (CHARHT R 0.688)
   (CHARDP R 0.013)
   )
(CHARACTER O 72 (comment period)
   (CHARWD R 0.25)
   (CHARHT R 0.156)
   (CHARDP R 0.013)
   )
(CHARACTER O 73 (comment comma)
   (CHARWD R 0.25)
   (CHARHT R 0.155)
   (CHARDP R 0.18)
   )
(CHARACTER O 74 (comment less)
   (CHARWD R 0.75)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 75 (comment uni210F)
   (CHARWD R 0.576)
   (CHARHT R 0.685)
   (CHARDP R 0.01)
   )
(CHARACTER O 76 (comment greater)
   (CHARWD R 0.75)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 77 (comment uni22C6)
   (CHARWD R 0.788)
   (CHARHT R 0.687)
   (CHARDP R 0.013)
   )
(CHARACTER O 100 (comment uni2268)
   (CHARWD R 0.75)
   (CHARHT R 0.729)
   (CHARDP R 0.294)
   )
(CHARACTER O 101 (comment u1D468)
   (CHARWD R 0.759)
   (CHARHT R 0.685)
   )
(CHARACTER O 102 (comment u1D469)
   (CHARWD R 0.726)
   (CHARHT R 0.669)
   (CHARIC R 0.04)
   )
(CHARACTER O 103 (comment u1D46A)
   (CHARWD R 0.701)
   (CHARHT R 0.685)
   (CHARDP R 0.012)
   (CHARIC R 0.084)
   )
(CHARACTER O 104 (comment u1D46B)
   (CHARWD R 0.818)
   (CHARHT R 0.669)
   (CHARIC R 0.068)
   )
(CHARACTER O 105 (comment u1D46C)
   (CHARWD R 0.732)
   (CHARHT R 0.669)
   (CHARIC R 0.062)
   )
(CHARACTER O 106 (comment u1D46D)
   (CHARWD R 0.635)
   (CHARHT R 0.669)
   (CHARIC R 0.155)
   )
(CHARACTER O 107 (comment u1D46E)
   (CHARWD R 0.768)
   (CHARHT R 0.685)
   (CHARDP R 0.012)
   (CHARIC R 0.02)
   )
(CHARACTER O 110 (comment u1D46F)
   (CHARWD R 0.891)
   (CHARHT R 0.669)
   (CHARIC R 0.095)
   )
(CHARACTER O 111 (comment u1D470)
   (CHARWD R 0.502)
   (CHARHT R 0.669)
   (CHARIC R 0.095)
   )
(CHARACTER O 112 (comment u1D471)
   (CHARWD R 0.558)
   (CHARHT R 0.669)
   (CHARDP R 0.012)
   (CHARIC R 0.128)
   )
(CHARACTER O 113 (comment u1D472)
   (CHARWD R 0.795)
   (CHARHT R 0.669)
   (CHARIC R 0.084)
   )
(CHARACTER O 114 (comment u1D473)
   (CHARWD R 0.744)
   (CHARHT R 0.669)
   )
(CHARACTER O 115 (comment u1D474)
   (CHARWD R 1.016)
   (CHARHT R 0.669)
   (CHARIC R 0.095)
   )
(CHARACTER O 116 (comment u1D475)
   (CHARWD R 0.869)
   (CHARHT R 0.669)
   (CHARIC R 0.095)
   )
(CHARACTER O 117 (comment u1D476)
   (CHARWD R 0.777)
   (CHARHT R 0.685)
   (CHARDP R 0.016)
   (CHARIC R 0.02)
   )
(CHARACTER O 120 (comment u1D477)
   (CHARWD R 0.612)
   (CHARHT R 0.669)
   (CHARIC R 0.161)
   )
(CHARACTER O 121 (comment u1D478)
   (CHARWD R 0.81)
   (CHARHT R 0.685)
   (CHARDP R 0.154)
   )
(CHARACTER O 122 (comment u1D479)
   (CHARWD R 0.801)
   (CHARHT R 0.669)
   (CHARIC R 0.025)
   )
(CHARACTER O 123 (comment u1D47A)
   (CHARWD R 0.671)
   (CHARHT R 0.685)
   (CHARDP R 0.01)
   (CHARIC R 0.073)
   )
(CHARACTER O 124 (comment u1D47B)
   (CHARWD R 0.568)
   (CHARHT R 0.669)
   (CHARIC R 0.172)
   )
(CHARACTER O 125 (comment u1D47C)
   (CHARWD R 0.733)
   (CHARHT R 0.669)
   (CHARDP R 0.01)
   (CHARIC R 0.117)
   )
(CHARACTER O 126 (comment u1D47D)
   (CHARWD R 0.593)
   (CHARHT R 0.669)
   (CHARDP R 0.015)
   (CHARIC R 0.244)
   )
(CHARACTER O 127 (comment u1D47E)
   (CHARWD R 0.925)
   (CHARHT R 0.669)
   (CHARDP R 0.017)
   (CHARIC R 0.244)
   )
(CHARACTER O 130 (comment u1D47F)
   (CHARWD R 0.808)
   (CHARHT R 0.669)
   (CHARIC R 0.062)
   )
(CHARACTER O 131 (comment u1D480)
   (CHARWD R 0.549)
   (CHARHT R 0.669)
   (CHARIC R 0.216)
   )
(CHARACTER O 132 (comment u1D481)
   (CHARWD R 0.797)
   (CHARHT R 0.669)
   (CHARIC R 0.073)
   )
(CHARACTER O 133 (comment uni266D)
   (CHARWD R 0.437)
   (CHARHT R 0.74)
   (CHARDP R 0.005)
   )
(CHARACTER O 134 (comment uni266E)
   (CHARWD R 0.49)
   (CHARHT R 0.818)
   (CHARDP R 0.21)
   )
(CHARACTER O 135 (comment uni266F)
   (CHARWD R 0.49)
   (CHARHT R 0.818)
   (CHARDP R 0.21)
   )
(CHARACTER O 136 (comment uni2323)
   (CHARWD R 1.026)
   (CHARHT R 0.378)
   )
(CHARACTER O 137 (comment uni2322)
   (CHARWD R 1.026)
   (CHARHT R 0.378)
   )
(CHARACTER O 140 (comment uni210F.var)
   (CHARWD R 0.579)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 141 (comment u1D482)
   (CHARWD R 0.581)
   (CHARHT R 0.462)
   (CHARDP R 0.01)
   )
(CHARACTER O 142 (comment u1D483)
   (CHARWD R 0.509)
   (CHARHT R 0.685)
   (CHARDP R 0.008)
   )
(CHARACTER O 143 (comment u1D484)
   (CHARWD R 0.477)
   (CHARHT R 0.462)
   (CHARDP R 0.01)
   (CHARIC R 0.05)
   )
(CHARACTER O 144 (comment u1D485)
   (CHARWD R 0.595)
   (CHARHT R 0.685)
   (CHARDP R 0.014)
   (CHARIC R 0.04)
   )
(CHARACTER O 145 (comment u1D486)
   (CHARWD R 0.498)
   (CHARHT R 0.462)
   (CHARDP R 0.01)
   )
(CHARACTER O 146 (comment u1D487)
   (CHARWD R 0.572)
   (CHARHT R 0.685)
   (CHARDP R 0.207)
   (CHARIC R 0.12)
   )
(CHARACTER O 147 (comment u1D488)
   (CHARWD R 0.527)
   (CHARHT R 0.462)
   (CHARDP R 0.203)
   )
(CHARACTER O 150 (comment u1D489)
   (CHARWD R 0.576)
   (CHARHT R 0.685)
   (CHARDP R 0.01)
   )
(CHARACTER O 151 (comment u1D48A)
   (CHARWD R 0.357)
   (CHARHT R 0.62)
   (CHARDP R 0.009)
   )
(CHARACTER O 152 (comment u1D48B)
   (CHARWD R 0.431)
   (CHARHT R 0.62)
   (CHARDP R 0.207)
   (CHARIC R 0.04)
   )
(CHARACTER O 153 (comment u1D48C)
   (CHARWD R 0.58)
   (CHARHT R 0.685)
   (CHARDP R 0.011)
   )
(CHARACTER O 154 (comment u1D48D)
   (CHARWD R 0.346)
   (CHARHT R 0.685)
   (CHARDP R 0.009)
   )
(CHARACTER O 155 (comment u1D48E)
   (CHARWD R 0.76)
   (CHARHT R 0.467)
   (CHARDP R 0.009)
   )
(CHARACTER O 156 (comment u1D48F)
   (CHARWD R 0.559)
   (CHARHT R 0.467)
   (CHARDP R 0.01)
   )
(CHARACTER O 157 (comment u1D490)
   (CHARWD R 0.561)
   (CHARHT R 0.462)
   (CHARDP R 0.01)
   )
(CHARACTER O 160 (comment u1D491)
   (CHARWD R 0.571)
   (CHARHT R 0.469)
   (CHARDP R 0.205)
   )
(CHARACTER O 161 (comment u1D492)
   (CHARWD R 0.526)
   (CHARHT R 0.462)
   (CHARDP R 0.205)
   (CHARIC R 0.04)
   )
(CHARACTER O 162 (comment u1D493)
   (CHARWD R 0.441)
   (CHARHT R 0.467)
   )
(CHARACTER O 163 (comment u1D494)
   (CHARWD R 0.474)
   (CHARHT R 0.462)
   (CHARDP R 0.011)
   )
(CHARACTER O 164 (comment u1D495)
   (CHARWD R 0.351)
   (CHARHT R 0.592)
   (CHARDP R 0.01)
   )
(CHARACTER O 165 (comment u1D496)
   (CHARWD R 0.535)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   )
(CHARACTER O 166 (comment u1D497)
   (CHARWD R 0.554)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 167 (comment u1D498)
   (CHARWD R 0.814)
   (CHARHT R 0.473)
   (CHARDP R 0.014)
   )
(CHARACTER O 170 (comment u1D499)
   (CHARWD R 0.587)
   (CHARHT R 0.462)
   (CHARDP R 0.008)
   )
(CHARACTER O 171 (comment u1D49A)
   (CHARWD R 0.519)
   (CHARHT R 0.462)
   (CHARDP R 0.205)
   (CHARIC R 0.048)
   )
(CHARACTER O 172 (comment u1D49B)
   (CHARWD R 0.531)
   (CHARHT R 0.462)
   (CHARDP R 0.019)
   )
(CHARACTER O 173 (comment u1D48A.dtls)
   (CHARWD R 0.357)
   (CHARHT R 0.462)
   (CHARDP R 0.009)
   )
(CHARACTER O 174 (comment u1D48B.dtls)
   (CHARWD R 0.431)
   (CHARHT R 0.462)
   (CHARDP R 0.207)
   (CHARIC R 0.04)
   )
(CHARACTER O 175 (comment uni2269)
   (CHARWD R 0.75)
   (CHARHT R 0.729)
   (CHARDP R 0.294)
   )
(CHARACTER O 176 (comment uni226A)
   (CHARWD R 1)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 177 (comment uni2040)
   (CHARWD R 0.798)
   (CHARHT R 0.7)
   )
(CHARACTER O 200 (comment uni0300)
   (CHARWD R 0.238)
   (CHARHT R 0.7)
   )
(CHARACTER O 201 (comment uni0301)
   (CHARWD R 0.238)
   (CHARHT R 0.7)
   )
(CHARACTER O 202 (comment uni0302)
   (CHARWD R 0.337)
   (CHARHT R 0.7)
   )
(CHARACTER O 203 (comment uni0303)
   (CHARWD R 0.365)
   (CHARHT R 0.7)
   )
(CHARACTER O 204 (comment uni0304)
   (CHARWD R 0.33)
   (CHARHT R 0.6)
   )
(CHARACTER O 205 (comment uni0306)
   (CHARWD R 0.303)
   (CHARHT R 0.7)
   )
(CHARACTER O 206 (comment uni0307)
   (CHARWD R 0.129)
   (CHARHT R 0.7)
   )
(CHARACTER O 207 (comment uni0308)
   (CHARWD R 0.339)
   (CHARHT R 0.7)
   )
(CHARACTER O 210 (comment uni0309)
   (CHARWD R 0.205)
   (CHARHT R 0.8)
   )
(CHARACTER O 211 (comment uni030A)
   (CHARWD R 0.213)
   (CHARHT R 0.8)
   )
(CHARACTER O 212 (comment uni030C)
   (CHARWD R 0.337)
   (CHARHT R 0.7)
   )
(CHARACTER O 213 (comment uni0310)
   (CHARWD R 0.303)
   (CHARHT R 0.8)
   )
(CHARACTER O 214 (comment uni0312)
   (CHARWD R 0.184)
   (CHARHT R 0.9)
   )
(CHARACTER O 215 (comment uni0315)
   (CHARWD R 0.184)
   (CHARHT R 0.9)
   )
(CHARACTER O 216 (comment uni031A)
   (CHARWD R 0.317)
   (CHARHT R 0.8)
   )
(CHARACTER O 217 (comment uni20D0)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 220 (comment uni20D1)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 221 (comment uni20D6)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 222 (comment uni20D7)
   (CHARWD R 0.484)
   (CHARHT R 0.8)
   )
(CHARACTER O 223 (comment uni20DB)
   (CHARWD R 0.549)
   (CHARHT R 0.7)
   )
(CHARACTER O 224 (comment uni20DC)
   (CHARWD R 0.759)
   (CHARHT R 0.7)
   )
(CHARACTER O 225 (comment uni20E1)
   (CHARWD R 0.594)
   (CHARHT R 0.8)
   )
(CHARACTER O 226 (comment uni20E7)
   (CHARWD R 0.843)
   (CHARHT R 0.8)
   (CHARDP R 0)
   )
(CHARACTER O 227 (comment uni20E9)
   (CHARWD R 0.564)
   (CHARHT R 0.7)
   )
(CHARACTER O 230 (comment uni20F0)
   (CHARWD R 0.27)
   (CHARHT R 0.8)
   )
(CHARACTER O 231 (comment uni20D6.x)
   (CHARWD R 0.225)
   (CHARHT R 0.715)
   )
(CHARACTER O 232 (comment uni0302.s1)
   (CHARWD R 0.56)
   (CHARHT R 0.767)
   (NEXTLARGER O 235)
   )
(CHARACTER O 233 (comment uni0303.s1)
   (CHARWD R 0.56)
   (CHARHT R 0.75)
   (NEXTLARGER O 236)
   )
(CHARACTER O 234 (comment uni030C.s1)
   (CHARWD R 0.56)
   (CHARHT R 0.767)
   (NEXTLARGER O 237)
   )
(CHARACTER O 235 (comment uni0302.s2)
   (CHARWD R 0.979)
   (CHARHT R 0.777)
   (NEXTLARGER O 240)
   )
(CHARACTER O 236 (comment uni0303.s2)
   (CHARWD R 0.979)
   (CHARHT R 0.76)
   (NEXTLARGER O 241)
   )
(CHARACTER O 237 (comment uni030C.s2)
   (CHARWD R 0.979)
   (CHARHT R 0.777)
   (NEXTLARGER O 242)
   )
(CHARACTER O 240 (comment uni0302.s3)
   (CHARWD R 1.46)
   (CHARHT R 0.777)
   (NEXTLARGER O 243)
   )
(CHARACTER O 241 (comment uni0303.s3)
   (CHARWD R 1.46)
   (CHARHT R 0.774)
   (NEXTLARGER O 244)
   )
(CHARACTER O 242 (comment uni030C.s3)
   (CHARWD R 1.46)
   (CHARHT R 0.777)
   (NEXTLARGER O 245)
   )
(CHARACTER O 243 (comment uni0302.s4)
   (CHARWD R 1.886)
   (CHARHT R 0.796)
   (NEXTLARGER O 246)
   )
(CHARACTER O 244 (comment uni0303.s4)
   (CHARWD R 1.886)
   (CHARHT R 0.771)
   (NEXTLARGER O 247)
   )
(CHARACTER O 245 (comment uni030C.s4)
   (CHARWD R 1.886)
   (CHARHT R 0.796)
   (NEXTLARGER O 250)
   )
(CHARACTER O 246 (comment uni0302.s5)
   (CHARWD R 2.328)
   (CHARHT R 0.816)
   )
(CHARACTER O 247 (comment uni0303.s5)
   (CHARWD R 2.328)
   (CHARHT R 0.78)
   )
(CHARACTER O 250 (comment uni030C.s5)
   (CHARWD R 2.328)
   (CHARHT R 0.816)
   )
(CHARACTER O 251 (comment uni23DE.l)
   (CHARWD R 0.857)
   (CHARHT R 0.135)
   (CHARDP R 0.308)
   )
(CHARACTER O 252 (comment uni23DE.r)
   (CHARWD R 0.857)
   (CHARHT R 0.135)
   (CHARDP R 0.308)
   )
(CHARACTER O 253 (comment uni23DF.l)
   (CHARWD R 0.857)
   (CHARHT R 0.443)
   )
(CHARACTER O 254 (comment uni23DF.r)
   (CHARWD R 0.857)
   (CHARHT R 0.443)
   )
(CHARACTER O 255 (comment uni23DE.x)
   (CHARWD R 0.225)
   (CHARHT R 0.135)
   )
(CHARACTER O 256 (comment uni23DE.m)
   (CHARWD R 1.762)
   (CHARHT R 0.398)
   )
(CHARACTER O 257 (comment uni23DF.m)
   (CHARWD R 1.762)
   (CHARHT R 0.135)
   (CHARDP R 0.263)
   )
(CHARACTER O 260 (comment uni23DC.l)
   (CHARWD R 1.779)
   (CHARHT R 0.135)
   (CHARDP R 0.478)
   )
(CHARACTER O 261 (comment uni23DC.r)
   (CHARWD R 1.779)
   (CHARHT R 0.135)
   (CHARDP R 0.478)
   )
(CHARACTER O 262 (comment uni23DD.l)
   (CHARWD R 1.779)
   (CHARHT R 0.613)
   )
(CHARACTER O 263 (comment uni23DD.r)
   (CHARWD R 1.779)
   (CHARHT R 0.613)
   )
(CHARACTER O 264 (comment uni23B4.l)
   (CHARWD R 1.779)
   (CHARHT R 0.135)
   (CHARDP R 0.266)
   )
(CHARACTER O 265 (comment uni23B4.r)
   (CHARWD R 1.779)
   (CHARHT R 0.135)
   (CHARDP R 0.266)
   )
(CHARACTER O 266 (comment uni23B5.l)
   (CHARWD R 1.779)
   (CHARHT R 0.401)
   )
(CHARACTER O 267 (comment uni23B5.r)
   (CHARWD R 1.779)
   (CHARHT R 0.401)
   )
(CHARACTER O 270 (comment uni226B)
   (CHARWD R 1)
   (CHARHT R 0.534)
   (CHARDP R 0.024)
   )
(CHARACTER O 271 (comment uni226C)
   (CHARWD R 0.417)
   (CHARHT R 0.732)
   (CHARDP R 0.193)
   )
(CHARACTER O 272 (comment uni226D)
   (CHARWD R 0.75)
   (CHARHT R 0.591)
   (CHARDP R 0.087)
   )
(CHARACTER O 273 (comment uni226E)
   (CHARWD R 0.75)
   (CHARHT R 0.625)
   (CHARDP R 0.115)
   )
(CHARACTER O 274 (comment uni226F)
   (CHARWD R 0.75)
   (CHARHT R 0.625)
   (CHARDP R 0.115)
   )
(CHARACTER O 275 (comment uni2270)
   (CHARWD R 0.75)
   (CHARHT R 0.717)
   (CHARDP R 0.235)
   )
(CHARACTER O 276 (comment uni2271)
   (CHARWD R 0.75)
   (CHARHT R 0.717)
   (CHARDP R 0.235)
   )
(CHARACTER O 277 (comment uni2272)
   (CHARWD R 0.75)
   (CHARHT R 0.69)
   (CHARDP R 0.182)
   )
(CHARACTER O 300 (comment uni2273)
   (CHARWD R 0.75)
   (CHARHT R 0.69)
   (CHARDP R 0.182)
   )
(CHARACTER O 301 (comment uni2274)
   (CHARWD R 0.75)
   (CHARHT R 0.78)
   (CHARDP R 0.282)
   )
(CHARACTER O 302 (comment uni2275)
   (CHARWD R 0.75)
   (CHARHT R 0.78)
   (CHARDP R 0.282)
   )
(CHARACTER O 303 (comment uni2276)
   (CHARWD R 0.75)
   (CHARHT R 0.734)
   (CHARDP R 0.226)
   )
(CHARACTER O 304 (comment uni2277)
   (CHARWD R 0.75)
   (CHARHT R 0.734)
   (CHARDP R 0.226)
   )
(CHARACTER O 305 (comment uni2278)
   (CHARWD R 0.75)
   (CHARHT R 0.824)
   (CHARDP R 0.316)
   )
(CHARACTER O 306 (comment uni2279)
   (CHARWD R 0.75)
   (CHARHT R 0.824)
   (CHARDP R 0.316)
   )
(CHARACTER O 307 (comment uni227A)
   (CHARWD R 0.75)
   (CHARHT R 0.531)
   (CHARDP R 0.023)
   )
(CHARACTER O 310 (comment uni227B)
   (CHARWD R 0.75)
   (CHARHT R 0.531)
   (CHARDP R 0.023)
   )
(CHARACTER O 311 (comment uni227C)
   (CHARWD R 0.75)
   (CHARHT R 0.645)
   (CHARDP R 0.138)
   )
(CHARACTER O 312 (comment uni227D)
   (CHARWD R 0.75)
   (CHARHT R 0.645)
   (CHARDP R 0.138)
   )
(CHARACTER O 313 (comment uni227E)
   (CHARWD R 0.75)
   (CHARHT R 0.676)
   (CHARDP R 0.169)
   )
(CHARACTER O 314 (comment uni227F)
   (CHARWD R 0.75)
   (CHARHT R 0.676)
   (CHARDP R 0.169)
   )
(CHARACTER O 315 (comment uni2280)
   (CHARWD R 0.75)
   (CHARHT R 0.625)
   (CHARDP R 0.115)
   )
(CHARACTER O 316 (comment uni2281)
   (CHARWD R 0.75)
   (CHARHT R 0.625)
   (CHARDP R 0.115)
   )
(CHARACTER O 317 (comment uni2282)
   (CHARWD R 0.75)
   (CHARHT R 0.547)
   (CHARDP R 0.013)
   )
(CHARACTER O 320 (comment uni2283)
   (CHARWD R 0.75)
   (CHARHT R 0.547)
   (CHARDP R 0.013)
   )
(CHARACTER O 321 (comment uni2284)
   (CHARWD R 0.75)
   (CHARHT R 0.68)
   (CHARDP R 0.146)
   )
(CHARACTER O 322 (comment uni2285)
   (CHARWD R 0.75)
   (CHARHT R 0.68)
   (CHARDP R 0.146)
   )
(CHARACTER O 323 (comment uni2286)
   (CHARWD R 0.75)
   (CHARHT R 0.647)
   (CHARDP R 0.101)
   )
(CHARACTER O 324 (comment uni2287)
   (CHARWD R 0.75)
   (CHARHT R 0.647)
   (CHARDP R 0.101)
   )
(CHARACTER O 325 (comment uni2288)
   (CHARWD R 0.75)
   (CHARHT R 0.747)
   (CHARDP R 0.201)
   )
(CHARACTER O 326 (comment uni2289)
   (CHARWD R 0.75)
   (CHARHT R 0.747)
   (CHARDP R 0.201)
   )
(CHARACTER O 327 (comment uni228A)
   (CHARWD R 0.75)
   (CHARHT R 0.734)
   (CHARDP R 0.2)
   )
(CHARACTER O 330 (comment uni228B)
   (CHARWD R 0.75)
   (CHARHT R 0.734)
   (CHARDP R 0.2)
   )
(CHARACTER O 331 (comment uni228C)
   (CHARWD R 0.65)
   (CHARHT R 0.541)
   (CHARDP R 0.033)
   )
(CHARACTER O 332 (comment uni228D)
   (CHARWD R 0.65)
   (CHARHT R 0.541)
   (CHARDP R 0.033)
   )
(CHARACTER O 333 (comment uni228E)
   (CHARWD R 0.65)
   (CHARHT R 0.541)
   (CHARDP R 0.033)
   )
(CHARACTER O 334 (comment uni228F)
   (CHARWD R 0.75)
   (CHARHT R 0.532)
   (CHARDP R 0.027)
   )
(CHARACTER O 335 (comment uni2290)
   (CHARWD R 0.75)
   (CHARHT R 0.532)
   (CHARDP R 0.027)
   )
(CHARACTER O 336 (comment uni2291)
   (CHARWD R 0.75)
   (CHARHT R 0.644)
   (CHARDP R 0.093)
   )
(CHARACTER O 337 (comment uni2292)
   (CHARWD R 0.75)
   (CHARHT R 0.644)
   (CHARDP R 0.093)
   )
(CHARACTER O 340 (comment uni2293)
   (CHARWD R 0.65)
   (CHARHT R 0.541)
   (CHARDP R 0.033)
   )
(CHARACTER O 341 (comment uni2294)
   (CHARWD R 0.65)
   (CHARHT R 0.541)
   (CHARDP R 0.033)
   )
(CHARACTER O 342 (comment uni2295)
   (CHARWD R 0.864)
   (CHARHT R 0.634)
   (CHARDP R 0.13)
   )
(CHARACTER O 343 (comment uni2296)
   (CHARWD R 0.864)
   (CHARHT R 0.634)
   (CHARDP R 0.13)
   )
(CHARACTER O 344 (comment uni2297)
   (CHARWD R 0.864)
   (CHARHT R 0.634)
   (CHARDP R 0.13)
   )
(CHARACTER O 345 (comment uni2298)
   (CHARWD R 0.864)
   (CHARHT R 0.634)
   (CHARDP R 0.13)
   )
(CHARACTER O 346 (comment uni2299)
   (CHARWD R 0.784)
   (CHARHT R 0.594)
   (CHARDP R 0.09)
   )
(CHARACTER O 347 (comment uni229A)
   (CHARWD R 0.842)
   (CHARHT R 0.634)
   (CHARDP R 0.13)
   )
(CHARACTER O 350 (comment uni229B)
   (CHARWD R 0.864)
   (CHARHT R 0.634)
   (CHARDP R 0.13)
   )
(CHARACTER O 351 (comment uni229C)
   (CHARWD R 0.864)
   (CHARHT R 0.634)
   (CHARDP R 0.13)
   )
(CHARACTER O 352 (comment uni229D)
   (CHARWD R 0.864)
   (CHARHT R 0.634)
   (CHARDP R 0.13)
   )
(CHARACTER O 353 (comment uni229E)
   (CHARWD R 0.91)
   (CHARHT R 0.661)
   (CHARDP R 0.158)
   )
(CHARACTER O 354 (comment uni229F)
   (CHARWD R 0.91)
   (CHARHT R 0.661)
   (CHARDP R 0.158)
   )
(CHARACTER O 355 (comment uni22A0)
   (CHARWD R 0.91)
   (CHARHT R 0.661)
   (CHARDP R 0.158)
   )
(CHARACTER O 356 (comment uni22A1)
   (CHARWD R 0.91)
   (CHARHT R 0.661)
   (CHARDP R 0.158)
   )
(CHARACTER O 357 (comment uni22A2)
   (CHARWD R 0.75)
   (CHARHT R 0.676)
   )
(CHARACTER O 360 (comment uni22A3)
   (CHARWD R 0.75)
   (CHARHT R 0.676)
   )
(CHARACTER O 361 (comment uni22A4)
   (CHARWD R 0.75)
   (CHARHT R 0.676)
   )
(CHARACTER O 362 (comment uni22A5)
   (CHARWD R 0.75)
   (CHARHT R 0.676)
   )
(CHARACTER O 363 (comment uni22A6)
   (CHARWD R 0.555)
   (CHARHT R 0.676)
   )
(CHARACTER O 364 (comment uni22A7)
   (CHARWD R 0.555)
   (CHARHT R 0.676)
   )
(CHARACTER O 365 (comment uni22A8)
   (CHARWD R 0.75)
   (CHARHT R 0.676)
   )
(CHARACTER O 366 (comment uni22A9)
   (CHARWD R 0.972)
   (CHARHT R 0.676)
   )
(CHARACTER O 367 (comment uni22AA)
   (CHARWD R 0.944)
   (CHARHT R 0.676)
   )
(CHARACTER O 370 (comment uni22AB)
   (CHARWD R 0.944)
   (CHARHT R 0.676)
   )
(CHARACTER O 371 (comment uni22AC)
   (CHARWD R 0.913)
   (CHARHT R 0.676)
   )
(CHARACTER O 372 (comment uni22AD)
   (CHARWD R 0.912)
   (CHARHT R 0.676)
   )
(CHARACTER O 373 (comment uni22AE)
   (CHARWD R 1.096)
   (CHARHT R 0.676)
   )
(CHARACTER O 374 (comment uni22AF)
   (CHARWD R 1.104)
   (CHARHT R 0.676)
   )
(CHARACTER O 375 (comment uni22B0)
   (CHARWD R 0.75)
   (CHARHT R 0.543)
   (CHARDP R 0.038)
   )
(CHARACTER O 376 (comment uni22B1)
   (CHARWD R 0.75)
   (CHARHT R 0.543)
   (CHARDP R 0.038)
   )
(CHARACTER O 377 (comment uni22B4)
   (CHARWD R 0.75)
   (CHARHT R 0.621)
   (CHARDP R 0.113)
   )
