(FAMILY STIXMathSans)
(CODINGSCHEME STIXMATHSF)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   )
(LIGTABLE
   (LABEL O 101) (comment u1D5A0)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 102) (comment u1D5A1)
   (KRN O 177 R -0.052) (comment uni2040)
   (STOP)
   (LABEL O 103) (comment u1D5A2)
   (KRN O 177 R 0.0285) (comment uni2040)
   (STOP)
   (LABEL O 104) (comment u1D5A3)
   (KRN O 177 R 0.019) (comment uni2040)
   (STOP)
   (LABEL O 105) (comment u1D5A4)
   (KRN O 177 R 0.0155) (comment uni2040)
   (STOP)
   (LABEL O 106) (comment u1D5A5)
   (KRN O 177 R 0.0305) (comment uni2040)
   (STOP)
   (LABEL O 107) (comment u1D5A6)
   (KRN O 177 R 0.0235) (comment uni2040)
   (STOP)
   (LABEL O 110) (comment u1D5A7)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 111) (comment u1D5A8)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 112) (comment u1D5A9)
   (KRN O 177 R 0.065) (comment uni2040)
   (STOP)
   (LABEL O 113) (comment u1D5AA)
   (KRN O 177 R -0.037) (comment uni2040)
   (STOP)
   (LABEL O 114) (comment u1D5AB)
   (KRN O 177 R 0.0385) (comment uni2040)
   (STOP)
   (LABEL O 115) (comment u1D5AC)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 116) (comment u1D5AD)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 117) (comment u1D5AE)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 120) (comment u1D5AF)
   (KRN O 177 R -0.0015) (comment uni2040)
   (STOP)
   (LABEL O 121) (comment u1D5B0)
   (KRN O 177 R 0.002) (comment uni2040)
   (STOP)
   (LABEL O 122) (comment u1D5B1)
   (KRN O 177 R -0.0335) (comment uni2040)
   (STOP)
   (LABEL O 123) (comment u1D5B2)
   (KRN O 177 R -0.0145) (comment uni2040)
   (STOP)
   (LABEL O 124) (comment u1D5B3)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 125) (comment u1D5B4)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 126) (comment u1D5B5)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 127) (comment u1D5B6)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 130) (comment u1D5B7)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 131) (comment u1D5B8)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 132) (comment u1D5B9)
   (KRN O 177 R -0.0035) (comment uni2040)
   (STOP)
   (LABEL O 141) (comment u1D5BA)
   (KRN O 177 R -0.011) (comment uni2040)
   (STOP)
   (LABEL O 142) (comment u1D5BB)
   (KRN O 177 R 0.016) (comment uni2040)
   (STOP)
   (LABEL O 143) (comment u1D5BC)
   (KRN O 177 R -0.001) (comment uni2040)
   (STOP)
   (LABEL O 144) (comment u1D5BD)
   (KRN O 177 R -0.015) (comment uni2040)
   (STOP)
   (LABEL O 145) (comment u1D5BE)
   (KRN O 177 R 0.003) (comment uni2040)
   (STOP)
   (LABEL O 146) (comment u1D5BF)
   (KRN O 177 R 0.026) (comment uni2040)
   (STOP)
   (LABEL O 147) (comment u1D5C0)
   (KRN O 177 R -0.004) (comment uni2040)
   (STOP)
   (LABEL O 150) (comment u1D5C1)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 151) (comment u1D5C2)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 152) (comment u1D5C3)
   (KRN O 177 R 0.014) (comment uni2040)
   (STOP)
   (LABEL O 153) (comment u1D5C4)
   (KRN O 177 R 0.0305) (comment uni2040)
   (STOP)
   (LABEL O 154) (comment u1D5C5)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 155) (comment u1D5C6)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 156) (comment u1D5C7)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 157) (comment u1D5C8)
   (KRN O 177 R -0.0005) (comment uni2040)
   (STOP)
   (LABEL O 160) (comment u1D5C9)
   (KRN O 177 R 0.019) (comment uni2040)
   (STOP)
   (LABEL O 161) (comment u1D5CA)
   (KRN O 177 R -0.018) (comment uni2040)
   (STOP)
   (LABEL O 162) (comment u1D5CB)
   (KRN O 177 R 0.027) (comment uni2040)
   (STOP)
   (LABEL O 163) (comment u1D5CC)
   (KRN O 177 R 0.0045) (comment uni2040)
   (STOP)
   (LABEL O 164) (comment u1D5CD)
   (KRN O 177 R -0.0215) (comment uni2040)
   (STOP)
   (LABEL O 165) (comment u1D5CE)
   (KRN O 177 R 0.0005) (comment uni2040)
   (STOP)
   (LABEL O 166) (comment u1D5CF)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 167) (comment u1D5D0)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 170) (comment u1D5D1)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 171) (comment u1D5D2)
   (KRN O 177 R 0.018) (comment uni2040)
   (STOP)
   (LABEL O 172) (comment u1D5D3)
   (KRN O 177 R -0.0025) (comment uni2040)
   (STOP)
   (LABEL O 173) (comment u1D5C2.dtls)
   (KRN O 177 R 0) (comment uni2040)
   (STOP)
   (LABEL O 174) (comment u1D5C3.dtls)
   (KRN O 177 R 0.012) (comment uni2040)
   (STOP)
   )
(CHARACTER O 0 (comment uniE17F)
   (CHARWD R 0.535)
   (CHARHT R 0.662)
   )
(CHARACTER O 1 (comment uniE180)
   (CHARWD R 0.666)
   (CHARHT R 0.674)
   )
(CHARACTER O 2 (comment uniE184)
   (CHARWD R 0.714)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 3 (comment uniE187)
   (CHARWD R 0.666)
   (CHARHT R 0.674)
   )
(CHARACTER O 4 (comment uniE18A)
   (CHARWD R 0.643)
   (CHARHT R 0.662)
   )
(CHARACTER O 5 (comment uniE18C)
   (CHARWD R 0.658)
   (CHARHT R 0.662)
   )
(CHARACTER O 6 (comment uniE18F)
   (CHARWD R 0.624)
   (CHARHT R 0.662)
   )
(CHARACTER O 7 (comment uniE191)
   (CHARWD R 0.69)
   (CHARHT R 0.676)
   )
(CHARACTER O 10 (comment uniE192)
   (CHARWD R 0.716)
   (CHARHT R 0.662)
   )
(CHARACTER O 11 (comment uniE194)
   (CHARWD R 0.724)
   (CHARHT R 0.681)
   )
(CHARACTER O 12 (comment uniE195)
   (CHARWD R 0.744)
   (CHARHT R 0.676)
   )
(CHARACTER O 13 (comment uniE196)
   (CHARWD R 0.537)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   )
(CHARACTER O 14 (comment uniE197)
   (CHARWD R 0.498)
   (CHARHT R 0.683)
   (CHARDP R 0.215)
   )
(CHARACTER O 15 (comment uniE198)
   (CHARWD R 0.474)
   (CHARHT R 0.463)
   (CHARDP R 0.216)
   )
(CHARACTER O 16 (comment uniE199)
   (CHARWD R 0.499)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 17 (comment uniE1AF)
   (CHARWD R 0.456)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   )
(CHARACTER O 20 (comment uniE19B)
   (CHARWD R 0.416)
   (CHARHT R 0.683)
   (CHARDP R 0.213)
   )
(CHARACTER O 21 (comment uniE19C)
   (CHARWD R 0.494)
   (CHARHT R 0.463)
   (CHARDP R 0.215)
   )
(CHARACTER O 22 (comment uniE19D)
   (CHARWD R 0.446)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 23 (comment uniE19E)
   (CHARWD R 0.27)
   (CHARHT R 0.464)
   (CHARDP R 0.01)
   )
(CHARACTER O 24 (comment uniE19F)
   (CHARWD R 0.472)
   (CHARHT R 0.464)
   )
(CHARACTER O 25 (comment uniE1A0)
   (CHARWD R 0.489)
   (CHARHT R 0.683)
   (CHARDP R 0.011)
   )
(CHARACTER O 26 (comment uniE1A1)
   (CHARWD R 0.487)
   (CHARHT R 0.453)
   (CHARDP R 0.215)
   )
(CHARACTER O 27 (comment uniE1A2)
   (CHARWD R 0.46)
   (CHARHT R 0.464)
   (CHARDP R 0.014)
   )
(CHARACTER O 30 (comment uniE1A3)
   (CHARWD R 0.418)
   (CHARHT R 0.683)
   (CHARDP R 0.215)
   )
(CHARACTER O 31 (comment uniE1A5)
   (CHARWD R 0.507)
   (CHARHT R 0.453)
   (CHARDP R 0.01)
   )
(CHARACTER O 32 (comment uniE1A6)
   (CHARWD R 0.498)
   (CHARHT R 0.462)
   (CHARDP R 0.216)
   )
(CHARACTER O 33 (comment uniE1A8)
   (CHARWD R 0.526)
   (CHARHT R 0.453)
   (CHARDP R 0.01)
   )
(CHARACTER O 34 (comment uniE1A9)
   (CHARWD R 0.426)
   (CHARHT R 0.453)
   (CHARDP R 0.01)
   )
(CHARACTER O 35 (comment uniE1AA)
   (CHARWD R 0.503)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   )
(CHARACTER O 36 (comment uniE1B1)
   (CHARWD R 0.622)
   (CHARHT R 0.684)
   (CHARDP R 0.216)
   )
(CHARACTER O 37 (comment uniE1AC)
   (CHARWD R 0.399)
   (CHARHT R 0.463)
   (CHARDP R 0.215)
   )
(CHARACTER O 40 (comment uniE1AD)
   (CHARWD R 0.654)
   (CHARHT R 0.461)
   (CHARDP R 0.216)
   )
(CHARACTER O 41 (comment uniE1AE)
   (CHARWD R 0.624)
   (CHARHT R 0.454)
   (CHARDP R 0.01)
   )
(CHARACTER O 42 (comment uniE19A)
   (CHARWD R 0.438)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   )
(CHARACTER O 43 (comment uniE1B0)
   (CHARWD R 0.489)
   (CHARHT R 0.683)
   (CHARDP R 0.012)
   )
(CHARACTER O 44 (comment uniE1B3)
   (CHARWD R 0.762)
   (CHARHT R 0.453)
   (CHARDP R 0.01)
   )
(CHARACTER O 45 (comment uniE1B2)
   (CHARWD R 0.491)
   (CHARHT R 0.463)
   (CHARDP R 0.216)
   )
(CHARACTER O 46 (comment uniE1A7)
   (CHARWD R 0.416)
   (CHARHT R 0.463)
   (CHARDP R 0.212)
   )
(CHARACTER O 47 (comment uniE1AB)
   (CHARWD R 0.632)
   (CHARHT R 0.464)
   (CHARDP R 0.216)
   )
(CHARACTER O 50 (comment nabla.sf)
   (CHARWD R 0.666)
   (CHARHT R 0.674)
   )
(CHARACTER O 51 (comment uniE17C)
   (CHARWD R 0.499)
   (CHARHT R 0.683)
   (CHARDP R 0.01)
   )
(CHARACTER O 52 (comment uniE0B4)
   (CHARWD R 0.313)
   (CHARHT R 0.556)
   )
(CHARACTER O 53 (comment uniE0B5)
   (CHARWD R 0.313)
   (CHARHT R 0.556)
   )
(CHARACTER O 54 (comment uni2190.x)
   (CHARWD R 0.315)
   (CHARHT R 0.286)
   )
(CHARACTER O 55 (comment uni21D0.x)
   (CHARWD R 0.315)
   (CHARHT R 0.386)
   )
(CHARACTER O 56 (comment uni21DA.x)
   (CHARWD R 0.315)
   (CHARHT R 0.486)
   )
(CHARACTER O 57 (comment uni2B45.x)
   (CHARWD R 0.315)
   (CHARHT R 0.541)
   (CHARDP R 0.035)
   )
(CHARACTER O 60 (comment u1D7E2)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 61 (comment u1D7E3)
   (CHARWD R 0.5)
   (CHARHT R 0.677)
   )
(CHARACTER O 62 (comment u1D7E4)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 63 (comment u1D7E5)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 64 (comment u1D7E6)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   )
(CHARACTER O 65 (comment u1D7E7)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 66 (comment u1D7E8)
   (CHARWD R 0.5)
   (CHARHT R 0.684)
   (CHARDP R 0.014)
   )
(CHARACTER O 67 (comment u1D7E9)
   (CHARWD R 0.5)
   (CHARHT R 0.662)
   (CHARDP R 0.008)
   )
(CHARACTER O 70 (comment u1D7EA)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 71 (comment u1D7EB)
   (CHARWD R 0.5)
   (CHARHT R 0.676)
   (CHARDP R 0.021)
   )
(CHARACTER O 72 (comment mapsfromchar)
   (CHARWD R 0)
   (CHARHT R 0.449)
   )
(CHARACTER O 73 (comment uniE0B6)
   (CHARWD R 0)
   (CHARHT R 0.449)
   )
(CHARACTER O 74 (comment uni23D0)
   (CHARWD R 0.511)
   (CHARHT R 0.202)
   (CHARDP R 0)
   (VARCHAR
      (REP O 74)
      )
   )
(CHARACTER O 75 (comment uni21D1.x)
   (CHARWD R 0.684)
   (CHARHT R 0.202)
   (CHARDP R 0)
   (VARCHAR
      (REP O 75)
      )
   )
(CHARACTER O 76 (comment uni290A.x)
   (CHARWD R 0.926)
   (CHARHT R 0.202)
   (CHARDP R 0)
   )
(CHARACTER O 77 (comment uni27F0.x)
   (CHARWD R 1.033)
   (CHARHT R 0.202)
   (CHARDP R 0)
   )
(CHARACTER O 100 (comment uni2B48)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.141)
   )
(CHARACTER O 101 (comment u1D5A0)
   (CHARWD R 0.666)
   (CHARHT R 0.674)
   )
(CHARACTER O 102 (comment u1D5A1)
   (CHARWD R 0.604)
   (CHARHT R 0.662)
   )
(CHARACTER O 103 (comment u1D5A2)
   (CHARWD R 0.671)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 104 (comment u1D5A3)
   (CHARWD R 0.692)
   (CHARHT R 0.662)
   )
(CHARACTER O 105 (comment u1D5A4)
   (CHARWD R 0.583)
   (CHARHT R 0.662)
   )
(CHARACTER O 106 (comment u1D5A5)
   (CHARWD R 0.535)
   (CHARHT R 0.662)
   )
(CHARACTER O 107 (comment u1D5A6)
   (CHARWD R 0.695)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 110 (comment u1D5A7)
   (CHARWD R 0.658)
   (CHARHT R 0.662)
   )
(CHARACTER O 111 (comment u1D5A8)
   (CHARWD R 0.401)
   (CHARHT R 0.662)
   )
(CHARACTER O 112 (comment u1D5A9)
   (CHARWD R 0.398)
   (CHARHT R 0.662)
   (CHARDP R 0.014)
   )
(CHARACTER O 113 (comment u1D5AA)
   (CHARWD R 0.634)
   (CHARHT R 0.662)
   )
(CHARACTER O 114 (comment u1D5AB)
   (CHARWD R 0.559)
   (CHARHT R 0.662)
   )
(CHARACTER O 115 (comment u1D5AC)
   (CHARWD R 0.843)
   (CHARHT R 0.662)
   )
(CHARACTER O 116 (comment u1D5AD)
   (CHARWD R 0.675)
   (CHARHT R 0.662)
   (CHARDP R 0.014)
   )
(CHARACTER O 117 (comment u1D5AE)
   (CHARWD R 0.714)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 120 (comment u1D5AF)
   (CHARWD R 0.525)
   (CHARHT R 0.662)
   )
(CHARACTER O 121 (comment u1D5B0)
   (CHARWD R 0.716)
   (CHARHT R 0.676)
   (CHARDP R 0.175)
   )
(CHARACTER O 122 (comment u1D5B1)
   (CHARWD R 0.589)
   (CHARHT R 0.662)
   )
(CHARACTER O 123 (comment u1D5B2)
   (CHARWD R 0.541)
   (CHARHT R 0.676)
   (CHARDP R 0.014)
   )
(CHARACTER O 124 (comment u1D5B3)
   (CHARWD R 0.608)
   (CHARHT R 0.662)
   )
(CHARACTER O 125 (comment u1D5B4)
   (CHARWD R 0.661)
   (CHARHT R 0.662)
   (CHARDP R 0.014)
   )
(CHARACTER O 126 (comment u1D5B5)
   (CHARWD R 0.654)
   (CHARHT R 0.662)
   (CHARDP R 0.011)
   )
(CHARACTER O 127 (comment u1D5B6)
   (CHARWD R 0.921)
   (CHARHT R 0.662)
   (CHARDP R 0.011)
   )
(CHARACTER O 130 (comment u1D5B7)
   (CHARWD R 0.7)
   (CHARHT R 0.662)
   )
(CHARACTER O 131 (comment u1D5B8)
   (CHARWD R 0.63)
   (CHARHT R 0.662)
   )
(CHARACTER O 132 (comment u1D5B9)
   (CHARWD R 0.637)
   (CHARHT R 0.662)
   )
(CHARACTER O 133 (comment uni2B49)
   (CHARWD R 0.926)
   (CHARHT R 0.508)
   )
(CHARACTER O 134 (comment uni2B4A)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.141)
   )
(CHARACTER O 135 (comment uni2B4B)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.002)
   )
(CHARACTER O 136 (comment uni2B4C)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   (CHARDP R 0.002)
   )
(CHARACTER O 137 (comment uni290A)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   (VARCHAR
      (TOP O 137)
      (REP O 76)
      )
   )
(CHARACTER O 140 (comment uni290B)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   (VARCHAR
      (BOT O 140)
      (REP O 76)
      )
   )
(CHARACTER O 141 (comment u1D5BA)
   (CHARWD R 0.448)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   )
(CHARACTER O 142 (comment u1D5BB)
   (CHARWD R 0.496)
   (CHARHT R 0.684)
   (CHARDP R 0.01)
   )
(CHARACTER O 143 (comment u1D5BC)
   (CHARWD R 0.456)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   )
(CHARACTER O 144 (comment u1D5BD)
   (CHARWD R 0.494)
   (CHARHT R 0.684)
   (CHARDP R 0.011)
   )
(CHARACTER O 145 (comment u1D5BE)
   (CHARWD R 0.444)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   )
(CHARACTER O 146 (comment u1D5BF)
   (CHARWD R 0.336)
   (CHARHT R 0.683)
   (CHARIC R 0.1)
   )
(CHARACTER O 147 (comment u1D5C0)
   (CHARWD R 0.496)
   (CHARHT R 0.463)
   (CHARDP R 0.216)
   )
(CHARACTER O 150 (comment u1D5C1)
   (CHARWD R 0.487)
   (CHARHT R 0.684)
   )
(CHARACTER O 151 (comment u1D5C2)
   (CHARWD R 0.22)
   (CHARHT R 0.679)
   )
(CHARACTER O 152 (comment u1D5C3)
   (CHARWD R 0.254)
   (CHARHT R 0.679)
   (CHARDP R 0.216)
   )
(CHARACTER O 153 (comment u1D5C4)
   (CHARWD R 0.453)
   (CHARHT R 0.684)
   )
(CHARACTER O 154 (comment u1D5C5)
   (CHARWD R 0.205)
   (CHARHT R 0.684)
   )
(CHARACTER O 155 (comment u1D5C6)
   (CHARWD R 0.756)
   (CHARHT R 0.464)
   )
(CHARACTER O 156 (comment u1D5C7)
   (CHARWD R 0.487)
   (CHARHT R 0.464)
   )
(CHARACTER O 157 (comment u1D5C8)
   (CHARWD R 0.499)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   )
(CHARACTER O 160 (comment u1D5C9)
   (CHARWD R 0.498)
   (CHARHT R 0.464)
   (CHARDP R 0.216)
   )
(CHARACTER O 161 (comment u1D5CA)
   (CHARWD R 0.498)
   (CHARHT R 0.464)
   (CHARDP R 0.216)
   )
(CHARACTER O 162 (comment u1D5CB)
   (CHARWD R 0.336)
   (CHARHT R 0.464)
   )
(CHARACTER O 163 (comment u1D5CC)
   (CHARWD R 0.389)
   (CHARHT R 0.463)
   (CHARDP R 0.01)
   )
(CHARACTER O 164 (comment u1D5CD)
   (CHARWD R 0.291)
   (CHARHT R 0.58)
   (CHARDP R 0.01)
   )
(CHARACTER O 165 (comment u1D5CE)
   (CHARWD R 0.491)
   (CHARHT R 0.453)
   (CHARDP R 0.011)
   )
(CHARACTER O 166 (comment u1D5CF)
   (CHARWD R 0.474)
   (CHARHT R 0.453)
   (CHARDP R 0.014)
   )
(CHARACTER O 167 (comment u1D5D0)
   (CHARWD R 0.702)
   (CHARHT R 0.453)
   (CHARDP R 0.014)
   )
(CHARACTER O 170 (comment u1D5D1)
   (CHARWD R 0.482)
   (CHARHT R 0.453)
   )
(CHARACTER O 171 (comment u1D5D2)
   (CHARWD R 0.484)
   (CHARHT R 0.453)
   (CHARDP R 0.216)
   )
(CHARACTER O 172 (comment u1D5D3)
   (CHARWD R 0.447)
   (CHARHT R 0.453)
   )
(CHARACTER O 173 (comment u1D5C2.dtls)
   (CHARWD R 0.22)
   (CHARHT R 0.464)
   )
(CHARACTER O 174 (comment u1D5C3.dtls)
   (CHARWD R 0.254)
   (CHARHT R 0.464)
   (CHARDP R 0.216)
   )
(CHARACTER O 175 (comment uni2190)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 176 (comment uni2191)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   (VARCHAR
      (TOP O 176)
      (REP O 74)
      )
   )
(CHARACTER O 177 (comment uni2040)
   (CHARWD R 0.798)
   (CHARHT R 0.7)
   )
(CHARACTER O 200 (comment uni0300)
   (CHARWD R 0.224)
   (CHARHT R 0.7)
   )
(CHARACTER O 201 (comment uni0301)
   (CHARWD R 0.224)
   (CHARHT R 0.7)
   )
(CHARACTER O 202 (comment uni0302)
   (CHARWD R 0.311)
   (CHARHT R 0.7)
   )
(CHARACTER O 203 (comment uni0303)
   (CHARWD R 0.33)
   (CHARHT R 0.6)
   )
(CHARACTER O 204 (comment uni0304)
   (CHARWD R 0.311)
   (CHARHT R 0.6)
   )
(CHARACTER O 205 (comment uni0306)
   (CHARWD R 0.281)
   (CHARHT R 0.7)
   )
(CHARACTER O 206 (comment uni0307)
   (CHARWD R 0.099)
   (CHARHT R 0.6)
   )
(CHARACTER O 207 (comment uni0308)
   (CHARWD R 0.298)
   (CHARHT R 0.6)
   )
(CHARACTER O 210 (comment uni0309)
   (CHARWD R 0.189)
   (CHARHT R 0.8)
   )
(CHARACTER O 211 (comment uni030A)
   (CHARWD R 0.199)
   (CHARHT R 0.7)
   )
(CHARACTER O 212 (comment uni030C)
   (CHARWD R 0.311)
   (CHARHT R 0.7)
   )
(CHARACTER O 213 (comment uni0310)
   (CHARWD R 0.281)
   (CHARHT R 0.8)
   )
(CHARACTER O 214 (comment uni0312)
   (CHARWD R 0.139)
   (CHARHT R 0.7)
   )
(CHARACTER O 215 (comment uni0315)
   (CHARWD R 0.139)
   (CHARHT R 0.7)
   )
(CHARACTER O 216 (comment uni031A)
   (CHARWD R 0.3)
   (CHARHT R 0.7)
   )
(CHARACTER O 217 (comment uni20D0)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 220 (comment uni20D1)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 221 (comment uni20D6)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 222 (comment uni20D7)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 223 (comment uni20DB)
   (CHARWD R 0.497)
   (CHARHT R 0.6)
   )
(CHARACTER O 224 (comment uni20DC)
   (CHARWD R 0.696)
   (CHARHT R 0.6)
   )
(CHARACTER O 225 (comment uni20E1)
   (CHARWD R 0.478)
   (CHARHT R 0.8)
   )
(CHARACTER O 226 (comment uni20E7)
   (CHARWD R 0.816)
   (CHARHT R 0.7)
   (CHARDP R 0.2)
   )
(CHARACTER O 227 (comment uni20E9)
   (CHARWD R 0.533)
   (CHARHT R 0.7)
   )
(CHARACTER O 230 (comment uni20F0)
   (CHARWD R 0.27)
   (CHARHT R 0.8)
   )
(CHARACTER O 231 (comment uni2192)
   (CHARWD R 0.926)
   (CHARHT R 0.448)
   )
(CHARACTER O 232 (comment uni2193)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   (VARCHAR
      (BOT O 232)
      (REP O 74)
      )
   )
(CHARACTER O 233 (comment uni2194)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 234 (comment uni2195)
   (CHARWD R 0.511)
   (CHARHT R 0.73)
   (CHARDP R 0.224)
   (VARCHAR
      (TOP O 176)
      (BOT O 232)
      (REP O 74)
      )
   )
(CHARACTER O 235 (comment uni2196)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 236 (comment uni2197)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 237 (comment uni2198)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 240 (comment uni2199)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 241 (comment uni219A)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 242 (comment uni219B)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 243 (comment uni219C)
   (CHARWD R 0.926)
   (CHARHT R 0.411)
   )
(CHARACTER O 244 (comment uni219D)
   (CHARWD R 0.926)
   (CHARHT R 0.411)
   )
(CHARACTER O 245 (comment uni219E)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 246 (comment uni219F)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.154)
   )
(CHARACTER O 247 (comment uni21A0)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 250 (comment uni21A1)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.154)
   )
(CHARACTER O 251 (comment uni21A2)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 252 (comment uni21A3)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 253 (comment uni21A4)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 254 (comment uni21A5)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.154)
   )
(CHARACTER O 255 (comment uni21A6)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 256 (comment uni21A7)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.154)
   )
(CHARACTER O 257 (comment uni21A8)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.154)
   )
(CHARACTER O 260 (comment uni21A9)
   (CHARWD R 0.926)
   (CHARHT R 0.553)
   )
(CHARACTER O 261 (comment uni21AA)
   (CHARWD R 0.926)
   (CHARHT R 0.553)
   )
(CHARACTER O 262 (comment uni21AB)
   (CHARWD R 0.926)
   (CHARHT R 0.553)
   )
(CHARACTER O 263 (comment uni21AC)
   (CHARWD R 0.926)
   (CHARHT R 0.553)
   )
(CHARACTER O 264 (comment uni21AD)
   (CHARWD R 1.2)
   (CHARHT R 0.449)
   )
(CHARACTER O 265 (comment uni21AE)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 266 (comment uni21AF)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.154)
   )
(CHARACTER O 267 (comment uni21B0)
   (CHARWD R 0.463)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 270 (comment uni21B1)
   (CHARWD R 0.463)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 271 (comment uni21B2)
   (CHARWD R 0.463)
   (CHARHT R 0.662)
   (CHARDP R 0.154)
   )
(CHARACTER O 272 (comment uni21B3)
   (CHARWD R 0.463)
   (CHARHT R 0.662)
   (CHARDP R 0.154)
   )
(CHARACTER O 273 (comment uni21B4)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.154)
   )
(CHARACTER O 274 (comment uni21B5)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 275 (comment uni21B6)
   (CHARWD R 0.926)
   (CHARHT R 0.534)
   )
(CHARACTER O 276 (comment uni21B7)
   (CHARWD R 0.926)
   (CHARHT R 0.534)
   )
(CHARACTER O 277 (comment uni21B8)
   (CHARWD R 0.926)
   (CHARHT R 0.732)
   (CHARDP R 0.156)
   )
(CHARACTER O 300 (comment uni21B9)
   (CHARWD R 0.926)
   (CHARHT R 0.598)
   (CHARDP R 0.092)
   )
(CHARACTER O 301 (comment uni21BA)
   (CHARWD R 0.974)
   (CHARHT R 0.686)
   (CHARDP R 0.116)
   )
(CHARACTER O 302 (comment uni21BB)
   (CHARWD R 0.974)
   (CHARHT R 0.686)
   (CHARDP R 0.116)
   )
(CHARACTER O 303 (comment uni21BC)
   (CHARWD R 0.955)
   (CHARHT R 0.494)
   )
(CHARACTER O 304 (comment uni21BD)
   (CHARWD R 0.955)
   (CHARHT R 0.286)
   )
(CHARACTER O 305 (comment uni21BE)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 306 (comment uni21BF)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 307 (comment uni21C0)
   (CHARWD R 0.955)
   (CHARHT R 0.494)
   )
(CHARACTER O 310 (comment uni21C1)
   (CHARWD R 0.955)
   (CHARHT R 0.286)
   )
(CHARACTER O 311 (comment uni21C2)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 312 (comment uni21C3)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 313 (comment uni21C4)
   (CHARWD R 0.926)
   (CHARHT R 0.598)
   (CHARDP R 0.092)
   )
(CHARACTER O 314 (comment uni21C5)
   (CHARWD R 0.773)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 315 (comment uni21C6)
   (CHARWD R 0.926)
   (CHARHT R 0.598)
   (CHARDP R 0.092)
   )
(CHARACTER O 316 (comment uni21C7)
   (CHARWD R 0.926)
   (CHARHT R 0.599)
   (CHARDP R 0.092)
   )
(CHARACTER O 317 (comment uni21C8)
   (CHARWD R 0.773)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 320 (comment uni21C9)
   (CHARWD R 0.926)
   (CHARHT R 0.599)
   (CHARDP R 0.092)
   )
(CHARACTER O 321 (comment uni21CA)
   (CHARWD R 0.773)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 322 (comment uni21CB)
   (CHARWD R 0.926)
   (CHARHT R 0.539)
   (CHARDP R 0.033)
   )
(CHARACTER O 323 (comment uni21CC)
   (CHARWD R 0.926)
   (CHARHT R 0.539)
   (CHARDP R 0.033)
   )
(CHARACTER O 324 (comment uni21CD)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 325 (comment uni21CE)
   (CHARWD R 0.926)
   (CHARHT R 0.517)
   (CHARDP R 0.01)
   )
(CHARACTER O 326 (comment uni21CF)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 327 (comment uni21D0)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 330 (comment uni21D1)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   (VARCHAR
      (TOP O 330)
      (REP O 75)
      )
   )
(CHARACTER O 331 (comment uni21D2)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 332 (comment uni21D3)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   (VARCHAR
      (BOT O 332)
      (REP O 75)
      )
   )
(CHARACTER O 333 (comment uni21D4)
   (CHARWD R 0.926)
   (CHARHT R 0.517)
   (CHARDP R 0.01)
   )
(CHARACTER O 334 (comment uni21D5)
   (CHARWD R 0.685)
   (CHARHT R 0.73)
   (CHARDP R 0.224)
   (VARCHAR
      (TOP O 330)
      (BOT O 332)
      (REP O 75)
      )
   )
(CHARACTER O 335 (comment uni21D6)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 336 (comment uni21D7)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 337 (comment uni21D8)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 340 (comment uni21D9)
   (CHARWD R 0.926)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 341 (comment uni21DA)
   (CHARWD R 0.926)
   (CHARHT R 0.644)
   (CHARDP R 0.139)
   )
(CHARACTER O 342 (comment uni21DB)
   (CHARWD R 0.926)
   (CHARHT R 0.645)
   (CHARDP R 0.138)
   )
(CHARACTER O 343 (comment uni21DC)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 344 (comment uni21DD)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 345 (comment uni21DE)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 346 (comment uni21DF)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 347 (comment uni21E0)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 350 (comment uni21E1)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 351 (comment uni21E2)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 352 (comment uni21E3)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 353 (comment uni21E4)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 354 (comment uni21E5)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 355 (comment uni21E6)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 356 (comment uni21E7)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 357 (comment uni21E8)
   (CHARWD R 0.926)
   (CHARHT R 0.551)
   (CHARDP R 0.045)
   )
(CHARACTER O 360 (comment uni21E9)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 361 (comment uni21EA)
   (CHARWD R 0.685)
   (CHARHT R 0.69)
   (CHARDP R 0.184)
   )
(CHARACTER O 362 (comment uni21F4)
   (CHARWD R 0.926)
   (CHARHT R 0.448)
   )
(CHARACTER O 363 (comment uni21F5)
   (CHARWD R 0.773)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 364 (comment uni21F6)
   (CHARWD R 0.926)
   (CHARHT R 0.739)
   (CHARDP R 0.232)
   )
(CHARACTER O 365 (comment uni21F7)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 366 (comment uni21F8)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 367 (comment uni21F9)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 370 (comment uni21FA)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 371 (comment uni21FB)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 372 (comment uni21FC)
   (CHARWD R 0.926)
   (CHARHT R 0.45)
   )
(CHARACTER O 373 (comment uni21FD)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 374 (comment uni21FE)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 375 (comment uni21FF)
   (CHARWD R 0.926)
   (CHARHT R 0.449)
   )
(CHARACTER O 376 (comment uni27F0)
   (CHARWD R 1.033)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   (VARCHAR
      (TOP O 376)
      (REP O 77)
      )
   )
(CHARACTER O 377 (comment uni27F1)
   (CHARWD R 1.033)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   (VARCHAR
      (BOT O 377)
      (REP O 77)
      )
   )
