(FAMILY STIXMathFraktur)
(CODINGSCHEME STIXMATHFRAK)
(DESIGNSIZE R 10.0)
(FONTDIMEN
   (SLANT R 0)
   (SPACE R 0)
   (STRETCH R 0)
   (SHRINK R 0)
   (XHEIGHT R 0.45)
   (QUAD R 1)
   (EXTRASPACE R 0)
   )
(LIGTABLE
   (LABEL O 173) (comment u1D526.dtls)
   (KRN O 177 R -0.015) (comment uni2040)
   (STOP)
   (LABEL O 174) (comment u1D527.dtls)
   (KRN O 177 R 0.0265) (comment uni2040)
   (STOP)
   )
(CHARACTER O 0 (comment uni267E)
   (CHARWD R 1.186)
   (CHARHT R 0.775)
   (CHARDP R 0.271)
   )
(CHARACTER O 1 (comment uni279B)
   (CHARWD R 0.918)
   (CHARHT R 0.433)
   )
(CHARACTER O 2 (comment uni27C0)
   (CHARWD R 0.685)
   (CHARHT R 0.584)
   )
(CHARACTER O 3 (comment uni27C1)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 4 (comment uni27C2)
   (CHARWD R 0.693)
   (CHARHT R 0.662)
   )
(CHARACTER O 5 (comment uni27C3)
   (CHARWD R 0.685)
   (CHARHT R 0.529)
   (CHARDP R 0.027)
   )
(CHARACTER O 6 (comment uni27C4)
   (CHARWD R 0.685)
   (CHARHT R 0.529)
   (CHARDP R 0.027)
   )
(CHARACTER O 7 (comment uni27C5)
   (CHARWD R 0.455)
   (CHARHT R 0.702)
   (CHARDP R 0.198)
   )
(CHARACTER O 10 (comment uni27C6)
   (CHARWD R 0.455)
   (CHARHT R 0.702)
   (CHARDP R 0.198)
   )
(CHARACTER O 11 (comment uni27C7)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 12 (comment uni27C8)
   (CHARWD R 0.966)
   (CHARHT R 0.533)
   (CHARDP R 0.025)
   )
(CHARACTER O 13 (comment uni27C9)
   (CHARWD R 0.966)
   (CHARHT R 0.533)
   (CHARDP R 0.025)
   )
(CHARACTER O 14 (comment uni27D0)
   (CHARWD R 1.064)
   (CHARHT R 0.744)
   (CHARDP R 0.242)
   )
(CHARACTER O 15 (comment uni27D1)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.029)
   )
(CHARACTER O 16 (comment uni27D2)
   (CHARWD R 0.62)
   (CHARHT R 0.536)
   (CHARDP R 0.031)
   )
(CHARACTER O 17 (comment uni27D3)
   (CHARWD R 0.685)
   (CHARHT R 0.584)
   )
(CHARACTER O 20 (comment uni27D4)
   (CHARWD R 0.685)
   (CHARHT R 0.584)
   )
(CHARACTER O 21 (comment uni27D5)
   (CHARWD R 1.019)
   (CHARHT R 0.582)
   (CHARDP R 0.08)
   )
(CHARACTER O 22 (comment uni27D6)
   (CHARWD R 1.019)
   (CHARHT R 0.582)
   (CHARDP R 0.08)
   )
(CHARACTER O 23 (comment uni27D7)
   (CHARWD R 1.228)
   (CHARHT R 0.582)
   (CHARDP R 0.08)
   )
(CHARACTER O 24 (comment uni27D8)
   (CHARWD R 0.866)
   (CHARHT R 0.718)
   (CHARDP R 0.213)
   )
(CHARACTER O 25 (comment uni27D9)
   (CHARWD R 0.866)
   (CHARHT R 0.718)
   (CHARDP R 0.213)
   )
(CHARACTER O 26 (comment uni27DA)
   (CHARWD R 1.376)
   (CHARHT R 0.662)
   )
(CHARACTER O 27 (comment uni27DB)
   (CHARWD R 1.376)
   (CHARHT R 0.662)
   )
(CHARACTER O 30 (comment uni27DC)
   (CHARWD R 0.849)
   (CHARHT R 0.403)
   )
(CHARACTER O 31 (comment uni27DD)
   (CHARWD R 1.574)
   (CHARHT R 0.45)
   )
(CHARACTER O 32 (comment uni27DE)
   (CHARWD R 1.574)
   (CHARHT R 0.45)
   )
(CHARACTER O 33 (comment uni27DF)
   (CHARWD R 0.502)
   (CHARHT R 0.693)
   (CHARDP R 0.187)
   )
(CHARACTER O 34 (comment uni27E0)
   (CHARWD R 0.79)
   (CHARHT R 0.795)
   (CHARDP R 0.289)
   )
(CHARACTER O 35 (comment uni27E1)
   (CHARWD R 0.764)
   (CHARHT R 0.589)
   (CHARDP R 0.087)
   )
(CHARACTER O 36 (comment uni27E2)
   (CHARWD R 0.803)
   (CHARHT R 0.589)
   (CHARDP R 0.087)
   )
(CHARACTER O 37 (comment uni27E3)
   (CHARWD R 0.803)
   (CHARHT R 0.589)
   (CHARDP R 0.087)
   )
(CHARACTER O 40 (comment uni27E4)
   (CHARWD R 1.182)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 41 (comment uni27E5)
   (CHARWD R 1.182)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 42 (comment uni27EC)
   (CHARWD R 0.488)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 43 (comment uni27ED)
   (CHARWD R 0.488)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 44 (comment uni2981)
   (CHARWD R 0.565)
   (CHARHT R 0.487)
   )
(CHARACTER O 45 (comment uni2982)
   (CHARWD R 0.503)
   (CHARHT R 0.566)
   (CHARDP R 0.059)
   )
(CHARACTER O 46 (comment uni2987)
   (CHARWD R 0.511)
   (CHARHT R 0.719)
   (CHARDP R 0.214)
   )
(CHARACTER O 47 (comment uni2988)
   (CHARWD R 0.511)
   (CHARHT R 0.719)
   (CHARDP R 0.214)
   )
(CHARACTER O 50 (comment uni2989)
   (CHARWD R 0.511)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 51 (comment uni298A)
   (CHARWD R 0.511)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 52 (comment uni298B)
   (CHARWD R 0.469)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 53 (comment uni298C)
   (CHARWD R 0.469)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 54 (comment uni298D)
   (CHARWD R 0.469)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 55 (comment uni298E)
   (CHARWD R 0.469)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 56 (comment uni298F)
   (CHARWD R 0.469)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 57 (comment uni2990)
   (CHARWD R 0.469)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 60 (comment uni2991)
   (CHARWD R 0.4)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 61 (comment uni2992)
   (CHARWD R 0.4)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 62 (comment uni2993)
   (CHARWD R 0.685)
   (CHARHT R 0.649)
   (CHARDP R 0.143)
   )
(CHARACTER O 63 (comment uni2994)
   (CHARWD R 0.685)
   (CHARHT R 0.649)
   (CHARDP R 0.143)
   )
(CHARACTER O 64 (comment uni2995)
   (CHARWD R 0.685)
   (CHARHT R 0.649)
   (CHARDP R 0.143)
   )
(CHARACTER O 65 (comment uni2996)
   (CHARWD R 0.685)
   (CHARHT R 0.649)
   (CHARDP R 0.143)
   )
(CHARACTER O 66 (comment uni2997)
   (CHARWD R 0.488)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 67 (comment uni2998)
   (CHARWD R 0.488)
   (CHARHT R 0.719)
   (CHARDP R 0.213)
   )
(CHARACTER O 70 (comment uni2999)
   (CHARWD R 0.211)
   (CHARHT R 0.661)
   (CHARDP R 0.155)
   )
(CHARACTER O 71 (comment uni299A)
   (CHARWD R 0.511)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 72 (comment uni299B)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   (CHARDP R 0.072)
   )
(CHARACTER O 73 (comment uni299C)
   (CHARWD R 0.685)
   (CHARHT R 0.584)
   )
(CHARACTER O 74 (comment uni299D)
   (CHARWD R 0.685)
   (CHARHT R 0.584)
   )
(CHARACTER O 75 (comment uni299E)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   )
(CHARACTER O 76 (comment uni299F)
   (CHARWD R 0.685)
   (CHARHT R 0.396)
   )
(CHARACTER O 77 (comment uni29A0)
   (CHARWD R 0.685)
   (CHARHT R 0.517)
   (CHARDP R 0.013)
   )
(CHARACTER O 100 (comment uni29A1)
   (CHARWD R 0.685)
   (CHARHT R 0.609)
   )
(CHARACTER O 101 (comment u1D504)
   (CHARWD R 0.785)
   (CHARHT R 0.695)
   (CHARDP R 0.022)
   )
(CHARACTER O 102 (comment u1D505)
   (CHARWD R 0.822)
   (CHARHT R 0.704)
   (CHARDP R 0.024)
   )
(CHARACTER O 103 (comment uni212D)
   (CHARWD R 0.717)
   (CHARHT R 0.695)
   (CHARDP R 0.024)
   )
(CHARACTER O 104 (comment u1D507)
   (CHARWD R 0.868)
   (CHARHT R 0.695)
   (CHARDP R 0.024)
   )
(CHARACTER O 105 (comment u1D508)
   (CHARWD R 0.729)
   (CHARHT R 0.695)
   (CHARDP R 0.024)
   )
(CHARACTER O 106 (comment u1D509)
   (CHARWD R 0.767)
   (CHARHT R 0.695)
   (CHARDP R 0.204)
   )
(CHARACTER O 107 (comment u1D50A)
   (CHARWD R 0.806)
   (CHARHT R 0.695)
   (CHARDP R 0.024)
   )
(CHARACTER O 110 (comment uni210C)
   (CHARWD R 0.824)
   (CHARHT R 0.695)
   (CHARDP R 0.204)
   )
(CHARACTER O 111 (comment uni2111)
   (CHARWD R 0.762)
   (CHARHT R 0.695)
   (CHARDP R 0.034)
   )
(CHARACTER O 112 (comment u1D50D)
   (CHARWD R 0.772)
   (CHARHT R 0.695)
   (CHARDP R 0.204)
   )
(CHARACTER O 113 (comment u1D50E)
   (CHARWD R 0.846)
   (CHARHT R 0.695)
   (CHARDP R 0.022)
   )
(CHARACTER O 114 (comment u1D50F)
   (CHARWD R 0.669)
   (CHARHT R 0.695)
   (CHARDP R 0.024)
   )
(CHARACTER O 115 (comment u1D510)
   (CHARWD R 1.083)
   (CHARHT R 0.695)
   (CHARDP R 0.022)
   )
(CHARACTER O 116 (comment u1D511)
   (CHARWD R 0.827)
   (CHARHT R 0.695)
   (CHARDP R 0.022)
   )
(CHARACTER O 117 (comment u1D512)
   (CHARWD R 0.837)
   (CHARHT R 0.695)
   (CHARDP R 0.024)
   )
(CHARACTER O 120 (comment u1D513)
   (CHARWD R 0.823)
   (CHARHT R 0.695)
   (CHARDP R 0.204)
   )
(CHARACTER O 121 (comment u1D514)
   (CHARWD R 0.865)
   (CHARHT R 0.695)
   (CHARDP R 0.064)
   )
(CHARACTER O 122 (comment uni211C)
   (CHARWD R 0.874)
   (CHARHT R 0.704)
   (CHARDP R 0.022)
   )
(CHARACTER O 123 (comment u1D516)
   (CHARWD R 0.856)
   (CHARHT R 0.695)
   (CHARDP R 0.024)
   )
(CHARACTER O 124 (comment u1D517)
   (CHARWD R 0.766)
   (CHARHT R 0.695)
   (CHARDP R 0.024)
   )
(CHARACTER O 125 (comment u1D518)
   (CHARWD R 0.787)
   (CHARHT R 0.696)
   (CHARDP R 0.022)
   )
(CHARACTER O 126 (comment u1D519)
   (CHARWD R 0.831)
   (CHARHT R 0.695)
   (CHARDP R 0.024)
   )
(CHARACTER O 127 (comment u1D51A)
   (CHARWD R 1.075)
   (CHARHT R 0.695)
   (CHARDP R 0.024)
   )
(CHARACTER O 130 (comment u1D51B)
   (CHARWD R 0.763)
   (CHARHT R 0.695)
   (CHARDP R 0.031)
   )
(CHARACTER O 131 (comment u1D51C)
   (CHARWD R 0.766)
   (CHARHT R 0.695)
   (CHARDP R 0.204)
   )
(CHARACTER O 132 (comment uni2128)
   (CHARWD R 0.726)
   (CHARHT R 0.695)
   (CHARDP R 0.204)
   )
(CHARACTER O 133 (comment uni29A2)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   )
(CHARACTER O 134 (comment uni29A3)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   )
(CHARACTER O 135 (comment uni29A4)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   (CHARDP R 0.2)
   )
(CHARACTER O 136 (comment uni29A5)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   (CHARDP R 0.2)
   )
(CHARACTER O 137 (comment uni29A6)
   (CHARWD R 0.9)
   (CHARHT R 0.547)
   )
(CHARACTER O 140 (comment uni29A7)
   (CHARWD R 0.9)
   (CHARHT R 0.547)
   )
(CHARACTER O 141 (comment u1D51E)
   (CHARWD R 0.53)
   (CHARHT R 0.468)
   (CHARDP R 0.018)
   )
(CHARACTER O 142 (comment u1D51F)
   (CHARWD R 0.513)
   (CHARHT R 0.695)
   (CHARDP R 0.018)
   )
(CHARACTER O 143 (comment u1D520)
   (CHARWD R 0.385)
   (CHARHT R 0.468)
   (CHARDP R 0.018)
   )
(CHARACTER O 144 (comment u1D521)
   (CHARWD R 0.506)
   (CHARHT R 0.695)
   (CHARDP R 0.018)
   )
(CHARACTER O 145 (comment u1D522)
   (CHARWD R 0.42)
   (CHARHT R 0.468)
   (CHARDP R 0.018)
   )
(CHARACTER O 146 (comment u1D523)
   (CHARWD R 0.327)
   (CHARHT R 0.694)
   (CHARDP R 0.209)
   )
(CHARACTER O 147 (comment u1D524)
   (CHARWD R 0.499)
   (CHARHT R 0.468)
   (CHARDP R 0.209)
   )
(CHARACTER O 150 (comment u1D525)
   (CHARWD R 0.528)
   (CHARHT R 0.695)
   (CHARDP R 0.209)
   )
(CHARACTER O 151 (comment u1D526)
   (CHARWD R 0.384)
   (CHARHT R 0.694)
   (CHARDP R 0.018)
   )
(CHARACTER O 152 (comment u1D527)
   (CHARWD R 0.345)
   (CHARHT R 0.695)
   (CHARDP R 0.209)
   )
(CHARACTER O 153 (comment u1D528)
   (CHARWD R 0.42)
   (CHARHT R 0.695)
   (CHARDP R 0.018)
   )
(CHARACTER O 154 (comment u1D529)
   (CHARWD R 0.398)
   (CHARHT R 0.695)
   (CHARDP R 0.018)
   )
(CHARACTER O 155 (comment u1D52A)
   (CHARWD R 0.91)
   (CHARHT R 0.468)
   (CHARDP R 0.025)
   )
(CHARACTER O 156 (comment u1D52B)
   (CHARWD R 0.636)
   (CHARHT R 0.468)
   (CHARDP R 0.025)
   )
(CHARACTER O 157 (comment u1D52C)
   (CHARWD R 0.503)
   (CHARHT R 0.468)
   (CHARDP R 0.018)
   )
(CHARACTER O 160 (comment u1D52D)
   (CHARWD R 0.555)
   (CHARHT R 0.586)
   (CHARDP R 0.209)
   )
(CHARACTER O 161 (comment u1D52E)
   (CHARWD R 0.507)
   (CHARHT R 0.468)
   (CHARDP R 0.209)
   )
(CHARACTER O 162 (comment u1D52F)
   (CHARWD R 0.463)
   (CHARHT R 0.468)
   (CHARDP R 0.018)
   )
(CHARACTER O 163 (comment u1D530)
   (CHARWD R 0.518)
   (CHARHT R 0.623)
   (CHARDP R 0.024)
   )
(CHARACTER O 164 (comment u1D531)
   (CHARWD R 0.374)
   (CHARHT R 0.656)
   (CHARDP R 0.018)
   )
(CHARACTER O 165 (comment u1D532)
   (CHARWD R 0.647)
   (CHARHT R 0.478)
   (CHARDP R 0.018)
   )
(CHARACTER O 166 (comment u1D533)
   (CHARWD R 0.515)
   (CHARHT R 0.586)
   (CHARDP R 0.018)
   )
(CHARACTER O 167 (comment u1D534)
   (CHARWD R 0.759)
   (CHARHT R 0.586)
   (CHARDP R 0.025)
   )
(CHARACTER O 170 (comment u1D535)
   (CHARWD R 0.456)
   (CHARHT R 0.468)
   (CHARDP R 0.189)
   )
(CHARACTER O 171 (comment u1D536)
   (CHARWD R 0.516)
   (CHARHT R 0.586)
   (CHARDP R 0.209)
   )
(CHARACTER O 172 (comment u1D537)
   (CHARWD R 0.457)
   (CHARHT R 0.468)
   (CHARDP R 0.209)
   )
(CHARACTER O 173 (comment u1D526.dtls)
   (CHARWD R 0.384)
   (CHARHT R 0.468)
   (CHARDP R 0.018)
   )
(CHARACTER O 174 (comment u1D527.dtls)
   (CHARWD R 0.345)
   (CHARHT R 0.468)
   (CHARDP R 0.209)
   )
(CHARACTER O 175 (comment uni29A8)
   (CHARWD R 0.685)
   (CHARHT R 0.574)
   (CHARDP R 0.072)
   )
(CHARACTER O 176 (comment uni29A9)
   (CHARWD R 0.685)
   (CHARHT R 0.574)
   (CHARDP R 0.072)
   )
(CHARACTER O 177 (comment uni2040)
   (CHARWD R 0.798)
   (CHARHT R 0.7)
   )
(CHARACTER O 200 (comment uni0300)
   (CHARWD R 0.224)
   (CHARHT R 0.7)
   )
(CHARACTER O 201 (comment uni0301)
   (CHARWD R 0.224)
   (CHARHT R 0.7)
   )
(CHARACTER O 202 (comment uni0302)
   (CHARWD R 0.311)
   (CHARHT R 0.7)
   )
(CHARACTER O 203 (comment uni0303)
   (CHARWD R 0.33)
   (CHARHT R 0.6)
   )
(CHARACTER O 204 (comment uni0304)
   (CHARWD R 0.311)
   (CHARHT R 0.6)
   )
(CHARACTER O 205 (comment uni0306)
   (CHARWD R 0.281)
   (CHARHT R 0.7)
   )
(CHARACTER O 206 (comment uni0307)
   (CHARWD R 0.099)
   (CHARHT R 0.6)
   )
(CHARACTER O 207 (comment uni0308)
   (CHARWD R 0.298)
   (CHARHT R 0.6)
   )
(CHARACTER O 210 (comment uni0309)
   (CHARWD R 0.189)
   (CHARHT R 0.8)
   )
(CHARACTER O 211 (comment uni030A)
   (CHARWD R 0.199)
   (CHARHT R 0.7)
   )
(CHARACTER O 212 (comment uni030C)
   (CHARWD R 0.311)
   (CHARHT R 0.7)
   )
(CHARACTER O 213 (comment uni0310)
   (CHARWD R 0.281)
   (CHARHT R 0.8)
   )
(CHARACTER O 214 (comment uni0312)
   (CHARWD R 0.139)
   (CHARHT R 0.7)
   )
(CHARACTER O 215 (comment uni0315)
   (CHARWD R 0.139)
   (CHARHT R 0.7)
   )
(CHARACTER O 216 (comment uni031A)
   (CHARWD R 0.3)
   (CHARHT R 0.7)
   )
(CHARACTER O 217 (comment uni20D0)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 220 (comment uni20D1)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 221 (comment uni20D6)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 222 (comment uni20D7)
   (CHARWD R 0.436)
   (CHARHT R 0.8)
   )
(CHARACTER O 223 (comment uni20DB)
   (CHARWD R 0.497)
   (CHARHT R 0.6)
   )
(CHARACTER O 224 (comment uni20DC)
   (CHARWD R 0.696)
   (CHARHT R 0.6)
   )
(CHARACTER O 225 (comment uni20E1)
   (CHARWD R 0.478)
   (CHARHT R 0.8)
   )
(CHARACTER O 226 (comment uni20E7)
   (CHARWD R 0.816)
   (CHARHT R 0.7)
   (CHARDP R 0.2)
   )
(CHARACTER O 227 (comment uni20E9)
   (CHARWD R 0.533)
   (CHARHT R 0.7)
   )
(CHARACTER O 230 (comment uni20F0)
   (CHARWD R 0.27)
   (CHARHT R 0.8)
   )
(CHARACTER O 231 (comment uni29AA)
   (CHARWD R 0.685)
   (CHARHT R 0.578)
   (CHARDP R 0.068)
   )
(CHARACTER O 232 (comment uni29AB)
   (CHARWD R 0.685)
   (CHARHT R 0.578)
   (CHARDP R 0.068)
   )
(CHARACTER O 233 (comment uni29AC)
   (CHARWD R 0.706)
   (CHARHT R 0.562)
   (CHARDP R 0.058)
   )
(CHARACTER O 234 (comment uni29AD)
   (CHARWD R 0.706)
   (CHARHT R 0.562)
   (CHARDP R 0.058)
   )
(CHARACTER O 235 (comment uni29AE)
   (CHARWD R 0.706)
   (CHARHT R 0.562)
   (CHARDP R 0.058)
   )
(CHARACTER O 236 (comment uni29AF)
   (CHARWD R 0.708)
   (CHARHT R 0.562)
   (CHARDP R 0.058)
   )
(CHARACTER O 237 (comment uni29B0)
   (CHARWD R 0.762)
   (CHARHT R 0.583)
   (CHARDP R 0.079)
   )
(CHARACTER O 240 (comment uni29B1)
   (CHARWD R 0.762)
   (CHARHT R 0.717)
   (CHARDP R 0.079)
   )
(CHARACTER O 241 (comment uni29B2)
   (CHARWD R 0.762)
   (CHARHT R 0.819)
   (CHARDP R 0.079)
   )
(CHARACTER O 242 (comment uni29B3)
   (CHARWD R 0.762)
   (CHARHT R 0.832)
   (CHARDP R 0.079)
   )
(CHARACTER O 243 (comment uni29B4)
   (CHARWD R 0.762)
   (CHARHT R 0.832)
   (CHARDP R 0.079)
   )
(CHARACTER O 244 (comment uni29B5)
   (CHARWD R 0.91)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 245 (comment uni29B6)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 246 (comment uni29B7)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 247 (comment uni29B8)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 250 (comment uni29B9)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 251 (comment uni29BA)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 252 (comment uni29BB)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 253 (comment uni29BC)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 254 (comment uni29BD)
   (CHARWD R 0.842)
   (CHARHT R 0.882)
   (CHARDP R 0.179)
   )
(CHARACTER O 255 (comment uni29BE)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 256 (comment uni29BF)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 257 (comment uni29C0)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 260 (comment uni29C1)
   (CHARWD R 0.842)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 261 (comment uni29C2)
   (CHARWD R 1.091)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 262 (comment uni29C3)
   (CHARWD R 1.091)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 263 (comment uni29C4)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 264 (comment uni29C5)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 265 (comment uni29C6)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 266 (comment uni29C7)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 267 (comment uni29C8)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.158)
   )
(CHARACTER O 270 (comment uni29C9)
   (CHARWD R 1.046)
   (CHARHT R 0.712)
   (CHARDP R 0.207)
   )
(CHARACTER O 271 (comment uni29CA)
   (CHARWD R 1.145)
   (CHARHT R 1.003)
   (CHARDP R 0.127)
   )
(CHARACTER O 272 (comment uni29CB)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.259)
   )
(CHARACTER O 273 (comment uni29CC)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 274 (comment uni29CD)
   (CHARWD R 1.165)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 275 (comment uni29CE)
   (CHARWD R 0.78)
   (CHARHT R 0.698)
   (CHARDP R 0.193)
   )
(CHARACTER O 276 (comment uni29CF)
   (CHARWD R 0.857)
   (CHARHT R 0.531)
   (CHARDP R 0.025)
   )
(CHARACTER O 277 (comment uni29D0)
   (CHARWD R 0.857)
   (CHARHT R 0.531)
   (CHARDP R 0.025)
   )
(CHARACTER O 300 (comment uni29D1)
   (CHARWD R 0.81)
   (CHARHT R 0.582)
   (CHARDP R 0.08)
   )
(CHARACTER O 301 (comment uni29D2)
   (CHARWD R 0.81)
   (CHARHT R 0.582)
   (CHARDP R 0.08)
   )
(CHARACTER O 302 (comment uni29D3)
   (CHARWD R 0.81)
   (CHARHT R 0.582)
   (CHARDP R 0.08)
   )
(CHARACTER O 303 (comment uni29D4)
   (CHARWD R 0.81)
   (CHARHT R 0.582)
   (CHARDP R 0.08)
   )
(CHARACTER O 304 (comment uni29D5)
   (CHARWD R 0.81)
   (CHARHT R 0.582)
   (CHARDP R 0.08)
   )
(CHARACTER O 305 (comment uni29D6)
   (CHARWD R 0.81)
   (CHARHT R 0.602)
   (CHARDP R 0.1)
   )
(CHARACTER O 306 (comment uni29D7)
   (CHARWD R 0.81)
   (CHARHT R 0.602)
   (CHARDP R 0.1)
   )
(CHARACTER O 307 (comment uni29D8)
   (CHARWD R 0.511)
   (CHARHT R 0.62)
   (CHARDP R 0.116)
   )
(CHARACTER O 310 (comment uni29D9)
   (CHARWD R 0.511)
   (CHARHT R 0.62)
   (CHARDP R 0.116)
   )
(CHARACTER O 311 (comment uni29DA)
   (CHARWD R 0.688)
   (CHARHT R 0.62)
   (CHARDP R 0.116)
   )
(CHARACTER O 312 (comment uni29DB)
   (CHARWD R 0.688)
   (CHARHT R 0.62)
   (CHARDP R 0.116)
   )
(CHARACTER O 313 (comment uni29DC)
   (CHARWD R 0.926)
   (CHARHT R 0.43)
   )
(CHARACTER O 314 (comment uni29DD)
   (CHARWD R 0.926)
   (CHARHT R 0.653)
   )
(CHARACTER O 315 (comment uni29DE)
   (CHARWD R 0.926)
   (CHARHT R 0.695)
   (CHARDP R 0.189)
   )
(CHARACTER O 316 (comment uni29DF)
   (CHARWD R 1.145)
   (CHARHT R 0.403)
   )
(CHARACTER O 317 (comment uni29E0)
   (CHARWD R 0.91)
   (CHARHT R 0.662)
   (CHARDP R 0.157)
   )
(CHARACTER O 320 (comment uni29E1)
   (CHARWD R 0.667)
   (CHARHT R 0.512)
   (CHARDP R 0.008)
   )
(CHARACTER O 321 (comment uni29E2)
   (CHARWD R 0.79)
   (CHARHT R 0.414)
   )
(CHARACTER O 322 (comment uni29E3)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 323 (comment uni29E4)
   (CHARWD R 0.685)
   (CHARHT R 0.842)
   (CHARDP R 0.156)
   )
(CHARACTER O 324 (comment uni29E5)
   (CHARWD R 0.685)
   (CHARHT R 0.662)
   (CHARDP R 0.156)
   )
(CHARACTER O 325 (comment uni29E6)
   (CHARWD R 0.798)
   (CHARHT R 0.584)
   (CHARDP R 0.078)
   )
(CHARACTER O 326 (comment uni29E7)
   (CHARWD R 0.628)
   (CHARHT R 0.695)
   (CHARDP R 0.189)
   )
(CHARACTER O 327 (comment uni29E8)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 330 (comment uni29E9)
   (CHARWD R 1.145)
   (CHARHT R 0.811)
   (CHARDP R 0.127)
   )
(CHARACTER O 331 (comment uni29EA)
   (CHARWD R 0.762)
   (CHARHT R 0.744)
   (CHARDP R 0.241)
   )
(CHARACTER O 332 (comment uni29EB)
   (CHARWD R 0.79)
   (CHARHT R 0.795)
   (CHARDP R 0.289)
   )
(CHARACTER O 333 (comment uni29EC)
   (CHARWD R 0.762)
   (CHARHT R 0.743)
   (CHARDP R 0.241)
   )
(CHARACTER O 334 (comment uni29ED)
   (CHARWD R 0.762)
   (CHARHT R 0.743)
   (CHARDP R 0.241)
   )
(CHARACTER O 335 (comment uni29EE)
   (CHARWD R 0.762)
   (CHARHT R 0.747)
   (CHARDP R 0.243)
   )
(CHARACTER O 336 (comment uni29EF)
   (CHARWD R 0.762)
   (CHARHT R 0.747)
   (CHARDP R 0.243)
   )
(CHARACTER O 337 (comment uni29F0)
   (CHARWD R 0.762)
   (CHARHT R 0.747)
   (CHARDP R 0.243)
   )
(CHARACTER O 340 (comment uni29F1)
   (CHARWD R 0.762)
   (CHARHT R 0.747)
   (CHARDP R 0.243)
   )
(CHARACTER O 341 (comment uni29F2)
   (CHARWD R 0.762)
   (CHARHT R 0.747)
   (CHARDP R 0.243)
   )
(CHARACTER O 342 (comment uni29F3)
   (CHARWD R 0.762)
   (CHARHT R 0.747)
   (CHARDP R 0.243)
   )
(CHARACTER O 343 (comment uni29F4)
   (CHARWD R 0.926)
   (CHARHT R 0.521)
   (CHARDP R 0.013)
   )
(CHARACTER O 344 (comment uni29F5)
   (CHARWD R 0.523)
   (CHARHT R 0.71)
   (CHARDP R 0.222)
   )
(CHARACTER O 345 (comment uni29F6)
   (CHARWD R 0.52)
   (CHARHT R 0.765)
   (CHARDP R 0.08)
   )
(CHARACTER O 346 (comment uni29F7)
   (CHARWD R 0.52)
   (CHARHT R 0.662)
   (CHARDP R 0.08)
   )
(CHARACTER O 347 (comment uni29FA)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.025)
   )
(CHARACTER O 350 (comment uni29FB)
   (CHARWD R 0.685)
   (CHARHT R 0.532)
   (CHARDP R 0.025)
   )
(CHARACTER O 351 (comment uni29FC)
   (CHARWD R 0.459)
   (CHARHT R 0.713)
   (CHARDP R 0.213)
   )
(CHARACTER O 352 (comment uni29FD)
   (CHARWD R 0.459)
   (CHARHT R 0.713)
   (CHARDP R 0.213)
   )
(CHARACTER O 353 (comment uni29FE)
   (CHARWD R 0.762)
   (CHARHT R 0.54)
   (CHARDP R 0.036)
   )
(CHARACTER O 354 (comment uni29FF)
   (CHARWD R 0.762)
   (CHARHT R 0.316)
   )
(CHARACTER O 355 (comment uni2A1D)
   (CHARWD R 1.27)
   (CHARHT R 0.77)
   (CHARDP R 0.252)
   )
(CHARACTER O 356 (comment uni2A1E)
   (CHARWD R 1.018)
   (CHARHT R 0.764)
   (CHARDP R 0.258)
   )
(CHARACTER O 357 (comment uni2A1F)
   (CHARWD R 0.503)
   (CHARHT R 0.566)
   (CHARDP R 0.291)
   )
(CHARACTER O 360 (comment uni2A20)
   (CHARWD R 1.177)
   (CHARHT R 0.633)
   (CHARDP R 0.127)
   )
(CHARACTER O 361 (comment uni2A21)
   (CHARWD R 0.547)
   (CHARHT R 0.805)
   (CHARDP R 0.3)
   )
(CHARACTER O 362 (comment uni2A22)
   (CHARWD R 0.685)
   (CHARHT R 0.819)
   (CHARDP R 0.041)
   )
(CHARACTER O 363 (comment uni2A23)
   (CHARWD R 0.685)
   (CHARHT R 0.707)
   (CHARDP R 0.041)
   )
(CHARACTER O 364 (comment uni2A24)
   (CHARWD R 0.685)
   (CHARHT R 0.704)
   (CHARDP R 0.041)
   )
(CHARACTER O 365 (comment uni2A25)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   (CHARDP R 0.235)
   )
(CHARACTER O 366 (comment uni2A26)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   (CHARDP R 0.198)
   )
(CHARACTER O 367 (comment uni2A27)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   (CHARDP R 0.21)
   )
(CHARACTER O 370 (comment uni2A28)
   (CHARWD R 0.685)
   (CHARHT R 0.547)
   (CHARDP R 0.041)
   )
(CHARACTER O 371 (comment uni2A29)
   (CHARWD R 0.685)
   (CHARHT R 0.556)
   )
(CHARACTER O 372 (comment uni2A2A)
   (CHARWD R 0.685)
   (CHARHT R 0.286)
   (CHARDP R 0.005)
   )
(CHARACTER O 373 (comment uni2A2B)
   (CHARWD R 0.685)
   (CHARHT R 0.511)
   (CHARDP R 0.005)
   )
(CHARACTER O 374 (comment uni2A2C)
   (CHARWD R 0.685)
   (CHARHT R 0.511)
   (CHARDP R 0.005)
   )
(CHARACTER O 375 (comment uni2A2D)
   (CHARWD R 0.724)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 376 (comment uni2A2E)
   (CHARWD R 0.724)
   (CHARHT R 0.623)
   (CHARDP R 0.119)
   )
(CHARACTER O 377 (comment uni2A2F)
   (CHARWD R 0.49)
   (CHARHT R 0.447)
   )
