(FAMILY ot1-stixgneral-bold)
(CODINGSCHEME STIXOT1)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 40)
(FONTDIMEN
   (SLANT R 0.000000)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 461)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   (LABEL O 13) (comment ff)
   (LIG C l O 17)
   (LIG C i O 16)
   (STOP)
   (LABEL O 32) (comment ae)
   (KRN C v R -29)
   (KRN C w R -31)
   (KRN C y R -27)
   (STOP)
   (LABEL O 34) (comment oslash)
   (KRN O 47 R -24) (comment quoteright)
   (KRN C y R -22)
   (KRN C x R -17)
   (KRN C w R -21)
   (KRN C v R -26)
   (KRN C t R -3)
   (KRN C T R -76)
   (STOP)
   (LABEL O 37) (comment Oslash)
   (KRN O 35 R -48) (comment AE)
   (KRN C Y R -54)
   (KRN C X R -42)
   (KRN C W R -40)
   (KRN C V R -54)
   (KRN C T R -9)
   (KRN C A R -36)
   (STOP)
   (LABEL O 41) (comment exclam)
   (LIG O 140 O 74)
   (STOP)
   (LABEL O 42) (comment quotedblright)
   (KRN C A R -58)
   (KRN C T R 6)
   (KRN C V R 4)
   (KRN C W R 3)
   (KRN C Y R 4)
   (KRN O 35 R -75) (comment AE)
   (STOP)
   (LABEL O 47) (comment quoteright)
   (LIG O 47 O 42)
   (KRN O 34 R -28) (comment oslash)
   (KRN O 54 R -32) (comment comma)
   (KRN O 56 R -33) (comment period)
   (KRN C A R -75)
   (KRN C d R -28)
   (KRN C o R -28)
   (KRN C r R -22)
   (KRN C s R -15)
   (KRN C t R -16)
   (KRN C v R -22)
   (KRN C w R -21)
   (KRN C y R -20)
   (KRN O 35 R -91) (comment AE)
   (STOP)
   (LABEL O 54) (comment comma)
   (KRN C 1 R -11)
   (KRN O 47 R -22) (comment quoteright)
   (KRN O 42 R 7) (comment quotedblright)
   (STOP)
   (LABEL O 55) (comment hyphen)
   (LIG O 55 O 173)
   (KRN C A R -13)
   (KRN C T R -61)
   (KRN C V R -59)
   (KRN C W R -45)
   (KRN C Y R -67)
   (KRN O 35 R -21) (comment AE)
   (STOP)
   (LABEL O 56) (comment period)
   (KRN O 47 R -27) (comment quoteright)
   (STOP)
   (LABEL O 77) (comment question)
   (LIG O 140 O 76)
   (STOP)
   (LABEL C A)
   (KRN O 34 R -32) (comment oslash)
   (KRN O 37 R -46) (comment Oslash)
   (KRN O 54 R 1) (comment comma)
   (KRN O 55 R -25) (comment hyphen)
   (KRN C C R -50)
   (KRN C G R -46)
   (KRN C O R -46)
   (KRN C Q R -46)
   (KRN C T R -51)
   (KRN C U R -58)
   (KRN C V R -109)
   (KRN C W R -95)
   (KRN C Y R -64)
   (KRN C a R -3)
   (KRN C b R -20)
   (KRN C c R -28)
   (KRN C d R -24)
   (KRN C e R -28)
   (KRN C g R -7)
   (KRN C o R -32)
   (KRN C q R -28)
   (KRN C t R -24)
   (KRN C u R -25)
   (KRN C v R -71)
   (KRN C w R -67)
   (KRN C y R -69)
   (KRN O 47 R -89) (comment quoteright)
   (KRN O 42 R -61) (comment quotedblright)
   (STOP)
   (LABEL C B)
   (KRN C A R -31)
   (KRN C O R -8)
   (KRN C V R -40)
   (KRN C W R -38)
   (KRN C Y R -40)
   (KRN O 35 R -28) (comment AE)
   (KRN O 37 R -8) (comment Oslash)
   (KRN O 36 R -3) (comment OE)
   (STOP)
   (LABEL C C)
   (KRN O 37 R -7) (comment Oslash)
   (KRN C A R -23)
   (KRN C H R -2)
   (KRN C K R -5)
   (KRN C O R -7)
   (KRN O 35 R -22) (comment AE)
   (STOP)
   (LABEL C D)
   (KRN C A R -34)
   (KRN C J R -40)
   (KRN C T R -6)
   (KRN C V R -53)
   (KRN C W R -42)
   (KRN C X R -41)
   (KRN C Y R -53)
   (STOP)
   (LABEL C F)
   (KRN O 37 R -8) (comment Oslash)
   (KRN O 54 R -49) (comment comma)
   (KRN O 55 R -26) (comment hyphen)
   (KRN O 56 R -50) (comment period)
   (KRN C A R -66)
   (KRN C J R -37)
   (KRN C O R -8)
   (KRN C a R -43)
   (KRN C e R -43)
   (KRN C i R -1)
   (KRN C j R -23)
   (KRN C o R -43)
   (KRN C r R -6)
   (KRN C u R -9)
   (KRN O 32 R -46) (comment ae)
   (KRN O 34 R -43) (comment oslash)
   (KRN O 33 R -42) (comment oe)
   (STOP)
   (LABEL C G)
   (KRN C A R -24)
   (KRN C T R -35)
   (KRN C V R -29)
   (KRN C W R -31)
   (KRN C Y R -29)
   (KRN O 35 R -22) (comment AE)
   (STOP)
   (LABEL C J)
   (KRN C A R -25)
   (KRN O 35 R -22) (comment AE)
   (STOP)
   (LABEL C K)
   (KRN O 34 R -22) (comment oslash)
   (KRN O 37 R -39) (comment Oslash)
   (KRN O 55 R -40) (comment hyphen)
   (KRN C C R -52)
   (KRN C G R -49)
   (KRN C O R -39)
   (KRN C S R 12)
   (KRN C T R -3)
   (KRN C a R 8)
   (KRN C e R -17)
   (KRN C o R -22)
   (KRN C u R -15)
   (KRN C y R -70)
   (KRN O 32 R 3) (comment ae)
   (KRN O 36 R -39) (comment OE)
   (STOP)
   (LABEL C L)
   (KRN O 37 R -3) (comment Oslash)
   (KRN O 55 R 29) (comment hyphen)
   (KRN C A R -2)
   (KRN C C R -8)
   (KRN C G R -4)
   (KRN C O R -3)
   (KRN C S R 2)
   (KRN C T R -65)
   (KRN C U R -24)
   (KRN C V R -87)
   (KRN C W R -72)
   (KRN C Y R -77)
   (KRN C u R -8)
   (KRN C y R -36)
   (KRN O 47 R -55) (comment quoteright)
   (KRN O 42 R -27) (comment quotedblright)
   (STOP)
   (LABEL C N)
   (KRN O 37 R -10) (comment Oslash)
   (KRN O 54 R 1) (comment comma)
   (KRN C A R -16)
   (KRN C C R -16)
   (KRN C G R -11)
   (KRN C O R -10)
   (KRN C a R -11)
   (KRN C e R -11)
   (KRN C o R -11)
   (KRN C u R -13)
   (KRN O 35 R -14) (comment AE)
   (KRN O 32 R -14) (comment ae)
   (KRN O 34 R -11) (comment oslash)
   (STOP)
   (LABEL C O)
   (KRN C A R -36)
   (KRN C T R -9)
   (KRN C V R -54)
   (KRN C W R -40)
   (KRN C X R -42)
   (KRN C Y R -54)
   (KRN O 35 R -48) (comment AE)
   (STOP)
   (LABEL C P)
   (KRN O 54 R -71) (comment comma)
   (KRN O 55 R -33) (comment hyphen)
   (KRN O 56 R -72) (comment period)
   (KRN C A R -67)
   (KRN C J R -58)
   (KRN C a R -15)
   (KRN C e R -25)
   (KRN C o R -28)
   (KRN O 35 R -79) (comment AE)
   (KRN O 32 R -19) (comment ae)
   (KRN O 34 R -28) (comment oslash)
   (KRN O 33 R -26) (comment oe)
   (STOP)
   (LABEL C R)
   (KRN O 34 R -21) (comment oslash)
   (KRN O 37 R -23) (comment Oslash)
   (KRN O 55 R -23) (comment hyphen)
   (KRN C C R -30)
   (KRN C G R -24)
   (KRN C O R -23)
   (KRN C T R -22)
   (KRN C U R -30)
   (KRN C V R -48)
   (KRN C W R -45)
   (KRN C Y R -48)
   (KRN C a R 10)
   (KRN C e R -16)
   (KRN C o R -21)
   (KRN C u R -13)
   (KRN C y R -25)
   (KRN O 32 R 4) (comment ae)
   (KRN O 36 R -18) (comment OE)
   (KRN O 33 R -17) (comment oe)
   (STOP)
   (LABEL C S)
   (KRN C A R -22)
   (KRN C T R -14)
   (KRN C V R -8)
   (KRN C W R -9)
   (KRN C Y R -7)
   (KRN C t R -7)
   (KRN O 35 R -21) (comment AE)
   (STOP)
   (LABEL C T)
   (KRN O 54 R -55) (comment comma)
   (KRN O 55 R -60) (comment hyphen)
   (KRN O 56 R -55) (comment period)
   (KRN O 72 R -42) (comment colon)
   (KRN O 73 R -42) (comment semicolon)
   (KRN C A R -40)
   (KRN C C R -16)
   (KRN C G R -12)
   (KRN C J R -38)
   (KRN C O R -9)
   (KRN C S R -3)
   (KRN C V R 10)
   (KRN C W R 9)
   (KRN C Y R 10)
   (KRN C a R -55)
   (KRN C c R -72)
   (KRN C e R -72)
   (KRN C g R -58)
   (KRN C i R -2)
   (KRN C j R -24)
   (KRN C o R -76)
   (KRN C r R -53)
   (KRN C s R -51)
   (KRN C u R -76)
   (KRN C v R -92)
   (KRN C w R -93)
   (KRN C y R -90)
   (KRN O 35 R -38) (comment AE)
   (KRN O 37 R -12) (comment Oslash)
   (KRN O 32 R -58) (comment ae)
   (KRN O 34 R -58) (comment oslash)
   (KRN O 36 R -5) (comment OE)
   (STOP)
   (LABEL C U)
   (KRN O 54 R -9) (comment comma)
   (KRN O 56 R -13) (comment period)
   (KRN C A R -36)
   (KRN C m R -9)
   (KRN C n R -12)
   (KRN C p R -14)
   (KRN C r R -14)
   (KRN O 35 R -47) (comment AE)
   (STOP)
   (LABEL C V)
   (KRN O 54 R -76) (comment comma)
   (KRN O 55 R -57) (comment hyphen)
   (KRN O 56 R -76) (comment period)
   (KRN O 72 R -42) (comment colon)
   (KRN O 73 R -42) (comment semicolon)
   (KRN C A R -96)
   (KRN C C R -58)
   (KRN C G R -53)
   (KRN C O R -52)
   (KRN C S R -25)
   (KRN C T R 7)
   (KRN C a R -72)
   (KRN C e R -72)
   (KRN C g R -73)
   (KRN C i R -12)
   (KRN C o R -72)
   (KRN C r R -52)
   (KRN C u R -50)
   (KRN C y R -50)
   (KRN O 35 R -97) (comment AE)
   (KRN O 37 R -52) (comment Oslash)
   (KRN O 32 R -76) (comment ae)
   (KRN O 34 R -72) (comment oslash)
   (STOP)
   (LABEL C W)
   (KRN O 54 R -58) (comment comma)
   (KRN O 55 R -40) (comment hyphen)
   (KRN O 56 R -58) (comment period)
   (KRN O 72 R -25) (comment colon)
   (KRN O 73 R -25) (comment semicolon)
   (KRN C A R -80)
   (KRN C C R -46)
   (KRN C G R -40)
   (KRN C O R -40)
   (KRN C S R -21)
   (KRN C T R 9)
   (KRN C a R -58)
   (KRN C e R -55)
   (KRN C g R -56)
   (KRN C i R -10)
   (KRN C o R -55)
   (KRN C r R -40)
   (KRN C u R -38)
   (KRN C y R -38)
   (KRN O 35 R -87) (comment AE)
   (KRN O 37 R -40) (comment Oslash)
   (KRN O 32 R -62) (comment ae)
   (KRN O 34 R -55) (comment oslash)
   (STOP)
   (LABEL C X)
   (KRN O 34 R -28) (comment oslash)
   (KRN O 37 R -49) (comment Oslash)
   (KRN O 55 R -34) (comment hyphen)
   (KRN C C R -51)
   (KRN C O R -49)
   (KRN C Q R -46)
   (KRN C a R 1)
   (KRN C e R -23)
   (KRN C o R -28)
   (KRN C u R -21)
   (KRN C y R -53)
   (STOP)
   (LABEL C Y)
   (KRN O 54 R -67) (comment comma)
   (KRN O 55 R -74) (comment hyphen)
   (KRN O 56 R -68) (comment period)
   (KRN O 72 R -48) (comment colon)
   (KRN O 73 R -48) (comment semicolon)
   (KRN C A R -56)
   (KRN C C R -65)
   (KRN C G R -60)
   (KRN C O R -59)
   (KRN C S R -26)
   (KRN C T R 6)
   (KRN C a R -70)
   (KRN C e R -77)
   (KRN C g R -74)
   (KRN C i R -13)
   (KRN C o R -82)
   (KRN C p R -64)
   (KRN C u R -65)
   (KRN C v R -67)
   (KRN O 35 R -53) (comment AE)
   (KRN O 37 R -61) (comment Oslash)
   (KRN O 32 R -74) (comment ae)
   (KRN O 34 R -82) (comment oslash)
   (STOP)
   (LABEL C Z)
   (KRN C v R -40)
   (KRN C w R -34)
   (KRN C y R -38)
   (STOP)
   (LABEL O 134) (comment quotedblleft)
   (KRN C A R -50)
   (KRN C T R 9)
   (KRN C V R 14)
   (KRN C W R 12)
   (KRN C Y R 16)
   (KRN O 35 R -67) (comment AE)
   (STOP)
   (LABEL O 140) (comment quoteleft)
   (LIG O 140 O 134)
   (KRN C A R -78)
   (KRN C T R -20)
   (KRN C V R -15)
   (KRN C W R -17)
   (KRN C Y R -14)
   (KRN O 35 R -94) (comment AE)
   (STOP)
   (LABEL C a)
   (KRN C j R -24)
   (KRN C v R -34)
   (KRN C w R -36)
   (KRN C y R -22)
   (KRN O 47 R -29) (comment quoteright)
   (STOP)
   (LABEL C b)
   (KRN C v R -33)
   (KRN C w R -35)
   (KRN C y R -24)
   (STOP)
   (LABEL C c)
   (KRN C h R -9)
   (KRN C k R -12)
   (STOP)
   (LABEL C e)
   (KRN C t R -9)
   (KRN C v R -19)
   (KRN C w R -19)
   (KRN C x R -10)
   (KRN C y R -17)
   (KRN O 47 R -20) (comment quoteright)
   (STOP)
   (LABEL C f)
   (LIG C f O 13)
   (LIG C l O 15)
   (LIG C i O 14)
   (KRN C a R -11)
   (KRN C e R -6)
   (KRN C j R -1)
   (KRN C o R -16)
   (KRN C s R -7)
   (KRN C t R -3)
   (KRN O 32 R -14) (comment ae)
   (KRN O 34 R -16) (comment oslash)
   (KRN O 33 R -24) (comment oe)
   (KRN O 47 R 18) (comment quoteright)
   (STOP)
   (LABEL C g)
   (KRN C a R -11)
   (KRN C e R -17)
   (KRN C l R -4)
   (KRN O 32 R -14) (comment ae)
   (STOP)
   (LABEL C h)
   (KRN C y R -27)
   (KRN O 47 R -29) (comment quoteright)
   (STOP)
   (LABEL C i)
   (KRN C T R -16)
   (KRN C j R -31)
   (STOP)
   (LABEL C k)
   (KRN O 34 R -29) (comment oslash)
   (KRN O 55 R -40) (comment hyphen)
   (KRN C e R -23)
   (KRN C g R -3)
   (KRN C o R -29)
   (KRN C s R 4)
   (KRN C u R -4)
   (KRN O 32 R -3) (comment ae)
   (STOP)
   (LABEL C l)
   (KRN C v R -19)
   (KRN C y R -17)
   (STOP)
   (LABEL C m)
   (KRN C p R -16)
   (KRN C v R -29)
   (KRN C w R -30)
   (KRN C y R -26)
   (STOP)
   (LABEL C n)
   (KRN C T R -49)
   (KRN C p R -13)
   (KRN C v R -27)
   (KRN C w R -29)
   (KRN C y R -25)
   (KRN O 47 R -26) (comment quoteright)
   (STOP)
   (LABEL C o)
   (KRN C T R -76)
   (KRN C t R -3)
   (KRN C v R -26)
   (KRN C w R -21)
   (KRN C x R -17)
   (KRN C y R -22)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL C p)
   (KRN C t R -9)
   (KRN C y R -26)
   (STOP)
   (LABEL C q)
   (KRN C c R -12)
   (KRN C u R -15)
   (STOP)
   (LABEL C r)
   (KRN O 54 R -58) (comment comma)
   (KRN O 55 R -15) (comment hyphen)
   (KRN O 56 R -58) (comment period)
   (KRN O 72 R -10) (comment colon)
   (KRN O 73 R -10) (comment semicolon)
   (KRN C a R -4)
   (KRN C c R -13)
   (KRN C d R -10)
   (KRN C e R -10)
   (KRN C f R 10)
   (KRN C g R -5)
   (KRN C h R -13)
   (KRN C i R 7)
   (KRN C j R -11)
   (KRN C k R -13)
   (KRN C l R -12)
   (KRN C m R 7)
   (KRN C n R 3)
   (KRN C o R -12)
   (KRN C p R 6)
   (KRN C q R -16)
   (KRN C t R 10)
   (KRN C u R 8)
   (KRN C v R 6)
   (KRN C w R 4)
   (KRN C x R 8)
   (KRN C y R 8)
   (KRN C z R -1)
   (KRN O 32 R -7) (comment ae)
   (KRN O 34 R -12) (comment oslash)
   (KRN O 33 R -10) (comment oe)
   (KRN O 47 R -7) (comment quoteright)
   (STOP)
   (LABEL C s)
   (KRN C t R -7)
   (KRN O 47 R -16) (comment quoteright)
   (STOP)
   (LABEL C t)
   (KRN O 34 R -4) (comment oslash)
   (KRN O 72 R 10) (comment colon)
   (KRN O 73 R 13) (comment semicolon)
   (KRN C S R 10)
   (KRN C a R 9)
   (KRN C e R -2)
   (KRN C h R -1)
   (KRN C o R -4)
   (KRN O 32 R 6) (comment ae)
   (KRN O 47 R -27) (comment quoteright)
   (STOP)
   (LABEL C u)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL C v)
   (KRN O 54 R -50) (comment comma)
   (KRN O 55 R -26) (comment hyphen)
   (KRN O 56 R -51) (comment period)
   (KRN O 72 R -9) (comment colon)
   (KRN O 73 R -9) (comment semicolon)
   (KRN C a R -16)
   (KRN C c R -26)
   (KRN C e R -23)
   (KRN C g R -15)
   (KRN C l R -3)
   (KRN C o R -25)
   (KRN C s R -11)
   (KRN O 32 R -24) (comment ae)
   (KRN O 34 R -25) (comment oslash)
   (STOP)
   (LABEL C w)
   (KRN O 54 R -43) (comment comma)
   (KRN O 55 R -23) (comment hyphen)
   (KRN O 56 R -48) (comment period)
   (KRN O 72 R -6) (comment colon)
   (KRN O 73 R -6) (comment semicolon)
   (KRN C a R -21)
   (KRN C c R -31)
   (KRN C e R -29)
   (KRN C g R -14)
   (KRN C l R -14)
   (KRN C o R -31)
   (KRN C s R -15)
   (KRN O 32 R -24) (comment ae)
   (KRN O 34 R -31) (comment oslash)
   (STOP)
   (LABEL C x)
   (KRN O 34 R -26) (comment oslash)
   (KRN C c R -24)
   (KRN C e R -25)
   (KRN C o R -26)
   (KRN C q R -25)
   (STOP)
   (LABEL C y)
   (KRN O 54 R -48) (comment comma)
   (KRN O 55 R -25) (comment hyphen)
   (KRN O 56 R -49) (comment period)
   (KRN O 72 R -10) (comment colon)
   (KRN O 73 R -10) (comment semicolon)
   (KRN C a R -22)
   (KRN C c R -33)
   (KRN C e R -24)
   (KRN C g R -19)
   (KRN C l R -11)
   (KRN C o R -24)
   (KRN C s R -17)
   (KRN O 32 R -26) (comment ae)
   (KRN O 34 R -24) (comment oslash)
   (STOP)
   (LABEL O 173) (comment endash)
   (LIG O 55 O 174)
   (STOP)
   )
(CHARACTER O 0 (comment uni0393)
   (CHARWD R 620)
   (CHARHT R 676)
   )
(CHARACTER O 1 (comment uni0394)
   (CHARWD R 722)
   (CHARHT R 690)
   )
(CHARACTER O 2 (comment uni0398)
   (CHARWD R 778)
   (CHARHT R 692)
   (CHARDP R 18)
   )
(CHARACTER O 3 (comment uni039B)
   (CHARWD R 707)
   (CHARHT R 690)
   )
(CHARACTER O 4 (comment uni039E)
   (CHARWD R 647)
   (CHARHT R 676)
   )
(CHARACTER O 5 (comment uni03A0)
   (CHARWD R 778)
   (CHARHT R 676)
   )
(CHARACTER O 6 (comment uni03A3)
   (CHARWD R 671)
   (CHARHT R 676)
   )
(CHARACTER O 7 (comment uni03A5)
   (CHARWD R 703)
   (CHARHT R 692)
   )
(CHARACTER O 10 (comment uni03A6)
   (CHARWD R 836)
   (CHARHT R 676)
   )
(CHARACTER O 11 (comment uni03A8)
   (CHARWD R 808)
   (CHARHT R 692)
   )
(CHARACTER O 12 (comment uni03A9)
   (CHARWD R 768)
   (CHARHT R 692)
   )
(CHARACTER O 13 (comment ff)
   (CHARWD R 610)
   (CHARHT R 691)
   (CHARIC R 56)
   )
(CHARACTER O 14 (comment fi)
   (CHARWD R 556)
   (CHARHT R 691)
   )
(CHARACTER O 15 (comment fl)
   (CHARWD R 556)
   (CHARHT R 691)
   )
(CHARACTER O 16 (comment ffi)
   (CHARWD R 833)
   (CHARHT R 691)
   )
(CHARACTER O 17 (comment ffl)
   (CHARWD R 833)
   (CHARHT R 691)
   )
(CHARACTER O 20 (comment dotlessi)
   (CHARWD R 278)
   (CHARHT R 461)
   )
(CHARACTER O 21 (comment uni0237)
   (CHARWD R 333)
   (CHARHT R 461)
   (CHARDP R 203)
   )
(CHARACTER O 22 (comment grave)
   (CHARWD R 333)
   (CHARHT R 713)
   )
(CHARACTER O 23 (comment acute)
   (CHARWD R 333)
   (CHARHT R 713)
   )
(CHARACTER O 24 (comment caron)
   (CHARWD R 333)
   (CHARHT R 704)
   (CHARIC R 2)
   )
(CHARACTER O 25 (comment breve)
   (CHARWD R 333)
   (CHARHT R 691)
   )
(CHARACTER O 26 (comment macron)
   (CHARWD R 333)
   (CHARHT R 637)
   )
(CHARACTER O 27 (comment ring)
   (CHARWD R 333)
   (CHARHT R 750)
   )
(CHARACTER O 30 (comment cedilla)
   (CHARWD R 333)
   (CHARDP R 218)
   )
(CHARACTER O 31 (comment germandbls)
   (CHARWD R 556)
   (CHARHT R 691)
   (CHARDP R 12)
   )
(CHARACTER O 32 (comment ae)
   (CHARWD R 722)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 33 (comment oe)
   (CHARWD R 722)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER O 34 (comment oslash)
   (CHARWD R 500)
   (CHARHT R 549)
   (CHARDP R 92)
   )
(CHARACTER O 35 (comment AE)
   (CHARWD R 1000)
   (CHARHT R 676)
   )
(CHARACTER O 36 (comment OE)
   (CHARWD R 1000)
   (CHARHT R 684)
   (CHARDP R 5)
   )
(CHARACTER O 37 (comment Oslash)
   (CHARWD R 778)
   (CHARHT R 737)
   (CHARDP R 74)
   )
(CHARACTER O 40 (comment space)
   (CHARWD R 250)
   )
(CHARACTER O 41 (comment exclam)
   (CHARWD R 333)
   (CHARHT R 691)
   (CHARDP R 13)
   )
(CHARACTER O 42 (comment quotedblright)
   (CHARWD R 500)
   (CHARHT R 691)
   )
(CHARACTER O 43 (comment numbersign)
   (CHARWD R 500)
   (CHARHT R 700)
   )
(CHARACTER O 44 (comment dollar)
   (CHARWD R 500)
   (CHARHT R 750)
   (CHARDP R 99)
   )
(CHARACTER O 45 (comment percent)
   (CHARWD R 749)
   (CHARHT R 706)
   (CHARDP R 29)
   )
(CHARACTER O 46 (comment ampersand)
   (CHARWD R 833)
   (CHARHT R 691)
   (CHARDP R 16)
   )
(CHARACTER O 47 (comment quoteright)
   (CHARWD R 333)
   (CHARHT R 691)
   )
(CHARACTER O 50 (comment parenleft)
   (CHARWD R 333)
   (CHARHT R 694)
   (CHARDP R 168)
   )
(CHARACTER O 51 (comment parenright)
   (CHARWD R 333)
   (CHARHT R 694)
   (CHARDP R 168)
   )
(CHARACTER O 52 (comment asterisk)
   (CHARWD R 500)
   (CHARHT R 691)
   )
(CHARACTER O 53 (comment plus)
   (CHARWD R 750)
   (CHARHT R 563)
   (CHARDP R 57)
   )
(CHARACTER O 54 (comment comma)
   (CHARWD R 250)
   (CHARHT R 155)
   (CHARDP R 180)
   )
(CHARACTER O 55 (comment hyphen)
   (CHARWD R 333)
   (CHARHT R 287)
   )
(CHARACTER O 56 (comment period)
   (CHARWD R 250)
   (CHARHT R 156)
   (CHARDP R 13)
   )
(CHARACTER O 57 (comment slash)
   (CHARWD R 278)
   (CHARHT R 691)
   (CHARDP R 19)
   (CHARIC R 24)
   )
(CHARACTER C 0
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER C 1
   (CHARWD R 500)
   (CHARHT R 688)
   )
(CHARACTER C 2
   (CHARWD R 500)
   (CHARHT R 688)
   )
(CHARACTER C 3
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 14)
   )
(CHARACTER C 4
   (CHARWD R 500)
   (CHARHT R 688)
   )
(CHARACTER C 5
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 8)
   )
(CHARACTER C 6
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER C 7
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER C 8
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER C 9
   (CHARWD R 500)
   (CHARHT R 688)
   (CHARDP R 13)
   )
(CHARACTER O 72 (comment colon)
   (CHARWD R 333)
   (CHARHT R 472)
   (CHARDP R 13)
   )
(CHARACTER O 73 (comment semicolon)
   (CHARWD R 333)
   (CHARHT R 472)
   (CHARDP R 180)
   )
(CHARACTER O 74 (comment exclamdown)
   (CHARWD R 333)
   (CHARHT R 501)
   (CHARDP R 203)
   )
(CHARACTER O 75 (comment equal)
   (CHARWD R 750)
   (CHARHT R 399)
   )
(CHARACTER O 76 (comment questiondown)
   (CHARWD R 500)
   (CHARHT R 501)
   (CHARDP R 201)
   )
(CHARACTER O 77 (comment question)
   (CHARWD R 500)
   (CHARHT R 689)
   (CHARDP R 13)
   )
(CHARACTER O 100 (comment at)
   (CHARWD R 930)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER C A
   (CHARWD R 722)
   (CHARHT R 690)
   )
(CHARACTER C B
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER C C
   (CHARWD R 722)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER C D
   (CHARWD R 722)
   (CHARHT R 676)
   )
(CHARACTER C E
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER C F
   (CHARWD R 611)
   (CHARHT R 676)
   )
(CHARACTER C G
   (CHARWD R 778)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER C H
   (CHARWD R 778)
   (CHARHT R 676)
   )
(CHARACTER C I
   (CHARWD R 389)
   (CHARHT R 676)
   )
(CHARACTER C J
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 96)
   )
(CHARACTER C K
   (CHARWD R 778)
   (CHARHT R 676)
   )
(CHARACTER C L
   (CHARWD R 667)
   (CHARHT R 677)
   )
(CHARACTER C M
   (CHARWD R 944)
   (CHARHT R 676)
   )
(CHARACTER C N
   (CHARWD R 722)
   (CHARHT R 676)
   (CHARDP R 18)
   )
(CHARACTER C O
   (CHARWD R 778)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER C P
   (CHARWD R 611)
   (CHARHT R 676)
   )
(CHARACTER C Q
   (CHARWD R 778)
   (CHARHT R 691)
   (CHARDP R 176)
   )
(CHARACTER C R
   (CHARWD R 722)
   (CHARHT R 676)
   )
(CHARACTER C S
   (CHARWD R 556)
   (CHARHT R 692)
   (CHARDP R 19)
   )
(CHARACTER C T
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER C U
   (CHARWD R 722)
   (CHARHT R 676)
   (CHARDP R 19)
   )
(CHARACTER C V
   (CHARWD R 722)
   (CHARHT R 676)
   (CHARDP R 18)
   )
(CHARACTER C W
   (CHARWD R 1000)
   (CHARHT R 676)
   (CHARDP R 15)
   )
(CHARACTER C X
   (CHARWD R 722)
   (CHARHT R 676)
   )
(CHARACTER C Y
   (CHARWD R 722)
   (CHARHT R 676)
   )
(CHARACTER C Z
   (CHARWD R 667)
   (CHARHT R 676)
   )
(CHARACTER O 133 (comment bracketleft)
   (CHARWD R 333)
   (CHARHT R 678)
   (CHARDP R 149)
   )
(CHARACTER O 134 (comment quotedblleft)
   (CHARWD R 500)
   (CHARHT R 691)
   )
(CHARACTER O 135 (comment bracketright)
   (CHARWD R 333)
   (CHARHT R 678)
   (CHARDP R 149)
   )
(CHARACTER O 136 (comment circumflex)
   (CHARWD R 333)
   (CHARHT R 704)
   (CHARIC R 2)
   )
(CHARACTER O 137 (comment dotaccent)
   (CHARWD R 333)
   (CHARHT R 666)
   )
(CHARACTER O 140 (comment quoteleft)
   (CHARWD R 333)
   (CHARHT R 691)
   )
(CHARACTER C a
   (CHARWD R 500)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER C b
   (CHARWD R 556)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER C c
   (CHARWD R 444)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER C d
   (CHARWD R 556)
   (CHARHT R 676)
   (CHARDP R 14)
   )
(CHARACTER C e
   (CHARWD R 444)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER C f
   (CHARWD R 333)
   (CHARHT R 691)
   (CHARIC R 56)
   )
(CHARACTER C g
   (CHARWD R 500)
   (CHARHT R 473)
   (CHARDP R 206)
   )
(CHARACTER C h
   (CHARWD R 556)
   (CHARHT R 676)
   )
(CHARACTER C i
   (CHARWD R 278)
   (CHARHT R 691)
   )
(CHARACTER C j
   (CHARWD R 333)
   (CHARHT R 691)
   (CHARDP R 203)
   )
(CHARACTER C k
   (CHARWD R 556)
   (CHARHT R 676)
   )
(CHARACTER C l
   (CHARWD R 278)
   (CHARHT R 676)
   )
(CHARACTER C m
   (CHARWD R 833)
   (CHARHT R 473)
   )
(CHARACTER C n
   (CHARWD R 556)
   (CHARHT R 473)
   )
(CHARACTER C o
   (CHARWD R 500)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER C p
   (CHARWD R 556)
   (CHARHT R 473)
   (CHARDP R 205)
   )
(CHARACTER C q
   (CHARWD R 556)
   (CHARHT R 473)
   (CHARDP R 205)
   )
(CHARACTER C r
   (CHARWD R 444)
   (CHARHT R 473)
   )
(CHARACTER C s
   (CHARWD R 389)
   (CHARHT R 473)
   (CHARDP R 14)
   )
(CHARACTER C t
   (CHARWD R 333)
   (CHARHT R 630)
   (CHARDP R 12)
   )
(CHARACTER C u
   (CHARWD R 556)
   (CHARHT R 461)
   (CHARDP R 14)
   )
(CHARACTER C v
   (CHARWD R 500)
   (CHARHT R 461)
   (CHARDP R 14)
   )
(CHARACTER C w
   (CHARWD R 722)
   (CHARHT R 461)
   (CHARDP R 14)
   )
(CHARACTER C x
   (CHARWD R 500)
   (CHARHT R 461)
   )
(CHARACTER C y
   (CHARWD R 500)
   (CHARHT R 461)
   (CHARDP R 205)
   )
(CHARACTER C z
   (CHARWD R 444)
   (CHARHT R 461)
   )
(CHARACTER O 173 (comment endash)
   (CHARWD R 500)
   (CHARHT R 271)
   )
(CHARACTER O 174 (comment emdash)
   (CHARWD R 1000)
   (CHARHT R 271)
   )
(CHARACTER O 175 (comment hungarumlaut)
   (CHARWD R 333)
   (CHARHT R 713)
   (CHARIC R 92)
   )
(CHARACTER O 176 (comment tilde)
   (CHARWD R 333)
   (CHARHT R 674)
   (CHARIC R 16)
   )
(CHARACTER O 177 (comment dieresis)
   (CHARWD R 333)
   (CHARHT R 666)
   (CHARIC R 4)
   )
