(FAMILY ts1-stixgneral-bold)
(CODINGSCHEME STIXTS1)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 16)
(FONTDIMEN
   (SLANT R 0.000000)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 461)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   )
(CHARACTER O 0 (comment grave)
   (CHARWD R 333)
   (CHARHT R 713)
   )
(CHARACTER O 1 (comment acute)
   (CHARWD R 333)
   (CHARHT R 713)
   )
(CHARACTER O 2 (comment circumflex)
   (CHARWD R 333)
   (CHARHT R 704)
   (CHARIC R 2)
   )
(CHARACTER O 3 (comment tilde)
   (CHARWD R 333)
   (CHARHT R 674)
   (CHARIC R 16)
   )
(CHARACTER O 4 (comment dieresis)
   (CHARWD R 333)
   (CHARHT R 666)
   (CHARIC R 4)
   )
(CHARACTER O 5 (comment hungarumlaut)
   (CHARWD R 333)
   (CHARHT R 713)
   (CHARIC R 92)
   )
(CHARACTER O 6 (comment ring)
   (CHARWD R 333)
   (CHARHT R 750)
   )
(CHARACTER O 7 (comment caron)
   (CHARWD R 333)
   (CHARHT R 704)
   (CHARIC R 2)
   )
(CHARACTER O 10 (comment breve)
   (CHARWD R 333)
   (CHARHT R 691)
   )
(CHARACTER O 11 (comment macron)
   (CHARWD R 333)
   (CHARHT R 637)
   )
(CHARACTER O 12 (comment dotaccent)
   (CHARWD R 333)
   (CHARHT R 666)
   )
(CHARACTER O 13 (comment cedilla)
   (CHARWD R 333)
   (CHARDP R 218)
   )
(CHARACTER O 14 (comment ogonek)
   (CHARWD R 333)
   (CHARHT R 44)
   (CHARDP R 173)
   )
(CHARACTER O 15 (comment quotesinglbase)
   (CHARWD R 333)
   (CHARHT R 155)
   (CHARDP R 180)
   )
(CHARACTER O 22 (comment quotedblbase)
   (CHARWD R 500)
   (CHARHT R 155)
   (CHARDP R 180)
   )
(CHARACTER O 30 (comment uni2190)
   (CHARWD R 977)
   (CHARHT R 451)
   )
(CHARACTER O 31 (comment uni2192)
   (CHARWD R 977)
   (CHARHT R 451)
   )
(CHARACTER O 44 (comment dollar)
   (CHARWD R 500)
   (CHARHT R 750)
   (CHARDP R 99)
   )
(CHARACTER O 47 (comment quotesingle)
   (CHARWD R 278)
   (CHARHT R 691)
   )
(CHARACTER O 52 (comment uni2217)
   (CHARWD R 585)
   (CHARHT R 502)
   )
(CHARACTER O 54 (comment comma)
   (CHARWD R 250)
   (CHARHT R 155)
   (CHARDP R 180)
   )
(CHARACTER O 56 (comment period)
   (CHARWD R 250)
   (CHARHT R 156)
   (CHARDP R 13)
   )
(CHARACTER O 57 (comment fraction)
   (CHARWD R 183)
   (CHARHT R 688)
   (CHARDP R 12)
   (CHARIC R 162)
   )
(CHARACTER O 60 (comment zero.oldstyle)
   (CHARWD R 523)
   (CHARHT R 422)
   (CHARDP R 10)
   )
(CHARACTER O 61 (comment one.oldstyle)
   (CHARWD R 523)
   (CHARHT R 425)
   )
(CHARACTER O 62 (comment two.oldstyle)
   (CHARWD R 523)
   (CHARHT R 421)
   )
(CHARACTER O 63 (comment three.oldstyle)
   (CHARWD R 523)
   (CHARHT R 424)
   (CHARDP R 198)
   )
(CHARACTER O 64 (comment four.oldstyle)
   (CHARWD R 523)
   (CHARHT R 420)
   (CHARDP R 198)
   )
(CHARACTER O 65 (comment five.oldstyle)
   (CHARWD R 523)
   (CHARHT R 421)
   (CHARDP R 198)
   )
(CHARACTER O 66 (comment six.oldstyle)
   (CHARWD R 523)
   (CHARHT R 614)
   (CHARDP R 8)
   )
(CHARACTER O 67 (comment seven.oldstyle)
   (CHARWD R 523)
   (CHARHT R 421)
   (CHARDP R 198)
   )
(CHARACTER O 70 (comment eight.oldstyle)
   (CHARWD R 523)
   (CHARHT R 606)
   (CHARDP R 12)
   )
(CHARACTER O 71 (comment nine.oldstyle)
   (CHARWD R 523)
   (CHARHT R 421)
   (CHARDP R 202)
   )
(CHARACTER O 74 (comment uni27E8)
   (CHARWD R 445)
   (CHARHT R 732)
   (CHARDP R 193)
   )
(CHARACTER O 75 (comment minus)
   (CHARWD R 750)
   (CHARHT R 297)
   )
(CHARACTER O 76 (comment uni27E9)
   (CHARWD R 445)
   (CHARHT R 732)
   (CHARDP R 193)
   )
(CHARACTER O 115 (comment uni2127)
   (CHARWD R 758)
   (CHARHT R 674)
   (CHARDP R 18)
   )
(CHARACTER O 127 (comment uni2126)
   (CHARWD R 758)
   (CHARHT R 692)
   )
(CHARACTER O 136 (comment uni2191)
   (CHARWD R 584)
   (CHARHT R 676)
   (CHARDP R 170)
   )
(CHARACTER O 137 (comment uni2193)
   (CHARWD R 584)
   (CHARHT R 676)
   (CHARDP R 170)
   )
(CHARACTER O 140 (comment grave)
   (CHARWD R 333)
   (CHARHT R 713)
   )
(CHARACTER O 176 (comment uni0330)
   (CHARWD R 0)
   (CHARDP R 235)
   )
(CHARACTER O 200 (comment breve)
   (CHARWD R 333)
   (CHARHT R 691)
   )
(CHARACTER O 201 (comment caron)
   (CHARWD R 333)
   (CHARHT R 704)
   (CHARIC R 2)
   )
(CHARACTER O 202 (comment hungarumlaut)
   (CHARWD R 333)
   (CHARHT R 713)
   (CHARIC R 92)
   )
(CHARACTER O 203 (comment uni030F)
   (CHARWD R 0)
   (CHARHT R 713)
   )
(CHARACTER O 204 (comment dagger)
   (CHARWD R 500)
   (CHARHT R 691)
   (CHARDP R 134)
   )
(CHARACTER O 205 (comment daggerdbl)
   (CHARWD R 500)
   (CHARHT R 691)
   (CHARDP R 132)
   )
(CHARACTER O 207 (comment perthousand)
   (CHARWD R 1110)
   (CHARHT R 706)
   (CHARDP R 29)
   )
(CHARACTER O 210 (comment bullet)
   (CHARWD R 560)
   (CHARHT R 462)
   )
(CHARACTER O 212 (comment dollar)
   (CHARWD R 500)
   (CHARHT R 750)
   (CHARDP R 99)
   )
(CHARACTER O 213 (comment cent)
   (CHARWD R 500)
   (CHARHT R 588)
   (CHARDP R 140)
   )
(CHARACTER O 214 (comment florin)
   (CHARWD R 500)
   (CHARHT R 706)
   (CHARDP R 155)
   )
(CHARACTER O 222 (comment uni20A4)
   (CHARWD R 500)
   (CHARHT R 684)
   (CHARDP R 16)
   )
(CHARACTER O 223 (comment uni211E)
   (CHARWD R 722)
   (CHARHT R 676)
   (CHARDP R 101)
   (CHARIC R 4)
   )
(CHARACTER O 227 (comment trademark)
   (CHARWD R 1000)
   (CHARHT R 676)
   )
(CHARACTER O 230 (comment uni2031)
   (CHARWD R 1472)
   (CHARHT R 706)
   (CHARDP R 29)
   )
(CHARACTER O 233 (comment uni2116)
   (CHARWD R 1093)
   (CHARHT R 691)
   (CHARDP R 18)
   )
(CHARACTER O 242 (comment cent)
   (CHARWD R 500)
   (CHARHT R 588)
   (CHARDP R 140)
   )
(CHARACTER O 243 (comment sterling)
   (CHARWD R 500)
   (CHARHT R 684)
   (CHARDP R 16)
   )
(CHARACTER O 244 (comment currency)
   (CHARWD R 500)
   (CHARHT R 542)
   (CHARDP R 10)
   (CHARIC R 26)
   )
(CHARACTER O 245 (comment yen)
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARIC R 47)
   )
(CHARACTER O 246 (comment brokenbar)
   (CHARWD R 220)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER O 247 (comment section)
   (CHARWD R 500)
   (CHARHT R 691)
   (CHARDP R 132)
   )
(CHARACTER O 250 (comment dieresis)
   (CHARWD R 333)
   (CHARHT R 666)
   (CHARIC R 4)
   )
(CHARACTER O 251 (comment copyright)
   (CHARWD R 747)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER O 252 (comment ordfeminine)
   (CHARWD R 300)
   (CHARHT R 688)
   (CHARIC R 1)
   )
(CHARACTER O 254 (comment logicalnot)
   (CHARWD R 750)
   (CHARHT R 399)
   )
(CHARACTER O 255 (comment uni24C5)
   (CHARWD R 695)
   (CHARHT R 690)
   (CHARDP R 19)
   )
(CHARACTER O 256 (comment registered)
   (CHARWD R 747)
   (CHARHT R 691)
   (CHARDP R 19)
   )
(CHARACTER O 257 (comment macron)
   (CHARWD R 333)
   (CHARHT R 637)
   )
(CHARACTER O 260 (comment degree)
   (CHARWD R 400)
   (CHARHT R 688)
   )
(CHARACTER O 261 (comment plusminus)
   (CHARWD R 770)
   (CHARHT R 518)
   (CHARDP R 151)
   )
(CHARACTER O 262 (comment twosuperior)
   (CHARWD R 300)
   (CHARHT R 688)
   )
(CHARACTER O 263 (comment threesuperior)
   (CHARWD R 300)
   (CHARHT R 688)
   )
(CHARACTER O 264 (comment acute)
   (CHARWD R 333)
   (CHARHT R 713)
   )
(CHARACTER O 265 (comment mu)
   (CHARWD R 556)
   (CHARHT R 461)
   (CHARDP R 206)
   )
(CHARACTER O 266 (comment paragraph)
   (CHARWD R 639)
   (CHARHT R 676)
   (CHARDP R 186)
   )
(CHARACTER O 267 (comment periodcentered)
   (CHARWD R 250)
   (CHARHT R 417)
   )
(CHARACTER O 271 (comment onesuperior)
   (CHARWD R 300)
   (CHARHT R 688)
   )
(CHARACTER O 272 (comment ordmasculine)
   (CHARWD R 330)
   (CHARHT R 688)
   )
(CHARACTER O 273 (comment uni221A)
   (CHARWD R 965)
   (CHARHT R 946)
   (CHARDP R 259)
   (CHARIC R 51)
   )
(CHARACTER O 274 (comment onequarter)
   (CHARWD R 750)
   (CHARHT R 688)
   (CHARDP R 12)
   )
(CHARACTER O 275 (comment onehalf)
   (CHARWD R 750)
   (CHARHT R 688)
   (CHARDP R 12)
   (CHARIC R 25)
   )
(CHARACTER O 276 (comment threequarters)
   (CHARWD R 750)
   (CHARHT R 688)
   (CHARDP R 12)
   )
(CHARACTER O 277 (comment uni20AC)
   (CHARWD R 500)
   (CHARHT R 672)
   (CHARDP R 12)
   )
(CHARACTER O 326 (comment multiply)
   (CHARWD R 702)
   (CHARHT R 538)
   (CHARDP R 33)
   )
(CHARACTER O 366 (comment divide)
   (CHARWD R 570)
   (CHARHT R 537)
   (CHARDP R 31)
   )
